namespace Microsoft.Win32
{
    [ComVisibleAttribute(..)]
    public abstract sealed class Registry
    {
        public static readonly RegistryKey ClassesRoot;
        public static readonly RegistryKey CurrentConfig;
        public static readonly RegistryKey CurrentUser;
        public static readonly RegistryKey DynData;
        public static readonly RegistryKey LocalMachine;
        public static readonly RegistryKey PerformanceData;
        public static readonly RegistryKey Users;
        public static object GetValue(string keyName, string valueName, object defaultValue);
        public static void SetValue(string keyName, string valueName, object value);
        public static void SetValue(string keyName, string valueName, object value, RegistryValueKind valueKind);
    }

    [ComVisibleAttribute(..)]
    public sealed class RegistryKey: MarshalByRefObject, IDisposable
    {
        public string Name { get; }
        public int SubKeyCount { get; }
        public int ValueCount { get; }
        public void Close();
        public RegistryKey CreateSubKey(string subkey);
        public RegistryKey CreateSubKey(string subkey, RegistryKeyPermissionCheck permissionCheck);
        public RegistryKey CreateSubKey(string subkey, RegistryKeyPermissionCheck permissionCheck, RegistrySecurity registrySecurity);
        public RegistryKey CreateSubKey(string subkey, RegistrySecurity registrySecurity);
        public void DeleteSubKey(string subkey);
        public void DeleteSubKey(string subkey, bool throwOnMissingSubKey);
        public void DeleteSubKeyTree(string subkey);
        public void DeleteValue(string name);
        public void DeleteValue(string name, bool throwOnMissingValue);
        public void Flush();
        public RegistrySecurity GetAccessControl();
        public RegistrySecurity GetAccessControl(AccessControlSections includeSections);
        public string[] GetSubKeyNames();
        public object GetValue(string name);
        public object GetValue(string name, object defaultValue);
        public object GetValue(string name, object defaultValue, bool doNotExpand);
        public object GetValue(string name, object defaultValue, RegistryValueOptions options);
        public RegistryValueKind GetValueKind(string name);
        public string[] GetValueNames();
        public static RegistryKey OpenRemoteBaseKey(RegistryHive hKey, string machineName);
        public RegistryKey OpenSubKey(string name);
        public RegistryKey OpenSubKey(string name, bool writable);
        public RegistryKey OpenSubKey(string name, RegistryKeyPermissionCheck permissionCheck);
        public RegistryKey OpenSubKey(string name, RegistryKeyPermissionCheck permissionCheck, RegistryRights rights);
        public void SetAccessControl(RegistrySecurity registrySecurity);
        public void SetValue(string name, object value);
        public void SetValue(string name, object value, RegistryValueKind valueKind);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum RegistryHive
    {
        ClassesRoot,
        CurrentConfig,
        CurrentUser,
        DynData,
        LocalMachine,
        PerformanceData,
        Users,
    }

    public enum RegistryKeyPermissionCheck
    {
        Default,
        ReadSubTree,
        ReadWriteSubTree,
    }

    [ComVisibleAttribute(..)]
    public enum RegistryValueKind
    {
        Binary,
        DWord,
        ExpandString,
        MultiString,
        QWord,
        String,
        Unknown,
    }

    [FlagsAttribute(..)]
    public enum RegistryValueOptions
    {
        DoNotExpandEnvironmentNames,
        None,
    }

} 
namespace Microsoft.Win32.SafeHandles
{
    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    public abstract class CriticalHandleMinusOneIsInvalid: CriticalHandle, IDisposable
    {
        protected CriticalHandleMinusOneIsInvalid();
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    public abstract class CriticalHandleZeroOrMinusOneIsInvalid: CriticalHandle, IDisposable
    {
        protected CriticalHandleZeroOrMinusOneIsInvalid();
    }

    [SecurityPermissionAttribute(..)]
    public sealed class SafeFileHandle: SafeHandleZeroOrMinusOneIsInvalid, IDisposable
    {
        public SafeFileHandle(IntPtr preexistingHandle, bool ownsHandle);
        protected override bool ReleaseHandle();
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    public abstract class SafeHandleMinusOneIsInvalid: SafeHandle, IDisposable
    {
        protected SafeHandleMinusOneIsInvalid(bool ownsHandle);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    public abstract class SafeHandleZeroOrMinusOneIsInvalid: SafeHandle, IDisposable
    {
        protected SafeHandleZeroOrMinusOneIsInvalid(bool ownsHandle);
    }

    [SecurityPermissionAttribute(..)]
    public sealed class SafeWaitHandle: SafeHandleZeroOrMinusOneIsInvalid, IDisposable
    {
        public SafeWaitHandle(IntPtr existingHandle, bool ownsHandle);
        protected override bool ReleaseHandle();
    }

} 
namespace System
{
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface _AppDomain
    {
        public string BaseDirectory { get; }
        public string DynamicDirectory { get; }
        public Evidence Evidence { get; }
        public string FriendlyName { get; }
        public string RelativeSearchPath { get; }
        public bool ShadowCopyFiles { get; }
        public void AppendPrivatePath(string path);
        public void ClearPrivatePath();
        public void ClearShadowCopyPath();
        public ObjectHandle CreateInstance(string assemblyName, string typeName);
        public ObjectHandle CreateInstance(string assemblyName, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityAttributes);
        public ObjectHandle CreateInstance(string assemblyName, string typeName, object[] activationAttributes);
        public ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName);
        public ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityAttributes);
        public ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName, object[] activationAttributes);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, Evidence evidence);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, Evidence evidence, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, Evidence evidence);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, Evidence evidence, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, Evidence evidence, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions, bool isSynchronized);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public void DoCallBack(CrossAppDomainDelegate theDelegate);
        public bool Equals(object other);
        public int ExecuteAssembly(string assemblyFile);
        public int ExecuteAssembly(string assemblyFile, Evidence assemblySecurity);
        public int ExecuteAssembly(string assemblyFile, Evidence assemblySecurity, string[] args);
        public Assembly[] GetAssemblies();
        public object GetData(string name);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public object GetLifetimeService();
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public object InitializeLifetimeService();
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public Assembly Load(AssemblyName assemblyRef);
        public Assembly Load(AssemblyName assemblyRef, Evidence assemblySecurity);
        public Assembly Load(byte[] rawAssembly);
        public Assembly Load(byte[] rawAssembly, byte[] rawSymbolStore);
        public Assembly Load(byte[] rawAssembly, byte[] rawSymbolStore, Evidence securityEvidence);
        public Assembly Load(string assemblyString);
        public Assembly Load(string assemblyString, Evidence assemblySecurity);
        public void SetAppDomainPolicy(PolicyLevel domainPolicy);
        public void SetCachePath(string s);
        public void SetData(string name, object data);
        public void SetPrincipalPolicy(PrincipalPolicy policy);
        public void SetShadowCopyPath(string s);
        public void SetThreadPrincipal(IPrincipal principal);
        public string ToString();
        public event AssemblyLoadEventHandler AssemblyLoad;
        public event ResolveEventHandler AssemblyResolve;
        public event EventHandler DomainUnload;
        public event EventHandler ProcessExit;
        public event ResolveEventHandler ResourceResolve;
        public event ResolveEventHandler TypeResolve;
        public event UnhandledExceptionEventHandler UnhandledException;
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ActivationContext: IDisposable, ISerializable
    {
        public ContextForm Form { get; }
        public ApplicationIdentity Identity { get; }
        public static ActivationContext CreatePartialActivationContext(ApplicationIdentity identity);
        public static ActivationContext CreatePartialActivationContext(ApplicationIdentity identity, string[] manifestPaths);
        public void Dispose();
        protected override void Finalize();
    }

    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public sealed class Activator: _Activator
    {
        public static ObjectHandle CreateComInstanceFrom(string assemblyName, string typeName);
        public static ObjectHandle CreateComInstanceFrom(string assemblyName, string typeName, byte[] hashValue, AssemblyHashAlgorithm hashAlgorithm);
        public static T CreateInstance<T>();
        public static ObjectHandle CreateInstance(ActivationContext activationContext);
        public static ObjectHandle CreateInstance(ActivationContext activationContext, string[] activationCustomData);
        public static ObjectHandle CreateInstance(string assemblyName, string typeName);
        public static ObjectHandle CreateInstance(string assemblyName, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityInfo);
        public static ObjectHandle CreateInstance(string assemblyName, string typeName, object[] activationAttributes);
        public static object CreateInstance(Type type);
        public static object CreateInstance(Type type, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture);
        public static object CreateInstance(Type type, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes);
        public static object CreateInstance(Type type, bool nonPublic);
        public static object CreateInstance(Type type, params object[] args);
        public static object CreateInstance(Type type, object[] args, object[] activationAttributes);
        public static ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName);
        public static ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityInfo);
        public static ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName, object[] activationAttributes);
        public static object GetObject(Type type, string url);
        public static object GetObject(Type type, string url, object state);
    }

    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public sealed class AppDomain: MarshalByRefObject, _AppDomain, IEvidenceFactory
    {
        public ActivationContext ActivationContext { get; }
        public ApplicationIdentity ApplicationIdentity { get; }
        public ApplicationTrust ApplicationTrust { get; }
        public string BaseDirectory { get; }
        public static AppDomain CurrentDomain { get; }
        public AppDomainManager DomainManager { get; }
        public string DynamicDirectory { get; }
        public Evidence Evidence { get; }
        public string FriendlyName { get; }
        public int Id { get; }
        public string RelativeSearchPath { get; }
        public AppDomainSetup SetupInformation { get; }
        public bool ShadowCopyFiles { get; }
        public void AppendPrivatePath(string path);
        public string ApplyPolicy(string assemblyName);
        public void ClearPrivatePath();
        public void ClearShadowCopyPath();
        public ObjectHandle CreateComInstanceFrom(string assemblyName, string typeName);
        public ObjectHandle CreateComInstanceFrom(string assemblyFile, string typeName, byte[] hashValue, AssemblyHashAlgorithm hashAlgorithm);
        public static AppDomain CreateDomain(string friendlyName);
        public static AppDomain CreateDomain(string friendlyName, Evidence securityInfo);
        public static AppDomain CreateDomain(string friendlyName, Evidence securityInfo, AppDomainSetup info);
        public static AppDomain CreateDomain(string friendlyName, Evidence securityInfo, AppDomainSetup info, PermissionSet grantSet, params StrongName[] fullTrustAssemblies);
        public static AppDomain CreateDomain(string friendlyName, Evidence securityInfo, string appBasePath, string appRelativeSearchPath, bool shadowCopyFiles);
        public static AppDomain CreateDomain(string friendlyName, Evidence securityInfo, string appBasePath, string appRelativeSearchPath, bool shadowCopyFiles, AppDomainInitializer adInit, string[] adInitArgs);
        public ObjectHandle CreateInstance(string assemblyName, string typeName);
        public ObjectHandle CreateInstance(string assemblyName, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityAttributes);
        public ObjectHandle CreateInstance(string assemblyName, string typeName, object[] activationAttributes);
        public object CreateInstanceAndUnwrap(string assemblyName, string typeName);
        public object CreateInstanceAndUnwrap(string assemblyName, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityAttributes);
        public object CreateInstanceAndUnwrap(string assemblyName, string typeName, object[] activationAttributes);
        public ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName);
        public ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityAttributes);
        public ObjectHandle CreateInstanceFrom(string assemblyFile, string typeName, object[] activationAttributes);
        public object CreateInstanceFromAndUnwrap(string assemblyName, string typeName);
        public object CreateInstanceFromAndUnwrap(string assemblyName, string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes, Evidence securityAttributes);
        public object CreateInstanceFromAndUnwrap(string assemblyName, string typeName, object[] activationAttributes);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, Evidence evidence);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, Evidence evidence, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, Evidence evidence);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, Evidence evidence, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, Evidence evidence, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions, bool isSynchronized);
        public AssemblyBuilder DefineDynamicAssembly(AssemblyName name, AssemblyBuilderAccess access, string dir, PermissionSet requiredPermissions, PermissionSet optionalPermissions, PermissionSet refusedPermissions);
        public void DoCallBack(CrossAppDomainDelegate callBackDelegate);
        public int ExecuteAssembly(string assemblyFile);
        public int ExecuteAssembly(string assemblyFile, Evidence assemblySecurity);
        public int ExecuteAssembly(string assemblyFile, Evidence assemblySecurity, string[] args);
        public int ExecuteAssembly(string assemblyFile, Evidence assemblySecurity, string[] args, byte[] hashValue, AssemblyHashAlgorithm hashAlgorithm);
        public int ExecuteAssemblyByName(AssemblyName assemblyName, Evidence assemblySecurity, params string[] args);
        public int ExecuteAssemblyByName(string assemblyName);
        public int ExecuteAssemblyByName(string assemblyName, Evidence assemblySecurity);
        public int ExecuteAssemblyByName(string assemblyName, Evidence assemblySecurity, params string[] args);
        public Assembly[] GetAssemblies();
        public static int GetCurrentThreadId();
        public object GetData(string name);
        public Type GetType();
        public override object InitializeLifetimeService();
        public bool IsDefaultAppDomain();
        public bool IsFinalizingForUnload();
        public Assembly Load(AssemblyName assemblyRef);
        public Assembly Load(AssemblyName assemblyRef, Evidence assemblySecurity);
        public Assembly Load(byte[] rawAssembly);
        public Assembly Load(byte[] rawAssembly, byte[] rawSymbolStore);
        public Assembly Load(byte[] rawAssembly, byte[] rawSymbolStore, Evidence securityEvidence);
        public Assembly Load(string assemblyString);
        public Assembly Load(string assemblyString, Evidence assemblySecurity);
        public Assembly[] ReflectionOnlyGetAssemblies();
        public void SetAppDomainPolicy(PolicyLevel domainPolicy);
        public void SetCachePath(string path);
        public void SetData(string name, object data);
        public void SetData(string name, object data, IPermission permission);
        public void SetDynamicBase(string path);
        public void SetPrincipalPolicy(PrincipalPolicy policy);
        public void SetShadowCopyFiles();
        public void SetShadowCopyPath(string path);
        public void SetThreadPrincipal(IPrincipal principal);
        public override string ToString();
        public static void Unload(AppDomain domain);
        public event AssemblyLoadEventHandler AssemblyLoad;
        public event ResolveEventHandler AssemblyResolve;
        public event EventHandler DomainUnload;
        public event EventHandler ProcessExit;
        public event ProvideAssemblyEvidenceEventHandler ProvideAssemblyEvidence;
        public event ResolveEventHandler ReflectionOnlyAssemblyResolve;
        public event ResolveEventHandler ResourceResolve;
        public event ResolveEventHandler TypeResolve;
        public event UnhandledExceptionEventHandler UnhandledException;
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class AppDomainManager: MarshalByRefObject
    {
        public AppDomainManager();
        public virtual ApplicationActivator ApplicationActivator { get; }
        public virtual Assembly EntryAssembly { get; }
        public virtual HostExecutionContextManager HostExecutionContextManager { get; }
        public virtual HostSecurityManager HostSecurityManager { get; }
        public AppDomainManagerInitializationOptions InitializationFlags { get; set; }
        public virtual AppDomain CreateDomain(string friendlyName, Evidence securityInfo, AppDomainSetup appDomainInfo);
        protected static AppDomain CreateDomainHelper(string friendlyName, Evidence securityInfo, AppDomainSetup appDomainInfo);
        public virtual void InitializeNewDomain(AppDomainSetup appDomainInfo);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public sealed class AppDomainSetup: IAppDomainSetup
    {
        public AppDomainSetup();
        public AppDomainSetup(ActivationArguments activationArguments);
        public AppDomainSetup(ActivationContext activationContext);
        public ActivationArguments ActivationArguments { get; set; }
        public AppDomainInitializer AppDomainInitializer { get; set; }
        public string[] AppDomainInitializerArguments { get; set; }
        public string ApplicationBase { get; set; }
        public string ApplicationName { get; set; }
        public ApplicationTrust ApplicationTrust { get; set; }
        public string CachePath { get; set; }
        public string ConfigurationFile { get; set; }
        public bool DisallowApplicationBaseProbing { get; set; }
        public bool DisallowBindingRedirects { get; set; }
        public bool DisallowCodeDownload { get; set; }
        public bool DisallowPublisherPolicy { get; set; }
        public string DynamicBase { get; set; }
        public string LicenseFile { get; set; }
        public LoaderOptimization LoaderOptimization { get; set; }
        public string PrivateBinPath { get; set; }
        public string PrivateBinPathProbe { get; set; }
        public string ShadowCopyDirectories { get; set; }
        public string ShadowCopyFiles { get; set; }
        public byte[] GetConfigurationBytes();
        public void SetConfigurationBytes(byte[] value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ApplicationId
    {
        public ApplicationId(byte[] publicKeyToken, string name, Version version, string processorArchitecture, string culture);
        public string Culture { get; }
        public string Name { get; }
        public string ProcessorArchitecture { get; }
        public byte[] PublicKeyToken { get; }
        public Version Version { get; }
        public ApplicationId Copy();
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ApplicationIdentity: ISerializable
    {
        public ApplicationIdentity(string applicationIdentityFullName);
        public string CodeBase { get; }
        public string FullName { get; }
        public override string ToString();
    }

    public struct ArgIterator
    {
        public ArgIterator(RuntimeArgumentHandle arglist);
        public ArgIterator(RuntimeArgumentHandle arglist, void* ptr);
        public void End();
        public override bool Equals(object o);
        public override int GetHashCode();
        public TypedReference GetNextArg();
        public TypedReference GetNextArg(RuntimeTypeHandle rth);
        public RuntimeTypeHandle GetNextArgType();
        public int GetRemainingCount();
    }

    [SerializableAttribute(..)]
    public struct ArraySegment<T>
    {
        public ArraySegment(T[] array);
        public ArraySegment(T[] array, int offset, int count);
        public T[] Array { get; }
        public int Count { get; }
        public int Offset { get; }
        public bool Equals(ArraySegment<T> obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static bool operator ==(ArraySegment<T> a, ArraySegment<T> b);
        public static bool operator !=(ArraySegment<T> a, ArraySegment<T> b);
    }

    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public abstract class Attribute: _Attribute
    {
        protected Attribute();
        public virtual object TypeId { get; }
        public override bool Equals(object obj);
        public static Attribute GetCustomAttribute(Assembly element, Type attributeType);
        public static Attribute GetCustomAttribute(Assembly element, Type attributeType, bool inherit);
        public static Attribute GetCustomAttribute(MemberInfo element, Type attributeType);
        public static Attribute GetCustomAttribute(MemberInfo element, Type attributeType, bool inherit);
        public static Attribute GetCustomAttribute(Module element, Type attributeType);
        public static Attribute GetCustomAttribute(Module element, Type attributeType, bool inherit);
        public static Attribute GetCustomAttribute(ParameterInfo element, Type attributeType);
        public static Attribute GetCustomAttribute(ParameterInfo element, Type attributeType, bool inherit);
        public static Attribute[] GetCustomAttributes(Assembly element);
        public static Attribute[] GetCustomAttributes(Assembly element, bool inherit);
        public static Attribute[] GetCustomAttributes(Assembly element, Type attributeType);
        public static Attribute[] GetCustomAttributes(Assembly element, Type attributeType, bool inherit);
        public static Attribute[] GetCustomAttributes(MemberInfo element);
        public static Attribute[] GetCustomAttributes(MemberInfo element, bool inherit);
        public static Attribute[] GetCustomAttributes(MemberInfo element, Type type);
        public static Attribute[] GetCustomAttributes(MemberInfo element, Type type, bool inherit);
        public static Attribute[] GetCustomAttributes(Module element);
        public static Attribute[] GetCustomAttributes(Module element, bool inherit);
        public static Attribute[] GetCustomAttributes(Module element, Type attributeType);
        public static Attribute[] GetCustomAttributes(Module element, Type attributeType, bool inherit);
        public static Attribute[] GetCustomAttributes(ParameterInfo element);
        public static Attribute[] GetCustomAttributes(ParameterInfo element, bool inherit);
        public static Attribute[] GetCustomAttributes(ParameterInfo element, Type attributeType);
        public static Attribute[] GetCustomAttributes(ParameterInfo element, Type attributeType, bool inherit);
        public override int GetHashCode();
        public virtual bool IsDefaultAttribute();
        public static bool IsDefined(Assembly element, Type attributeType);
        public static bool IsDefined(Assembly element, Type attributeType, bool inherit);
        public static bool IsDefined(MemberInfo element, Type attributeType);
        public static bool IsDefined(MemberInfo element, Type attributeType, bool inherit);
        public static bool IsDefined(Module element, Type attributeType);
        public static bool IsDefined(Module element, Type attributeType, bool inherit);
        public static bool IsDefined(ParameterInfo element, Type attributeType);
        public static bool IsDefined(ParameterInfo element, Type attributeType, bool inherit);
        public virtual bool Match(object obj);
    }

    public abstract sealed class BitConverter
    {
        public static readonly bool IsLittleEndian;
        public static long DoubleToInt64Bits(double value);
        public static byte[] GetBytes(bool value);
        public static byte[] GetBytes(char value);
        public static byte[] GetBytes(double value);
        public static byte[] GetBytes(float value);
        public static byte[] GetBytes(int value);
        public static byte[] GetBytes(long value);
        public static byte[] GetBytes(short value);
        public static byte[] GetBytes(uint value);
        public static byte[] GetBytes(ulong value);
        public static byte[] GetBytes(ushort value);
        public static double Int64BitsToDouble(long value);
        public static bool ToBoolean(byte[] value, int startIndex);
        public static char ToChar(byte[] value, int startIndex);
        public static double ToDouble(byte[] value, int startIndex);
        public static short ToInt16(byte[] value, int startIndex);
        public static int ToInt32(byte[] value, int startIndex);
        public static long ToInt64(byte[] value, int startIndex);
        public static float ToSingle(byte[] value, int startIndex);
        public static string ToString(byte[] value);
        public static string ToString(byte[] value, int startIndex);
        public static string ToString(byte[] value, int startIndex, int length);
        public static ushort ToUInt16(byte[] value, int startIndex);
        public static uint ToUInt32(byte[] value, int startIndex);
        public static ulong ToUInt64(byte[] value, int startIndex);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Boolean: IComparable, IComparable, IConvertible, IEquatable
    {
        public static readonly string FalseString;
        public static readonly string TrueString;
        public int CompareTo(bool value);
        public int CompareTo(object obj);
        public bool Equals(bool obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static bool Parse(string value);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public static bool TryParse(string value, ref bool result);
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class Buffer
    {
        public static void BlockCopy(Array src, int srcOffset, Array dst, int dstOffset, int count);
        public static int ByteLength(Array array);
        public static byte GetByte(Array array, int index);
        public static void SetByte(Array array, int index, byte value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Byte: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const byte MaxValue;
        public const byte MinValue;
        public int CompareTo(byte value);
        public int CompareTo(object value);
        public bool Equals(byte obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static byte Parse(string s);
        public static byte Parse(string s, IFormatProvider provider);
        public static byte Parse(string s, NumberStyles style);
        public static byte Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, ref byte result);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref byte result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Char: IComparable, IComparable, IConvertible, IEquatable
    {
        public const char MaxValue;
        public const char MinValue;
        public int CompareTo(char value);
        public int CompareTo(object value);
        public static string ConvertFromUtf32(int utf32);
        public static int ConvertToUtf32(char highSurrogate, char lowSurrogate);
        public static int ConvertToUtf32(string s, int index);
        public bool Equals(char obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static double GetNumericValue(char c);
        public static double GetNumericValue(string s, int index);
        public TypeCode GetTypeCode();
        public static UnicodeCategory GetUnicodeCategory(char c);
        public static UnicodeCategory GetUnicodeCategory(string s, int index);
        public static bool IsControl(char c);
        public static bool IsControl(string s, int index);
        public static bool IsDigit(char c);
        public static bool IsDigit(string s, int index);
        public static bool IsHighSurrogate(char c);
        public static bool IsHighSurrogate(string s, int index);
        public static bool IsLetter(char c);
        public static bool IsLetter(string s, int index);
        public static bool IsLetterOrDigit(char c);
        public static bool IsLetterOrDigit(string s, int index);
        public static bool IsLower(char c);
        public static bool IsLower(string s, int index);
        public static bool IsLowSurrogate(char c);
        public static bool IsLowSurrogate(string s, int index);
        public static bool IsNumber(char c);
        public static bool IsNumber(string s, int index);
        public static bool IsPunctuation(char c);
        public static bool IsPunctuation(string s, int index);
        public static bool IsSeparator(char c);
        public static bool IsSeparator(string s, int index);
        public static bool IsSurrogate(char c);
        public static bool IsSurrogate(string s, int index);
        public static bool IsSurrogatePair(char highSurrogate, char lowSurrogate);
        public static bool IsSurrogatePair(string s, int index);
        public static bool IsSymbol(char c);
        public static bool IsSymbol(string s, int index);
        public static bool IsUpper(char c);
        public static bool IsUpper(string s, int index);
        public static bool IsWhiteSpace(char c);
        public static bool IsWhiteSpace(string s, int index);
        public static char Parse(string s);
        public static char ToLower(char c);
        public static char ToLower(char c, CultureInfo culture);
        public static char ToLowerInvariant(char c);
        public override string ToString();
        public static string ToString(char c);
        public string ToString(IFormatProvider provider);
        public static char ToUpper(char c);
        public static char ToUpper(char c, CultureInfo culture);
        public static char ToUpperInvariant(char c);
        public static bool TryParse(string s, ref char result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class CharEnumerator: ICloneable, IEnumerator
    {
        public char Current { get; }
        public object Clone();
        public bool MoveNext();
        public void Reset();
    }

    public abstract sealed class Console
    {
        public static ConsoleColor BackgroundColor { get; set; }
        public static int BufferHeight { get; set; }
        public static int BufferWidth { get; set; }
        public static bool CapsLock { get; }
        public static int CursorLeft { get; set; }
        public static int CursorSize { get; set; }
        public static int CursorTop { get; set; }
        public static bool CursorVisible { get; set; }
        public static TextWriter Error { get; }
        public static ConsoleColor ForegroundColor { get; set; }
        public static TextReader In { get; }
        public static Encoding InputEncoding { get; set; }
        public static bool KeyAvailable { get; }
        public static int LargestWindowHeight { get; }
        public static int LargestWindowWidth { get; }
        public static bool NumberLock { get; }
        public static TextWriter Out { get; }
        public static Encoding OutputEncoding { get; set; }
        public static string Title { get; set; }
        public static bool TreatControlCAsInput { get; set; }
        public static int WindowHeight { get; set; }
        public static int WindowLeft { get; set; }
        public static int WindowTop { get; set; }
        public static int WindowWidth { get; set; }
        public static void Beep();
        public static void Beep(int frequency, int duration);
        public static void Clear();
        public static void MoveBufferArea(int sourceLeft, int sourceTop, int sourceWidth, int sourceHeight, int targetLeft, int targetTop);
        public static void MoveBufferArea(int sourceLeft, int sourceTop, int sourceWidth, int sourceHeight, int targetLeft, int targetTop, char sourceChar, ConsoleColor sourceForeColor, ConsoleColor sourceBackColor);
        public static Stream OpenStandardError();
        public static Stream OpenStandardError(int bufferSize);
        public static Stream OpenStandardInput();
        public static Stream OpenStandardInput(int bufferSize);
        public static Stream OpenStandardOutput();
        public static Stream OpenStandardOutput(int bufferSize);
        public static int Read();
        public static ConsoleKeyInfo ReadKey();
        public static ConsoleKeyInfo ReadKey(bool intercept);
        public static string ReadLine();
        public static void ResetColor();
        public static void SetBufferSize(int width, int height);
        public static void SetCursorPosition(int left, int top);
        public static void SetError(TextWriter newError);
        public static void SetIn(TextReader newIn);
        public static void SetOut(TextWriter newOut);
        public static void SetWindowPosition(int left, int top);
        public static void SetWindowSize(int width, int height);
        public static void Write(bool value);
        public static void Write(char value);
        public static void Write(char[] buffer);
        public static void Write(char[] buffer, int index, int count);
        public static void Write(decimal value);
        public static void Write(double value);
        public static void Write(float value);
        public static void Write(int value);
        public static void Write(long value);
        public static void Write(object value);
        public static void Write(string value);
        public static void Write(string format, object arg0);
        public static void Write(string format, object arg0, object arg1);
        public static void Write(string format, object arg0, object arg1, object arg2);
        public static void Write(string format, object arg0, object arg1, object arg2, object arg3, __arglist);
        public static void Write(string format, params object[] arg);
        public static void Write(uint value);
        public static void Write(ulong value);
        public static void WriteLine();
        public static void WriteLine(bool value);
        public static void WriteLine(char value);
        public static void WriteLine(char[] buffer);
        public static void WriteLine(char[] buffer, int index, int count);
        public static void WriteLine(decimal value);
        public static void WriteLine(double value);
        public static void WriteLine(float value);
        public static void WriteLine(int value);
        public static void WriteLine(long value);
        public static void WriteLine(object value);
        public static void WriteLine(string value);
        public static void WriteLine(string format, object arg0);
        public static void WriteLine(string format, object arg0, object arg1);
        public static void WriteLine(string format, object arg0, object arg1, object arg2);
        public static void WriteLine(string format, object arg0, object arg1, object arg2, object arg3, __arglist);
        public static void WriteLine(string format, params object[] arg);
        public static void WriteLine(uint value);
        public static void WriteLine(ulong value);
        public event ConsoleCancelEventHandler CancelKeyPress;
    }

    [SerializableAttribute(..)]
    public struct ConsoleKeyInfo
    {
        public ConsoleKeyInfo(char keyChar, ConsoleKey key, bool shift, bool alt, bool control);
        public ConsoleKey Key { get; }
        public char KeyChar { get; }
        public ConsoleModifiers Modifiers { get; }
        public bool Equals(ConsoleKeyInfo obj);
        public override bool Equals(object value);
        public override int GetHashCode();
        public static bool operator ==(ConsoleKeyInfo a, ConsoleKeyInfo b);
        public static bool operator !=(ConsoleKeyInfo a, ConsoleKeyInfo b);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class ContextBoundObject: MarshalByRefObject
    {
        protected ContextBoundObject();
    }

    public abstract sealed class Convert
    {
        public static readonly object DBNull;
        public static object ChangeType(object value, Type conversionType);
        public static object ChangeType(object value, Type conversionType, IFormatProvider provider);
        public static object ChangeType(object value, TypeCode typeCode);
        public static object ChangeType(object value, TypeCode typeCode, IFormatProvider provider);
        public static byte[] FromBase64CharArray(char[] inArray, int offset, int length);
        public static byte[] FromBase64String(string s);
        public static TypeCode GetTypeCode(object value);
        public static bool IsDBNull(object value);
        public static int ToBase64CharArray(byte[] inArray, int offsetIn, int length, char[] outArray, int offsetOut);
        public static int ToBase64CharArray(byte[] inArray, int offsetIn, int length, char[] outArray, int offsetOut, Base64FormattingOptions options);
        public static int ToBase64CharArray(byte[] inArray, int offsetIn, int length, char[] outArray, int offsetOut, bool insertLineBreaks);
        public static string ToBase64String(byte[] inArray);
        public static string ToBase64String(byte[] inArray, Base64FormattingOptions options);
        public static string ToBase64String(byte[] inArray, bool insertLineBreaks);
        public static string ToBase64String(byte[] inArray, int offset, int length);
        public static string ToBase64String(byte[] inArray, int offset, int length, Base64FormattingOptions options);
        public static string ToBase64String(byte[] inArray, int offset, int length, bool insertLineBreaks);
        public static bool ToBoolean(bool value);
        public static bool ToBoolean(byte value);
        public static bool ToBoolean(char value);
        public static bool ToBoolean(DateTime value);
        public static bool ToBoolean(decimal value);
        public static bool ToBoolean(double value);
        public static bool ToBoolean(float value);
        public static bool ToBoolean(int value);
        public static bool ToBoolean(long value);
        public static bool ToBoolean(object value);
        public static bool ToBoolean(object value, IFormatProvider provider);
        public static bool ToBoolean(sbyte value);
        public static bool ToBoolean(short value);
        public static bool ToBoolean(string value);
        public static bool ToBoolean(string value, IFormatProvider provider);
        public static bool ToBoolean(uint value);
        public static bool ToBoolean(ulong value);
        public static bool ToBoolean(ushort value);
        public static byte ToByte(bool value);
        public static byte ToByte(byte value);
        public static byte ToByte(char value);
        public static byte ToByte(DateTime value);
        public static byte ToByte(decimal value);
        public static byte ToByte(double value);
        public static byte ToByte(float value);
        public static byte ToByte(int value);
        public static byte ToByte(long value);
        public static byte ToByte(object value);
        public static byte ToByte(object value, IFormatProvider provider);
        public static byte ToByte(sbyte value);
        public static byte ToByte(short value);
        public static byte ToByte(string value);
        public static byte ToByte(string value, IFormatProvider provider);
        public static byte ToByte(string value, int fromBase);
        public static byte ToByte(uint value);
        public static byte ToByte(ulong value);
        public static byte ToByte(ushort value);
        public static char ToChar(bool value);
        public static char ToChar(byte value);
        public static char ToChar(char value);
        public static char ToChar(DateTime value);
        public static char ToChar(decimal value);
        public static char ToChar(double value);
        public static char ToChar(float value);
        public static char ToChar(int value);
        public static char ToChar(long value);
        public static char ToChar(object value);
        public static char ToChar(object value, IFormatProvider provider);
        public static char ToChar(sbyte value);
        public static char ToChar(short value);
        public static char ToChar(string value);
        public static char ToChar(string value, IFormatProvider provider);
        public static char ToChar(uint value);
        public static char ToChar(ulong value);
        public static char ToChar(ushort value);
        public static DateTime ToDateTime(bool value);
        public static DateTime ToDateTime(byte value);
        public static DateTime ToDateTime(char value);
        public static DateTime ToDateTime(DateTime value);
        public static DateTime ToDateTime(decimal value);
        public static DateTime ToDateTime(double value);
        public static DateTime ToDateTime(float value);
        public static DateTime ToDateTime(int value);
        public static DateTime ToDateTime(long value);
        public static DateTime ToDateTime(object value);
        public static DateTime ToDateTime(object value, IFormatProvider provider);
        public static DateTime ToDateTime(sbyte value);
        public static DateTime ToDateTime(short value);
        public static DateTime ToDateTime(string value);
        public static DateTime ToDateTime(string value, IFormatProvider provider);
        public static DateTime ToDateTime(uint value);
        public static DateTime ToDateTime(ulong value);
        public static DateTime ToDateTime(ushort value);
        public static decimal ToDecimal(bool value);
        public static decimal ToDecimal(byte value);
        public static decimal ToDecimal(char value);
        public static decimal ToDecimal(DateTime value);
        public static decimal ToDecimal(decimal value);
        public static decimal ToDecimal(double value);
        public static decimal ToDecimal(float value);
        public static decimal ToDecimal(int value);
        public static decimal ToDecimal(long value);
        public static decimal ToDecimal(object value);
        public static decimal ToDecimal(object value, IFormatProvider provider);
        public static decimal ToDecimal(sbyte value);
        public static decimal ToDecimal(short value);
        public static decimal ToDecimal(string value);
        public static decimal ToDecimal(string value, IFormatProvider provider);
        public static decimal ToDecimal(uint value);
        public static decimal ToDecimal(ulong value);
        public static decimal ToDecimal(ushort value);
        public static double ToDouble(bool value);
        public static double ToDouble(byte value);
        public static double ToDouble(char value);
        public static double ToDouble(DateTime value);
        public static double ToDouble(decimal value);
        public static double ToDouble(double value);
        public static double ToDouble(float value);
        public static double ToDouble(int value);
        public static double ToDouble(long value);
        public static double ToDouble(object value);
        public static double ToDouble(object value, IFormatProvider provider);
        public static double ToDouble(sbyte value);
        public static double ToDouble(short value);
        public static double ToDouble(string value);
        public static double ToDouble(string value, IFormatProvider provider);
        public static double ToDouble(uint value);
        public static double ToDouble(ulong value);
        public static double ToDouble(ushort value);
        public static short ToInt16(bool value);
        public static short ToInt16(byte value);
        public static short ToInt16(char value);
        public static short ToInt16(DateTime value);
        public static short ToInt16(decimal value);
        public static short ToInt16(double value);
        public static short ToInt16(float value);
        public static short ToInt16(int value);
        public static short ToInt16(long value);
        public static short ToInt16(object value);
        public static short ToInt16(object value, IFormatProvider provider);
        public static short ToInt16(sbyte value);
        public static short ToInt16(short value);
        public static short ToInt16(string value);
        public static short ToInt16(string value, IFormatProvider provider);
        public static short ToInt16(string value, int fromBase);
        public static short ToInt16(uint value);
        public static short ToInt16(ulong value);
        public static short ToInt16(ushort value);
        public static int ToInt32(bool value);
        public static int ToInt32(byte value);
        public static int ToInt32(char value);
        public static int ToInt32(DateTime value);
        public static int ToInt32(decimal value);
        public static int ToInt32(double value);
        public static int ToInt32(float value);
        public static int ToInt32(int value);
        public static int ToInt32(long value);
        public static int ToInt32(object value);
        public static int ToInt32(object value, IFormatProvider provider);
        public static int ToInt32(sbyte value);
        public static int ToInt32(short value);
        public static int ToInt32(string value);
        public static int ToInt32(string value, IFormatProvider provider);
        public static int ToInt32(string value, int fromBase);
        public static int ToInt32(uint value);
        public static int ToInt32(ulong value);
        public static int ToInt32(ushort value);
        public static long ToInt64(bool value);
        public static long ToInt64(byte value);
        public static long ToInt64(char value);
        public static long ToInt64(DateTime value);
        public static long ToInt64(decimal value);
        public static long ToInt64(double value);
        public static long ToInt64(float value);
        public static long ToInt64(int value);
        public static long ToInt64(long value);
        public static long ToInt64(object value);
        public static long ToInt64(object value, IFormatProvider provider);
        public static long ToInt64(sbyte value);
        public static long ToInt64(short value);
        public static long ToInt64(string value);
        public static long ToInt64(string value, IFormatProvider provider);
        public static long ToInt64(string value, int fromBase);
        public static long ToInt64(uint value);
        public static long ToInt64(ulong value);
        public static long ToInt64(ushort value);
        public static sbyte ToSByte(bool value);
        public static sbyte ToSByte(byte value);
        public static sbyte ToSByte(char value);
        public static sbyte ToSByte(DateTime value);
        public static sbyte ToSByte(decimal value);
        public static sbyte ToSByte(double value);
        public static sbyte ToSByte(float value);
        public static sbyte ToSByte(int value);
        public static sbyte ToSByte(long value);
        public static sbyte ToSByte(object value);
        public static sbyte ToSByte(object value, IFormatProvider provider);
        public static sbyte ToSByte(sbyte value);
        public static sbyte ToSByte(short value);
        public static sbyte ToSByte(string value);
        public static sbyte ToSByte(string value, IFormatProvider provider);
        public static sbyte ToSByte(string value, int fromBase);
        public static sbyte ToSByte(uint value);
        public static sbyte ToSByte(ulong value);
        public static sbyte ToSByte(ushort value);
        public static float ToSingle(bool value);
        public static float ToSingle(byte value);
        public static float ToSingle(char value);
        public static float ToSingle(DateTime value);
        public static float ToSingle(decimal value);
        public static float ToSingle(double value);
        public static float ToSingle(float value);
        public static float ToSingle(int value);
        public static float ToSingle(long value);
        public static float ToSingle(object value);
        public static float ToSingle(object value, IFormatProvider provider);
        public static float ToSingle(sbyte value);
        public static float ToSingle(short value);
        public static float ToSingle(string value);
        public static float ToSingle(string value, IFormatProvider provider);
        public static float ToSingle(uint value);
        public static float ToSingle(ulong value);
        public static float ToSingle(ushort value);
        public static string ToString(bool value);
        public static string ToString(bool value, IFormatProvider provider);
        public static string ToString(byte value);
        public static string ToString(byte value, IFormatProvider provider);
        public static string ToString(byte value, int toBase);
        public static string ToString(char value);
        public static string ToString(char value, IFormatProvider provider);
        public static string ToString(DateTime value);
        public static string ToString(DateTime value, IFormatProvider provider);
        public static string ToString(decimal value);
        public static string ToString(decimal value, IFormatProvider provider);
        public static string ToString(double value);
        public static string ToString(double value, IFormatProvider provider);
        public static string ToString(float value);
        public static string ToString(float value, IFormatProvider provider);
        public static string ToString(int value);
        public static string ToString(int value, IFormatProvider provider);
        public static string ToString(int value, int toBase);
        public static string ToString(long value);
        public static string ToString(long value, IFormatProvider provider);
        public static string ToString(long value, int toBase);
        public static string ToString(object value);
        public static string ToString(object value, IFormatProvider provider);
        public static string ToString(sbyte value);
        public static string ToString(sbyte value, IFormatProvider provider);
        public static string ToString(short value);
        public static string ToString(short value, IFormatProvider provider);
        public static string ToString(short value, int toBase);
        public static string ToString(string value);
        public static string ToString(string value, IFormatProvider provider);
        public static string ToString(uint value);
        public static string ToString(uint value, IFormatProvider provider);
        public static string ToString(ulong value);
        public static string ToString(ulong value, IFormatProvider provider);
        public static string ToString(ushort value);
        public static string ToString(ushort value, IFormatProvider provider);
        public static ushort ToUInt16(bool value);
        public static ushort ToUInt16(byte value);
        public static ushort ToUInt16(char value);
        public static ushort ToUInt16(DateTime value);
        public static ushort ToUInt16(decimal value);
        public static ushort ToUInt16(double value);
        public static ushort ToUInt16(float value);
        public static ushort ToUInt16(int value);
        public static ushort ToUInt16(long value);
        public static ushort ToUInt16(object value);
        public static ushort ToUInt16(object value, IFormatProvider provider);
        public static ushort ToUInt16(sbyte value);
        public static ushort ToUInt16(short value);
        public static ushort ToUInt16(string value);
        public static ushort ToUInt16(string value, IFormatProvider provider);
        public static ushort ToUInt16(string value, int fromBase);
        public static ushort ToUInt16(uint value);
        public static ushort ToUInt16(ulong value);
        public static ushort ToUInt16(ushort value);
        public static uint ToUInt32(bool value);
        public static uint ToUInt32(byte value);
        public static uint ToUInt32(char value);
        public static uint ToUInt32(DateTime value);
        public static uint ToUInt32(decimal value);
        public static uint ToUInt32(double value);
        public static uint ToUInt32(float value);
        public static uint ToUInt32(int value);
        public static uint ToUInt32(long value);
        public static uint ToUInt32(object value);
        public static uint ToUInt32(object value, IFormatProvider provider);
        public static uint ToUInt32(sbyte value);
        public static uint ToUInt32(short value);
        public static uint ToUInt32(string value);
        public static uint ToUInt32(string value, IFormatProvider provider);
        public static uint ToUInt32(string value, int fromBase);
        public static uint ToUInt32(uint value);
        public static uint ToUInt32(ulong value);
        public static uint ToUInt32(ushort value);
        public static ulong ToUInt64(bool value);
        public static ulong ToUInt64(byte value);
        public static ulong ToUInt64(char value);
        public static ulong ToUInt64(DateTime value);
        public static ulong ToUInt64(decimal value);
        public static ulong ToUInt64(double value);
        public static ulong ToUInt64(float value);
        public static ulong ToUInt64(int value);
        public static ulong ToUInt64(long value);
        public static ulong ToUInt64(object value);
        public static ulong ToUInt64(object value, IFormatProvider provider);
        public static ulong ToUInt64(sbyte value);
        public static ulong ToUInt64(short value);
        public static ulong ToUInt64(string value);
        public static ulong ToUInt64(string value, IFormatProvider provider);
        public static ulong ToUInt64(string value, int fromBase);
        public static ulong ToUInt64(uint value);
        public static ulong ToUInt64(ulong value);
        public static ulong ToUInt64(ushort value);
    }

    [SerializableAttribute(..)]
    public struct DateTime: IComparable, IComparable, IConvertible, IEquatable, IFormattable, ISerializable
    {
        public DateTime(int year, int month, int day);
        public DateTime(int year, int month, int day, Calendar calendar);
        public DateTime(int year, int month, int day, int hour, int minute, int second);
        public DateTime(int year, int month, int day, int hour, int minute, int second, Calendar calendar);
        public DateTime(int year, int month, int day, int hour, int minute, int second, DateTimeKind kind);
        public DateTime(int year, int month, int day, int hour, int minute, int second, int millisecond);
        public DateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, Calendar calendar);
        public DateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, Calendar calendar, DateTimeKind kind);
        public DateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, DateTimeKind kind);
        public DateTime(long ticks);
        public DateTime(long ticks, DateTimeKind kind);
        public static readonly DateTime MaxValue;
        public static readonly DateTime MinValue;
        public DateTime Date { get; }
        public int Day { get; }
        public DayOfWeek DayOfWeek { get; }
        public int DayOfYear { get; }
        public int Hour { get; }
        public DateTimeKind Kind { get; }
        public int Millisecond { get; }
        public int Minute { get; }
        public int Month { get; }
        public static DateTime Now { get; }
        public int Second { get; }
        public long Ticks { get; }
        public TimeSpan TimeOfDay { get; }
        public static DateTime Today { get; }
        public static DateTime UtcNow { get; }
        public int Year { get; }
        public DateTime Add(TimeSpan value);
        public DateTime AddDays(double value);
        public DateTime AddHours(double value);
        public DateTime AddMilliseconds(double value);
        public DateTime AddMinutes(double value);
        public DateTime AddMonths(int months);
        public DateTime AddSeconds(double value);
        public DateTime AddTicks(long value);
        public DateTime AddYears(int value);
        public static int Compare(DateTime t1, DateTime t2);
        public int CompareTo(DateTime value);
        public int CompareTo(object value);
        public static int DaysInMonth(int year, int month);
        public bool Equals(DateTime value);
        public static bool Equals(DateTime t1, DateTime t2);
        public override bool Equals(object value);
        public static DateTime FromBinary(long dateData);
        public static DateTime FromFileTime(long fileTime);
        public static DateTime FromFileTimeUtc(long fileTime);
        public static DateTime FromOADate(double d);
        public string[] GetDateTimeFormats();
        public string[] GetDateTimeFormats(char format);
        public string[] GetDateTimeFormats(char format, IFormatProvider provider);
        public string[] GetDateTimeFormats(IFormatProvider provider);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public bool IsDaylightSavingTime();
        public static bool IsLeapYear(int year);
        public static DateTime Parse(string s);
        public static DateTime Parse(string s, IFormatProvider provider);
        public static DateTime Parse(string s, IFormatProvider provider, DateTimeStyles styles);
        public static DateTime ParseExact(string s, string format, IFormatProvider provider);
        public static DateTime ParseExact(string s, string format, IFormatProvider provider, DateTimeStyles style);
        public static DateTime ParseExact(string s, string[] formats, IFormatProvider provider, DateTimeStyles style);
        public static DateTime SpecifyKind(DateTime value, DateTimeKind kind);
        public TimeSpan Subtract(DateTime value);
        public DateTime Subtract(TimeSpan value);
        public long ToBinary();
        public long ToFileTime();
        public long ToFileTimeUtc();
        public DateTime ToLocalTime();
        public string ToLongDateString();
        public string ToLongTimeString();
        public double ToOADate();
        public string ToShortDateString();
        public string ToShortTimeString();
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public DateTime ToUniversalTime();
        public static bool TryParse(string s, ref DateTime result);
        public static bool TryParse(string s, IFormatProvider provider, DateTimeStyles styles, ref DateTime result);
        public static bool TryParseExact(string s, string format, IFormatProvider provider, DateTimeStyles style, ref DateTime result);
        public static bool TryParseExact(string s, string[] formats, IFormatProvider provider, DateTimeStyles style, ref DateTime result);
        public static DateTime operator +(DateTime d, TimeSpan t);
        public static TimeSpan operator -(DateTime d1, DateTime d2);
        public static DateTime operator -(DateTime d, TimeSpan t);
        public static bool operator ==(DateTime d1, DateTime d2);
        public static bool operator !=(DateTime d1, DateTime d2);
        public static bool operator >=(DateTime t1, DateTime t2);
        public static bool operator <=(DateTime t1, DateTime t2);
        public static bool operator >(DateTime t1, DateTime t2);
        public static bool operator <(DateTime t1, DateTime t2);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DBNull: IConvertible, ISerializable
    {
        public static readonly DBNull Value;
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public TypeCode GetTypeCode();
        public override string ToString();
        public string ToString(IFormatProvider provider);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Decimal: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public Decimal(double value);
        public Decimal(float value);
        public Decimal(int value);
        public Decimal(int lo, int mid, int hi, bool isNegative, byte scale);
        public Decimal(int[] bits);
        public Decimal(long value);
        public Decimal(uint value);
        public Decimal(ulong value);
        public static readonly decimal MaxValue;
        public static readonly decimal MinusOne;
        public static readonly decimal MinValue;
        public static readonly decimal One;
        public static readonly decimal Zero;
        public static decimal Add(decimal d1, decimal d2);
        public static decimal Ceiling(decimal d);
        public static int Compare(decimal d1, decimal d2);
        public int CompareTo(decimal value);
        public int CompareTo(object value);
        public static decimal Divide(decimal d1, decimal d2);
        public bool Equals(decimal value);
        public static bool Equals(decimal d1, decimal d2);
        public override bool Equals(object value);
        public static decimal Floor(decimal d);
        public static decimal FromOACurrency(long cy);
        public static int[] GetBits(decimal d);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static decimal Multiply(decimal d1, decimal d2);
        public static decimal Negate(decimal d);
        public static decimal Parse(string s);
        public static decimal Parse(string s, IFormatProvider provider);
        public static decimal Parse(string s, NumberStyles style);
        public static decimal Parse(string s, NumberStyles style, IFormatProvider provider);
        public static decimal Remainder(decimal d1, decimal d2);
        public static decimal Round(decimal d);
        public static decimal Round(decimal d, int decimals);
        public static decimal Round(decimal d, int decimals, MidpointRounding mode);
        public static decimal Round(decimal d, MidpointRounding mode);
        public static decimal Subtract(decimal d1, decimal d2);
        public static byte ToByte(decimal value);
        public static double ToDouble(decimal d);
        public static short ToInt16(decimal value);
        public static int ToInt32(decimal d);
        public static long ToInt64(decimal d);
        public static long ToOACurrency(decimal value);
        public static sbyte ToSByte(decimal value);
        public static float ToSingle(decimal d);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static ushort ToUInt16(decimal value);
        public static uint ToUInt32(decimal d);
        public static ulong ToUInt64(decimal d);
        public static decimal Truncate(decimal d);
        public static bool TryParse(string s, ref decimal result);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref decimal result);
        public static decimal operator +(decimal d);
        public static decimal operator +(decimal d1, decimal d2);
        public static decimal operator ++(decimal d);
        public static decimal operator -(decimal d);
        public static decimal operator -(decimal d1, decimal d2);
        public static decimal operator --(decimal d);
        public static decimal operator *(decimal d1, decimal d2);
        public static decimal operator /(decimal d1, decimal d2);
        public static decimal operator %(decimal d1, decimal d2);
        public static bool operator ==(decimal d1, decimal d2);
        public static bool operator !=(decimal d1, decimal d2);
        public static bool operator >=(decimal d1, decimal d2);
        public static bool operator <=(decimal d1, decimal d2);
        public static bool operator >(decimal d1, decimal d2);
        public static bool operator <(decimal d1, decimal d2);
        public static implicit operator decimal(byte value);
        public static implicit operator decimal(char value);
        public static implicit operator decimal(int value);
        public static implicit operator decimal(long value);
        public static implicit operator decimal(sbyte value);
        public static implicit operator decimal(short value);
        public static implicit operator decimal(uint value);
        public static implicit operator decimal(ulong value);
        public static implicit operator decimal(ushort value);
        public static explicit operator byte(decimal value);
        public static explicit operator char(decimal value);
        public static explicit operator decimal(double value);
        public static explicit operator decimal(float value);
        public static explicit operator double(decimal value);
        public static explicit operator float(decimal value);
        public static explicit operator int(decimal value);
        public static explicit operator long(decimal value);
        public static explicit operator sbyte(decimal value);
        public static explicit operator short(decimal value);
        public static explicit operator uint(decimal value);
        public static explicit operator ulong(decimal value);
        public static explicit operator ushort(decimal value);
    }

    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Delegate: ICloneable, ISerializable
    {
        protected Delegate(object target, string method);
        protected Delegate(Type target, string method);
        public MethodInfo Method { get; }
        public object Target { get; }
        public virtual object Clone();
        public static Delegate Combine(Delegate a, Delegate b);
        public static Delegate Combine(params Delegate[] delegates);
        protected virtual Delegate CombineImpl(Delegate d);
        public static Delegate CreateDelegate(Type type, MethodInfo method);
        public static Delegate CreateDelegate(Type type, MethodInfo method, bool throwOnBindFailure);
        public static Delegate CreateDelegate(Type type, object firstArgument, MethodInfo method);
        public static Delegate CreateDelegate(Type type, object firstArgument, MethodInfo method, bool throwOnBindFailure);
        public static Delegate CreateDelegate(Type type, object target, string method);
        public static Delegate CreateDelegate(Type type, object target, string method, bool ignoreCase);
        public static Delegate CreateDelegate(Type type, object target, string method, bool ignoreCase, bool throwOnBindFailure);
        public static Delegate CreateDelegate(Type type, object firstArgument, Type target, string method);
        public static Delegate CreateDelegate(Type type, object firstArgument, Type target, string method, bool ignoreCase);
        public static Delegate CreateDelegate(Type type, object firstArgument, Type target, string method, bool ignoreCase, bool throwOnBindFailure);
        public static Delegate CreateDelegate(Type type, Type target, string method);
        public static Delegate CreateDelegate(Type type, Type target, string method, bool ignoreCase);
        public static Delegate CreateDelegate(Type type, Type target, string method, bool ignoreCase, bool throwOnBindFailure);
        public object DynamicInvoke(params object[] args);
        protected virtual object DynamicInvokeImpl(object[] args);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public virtual Delegate[] GetInvocationList();
        protected virtual MethodInfo GetMethodImpl();
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public static Delegate Remove(Delegate source, Delegate value);
        public static Delegate RemoveAll(Delegate source, Delegate value);
        protected virtual Delegate RemoveImpl(Delegate d);
        public static bool operator ==(Delegate d1, Delegate d2);
        public static bool operator !=(Delegate d1, Delegate d2);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Double: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const double Epsilon;
        public const double MaxValue;
        public const double MinValue;
        public const double NaN;
        public const double NegativeInfinity;
        public const double PositiveInfinity;
        public int CompareTo(double value);
        public int CompareTo(object value);
        public bool Equals(double obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static bool IsInfinity(double d);
        public static bool IsNaN(double d);
        public static bool IsNegativeInfinity(double d);
        public static bool IsPositiveInfinity(double d);
        public static double Parse(string s);
        public static double Parse(string s, IFormatProvider provider);
        public static double Parse(string s, NumberStyles style);
        public static double Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, ref double result);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref double result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Enum: ValueType, IComparable, IConvertible, IFormattable
    {
        protected Enum();
        public int CompareTo(object target);
        public override bool Equals(object obj);
        public static string Format(Type enumType, object value, string format);
        public override int GetHashCode();
        public static string GetName(Type enumType, object value);
        public static string[] GetNames(Type enumType);
        public TypeCode GetTypeCode();
        public static Type GetUnderlyingType(Type enumType);
        public static Array GetValues(Type enumType);
        public static bool IsDefined(Type enumType, object value);
        public static object Parse(Type enumType, string value);
        public static object Parse(Type enumType, string value, bool ignoreCase);
        public static object ToObject(Type enumType, byte value);
        public static object ToObject(Type enumType, int value);
        public static object ToObject(Type enumType, long value);
        public static object ToObject(Type enumType, object value);
        public static object ToObject(Type enumType, sbyte value);
        public static object ToObject(Type enumType, short value);
        public static object ToObject(Type enumType, uint value);
        public static object ToObject(Type enumType, ulong value);
        public static object ToObject(Type enumType, ushort value);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class Environment
    {
        public static string CommandLine { get; }
        public static string CurrentDirectory { get; set; }
        public static int ExitCode { get; set; }
        public static bool HasShutdownStarted { get; }
        public static string MachineName { get; }
        public static string NewLine { get; }
        public static OperatingSystem OSVersion { get; }
        public static int ProcessorCount { get; }
        public static string StackTrace { get; }
        public static string SystemDirectory { get; }
        public static int TickCount { get; }
        public static string UserDomainName { get; }
        public static bool UserInteractive { get; }
        public static string UserName { get; }
        public static Version Version { get; }
        public static long WorkingSet { get; }
        public static void Exit(int exitCode);
        public static string ExpandEnvironmentVariables(string name);
        public static void FailFast(string message);
        public static string[] GetCommandLineArgs();
        public static string GetEnvironmentVariable(string variable);
        public static string GetEnvironmentVariable(string variable, EnvironmentVariableTarget target);
        public static IDictionary GetEnvironmentVariables();
        public static IDictionary GetEnvironmentVariables(EnvironmentVariableTarget target);
        public static string GetFolderPath(SpecialFolder folder);
        public static string[] GetLogicalDrives();
        public static void SetEnvironmentVariable(string variable, string value);
        public static void SetEnvironmentVariable(string variable, string value, EnvironmentVariableTarget target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class EventArgs
    {
        public EventArgs();
        public static readonly EventArgs Empty;
    }

    [SerializableAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public class Exception: _Exception, ISerializable
    {
        public Exception();
        protected Exception(SerializationInfo info, StreamingContext context);
        public Exception(string message);
        public Exception(string message, Exception innerException);
        public virtual IDictionary Data { get; }
        public virtual string HelpLink { get; set; }
        public Exception InnerException { get; }
        public virtual string Message { get; }
        public virtual string Source { get; set; }
        public virtual string StackTrace { get; }
        public MethodBase TargetSite { get; }
        public virtual Exception GetBaseException();
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public Type GetType();
        public override string ToString();
    }

    public abstract sealed class GC
    {
        public static int MaxGeneration { get; }
        public static void AddMemoryPressure(long bytesAllocated);
        public static void Collect();
        public static void Collect(int generation);
        public static int CollectionCount(int generation);
        public static int GetGeneration(object obj);
        public static int GetGeneration(WeakReference wo);
        public static long GetTotalMemory(bool forceFullCollection);
        public static void KeepAlive(object obj);
        public static void RemoveMemoryPressure(long bytesAllocated);
        public static void ReRegisterForFinalize(object obj);
        public static void SuppressFinalize(object obj);
        public static void WaitForPendingFinalizers();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Guid: IComparable, IComparable, IEquatable, IFormattable
    {
        public Guid(byte[] b);
        public Guid(int a, short b, short c, byte d, byte e, byte f, byte g, byte h, byte i, byte j, byte k);
        public Guid(int a, short b, short c, byte[] d);
        public Guid(string g);
        public Guid(uint a, ushort b, ushort c, byte d, byte e, byte f, byte g, byte h, byte i, byte j, byte k);
        public static readonly Guid Empty;
        public int CompareTo(Guid value);
        public int CompareTo(object value);
        public bool Equals(Guid g);
        public override bool Equals(object o);
        public override int GetHashCode();
        public static Guid NewGuid();
        public byte[] ToByteArray();
        public override string ToString();
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool operator ==(Guid a, Guid b);
        public static bool operator !=(Guid a, Guid b);
    }

    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface IAppDomainSetup
    {
        public string ApplicationBase { get; set; }
        public string ApplicationName { get; set; }
        public string CachePath { get; set; }
        public string ConfigurationFile { get; set; }
        public string DynamicBase { get; set; }
        public string LicenseFile { get; set; }
        public string PrivateBinPath { get; set; }
        public string PrivateBinPathProbe { get; set; }
        public string ShadowCopyDirectories { get; set; }
        public string ShadowCopyFiles { get; set; }
    }

    [ComVisibleAttribute(..)]
    public interface IAsyncResult
    {
        public object AsyncState { get; }
        public WaitHandle AsyncWaitHandle { get; }
        public bool CompletedSynchronously { get; }
        public bool IsCompleted { get; }
    }

    [ObsoleteAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface ICancelableAsyncResult: IAsyncResult
    {
        public void Cancel();
    }

    [ComVisibleAttribute(..)]
    public interface ICloneable
    {
        public object Clone();
    }

    [ComVisibleAttribute(..)]
    public interface IComparable
    {
        public int CompareTo(object obj);
    }

    public interface IComparable<T>
    {
        public int CompareTo(T other);
    }

    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface IConvertible
    {
        public TypeCode GetTypeCode();
        public bool ToBoolean(IFormatProvider provider);
        public byte ToByte(IFormatProvider provider);
        public char ToChar(IFormatProvider provider);
        public DateTime ToDateTime(IFormatProvider provider);
        public decimal ToDecimal(IFormatProvider provider);
        public double ToDouble(IFormatProvider provider);
        public short ToInt16(IFormatProvider provider);
        public int ToInt32(IFormatProvider provider);
        public long ToInt64(IFormatProvider provider);
        public sbyte ToSByte(IFormatProvider provider);
        public float ToSingle(IFormatProvider provider);
        public string ToString(IFormatProvider provider);
        public object ToType(Type conversionType, IFormatProvider provider);
        public ushort ToUInt16(IFormatProvider provider);
        public uint ToUInt32(IFormatProvider provider);
        public ulong ToUInt64(IFormatProvider provider);
    }

    [ComVisibleAttribute(..)]
    public interface ICustomFormatter
    {
        public string Format(string format, object arg, IFormatProvider formatProvider);
    }

    [ComVisibleAttribute(..)]
    public interface IDisposable
    {
        public void Dispose();
    }

    public interface IEquatable<T>
    {
        public bool Equals(T other);
    }

    [ComVisibleAttribute(..)]
    public interface IFormatProvider
    {
        public object GetFormat(Type formatType);
    }

    [ComVisibleAttribute(..)]
    public interface IFormattable
    {
        public string ToString(string format, IFormatProvider formatProvider);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Int16: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const short MaxValue;
        public const short MinValue;
        public int CompareTo(object value);
        public int CompareTo(short value);
        public override bool Equals(object obj);
        public bool Equals(short obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static short Parse(string s);
        public static short Parse(string s, IFormatProvider provider);
        public static short Parse(string s, NumberStyles style);
        public static short Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref short result);
        public static bool TryParse(string s, ref short result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Int32: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const int MaxValue;
        public const int MinValue;
        public int CompareTo(int value);
        public int CompareTo(object value);
        public bool Equals(int obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static int Parse(string s);
        public static int Parse(string s, IFormatProvider provider);
        public static int Parse(string s, NumberStyles style);
        public static int Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, ref int result);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref int result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Int64: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const long MaxValue;
        public const long MinValue;
        public int CompareTo(long value);
        public int CompareTo(object value);
        public bool Equals(long obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static long Parse(string s);
        public static long Parse(string s, IFormatProvider provider);
        public static long Parse(string s, NumberStyles style);
        public static long Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, ref long result);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref long result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct IntPtr: ISerializable
    {
        public IntPtr(int value);
        public IntPtr(long value);
        public IntPtr(void* value);
        public static readonly IntPtr Zero;
        public static int Size { get; }
        public override bool Equals(object obj);
        public override int GetHashCode();
        public int ToInt32();
        public long ToInt64();
        public void* ToPointer();
        public override string ToString();
        public string ToString(string format);
        public static bool operator ==(IntPtr value1, IntPtr value2);
        public static bool operator !=(IntPtr value1, IntPtr value2);
        public static explicit operator int(IntPtr value);
        public static explicit operator IntPtr(int value);
        public static explicit operator IntPtr(long value);
        public static explicit operator IntPtr(void* value);
        public static explicit operator long(IntPtr value);
        public static explicit operator void*(IntPtr value);
    }

    [ComVisibleAttribute(..)]
    public interface INullableValue
    {
        public bool HasValue { get; }
        public object Value { get; }
    }

    public interface IServiceProvider
    {
        public object GetService(Type serviceType);
    }

    [ComVisibleAttribute(..)]
    public sealed class LocalDataStoreSlot
    {
        protected override void Finalize();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class MarshalByRefObject
    {
        protected MarshalByRefObject();
        public virtual ObjRef CreateObjRef(Type requestedType);
        public object GetLifetimeService();
        public virtual object InitializeLifetimeService();
        protected MarshalByRefObject MemberwiseClone(bool cloneIdentity);
    }

    public abstract sealed class Math
    {
        public const double E;
        public const double PI;
        public static decimal Abs(decimal value);
        public static double Abs(double value);
        public static float Abs(float value);
        public static int Abs(int value);
        public static long Abs(long value);
        public static sbyte Abs(sbyte value);
        public static short Abs(short value);
        public static double Acos(double d);
        public static double Asin(double d);
        public static double Atan(double d);
        public static double Atan2(double y, double x);
        public static long BigMul(int a, int b);
        public static decimal Ceiling(decimal d);
        public static double Ceiling(double a);
        public static double Cos(double d);
        public static double Cosh(double value);
        public static int DivRem(int a, int b, ref int result);
        public static long DivRem(long a, long b, ref long result);
        public static double Exp(double d);
        public static decimal Floor(decimal d);
        public static double Floor(double d);
        public static double IEEERemainder(double x, double y);
        public static double Log(double d);
        public static double Log(double a, double newBase);
        public static double Log10(double d);
        public static byte Max(byte val1, byte val2);
        public static decimal Max(decimal val1, decimal val2);
        public static double Max(double val1, double val2);
        public static float Max(float val1, float val2);
        public static int Max(int val1, int val2);
        public static long Max(long val1, long val2);
        public static sbyte Max(sbyte val1, sbyte val2);
        public static short Max(short val1, short val2);
        public static uint Max(uint val1, uint val2);
        public static ulong Max(ulong val1, ulong val2);
        public static ushort Max(ushort val1, ushort val2);
        public static byte Min(byte val1, byte val2);
        public static decimal Min(decimal val1, decimal val2);
        public static double Min(double val1, double val2);
        public static float Min(float val1, float val2);
        public static int Min(int val1, int val2);
        public static long Min(long val1, long val2);
        public static sbyte Min(sbyte val1, sbyte val2);
        public static short Min(short val1, short val2);
        public static uint Min(uint val1, uint val2);
        public static ulong Min(ulong val1, ulong val2);
        public static ushort Min(ushort val1, ushort val2);
        public static double Pow(double x, double y);
        public static decimal Round(decimal d);
        public static decimal Round(decimal d, int decimals);
        public static decimal Round(decimal d, int decimals, MidpointRounding mode);
        public static decimal Round(decimal d, MidpointRounding mode);
        public static double Round(double a);
        public static double Round(double value, int digits);
        public static double Round(double value, int digits, MidpointRounding mode);
        public static double Round(double value, MidpointRounding mode);
        public static int Sign(decimal value);
        public static int Sign(double value);
        public static int Sign(float value);
        public static int Sign(int value);
        public static int Sign(long value);
        public static int Sign(sbyte value);
        public static int Sign(short value);
        public static double Sin(double a);
        public static double Sinh(double value);
        public static double Sqrt(double d);
        public static double Tan(double a);
        public static double Tanh(double value);
        public static decimal Truncate(decimal d);
        public static double Truncate(double d);
    }

    [ComVisibleAttribute(..)]
    public struct ModuleHandle
    {
        public static readonly ModuleHandle EmptyHandle;
        public bool Equals(ModuleHandle handle);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public void GetPEKind(ref PortableExecutableKinds peKind, ref ImageFileMachine machine);
        public RuntimeFieldHandle GetRuntimeFieldHandleFromMetadataToken(int fieldToken);
        public RuntimeMethodHandle GetRuntimeMethodHandleFromMetadataToken(int methodToken);
        public RuntimeTypeHandle GetRuntimeTypeHandleFromMetadataToken(int typeToken);
        public RuntimeFieldHandle ResolveFieldHandle(int fieldToken);
        public RuntimeFieldHandle ResolveFieldHandle(int fieldToken, RuntimeTypeHandle[] typeInstantiationContext, RuntimeTypeHandle[] methodInstantiationContext);
        public RuntimeMethodHandle ResolveMethodHandle(int methodToken);
        public RuntimeMethodHandle ResolveMethodHandle(int methodToken, RuntimeTypeHandle[] typeInstantiationContext, RuntimeTypeHandle[] methodInstantiationContext);
        public RuntimeTypeHandle ResolveTypeHandle(int typeToken);
        public RuntimeTypeHandle ResolveTypeHandle(int typeToken, RuntimeTypeHandle[] typeInstantiationContext, RuntimeTypeHandle[] methodInstantiationContext);
        public static bool operator ==(ModuleHandle left, ModuleHandle right);
        public static bool operator !=(ModuleHandle left, ModuleHandle right);
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class Nullable
    {
        public static int Compare<T>(Nullable<T> n1, Nullable<T> n2);
        public static bool Equals<T>(Nullable<T> n1, Nullable<T> n2);
        public static Nullable<T> FromObject<T>(object value);
        public static Type GetUnderlyingType(Type nullableType);
        public static T GetValueOrDefault<T>(Nullable<T> value);
        public static T GetValueOrDefault<T>(Nullable<T> value, T valueWhenNull);
        public static bool HasValue<T>(Nullable<T> value);
        public static object ToObject<T>(Nullable<T> value);
        public static object Unwrap(object value);
        public static object Wrap(object value, Type type);
    }

    [SerializableAttribute(..)]
    public struct Nullable<T>: IComparable, IComparable, IEquatable, IFormattable, INullableValue where T:ValueType
    {
        public Nullable(T value);
        public bool HasValue { get; }
        public T Value { get; }
        public int CompareTo(Nullable<T> other);
        public int CompareTo(object other);
        public bool Equals(Nullable<T> other);
        public override bool Equals(object other);
        public static Nullable<T> FromObject(object value);
        public override int GetHashCode();
        public T GetValueOrDefault();
        public T GetValueOrDefault(T defaultValue);
        public object ToObject();
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool operator ==(Nullable<T> x, Nullable<T> y);
        public static bool operator !=(Nullable<T> x, Nullable<T> y);
        public static implicit operator Nullable<T>(T value);
        public static explicit operator T(Nullable<T> value);
    }

    [SerializableAttribute(..)]
    public class Object
    {
        public Object();
        public virtual bool Equals(object obj);
        public static bool Equals(object objA, object objB);
        protected override void Finalize();
        public virtual int GetHashCode();
        public Type GetType();
        protected object MemberwiseClone();
        public static bool ReferenceEquals(object objA, object objB);
        public virtual string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class OperatingSystem: ICloneable, ISerializable
    {
        public OperatingSystem(PlatformID platform, Version version);
        public PlatformID Platform { get; }
        public string ServicePack { get; }
        public Version Version { get; }
        public string VersionString { get; }
        public object Clone();
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class Random
    {
        public Random();
        public Random(int Seed);
        public virtual int Next();
        public virtual int Next(int maxValue);
        public virtual int Next(int minValue, int maxValue);
        public virtual void NextBytes(byte[] buffer);
        public virtual double NextDouble();
        protected virtual double Sample();
    }

    [ComVisibleAttribute(..)]
    public struct RuntimeArgumentHandle
    {
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct RuntimeFieldHandle: ISerializable
    {
        public IntPtr Value { get; }
        public override bool Equals(object obj);
        public bool Equals(RuntimeFieldHandle handle);
        public override int GetHashCode();
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public static bool operator ==(RuntimeFieldHandle left, RuntimeFieldHandle right);
        public static bool operator !=(RuntimeFieldHandle left, RuntimeFieldHandle right);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct RuntimeMethodHandle: ISerializable
    {
        public IntPtr Value { get; }
        public override bool Equals(object obj);
        public bool Equals(RuntimeMethodHandle handle);
        public IntPtr GetFunctionPointer();
        public override int GetHashCode();
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public static bool operator ==(RuntimeMethodHandle left, RuntimeMethodHandle right);
        public static bool operator !=(RuntimeMethodHandle left, RuntimeMethodHandle right);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct RuntimeTypeHandle: ISerializable
    {
        public IntPtr Value { get; }
        public override bool Equals(object obj);
        public bool Equals(RuntimeTypeHandle handle);
        public override int GetHashCode();
        public ModuleHandle GetModuleHandle();
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public static bool operator ==(object left, RuntimeTypeHandle right);
        public static bool operator ==(RuntimeTypeHandle left, object right);
        public static bool operator !=(object left, RuntimeTypeHandle right);
        public static bool operator !=(RuntimeTypeHandle left, object right);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public struct SByte: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const sbyte MaxValue;
        public const sbyte MinValue;
        public int CompareTo(object obj);
        public int CompareTo(sbyte value);
        public override bool Equals(object obj);
        public bool Equals(sbyte obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static sbyte Parse(string s);
        public static sbyte Parse(string s, IFormatProvider provider);
        public static sbyte Parse(string s, NumberStyles style);
        public static sbyte Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref sbyte result);
        public static bool TryParse(string s, ref sbyte result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Single: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const float Epsilon;
        public const float MaxValue;
        public const float MinValue;
        public const float NaN;
        public const float NegativeInfinity;
        public const float PositiveInfinity;
        public int CompareTo(float value);
        public int CompareTo(object value);
        public bool Equals(float obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static bool IsInfinity(float f);
        public static bool IsNaN(float f);
        public static bool IsNegativeInfinity(float f);
        public static bool IsPositiveInfinity(float f);
        public static float Parse(string s);
        public static float Parse(string s, IFormatProvider provider);
        public static float Parse(string s, NumberStyles style);
        public static float Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, ref float result);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref float result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class StringComparer: IComparer, IComparer, IEqualityComparer, IEqualityComparer
    {
        protected StringComparer();
        public static StringComparer CurrentCulture { get; }
        public static StringComparer CurrentCultureIgnoreCase { get; }
        public static StringComparer InvariantCulture { get; }
        public static StringComparer InvariantCultureIgnoreCase { get; }
        public static StringComparer Ordinal { get; }
        public static StringComparer OrdinalIgnoreCase { get; }
        public int Compare(object x, object y);
        public abstract int Compare(string x, string y);
        public static StringComparer Create(CultureInfo culture, bool ignoreCase);
        public bool Equals(object x, object y);
        public abstract bool Equals(string x, string y);
        public int GetHashCode(object obj);
        public abstract int GetHashCode(string obj);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct TimeSpan: IComparable, IComparable, IEquatable
    {
        public TimeSpan(int hours, int minutes, int seconds);
        public TimeSpan(int days, int hours, int minutes, int seconds);
        public TimeSpan(int days, int hours, int minutes, int seconds, int milliseconds);
        public TimeSpan(long ticks);
        public static readonly TimeSpan MaxValue;
        public static readonly TimeSpan MinValue;
        public const long TicksPerDay;
        public const long TicksPerHour;
        public const long TicksPerMillisecond;
        public const long TicksPerMinute;
        public const long TicksPerSecond;
        public static readonly TimeSpan Zero;
        public int Days { get; }
        public int Hours { get; }
        public int Milliseconds { get; }
        public int Minutes { get; }
        public int Seconds { get; }
        public long Ticks { get; }
        public double TotalDays { get; }
        public double TotalHours { get; }
        public double TotalMilliseconds { get; }
        public double TotalMinutes { get; }
        public double TotalSeconds { get; }
        public TimeSpan Add(TimeSpan ts);
        public static int Compare(TimeSpan t1, TimeSpan t2);
        public int CompareTo(object value);
        public int CompareTo(TimeSpan value);
        public TimeSpan Duration();
        public override bool Equals(object value);
        public bool Equals(TimeSpan obj);
        public static bool Equals(TimeSpan t1, TimeSpan t2);
        public static TimeSpan FromDays(double value);
        public static TimeSpan FromHours(double value);
        public static TimeSpan FromMilliseconds(double value);
        public static TimeSpan FromMinutes(double value);
        public static TimeSpan FromSeconds(double value);
        public static TimeSpan FromTicks(long value);
        public override int GetHashCode();
        public TimeSpan Negate();
        public static TimeSpan Parse(string s);
        public TimeSpan Subtract(TimeSpan ts);
        public override string ToString();
        public static bool TryParse(string s, ref TimeSpan result);
        public static TimeSpan operator +(TimeSpan t);
        public static TimeSpan operator +(TimeSpan t1, TimeSpan t2);
        public static TimeSpan operator -(TimeSpan t);
        public static TimeSpan operator -(TimeSpan t1, TimeSpan t2);
        public static bool operator ==(TimeSpan t1, TimeSpan t2);
        public static bool operator !=(TimeSpan t1, TimeSpan t2);
        public static bool operator >=(TimeSpan t1, TimeSpan t2);
        public static bool operator <=(TimeSpan t1, TimeSpan t2);
        public static bool operator >(TimeSpan t1, TimeSpan t2);
        public static bool operator <(TimeSpan t1, TimeSpan t2);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class TimeZone
    {
        protected TimeZone();
        public static TimeZone CurrentTimeZone { get; }
        public abstract string DaylightName { get; }
        public abstract string StandardName { get; }
        public abstract DaylightTime GetDaylightChanges(int year);
        public abstract TimeSpan GetUtcOffset(DateTime time);
        public virtual bool IsDaylightSavingTime(DateTime time);
        public static bool IsDaylightSavingTime(DateTime time, DaylightTime daylightTimes);
        public virtual DateTime ToLocalTime(DateTime time);
        public virtual DateTime ToUniversalTime(DateTime time);
    }

    [SerializableAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public abstract class Type: MemberInfo, _MemberInfo, _Type, ICustomAttributeProvider, IReflect
    {
        protected Type();
        public static readonly char Delimiter;
        public static readonly Type[] EmptyTypes;
        public static readonly MemberFilter FilterAttribute;
        public static readonly MemberFilter FilterName;
        public static readonly MemberFilter FilterNameIgnoreCase;
        public static readonly object Missing;
        public abstract Assembly Assembly { get; }
        public abstract string AssemblyQualifiedName { get; }
        public TypeAttributes Attributes { get; }
        public abstract Type BaseType { get; }
        public virtual bool ContainsGenericParameters { get; }
        public virtual MethodBase DeclaringMethod { get; }
        public static Binder DefaultBinder { get; }
        public abstract string FullName { get; }
        public virtual GenericParameterAttributes GenericParameterAttributes { get; }
        public virtual int GenericParameterPosition { get; }
        public abstract Guid GUID { get; }
        public bool HasElementType { get; }
        public virtual bool HasGenericArguments { get; }
        public bool IsAbstract { get; }
        public bool IsAnsiClass { get; }
        public bool IsArray { get; }
        public bool IsAutoClass { get; }
        public bool IsAutoLayout { get; }
        public bool IsByRef { get; }
        public bool IsClass { get; }
        public bool IsCOMObject { get; }
        public bool IsContextful { get; }
        public bool IsEnum { get; }
        public bool IsExplicitLayout { get; }
        public virtual bool IsGenericParameter { get; }
        public virtual bool IsGenericType { get; }
        public virtual bool IsGenericTypeDefinition { get; }
        public bool IsImport { get; }
        public bool IsInterface { get; }
        public bool IsLayoutSequential { get; }
        public bool IsMarshalByRef { get; }
        public bool IsNested { get; }
        public bool IsNestedAssembly { get; }
        public bool IsNestedFamANDAssem { get; }
        public bool IsNestedFamily { get; }
        public bool IsNestedFamORAssem { get; }
        public bool IsNestedPrivate { get; }
        public bool IsNestedPublic { get; }
        public bool IsNotPublic { get; }
        public bool IsPointer { get; }
        public bool IsPrimitive { get; }
        public bool IsPublic { get; }
        public bool IsSealed { get; }
        public bool IsSerializable { get; }
        public bool IsSpecialName { get; }
        public bool IsUnicodeClass { get; }
        public bool IsValueType { get; }
        public bool IsVisible { get; }
        public abstract Module Module { get; }
        public abstract string Namespace { get; }
        public virtual StructLayoutAttribute StructLayoutAttribute { get; }
        public virtual RuntimeTypeHandle TypeHandle { get; }
        public ConstructorInfo TypeInitializer { get; }
        public abstract Type UnderlyingSystemType { get; }
        public virtual Type BindGenericParameters(params Type[] typeArguments);
        public override bool Equals(object o);
        public bool Equals(Type o);
        public virtual Type[] FindInterfaces(TypeFilter filter, object filterCriteria);
        public virtual MemberInfo[] FindMembers(MemberTypes memberType, BindingFlags bindingAttr, MemberFilter filter, object filterCriteria);
        public virtual int GetArrayRank();
        protected abstract TypeAttributes GetAttributeFlagsImpl();
        public ConstructorInfo GetConstructor(BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public ConstructorInfo GetConstructor(BindingFlags bindingAttr, Binder binder, Type[] types, ParameterModifier[] modifiers);
        public ConstructorInfo GetConstructor(Type[] types);
        protected abstract ConstructorInfo GetConstructorImpl(BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public ConstructorInfo[] GetConstructors();
        public abstract ConstructorInfo[] GetConstructors(BindingFlags bindingAttr);
        public virtual MemberInfo[] GetDefaultMembers();
        public abstract Type GetElementType();
        public EventInfo GetEvent(string name);
        public abstract EventInfo GetEvent(string name, BindingFlags bindingAttr);
        public virtual EventInfo[] GetEvents();
        public abstract EventInfo[] GetEvents(BindingFlags bindingAttr);
        public FieldInfo GetField(string name);
        public abstract FieldInfo GetField(string name, BindingFlags bindingAttr);
        public FieldInfo[] GetFields();
        public abstract FieldInfo[] GetFields(BindingFlags bindingAttr);
        public virtual Type[] GetGenericArguments();
        public virtual Type[] GetGenericParameterConstraints();
        public virtual Type GetGenericTypeDefinition();
        public override int GetHashCode();
        public Type GetInterface(string name);
        public abstract Type GetInterface(string name, bool ignoreCase);
        public virtual InterfaceMapping GetInterfaceMap(Type interfaceType);
        public abstract Type[] GetInterfaces();
        public MemberInfo[] GetMember(string name);
        public virtual MemberInfo[] GetMember(string name, BindingFlags bindingAttr);
        public virtual MemberInfo[] GetMember(string name, MemberTypes type, BindingFlags bindingAttr);
        public MemberInfo[] GetMembers();
        public abstract MemberInfo[] GetMembers(BindingFlags bindingAttr);
        public MethodInfo GetMethod(string name);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr, Binder binder, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo GetMethod(string name, Type[] types);
        public MethodInfo GetMethod(string name, Type[] types, ParameterModifier[] modifiers);
        protected abstract MethodInfo GetMethodImpl(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo[] GetMethods();
        public abstract MethodInfo[] GetMethods(BindingFlags bindingAttr);
        public Type GetNestedType(string name);
        public abstract Type GetNestedType(string name, BindingFlags bindingAttr);
        public Type[] GetNestedTypes();
        public abstract Type[] GetNestedTypes(BindingFlags bindingAttr);
        public PropertyInfo[] GetProperties();
        public abstract PropertyInfo[] GetProperties(BindingFlags bindingAttr);
        public PropertyInfo GetProperty(string name);
        public PropertyInfo GetProperty(string name, BindingFlags bindingAttr);
        public PropertyInfo GetProperty(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        public PropertyInfo GetProperty(string name, Type returnType);
        public PropertyInfo GetProperty(string name, Type returnType, Type[] types);
        public PropertyInfo GetProperty(string name, Type returnType, Type[] types, ParameterModifier[] modifiers);
        public PropertyInfo GetProperty(string name, Type[] types);
        protected abstract PropertyInfo GetPropertyImpl(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        public Type GetType();
        public static Type GetType(string typeName);
        public static Type GetType(string typeName, bool throwOnError);
        public static Type GetType(string typeName, bool throwOnError, bool ignoreCase);
        public static Type[] GetTypeArray(object[] args);
        public static TypeCode GetTypeCode(Type type);
        public static Type GetTypeFromCLSID(Guid clsid);
        public static Type GetTypeFromCLSID(Guid clsid, bool throwOnError);
        public static Type GetTypeFromCLSID(Guid clsid, string server);
        public static Type GetTypeFromCLSID(Guid clsid, string server, bool throwOnError);
        public static Type GetTypeFromHandle(RuntimeTypeHandle handle);
        public static Type GetTypeFromProgID(string progID);
        public static Type GetTypeFromProgID(string progID, bool throwOnError);
        public static Type GetTypeFromProgID(string progID, string server);
        public static Type GetTypeFromProgID(string progID, string server, bool throwOnError);
        public static RuntimeTypeHandle GetTypeHandle(object o);
        protected abstract bool HasElementTypeImpl();
        public object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args);
        public object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, CultureInfo culture);
        public abstract object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] namedParameters);
        protected abstract bool IsArrayImpl();
        public virtual bool IsAssignableFrom(Type c);
        protected abstract bool IsByRefImpl();
        protected abstract bool IsCOMObjectImpl();
        protected virtual bool IsContextfulImpl();
        public virtual bool IsInstanceOfType(object o);
        protected virtual bool IsMarshalByRefImpl();
        protected abstract bool IsPointerImpl();
        protected abstract bool IsPrimitiveImpl();
        public virtual bool IsSubclassOf(Type c);
        protected virtual bool IsValueTypeImpl();
        public virtual Type MakeArrayType();
        public virtual Type MakeArrayType(int rank);
        public virtual Type MakeByRefType();
        public virtual Type MakeGenericType(params Type[] typeArguments);
        public virtual Type MakePointerType();
        public static Type ReflectionOnlyGetType(string typeName, bool throwIfNotFound, bool ignoreCase);
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public struct TypedReference
    {
        public override bool Equals(object o);
        public override int GetHashCode();
        public static Type GetTargetType(TypedReference value);
        public static TypedReference MakeTypedReference(object target, FieldInfo[] flds);
        public static void SetTypedReference(TypedReference target, object value);
        public static RuntimeTypeHandle TargetTypeToken(TypedReference value);
        public static object ToObject(TypedReference value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public struct UInt16: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const ushort MaxValue;
        public const ushort MinValue;
        public int CompareTo(object value);
        public int CompareTo(ushort value);
        public override bool Equals(object obj);
        public bool Equals(ushort obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static ushort Parse(string s);
        public static ushort Parse(string s, IFormatProvider provider);
        public static ushort Parse(string s, NumberStyles style);
        public static ushort Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref ushort result);
        public static bool TryParse(string s, ref ushort result);
    }

    [SerializableAttribute(..)]
    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct UInt32: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const uint MaxValue;
        public const uint MinValue;
        public int CompareTo(object value);
        public int CompareTo(uint value);
        public override bool Equals(object obj);
        public bool Equals(uint obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static uint Parse(string s);
        public static uint Parse(string s, IFormatProvider provider);
        public static uint Parse(string s, NumberStyles style);
        public static uint Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref uint result);
        public static bool TryParse(string s, ref uint result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public struct UInt64: IComparable, IComparable, IConvertible, IEquatable, IFormattable
    {
        public const ulong MaxValue;
        public const ulong MinValue;
        public int CompareTo(object value);
        public int CompareTo(ulong value);
        public override bool Equals(object obj);
        public bool Equals(ulong obj);
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public static ulong Parse(string s);
        public static ulong Parse(string s, IFormatProvider provider);
        public static ulong Parse(string s, NumberStyles style);
        public static ulong Parse(string s, NumberStyles style, IFormatProvider provider);
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToString(string format);
        public string ToString(string format, IFormatProvider provider);
        public static bool TryParse(string s, NumberStyles style, IFormatProvider provider, ref ulong result);
        public static bool TryParse(string s, ref ulong result);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public struct UIntPtr: ISerializable
    {
        public UIntPtr(uint value);
        public UIntPtr(ulong value);
        public UIntPtr(void* value);
        public static readonly UIntPtr Zero;
        public static int Size { get; }
        public override bool Equals(object obj);
        public override int GetHashCode();
        public void* ToPointer();
        public override string ToString();
        public uint ToUInt32();
        public ulong ToUInt64();
        public static bool operator ==(UIntPtr value1, UIntPtr value2);
        public static bool operator !=(UIntPtr value1, UIntPtr value2);
        public static explicit operator uint(UIntPtr value);
        public static explicit operator UIntPtr(uint value);
        public static explicit operator UIntPtr(ulong value);
        public static explicit operator UIntPtr(void* value);
        public static explicit operator ulong(UIntPtr value);
        public static explicit operator void*(UIntPtr value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class ValueType
    {
        protected ValueType();
        public override bool Equals(object obj);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Version: ICloneable, IComparable, IComparable, IEquatable
    {
        public Version();
        public Version(int major, int minor);
        public Version(int major, int minor, int build);
        public Version(int major, int minor, int build, int revision);
        public Version(string version);
        public int Build { get; }
        public int Major { get; }
        public short MajorRevision { get; }
        public int Minor { get; }
        public short MinorRevision { get; }
        public int Revision { get; }
        public object Clone();
        public int CompareTo(object version);
        public int CompareTo(Version value);
        public override bool Equals(object obj);
        public bool Equals(Version obj);
        public override int GetHashCode();
        public override string ToString();
        public string ToString(int fieldCount);
        public static bool operator ==(Version v1, Version v2);
        public static bool operator !=(Version v1, Version v2);
        public static bool operator >=(Version v1, Version v2);
        public static bool operator <=(Version v1, Version v2);
        public static bool operator >(Version v1, Version v2);
        public static bool operator <(Version v1, Version v2);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Void
    {
    }

    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class WeakReference: ISerializable
    {
        public WeakReference(object target);
        public WeakReference(object target, bool trackResurrection);
        protected WeakReference(SerializationInfo info, StreamingContext context);
        public virtual bool IsAlive { get; }
        public virtual object Target { get; set; }
        public virtual bool TrackResurrection { get; }
        protected override void Finalize();
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum AppDomainManagerInitializationOptions
    {
        None,
        RegisterWithHost,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum AttributeTargets
    {
        All,
        Assembly,
        Class,
        Constructor,
        Delegate,
        Enum,
        Event,
        Field,
        GenericParameter,
        Interface,
        Method,
        Module,
        Parameter,
        Property,
        ReturnValue,
        Struct,
    }

    [FlagsAttribute(..)]
    public enum Base64FormattingOptions
    {
        InsertLineBreaks,
        None,
    }

    [SerializableAttribute(..)]
    public enum ConsoleColor
    {
        Black,
        Blue,
        Cyan,
        DarkBlue,
        DarkCyan,
        DarkGray,
        DarkGreen,
        DarkMagenta,
        DarkRed,
        DarkYellow,
        Gray,
        Green,
        Magenta,
        Red,
        White,
        Yellow,
    }

    [SerializableAttribute(..)]
    public enum ConsoleKey
    {
        A,
        Add,
        Applications,
        Attention,
        B,
        Backspace,
        BackSpace,
        BrowserBack,
        BrowserFavorites,
        BrowserForward,
        BrowserHome,
        BrowserRefresh,
        BrowserSearch,
        BrowserStop,
        C,
        Clear,
        CrSel,
        D,
        D0,
        D1,
        D2,
        D3,
        D4,
        D5,
        D6,
        D7,
        D8,
        D9,
        Decimal,
        Delete,
        Divide,
        DownArrow,
        E,
        End,
        Enter,
        EraseEndOfFile,
        Escape,
        Execute,
        ExSel,
        F,
        F1,
        F10,
        F11,
        F12,
        F13,
        F14,
        F15,
        F16,
        F17,
        F18,
        F19,
        F2,
        F20,
        F21,
        F22,
        F23,
        F24,
        F3,
        F4,
        F5,
        F6,
        F7,
        F8,
        F9,
        G,
        H,
        Help,
        Home,
        I,
        Insert,
        J,
        K,
        L,
        LaunchApp1,
        LaunchApp2,
        LaunchMail,
        LaunchMediaSelect,
        LeftArrow,
        LeftWindows,
        M,
        MediaNext,
        MediaPlay,
        MediaPrevious,
        MediaStop,
        Multiply,
        N,
        NoName,
        NumPad0,
        NumPad1,
        NumPad2,
        NumPad3,
        NumPad4,
        NumPad5,
        NumPad6,
        NumPad7,
        NumPad8,
        NumPad9,
        O,
        Oem1,
        Oem102,
        Oem2,
        Oem3,
        Oem4,
        Oem5,
        Oem6,
        Oem7,
        Oem8,
        OemClear,
        OemComma,
        OemMinus,
        OemPeriod,
        OemPlus,
        P,
        Pa1,
        Packet,
        PageDown,
        PageUp,
        Pause,
        Play,
        Print,
        PrintScreen,
        Process,
        Q,
        R,
        RightArrow,
        RightWindows,
        S,
        Select,
        Separator,
        Sleep,
        Spacebar,
        SpaceBar,
        Subtract,
        T,
        Tab,
        U,
        UpArrow,
        V,
        VolumeDown,
        VolumeMute,
        VolumeUp,
        W,
        X,
        Y,
        Z,
        Zoom,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum ConsoleModifiers
    {
        Alt,
        Control,
        Shift,
    }

    [SerializableAttribute(..)]
    public enum ConsoleSpecialKey
    {
        ControlBreak,
        ControlC,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    [FlagsAttribute(..)]
    public enum ConsoleSpecialKeys
    {
        ControlBreak,
        ControlC,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum DateTimeKind
    {
        Local,
        Unspecified,
        Utc,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum DayOfWeek
    {
        Friday,
        Monday,
        Saturday,
        Sunday,
        Thursday,
        Tuesday,
        Wednesday,
    }

    [ComVisibleAttribute(..)]
    public enum EnvironmentVariableTarget
    {
        Machine,
        Process,
        User,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum LoaderOptimization
    {
        DisallowBindings,
        DomainMask,
        MultiDomain,
        MultiDomainHost,
        NotSpecified,
        SingleDomain,
    }

    [ComVisibleAttribute(..)]
    public enum MidpointRounding
    {
        AwayFromZero,
        ToEven,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PlatformID
    {
        Unix,
        Win32NT,
        Win32S,
        Win32Windows,
        WinCE,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum StringComparison
    {
        CurrentCulture,
        CurrentCultureIgnoreCase,
        InvariantCulture,
        InvariantCultureIgnoreCase,
        Ordinal,
        OrdinalIgnoreCase,
    }

    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum StringSplitOptions
    {
        None,
        RemoveEmptyEntries,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum TypeCode
    {
        Boolean,
        Byte,
        Char,
        DateTime,
        DBNull,
        Decimal,
        Double,
        Empty,
        Int16,
        Int32,
        Int64,
        Object,
        SByte,
        Single,
        String,
        UInt16,
        UInt32,
        UInt64,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Array: ICloneable, IList
    {
        public bool IsFixedSize { get; }
        public bool IsReadOnly { get; }
        public bool IsSynchronized { get; }
        public int Length { get; }
        public long LongLength { get; }
        public int Rank { get; }
        public object SyncRoot { get; }
        public static ReadOnlyCollection<T> AsReadOnly<T>(T[] array);
        public static int BinarySearch(Array array, int index, int length, object value);
        public static int BinarySearch(Array array, int index, int length, object value, IComparer comparer);
        public static int BinarySearch(Array array, object value);
        public static int BinarySearch(Array array, object value, IComparer comparer);
        public static int BinarySearch<T>(T[] array, int index, int length, T value);
        public static int BinarySearch<T>(T[] array, int index, int length, T value, IComparer<T> comparer);
        public static int BinarySearch<T>(T[] array, T value);
        public static int BinarySearch<T>(T[] array, T value, IComparer<T> comparer);
        public static void Clear(Array array, int index, int length);
        public object Clone();
        public static void ConstrainedCopy(Array sourceArray, int sourceIndex, Array destinationArray, int destinationIndex, int length);
        public static TOutput[] ConvertAll<TInput,TOutput>(TInput[] array, Converter<TInput,TOutput> converter);
        public static void Copy(Array sourceArray, Array destinationArray, int length);
        public static void Copy(Array sourceArray, Array destinationArray, long length);
        public static void Copy(Array sourceArray, int sourceIndex, Array destinationArray, int destinationIndex, int length);
        public static void Copy(Array sourceArray, long sourceIndex, Array destinationArray, long destinationIndex, long length);
        public void CopyTo(Array array, int index);
        public void CopyTo(Array array, long index);
        public static Array CreateInstance(Type elementType, int length);
        public static Array CreateInstance(Type elementType, int length1, int length2);
        public static Array CreateInstance(Type elementType, int length1, int length2, int length3);
        public static Array CreateInstance(Type elementType, params int[] lengths);
        public static Array CreateInstance(Type elementType, int[] lengths, int[] lowerBounds);
        public static Array CreateInstance(Type elementType, params long[] lengths);
        public static bool Exists<T>(T[] array, Predicate<T> match);
        public static T Find<T>(T[] array, Predicate<T> match);
        public static T[] FindAll<T>(T[] array, Predicate<T> match);
        public static int FindIndex<T>(T[] array, int startIndex, int count, Predicate<T> match);
        public static int FindIndex<T>(T[] array, int startIndex, Predicate<T> match);
        public static int FindIndex<T>(T[] array, Predicate<T> match);
        public static T FindLast<T>(T[] array, Predicate<T> match);
        public static int FindLastIndex<T>(T[] array, int startIndex, int count, Predicate<T> match);
        public static int FindLastIndex<T>(T[] array, int startIndex, Predicate<T> match);
        public static int FindLastIndex<T>(T[] array, Predicate<T> match);
        public static void ForEach<T>(T[] array, Action<T> action);
        public IEnumerator GetEnumerator();
        public int GetLength(int dimension);
        public long GetLongLength(int dimension);
        public int GetLowerBound(int dimension);
        public int GetUpperBound(int dimension);
        public object GetValue(int index);
        public object GetValue(int index1, int index2);
        public object GetValue(int index1, int index2, int index3);
        public object GetValue(params int[] indices);
        public object GetValue(long index);
        public object GetValue(long index1, long index2);
        public object GetValue(long index1, long index2, long index3);
        public object GetValue(params long[] indices);
        public static int IndexOf(Array array, object value);
        public static int IndexOf(Array array, object value, int startIndex);
        public static int IndexOf(Array array, object value, int startIndex, int count);
        public static int IndexOf<T>(T[] array, T value);
        public static int IndexOf<T>(T[] array, T value, int startIndex);
        public static int IndexOf<T>(T[] array, T value, int startIndex, int count);
        public void Initialize();
        public static int LastIndexOf(Array array, object value);
        public static int LastIndexOf(Array array, object value, int startIndex);
        public static int LastIndexOf(Array array, object value, int startIndex, int count);
        public static int LastIndexOf<T>(T[] array, T value);
        public static int LastIndexOf<T>(T[] array, T value, int startIndex);
        public static int LastIndexOf<T>(T[] array, T value, int startIndex, int count);
        public static void Resize<T>(ref T[] array, int newSize);
        public static void Reverse(Array array);
        public static void Reverse(Array array, int index, int length);
        public void SetValue(object value, int index);
        public void SetValue(object value, int index1, int index2);
        public void SetValue(object value, int index1, int index2, int index3);
        public void SetValue(object value, params int[] indices);
        public void SetValue(object value, long index);
        public void SetValue(object value, long index1, long index2);
        public void SetValue(object value, long index1, long index2, long index3);
        public void SetValue(object value, params long[] indices);
        public static void Sort(Array array);
        public static void Sort(Array keys, Array items);
        public static void Sort(Array keys, Array items, IComparer comparer);
        public static void Sort(Array keys, Array items, int index, int length);
        public static void Sort(Array keys, Array items, int index, int length, IComparer comparer);
        public static void Sort(Array array, IComparer comparer);
        public static void Sort(Array array, int index, int length);
        public static void Sort(Array array, int index, int length, IComparer comparer);
        public static void Sort<T>(T[] array);
        public static void Sort<T>(T[] array, Comparison<T> comparison);
        public static void Sort<T>(T[] array, IComparer<T> comparer);
        public static void Sort<T>(T[] array, int index, int length);
        public static void Sort<T>(T[] array, int index, int length, IComparer<T> comparer);
        public static void Sort<TKey,TValue>(TKey[] keys, TValue[] items);
        public static void Sort<TKey,TValue>(TKey[] keys, TValue[] items, IComparer<TKey> comparer);
        public static void Sort<TKey,TValue>(TKey[] keys, TValue[] items, int index, int length);
        public static void Sort<TKey,TValue>(TKey[] keys, TValue[] items, int index, int length, IComparer<TKey> comparer);
        public static bool TrueForAll<T>(T[] array, Predicate<T> match);
    }

    [SerializableAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class String: ICloneable, IComparable, IComparable, IConvertible, IEnumerable, IEquatable
    {
        public String(char* value);
        public String(char* value, int startIndex, int length);
        public String(char c, int count);
        public String(char[] value);
        public String(char[] value, int startIndex, int length);
        public String(sbyte* value);
        public String(sbyte* value, int startIndex, int length);
        public String(sbyte* value, int startIndex, int length, Encoding enc);
        public static readonly string Empty;
        public int Length { get; }
        public char this[int index] { get; }
        public object Clone();
        public static int Compare(string strA, int indexA, string strB, int indexB, int length);
        public static int Compare(string strA, int indexA, string strB, int indexB, int length, bool ignoreCase);
        public static int Compare(string strA, int indexA, string strB, int indexB, int length, bool ignoreCase, CultureInfo culture);
        public static int Compare(string strA, int indexA, string strB, int indexB, int length, StringComparison comparisonType);
        public static int Compare(string strA, string strB);
        public static int Compare(string strA, string strB, bool ignoreCase);
        public static int Compare(string strA, string strB, bool ignoreCase, CultureInfo culture);
        public static int Compare(string strA, string strB, StringComparison comparisonType);
        public static int CompareOrdinal(string strA, int indexA, string strB, int indexB, int length);
        public static int CompareOrdinal(string strA, string strB);
        public int CompareTo(object value);
        public int CompareTo(string strB);
        public static string Concat(object arg0);
        public static string Concat(object arg0, object arg1);
        public static string Concat(object arg0, object arg1, object arg2);
        public static string Concat(object arg0, object arg1, object arg2, object arg3, __arglist);
        public static string Concat(params object[] args);
        public static string Concat(string str0, string str1);
        public static string Concat(string str0, string str1, string str2);
        public static string Concat(string str0, string str1, string str2, string str3);
        public static string Concat(params string[] values);
        public bool Contains(string value);
        public static string Copy(string str);
        public void CopyTo(int sourceIndex, char[] destination, int destinationIndex, int count);
        public bool EndsWith(string value);
        public bool EndsWith(string value, bool ignoreCase, CultureInfo culture);
        public bool EndsWith(string value, StringComparison comparisonType);
        public override bool Equals(object obj);
        public bool Equals(string value);
        public static bool Equals(string a, string b);
        public static bool Equals(string a, string b, StringComparison comparisonType);
        public bool Equals(string value, StringComparison comparisonType);
        public static string Format(IFormatProvider provider, string format, params object[] args);
        public static string Format(string format, object arg0);
        public static string Format(string format, object arg0, object arg1);
        public static string Format(string format, object arg0, object arg1, object arg2);
        public static string Format(string format, params object[] args);
        public CharEnumerator GetEnumerator();
        public override int GetHashCode();
        public TypeCode GetTypeCode();
        public int IndexOf(char value);
        public int IndexOf(char value, int startIndex);
        public int IndexOf(char value, int startIndex, int count);
        public int IndexOf(string value);
        public int IndexOf(string value, int startIndex);
        public int IndexOf(string value, int startIndex, int count);
        public int IndexOfAny(char[] anyOf);
        public int IndexOfAny(char[] anyOf, int startIndex);
        public int IndexOfAny(char[] anyOf, int startIndex, int count);
        public string Insert(int startIndex, string value);
        public static string Intern(string str);
        public static string IsInterned(string str);
        public bool IsNormalized();
        public bool IsNormalized(NormalizationForm normalizationForm);
        public static bool IsNullOrEmpty(string value);
        public static string Join(string separator, string[] value);
        public static string Join(string separator, string[] value, int startIndex, int count);
        public int LastIndexOf(char value);
        public int LastIndexOf(char value, int startIndex);
        public int LastIndexOf(char value, int startIndex, int count);
        public int LastIndexOf(string value);
        public int LastIndexOf(string value, int startIndex);
        public int LastIndexOf(string value, int startIndex, int count);
        public int LastIndexOfAny(char[] anyOf);
        public int LastIndexOfAny(char[] anyOf, int startIndex);
        public int LastIndexOfAny(char[] anyOf, int startIndex, int count);
        public string Normalize();
        public string Normalize(NormalizationForm normalizationForm);
        public string PadLeft(int totalWidth);
        public string PadLeft(int totalWidth, char paddingChar);
        public string PadRight(int totalWidth);
        public string PadRight(int totalWidth, char paddingChar);
        public string Remove(int startIndex);
        public string Remove(int startIndex, int count);
        public string Replace(char oldChar, char newChar);
        public string Replace(string oldValue, string newValue);
        public string[] Split(params char[] separator);
        public string[] Split(char[] separator, bool omitEmptyEntries);
        public string[] Split(char[] separator, int count);
        public string[] Split(char[] separator, int count, bool omitEmptyEntries);
        public string[] Split(char[] separator, int count, StringSplitOptions options);
        public string[] Split(char[] separator, StringSplitOptions options);
        public string[] Split(string[] separator, bool omitEmptyEntries);
        public string[] Split(string[] separator, int count, bool omitEmptyEntries);
        public string[] Split(string[] separator, int count, StringSplitOptions options);
        public string[] Split(string[] separator, StringSplitOptions options);
        public bool StartsWith(string value);
        public bool StartsWith(string value, bool ignoreCase, CultureInfo culture);
        public bool StartsWith(string value, StringComparison comparisonType);
        public string Substring(int startIndex);
        public string Substring(int startIndex, int length);
        public char[] ToCharArray();
        public char[] ToCharArray(int startIndex, int length);
        public string ToLower();
        public string ToLower(CultureInfo culture);
        public string ToLowerInvariant();
        public override string ToString();
        public string ToString(IFormatProvider provider);
        public string ToUpper();
        public string ToUpper(CultureInfo culture);
        public string ToUpperInvariant();
        public string Trim();
        public string Trim(params char[] trimChars);
        public string TrimEnd(params char[] trimChars);
        public string TrimStart(params char[] trimChars);
        public static bool operator ==(string a, string b);
        public static bool operator !=(string a, string b);
    }

    public delegate void Action<T>(T obj);

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate void AppDomainInitializer(string[] args);

    [ComVisibleAttribute(..)]
    public class AssemblyLoadEventArgs: EventArgs
    {
        public AssemblyLoadEventArgs(Assembly loadedAssembly);
        public Assembly LoadedAssembly { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate void AssemblyLoadEventHandler(object sender, AssemblyLoadEventArgs args);

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate void AsyncCallback(IAsyncResult ar);

    public delegate int Comparison<T>(T x, T y);

    [SerializableAttribute(..)]
    public sealed class ConsoleCancelEventArgs: EventArgs
    {
        public bool Cancel { get; set; }
        public ConsoleSpecialKey SpecialKey { get; }
        public ConsoleSpecialKeys SpecialKeys { get; }
    }

    public delegate void ConsoleCancelEventHandler(object sender, ConsoleCancelEventArgs e);

    public delegate TOutput Converter<TInput,TOutput>(TInput input);

    [ComVisibleAttribute(..)]
    public delegate void CrossAppDomainDelegate();

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate void EventHandler(object sender, EventArgs e);

    [SerializableAttribute(..)]
    public delegate void EventHandler<TEventArgs>(object sender, TEventArgs e) where TEventArgs:EventArgs;

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class MulticastDelegate: Delegate, ICloneable, ISerializable
    {
        protected MulticastDelegate(object target, string method);
        protected MulticastDelegate(Type target, string method);
        protected sealed override Delegate CombineImpl(Delegate follow);
        public sealed override bool Equals(object obj);
        public sealed override int GetHashCode();
        public sealed override Delegate[] GetInvocationList();
        protected override MethodInfo GetMethodImpl();
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
        protected sealed override Delegate RemoveImpl(Delegate value);
        public static bool operator ==(MulticastDelegate d1, MulticastDelegate d2);
        public static bool operator !=(MulticastDelegate d1, MulticastDelegate d2);
    }

    public delegate bool Predicate<T>(T obj);

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate void ProvideAssemblyEvidenceEventHandler(object sender, ProvideAssemblyEvidenceEventArgs e);

    [ComVisibleAttribute(..)]
    public class ResolveEventArgs: EventArgs
    {
        public ResolveEventArgs(string name);
        public string Name { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate Assembly ResolveEventHandler(object sender, ResolveEventArgs args);

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class UnhandledExceptionEventArgs: EventArgs
    {
        public UnhandledExceptionEventArgs(object exception, bool isTerminating);
        public object ExceptionObject { get; }
        public bool IsTerminating { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate void UnhandledExceptionEventHandler(object sender, UnhandledExceptionEventArgs e);

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AttributeUsageAttribute: Attribute, _Attribute
    {
        public AttributeUsageAttribute(AttributeTargets validOn);
        public bool AllowMultiple { get; set; }
        public bool Inherited { get; set; }
        public AttributeTargets ValidOn { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class CLSCompliantAttribute: Attribute, _Attribute
    {
        public CLSCompliantAttribute(bool isCompliant);
        public bool IsCompliant { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ContextStaticAttribute: Attribute, _Attribute
    {
        public ContextStaticAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class FlagsAttribute: Attribute, _Attribute
    {
        public FlagsAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class LoaderOptimizationAttribute: Attribute, _Attribute
    {
        public LoaderOptimizationAttribute(byte value);
        public LoaderOptimizationAttribute(LoaderOptimization value);
        public LoaderOptimization Value { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class MTAThreadAttribute: Attribute, _Attribute
    {
        public MTAThreadAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class NonSerializedAttribute: Attribute, _Attribute
    {
        public NonSerializedAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class ObsoleteAttribute: Attribute, _Attribute
    {
        public ObsoleteAttribute();
        public ObsoleteAttribute(string message);
        public ObsoleteAttribute(string message, bool error);
        public bool IsError { get; }
        public string Message { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ParamArrayAttribute: Attribute, _Attribute
    {
        public ParamArrayAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class SerializableAttribute: Attribute, _Attribute
    {
        public SerializableAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class STAThreadAttribute: Attribute, _Attribute
    {
        public STAThreadAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class ThreadStaticAttribute: Attribute, _Attribute
    {
        public ThreadStaticAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class AccessViolationException: SystemException, _Exception, ISerializable
    {
        public AccessViolationException();
        protected AccessViolationException(SerializationInfo info, StreamingContext context);
        public AccessViolationException(string message);
        public AccessViolationException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class AppDomainUnloadedException: SystemException, _Exception, ISerializable
    {
        public AppDomainUnloadedException();
        protected AppDomainUnloadedException(SerializationInfo info, StreamingContext context);
        public AppDomainUnloadedException(string message);
        public AppDomainUnloadedException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ApplicationException: Exception, _Exception, ISerializable
    {
        public ApplicationException();
        protected ApplicationException(SerializationInfo info, StreamingContext context);
        public ApplicationException(string message);
        public ApplicationException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ArgumentException: SystemException, _Exception, ISerializable
    {
        public ArgumentException();
        protected ArgumentException(SerializationInfo info, StreamingContext context);
        public ArgumentException(string message);
        public ArgumentException(string message, Exception innerException);
        public ArgumentException(string message, string paramName);
        public ArgumentException(string message, string paramName, Exception innerException);
        public virtual string ParamName { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ArgumentNullException: ArgumentException, _Exception, ISerializable
    {
        public ArgumentNullException();
        protected ArgumentNullException(SerializationInfo info, StreamingContext context);
        public ArgumentNullException(string paramName);
        public ArgumentNullException(string message, Exception innerException);
        public ArgumentNullException(string paramName, string message);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ArgumentOutOfRangeException: ArgumentException, _Exception, ISerializable
    {
        public ArgumentOutOfRangeException();
        protected ArgumentOutOfRangeException(SerializationInfo info, StreamingContext context);
        public ArgumentOutOfRangeException(string paramName);
        public ArgumentOutOfRangeException(string message, Exception innerException);
        public ArgumentOutOfRangeException(string paramName, object actualValue, string message);
        public ArgumentOutOfRangeException(string paramName, string message);
        public virtual object ActualValue { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ArithmeticException: SystemException, _Exception, ISerializable
    {
        public ArithmeticException();
        protected ArithmeticException(SerializationInfo info, StreamingContext context);
        public ArithmeticException(string message);
        public ArithmeticException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ArrayTypeMismatchException: SystemException, _Exception, ISerializable
    {
        public ArrayTypeMismatchException();
        protected ArrayTypeMismatchException(SerializationInfo info, StreamingContext context);
        public ArrayTypeMismatchException(string message);
        public ArrayTypeMismatchException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class BadImageFormatException: SystemException, _Exception, ISerializable
    {
        public BadImageFormatException();
        protected BadImageFormatException(SerializationInfo info, StreamingContext context);
        public BadImageFormatException(string message);
        public BadImageFormatException(string message, Exception inner);
        public BadImageFormatException(string message, string fileName);
        public BadImageFormatException(string message, string fileName, Exception inner);
        public string FileName { get; }
        public string FusionLog { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CannotUnloadAppDomainException: SystemException, _Exception, ISerializable
    {
        public CannotUnloadAppDomainException();
        protected CannotUnloadAppDomainException(SerializationInfo info, StreamingContext context);
        public CannotUnloadAppDomainException(string message);
        public CannotUnloadAppDomainException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public class ContextMarshalException: SystemException, _Exception, ISerializable
    {
        public ContextMarshalException();
        protected ContextMarshalException(SerializationInfo info, StreamingContext context);
        public ContextMarshalException(string message);
        public ContextMarshalException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DataMisalignedException: SystemException, _Exception, ISerializable
    {
        public DataMisalignedException();
        public DataMisalignedException(string message);
        public DataMisalignedException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class DivideByZeroException: ArithmeticException, _Exception, ISerializable
    {
        public DivideByZeroException();
        protected DivideByZeroException(SerializationInfo info, StreamingContext context);
        public DivideByZeroException(string message);
        public DivideByZeroException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class DllNotFoundException: TypeLoadException, _Exception, ISerializable
    {
        public DllNotFoundException();
        protected DllNotFoundException(SerializationInfo info, StreamingContext context);
        public DllNotFoundException(string message);
        public DllNotFoundException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class DuplicateWaitObjectException: ArgumentException, _Exception, ISerializable
    {
        public DuplicateWaitObjectException();
        protected DuplicateWaitObjectException(SerializationInfo info, StreamingContext context);
        public DuplicateWaitObjectException(string parameterName);
        public DuplicateWaitObjectException(string message, Exception innerException);
        public DuplicateWaitObjectException(string parameterName, string message);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class EntryPointNotFoundException: TypeLoadException, _Exception, ISerializable
    {
        public EntryPointNotFoundException();
        protected EntryPointNotFoundException(SerializationInfo info, StreamingContext context);
        public EntryPointNotFoundException(string message);
        public EntryPointNotFoundException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ExecutionEngineException: SystemException, _Exception, ISerializable
    {
        public ExecutionEngineException();
        public ExecutionEngineException(string message);
        public ExecutionEngineException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class FieldAccessException: MemberAccessException, _Exception, ISerializable
    {
        public FieldAccessException();
        protected FieldAccessException(SerializationInfo info, StreamingContext context);
        public FieldAccessException(string message);
        public FieldAccessException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class FormatException: SystemException, _Exception, ISerializable
    {
        public FormatException();
        protected FormatException(SerializationInfo info, StreamingContext context);
        public FormatException(string message);
        public FormatException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class IndexOutOfRangeException: SystemException, _Exception, ISerializable
    {
        public IndexOutOfRangeException();
        public IndexOutOfRangeException(string message);
        public IndexOutOfRangeException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    public sealed class InsufficientMemoryException: OutOfMemoryException, _Exception, ISerializable
    {
        public InsufficientMemoryException();
        public InsufficientMemoryException(string message);
        public InsufficientMemoryException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class InvalidCastException: SystemException, _Exception, ISerializable
    {
        public InvalidCastException();
        protected InvalidCastException(SerializationInfo info, StreamingContext context);
        public InvalidCastException(string message);
        public InvalidCastException(string message, Exception innerException);
        public InvalidCastException(string message, int errorCode);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class InvalidOperationException: SystemException, _Exception, ISerializable
    {
        public InvalidOperationException();
        protected InvalidOperationException(SerializationInfo info, StreamingContext context);
        public InvalidOperationException(string message);
        public InvalidOperationException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class InvalidProgramException: SystemException, _Exception, ISerializable
    {
        public InvalidProgramException();
        public InvalidProgramException(string message);
        public InvalidProgramException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MemberAccessException: SystemException, _Exception, ISerializable
    {
        public MemberAccessException();
        protected MemberAccessException(SerializationInfo info, StreamingContext context);
        public MemberAccessException(string message);
        public MemberAccessException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MethodAccessException: MemberAccessException, _Exception, ISerializable
    {
        public MethodAccessException();
        protected MethodAccessException(SerializationInfo info, StreamingContext context);
        public MethodAccessException(string message);
        public MethodAccessException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MissingFieldException: MissingMemberException, _Exception, ISerializable
    {
        public MissingFieldException();
        protected MissingFieldException(SerializationInfo info, StreamingContext context);
        public MissingFieldException(string message);
        public MissingFieldException(string message, Exception inner);
        public MissingFieldException(string className, string fieldName);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MissingMemberException: MemberAccessException, _Exception, ISerializable
    {
        public MissingMemberException();
        protected MissingMemberException(SerializationInfo info, StreamingContext context);
        public MissingMemberException(string message);
        public MissingMemberException(string message, Exception inner);
        public MissingMemberException(string className, string memberName);
        protected string ClassName;
        protected string MemberName;
        protected byte[] Signature;
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MissingMethodException: MissingMemberException, _Exception, ISerializable
    {
        public MissingMethodException();
        protected MissingMethodException(SerializationInfo info, StreamingContext context);
        public MissingMethodException(string message);
        public MissingMethodException(string message, Exception inner);
        public MissingMethodException(string className, string methodName);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class MulticastNotSupportedException: SystemException, _Exception, ISerializable
    {
        public MulticastNotSupportedException();
        public MulticastNotSupportedException(string message);
        public MulticastNotSupportedException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    [ComVisibleAttribute(..)]
    public class NotCancelableException: SystemException, _Exception, ISerializable
    {
        public NotCancelableException();
        protected NotCancelableException(SerializationInfo info, StreamingContext context);
        public NotCancelableException(string message);
        public NotCancelableException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class NotFiniteNumberException: ArithmeticException, _Exception, ISerializable
    {
        public NotFiniteNumberException();
        public NotFiniteNumberException(double offendingNumber);
        protected NotFiniteNumberException(SerializationInfo info, StreamingContext context);
        public NotFiniteNumberException(string message);
        public NotFiniteNumberException(string message, double offendingNumber);
        public NotFiniteNumberException(string message, double offendingNumber, Exception innerException);
        public NotFiniteNumberException(string message, Exception innerException);
        public double OffendingNumber { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class NotImplementedException: SystemException, _Exception, ISerializable
    {
        public NotImplementedException();
        protected NotImplementedException(SerializationInfo info, StreamingContext context);
        public NotImplementedException(string message);
        public NotImplementedException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class NotSupportedException: SystemException, _Exception, ISerializable
    {
        public NotSupportedException();
        protected NotSupportedException(SerializationInfo info, StreamingContext context);
        public NotSupportedException(string message);
        public NotSupportedException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class NullReferenceException: SystemException, _Exception, ISerializable
    {
        public NullReferenceException();
        protected NullReferenceException(SerializationInfo info, StreamingContext context);
        public NullReferenceException(string message);
        public NullReferenceException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ObjectDisposedException: InvalidOperationException, _Exception, ISerializable
    {
        protected ObjectDisposedException(SerializationInfo info, StreamingContext context);
        public ObjectDisposedException(string objectName);
        public ObjectDisposedException(string message, Exception innerException);
        public ObjectDisposedException(string objectName, string message);
        public string ObjectName { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class OperationCanceledException: SystemException, _Exception, ISerializable
    {
        public OperationCanceledException();
        protected OperationCanceledException(SerializationInfo info, StreamingContext context);
        public OperationCanceledException(string message);
        public OperationCanceledException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class OutOfMemoryException: SystemException, _Exception, ISerializable
    {
        public OutOfMemoryException();
        protected OutOfMemoryException(SerializationInfo info, StreamingContext context);
        public OutOfMemoryException(string message);
        public OutOfMemoryException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class OverflowException: ArithmeticException, _Exception, ISerializable
    {
        public OverflowException();
        protected OverflowException(SerializationInfo info, StreamingContext context);
        public OverflowException(string message);
        public OverflowException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class PlatformNotSupportedException: NotSupportedException, _Exception, ISerializable
    {
        public PlatformNotSupportedException();
        protected PlatformNotSupportedException(SerializationInfo info, StreamingContext context);
        public PlatformNotSupportedException(string message);
        public PlatformNotSupportedException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class RankException: SystemException, _Exception, ISerializable
    {
        public RankException();
        protected RankException(SerializationInfo info, StreamingContext context);
        public RankException(string message);
        public RankException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class StackOverflowException: SystemException, _Exception, ISerializable
    {
        public StackOverflowException();
        public StackOverflowException(string message);
        public StackOverflowException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SystemException: Exception, _Exception, ISerializable
    {
        public SystemException();
        protected SystemException(SerializationInfo info, StreamingContext context);
        public SystemException(string message);
        public SystemException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TimeoutException: SystemException, _Exception, ISerializable
    {
        public TimeoutException();
        protected TimeoutException(SerializationInfo info, StreamingContext context);
        public TimeoutException(string message);
        public TimeoutException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class TypeInitializationException: SystemException, _Exception, ISerializable
    {
        public TypeInitializationException(string fullTypeName, Exception innerException);
        public string TypeName { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TypeLoadException: SystemException, _Exception, ISerializable
    {
        public TypeLoadException();
        protected TypeLoadException(SerializationInfo info, StreamingContext context);
        public TypeLoadException(string message);
        public TypeLoadException(string message, Exception inner);
        public string TypeName { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TypeUnloadedException: SystemException, _Exception, ISerializable
    {
        public TypeUnloadedException();
        protected TypeUnloadedException(SerializationInfo info, StreamingContext context);
        public TypeUnloadedException(string message);
        public TypeUnloadedException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class UnauthorizedAccessException: SystemException, _Exception, ISerializable
    {
        public UnauthorizedAccessException();
        protected UnauthorizedAccessException(SerializationInfo info, StreamingContext context);
        public UnauthorizedAccessException(string message);
        public UnauthorizedAccessException(string message, Exception inner);
    }

} 
namespace System.Collections
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CaseInsensitiveComparer: IComparer
    {
        public CaseInsensitiveComparer();
        public CaseInsensitiveComparer(CultureInfo culture);
        public static CaseInsensitiveComparer Default { get; }
        public static CaseInsensitiveComparer DefaultInvariant { get; }
        public int Compare(object a, object b);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public class CaseInsensitiveHashCodeProvider: IHashCodeProvider
    {
        public CaseInsensitiveHashCodeProvider();
        public CaseInsensitiveHashCodeProvider(CultureInfo culture);
        public static CaseInsensitiveHashCodeProvider Default { get; }
        public static CaseInsensitiveHashCodeProvider DefaultInvariant { get; }
        public int GetHashCode(object obj);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Comparer: IComparer, ISerializable
    {
        public Comparer(CultureInfo culture);
        public static readonly Comparer Default;
        public static readonly Comparer DefaultInvariant;
        public int Compare(object a, object b);
        public void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct DictionaryEntry
    {
        public DictionaryEntry(object key, object value);
        public object Key { get; set; }
        public object Value { get; set; }
    }

    [ComVisibleAttribute(..)]
    public interface IComparer
    {
        public int Compare(object x, object y);
    }

    [ComVisibleAttribute(..)]
    public interface IDictionaryEnumerator: IEnumerator
    {
        public DictionaryEntry Entry { get; }
        public object Key { get; }
        public object Value { get; }
    }

    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface IEnumerator
    {
        public object Current { get; }
        public bool MoveNext();
        public void Reset();
    }

    [ComVisibleAttribute(..)]
    public interface IEqualityComparer
    {
        public bool Equals(object x, object y);
        public int GetHashCode(object obj);
    }

    [ObsoleteAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface IHashCodeProvider
    {
        public int GetHashCode(object obj);
    }

    [SerializableAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    public class ArrayList: ICloneable, IList
    {
        public ArrayList();
        public ArrayList(ICollection c);
        public ArrayList(int capacity);
        public virtual int Capacity { get; set; }
        public virtual int Count { get; }
        public virtual bool IsFixedSize { get; }
        public virtual bool IsReadOnly { get; }
        public virtual bool IsSynchronized { get; }
        public virtual object SyncRoot { get; }
        public virtual object this[int index] { get; set; }
        public static ArrayList Adapter(IList list);
        public virtual int Add(object value);
        public virtual void AddRange(ICollection c);
        public virtual int BinarySearch(int index, int count, object value, IComparer comparer);
        public virtual int BinarySearch(object value);
        public virtual int BinarySearch(object value, IComparer comparer);
        public virtual void Clear();
        public virtual object Clone();
        public virtual bool Contains(object item);
        public virtual void CopyTo(Array array);
        public virtual void CopyTo(Array array, int arrayIndex);
        public virtual void CopyTo(int index, Array array, int arrayIndex, int count);
        public static ArrayList FixedSize(ArrayList list);
        public static IList FixedSize(IList list);
        public virtual IEnumerator GetEnumerator();
        public virtual IEnumerator GetEnumerator(int index, int count);
        public virtual ArrayList GetRange(int index, int count);
        public virtual int IndexOf(object value);
        public virtual int IndexOf(object value, int startIndex);
        public virtual int IndexOf(object value, int startIndex, int count);
        public virtual void Insert(int index, object value);
        public virtual void InsertRange(int index, ICollection c);
        public virtual int LastIndexOf(object value);
        public virtual int LastIndexOf(object value, int startIndex);
        public virtual int LastIndexOf(object value, int startIndex, int count);
        public static ArrayList ReadOnly(ArrayList list);
        public static IList ReadOnly(IList list);
        public virtual void Remove(object obj);
        public virtual void RemoveAt(int index);
        public virtual void RemoveRange(int index, int count);
        public static ArrayList Repeat(object value, int count);
        public virtual void Reverse();
        public virtual void Reverse(int index, int count);
        public virtual void SetRange(int index, ICollection c);
        public virtual void Sort();
        public virtual void Sort(IComparer comparer);
        public virtual void Sort(int index, int count, IComparer comparer);
        public static ArrayList Synchronized(ArrayList list);
        public static IList Synchronized(IList list);
        public virtual object[] ToArray();
        public virtual Array ToArray(Type type);
        public virtual void TrimToSize();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public sealed class BitArray: ICloneable, ICollection
    {
        public BitArray(BitArray bits);
        public BitArray(bool[] values);
        public BitArray(byte[] bytes);
        public BitArray(int length);
        public BitArray(int length, bool defaultValue);
        public BitArray(int[] values);
        public int Count { get; }
        public bool IsReadOnly { get; }
        public bool IsSynchronized { get; }
        public int Length { get; set; }
        public object SyncRoot { get; }
        public bool this[int index] { get; set; }
        public BitArray And(BitArray value);
        public object Clone();
        public void CopyTo(Array array, int index);
        public bool Get(int index);
        public IEnumerator GetEnumerator();
        public BitArray Not();
        public BitArray Or(BitArray value);
        public void Set(int index, bool value);
        public void SetAll(bool value);
        public BitArray Xor(BitArray value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class CollectionBase: IList
    {
        protected CollectionBase();
        protected CollectionBase(int capacity);
        public int Capacity { get; set; }
        public int Count { get; }
        public void Clear();
        public IEnumerator GetEnumerator();
        protected virtual void OnClear();
        protected virtual void OnClearComplete();
        protected virtual void OnInsert(int index, object value);
        protected virtual void OnInsertComplete(int index, object value);
        protected virtual void OnRemove(int index, object value);
        protected virtual void OnRemoveComplete(int index, object value);
        protected virtual void OnSet(int index, object oldValue, object newValue);
        protected virtual void OnSetComplete(int index, object oldValue, object newValue);
        protected virtual void OnValidate(object value);
        public void RemoveAt(int index);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class DictionaryBase: IDictionary
    {
        protected DictionaryBase();
        public int Count { get; }
        public void Clear();
        public void CopyTo(Array array, int index);
        public IDictionaryEnumerator GetEnumerator();
        protected virtual void OnClear();
        protected virtual void OnClearComplete();
        protected virtual object OnGet(object key, object currentValue);
        protected virtual void OnInsert(object key, object value);
        protected virtual void OnInsertComplete(object key, object value);
        protected virtual void OnRemove(object key, object value);
        protected virtual void OnRemoveComplete(object key, object value);
        protected virtual void OnSet(object key, object oldValue, object newValue);
        protected virtual void OnSetComplete(object key, object oldValue, object newValue);
        protected virtual void OnValidate(object key, object value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    [DefaultMemberAttribute(..)]
    public class Hashtable: ICloneable, IDeserializationCallback, IDictionary, ISerializable
    {
        public Hashtable();
        public Hashtable(IDictionary d);
        public Hashtable(IDictionary d, float loadFactor);
        public Hashtable(IDictionary d, float loadFactor, IEqualityComparer equalityComparer);
        public Hashtable(IDictionary d, float loadFactor, IHashCodeProvider hcp, IComparer comparer);
        public Hashtable(IDictionary d, IEqualityComparer equalityComparer);
        public Hashtable(IDictionary d, IHashCodeProvider hcp, IComparer comparer);
        public Hashtable(IEqualityComparer equalityComparer);
        public Hashtable(IHashCodeProvider hcp, IComparer comparer);
        public Hashtable(int capacity);
        public Hashtable(int capacity, float loadFactor);
        public Hashtable(int capacity, float loadFactor, IEqualityComparer equalityComparer);
        public Hashtable(int capacity, float loadFactor, IHashCodeProvider hcp, IComparer comparer);
        public Hashtable(int capacity, IEqualityComparer equalityComparer);
        public Hashtable(int capacity, IHashCodeProvider hcp, IComparer comparer);
        protected Hashtable(SerializationInfo info, StreamingContext context);
        public virtual int Count { get; }
        public virtual bool IsFixedSize { get; }
        public virtual bool IsReadOnly { get; }
        public virtual bool IsSynchronized { get; }
        public virtual ICollection Keys { get; }
        public virtual object SyncRoot { get; }
        public virtual ICollection Values { get; }
        public virtual object this[object key] { get; set; }
        public virtual void Add(object key, object value);
        public virtual void Clear();
        public virtual object Clone();
        public virtual bool Contains(object key);
        public virtual bool ContainsKey(object key);
        public virtual bool ContainsValue(object value);
        public virtual void CopyTo(Array array, int arrayIndex);
        public virtual IDictionaryEnumerator GetEnumerator();
        protected virtual int GetHash(object key);
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        protected virtual bool KeyEquals(object item, object key);
        public virtual void OnDeserialization(object sender);
        public virtual void Remove(object key);
        public static Hashtable Synchronized(Hashtable table);
    }

    [ComVisibleAttribute(..)]
    public interface ICollection: IEnumerable
    {
        public int Count { get; }
        public bool IsSynchronized { get; }
        public object SyncRoot { get; }
        public void CopyTo(Array array, int index);
    }

    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public interface IDictionary: ICollection
    {
        public bool IsFixedSize { get; }
        public bool IsReadOnly { get; }
        public ICollection Keys { get; }
        public ICollection Values { get; }
        public object this[object key] { get; set; }
        public void Add(object key, object value);
        public void Clear();
        public bool Contains(object key);
        public IDictionaryEnumerator GetEnumerator();
        public void Remove(object key);
    }

    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface IEnumerable
    {
        public IEnumerator GetEnumerator();
    }

    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public interface IList: ICollection
    {
        public bool IsFixedSize { get; }
        public bool IsReadOnly { get; }
        public object this[int index] { get; set; }
        public int Add(object value);
        public void Clear();
        public bool Contains(object value);
        public int IndexOf(object value);
        public void Insert(int index, object value);
        public void Remove(object value);
        public void RemoveAt(int index);
    }

    [SerializableAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [ComVisibleAttribute(..)]
    public class Queue: ICloneable, ICollection
    {
        public Queue();
        public Queue(ICollection col);
        public Queue(int capacity);
        public Queue(int capacity, float growFactor);
        public virtual int Count { get; }
        public virtual bool IsSynchronized { get; }
        public virtual object SyncRoot { get; }
        public virtual void Clear();
        public virtual object Clone();
        public virtual bool Contains(object obj);
        public virtual void CopyTo(Array array, int index);
        public virtual object Dequeue();
        public virtual void Enqueue(object obj);
        public virtual IEnumerator GetEnumerator();
        public virtual object Peek();
        public static Queue Synchronized(Queue queue);
        public virtual object[] ToArray();
        public virtual void TrimToSize();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class ReadOnlyCollectionBase: ICollection
    {
        protected ReadOnlyCollectionBase();
        public virtual int Count { get; }
        public virtual IEnumerator GetEnumerator();
    }

    [SerializableAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    [DefaultMemberAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SortedList: ICloneable, IDictionary
    {
        public SortedList();
        public SortedList(IComparer comparer);
        public SortedList(IComparer comparer, int capacity);
        public SortedList(IDictionary d);
        public SortedList(IDictionary d, IComparer comparer);
        public SortedList(int initialCapacity);
        public virtual int Capacity { get; set; }
        public virtual int Count { get; }
        public virtual bool IsFixedSize { get; }
        public virtual bool IsReadOnly { get; }
        public virtual bool IsSynchronized { get; }
        public virtual ICollection Keys { get; }
        public virtual object SyncRoot { get; }
        public virtual ICollection Values { get; }
        public virtual object this[object key] { get; set; }
        public virtual void Add(object key, object value);
        public virtual void Clear();
        public virtual object Clone();
        public virtual bool Contains(object key);
        public virtual bool ContainsKey(object key);
        public virtual bool ContainsValue(object value);
        public virtual void CopyTo(Array array, int arrayIndex);
        public virtual object GetByIndex(int index);
        public virtual IDictionaryEnumerator GetEnumerator();
        public virtual object GetKey(int index);
        public virtual IList GetKeyList();
        public virtual IList GetValueList();
        public virtual int IndexOfKey(object key);
        public virtual int IndexOfValue(object value);
        public virtual void Remove(object key);
        public virtual void RemoveAt(int index);
        public virtual void SetByIndex(int index, object value);
        public static SortedList Synchronized(SortedList list);
        public virtual void TrimToSize();
    }

    [SerializableAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [ComVisibleAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    public class Stack: ICloneable, ICollection
    {
        public Stack();
        public Stack(ICollection col);
        public Stack(int initialCapacity);
        public virtual int Count { get; }
        public virtual bool IsSynchronized { get; }
        public virtual object SyncRoot { get; }
        public virtual void Clear();
        public virtual object Clone();
        public virtual bool Contains(object obj);
        public virtual void CopyTo(Array array, int index);
        public virtual IEnumerator GetEnumerator();
        public virtual object Peek();
        public virtual object Pop();
        public virtual void Push(object obj);
        public static Stack Synchronized(Stack stack);
        public virtual object[] ToArray();
    }

} 
namespace System.Collections.Generic
{
    [SerializableAttribute(..)]
    [TypeDependencyAttribute(..)]
    public abstract class Comparer<T>: IComparer, IComparer
    {
        protected Comparer();
        public static Comparer<T> Default { get; }
        public abstract int Compare(T x, T y);
    }

    [SerializableAttribute(..)]
    [TypeDependencyAttribute(..)]
    public abstract class EqualityComparer<T>: IEqualityComparer, IEqualityComparer
    {
        protected EqualityComparer();
        public static EqualityComparer<T> Default { get; }
        public abstract bool Equals(T x, T y);
        public abstract int GetHashCode(T obj);
    }

    public interface IComparer<T>
    {
        public int Compare(T x, T y);
    }

    public interface IEnumerator<T>: IDisposable, IEnumerator
    {
        public T Current { get; }
    }

    public interface IEqualityComparer<T>
    {
        public bool Equals(T x, T y);
        public int GetHashCode(T obj);
    }

    [SerializableAttribute(..)]
    public struct KeyValuePair<TKey,TValue>
    {
        public KeyValuePair(TKey key, TValue value);
        public TKey Key;
        public TValue Value;
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    public class Dictionary<TKey,TValue>: IDeserializationCallback, IDictionary, IDictionary, ISerializable
    {
        public Dictionary();
        public Dictionary(IDictionary<TKey,TValue> dictionary);
        public Dictionary(IDictionary<TKey,TValue> dictionary, IEqualityComparer<TKey> comparer);
        public Dictionary(IEqualityComparer<TKey> comparer);
        public Dictionary(int capacity);
        public Dictionary(int capacity, IEqualityComparer<TKey> comparer);
        protected Dictionary(SerializationInfo info, StreamingContext context);
        public IEqualityComparer<TKey> Comparer { get; }
        public int Count { get; }
        public KeyCollection<TKey,TValue> Keys { get; }
        public ValueCollection<TKey,TValue> Values { get; }
        public TValue this[TKey key] { get; set; }
        public void Add(TKey key, TValue value);
        public void Clear();
        public bool ContainsKey(TKey key);
        public bool ContainsValue(TValue value);
        public Enumerator<TKey,TValue> GetEnumerator();
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public virtual void OnDeserialization(object sender);
        public bool Remove(TKey key);
        public bool TryGetValue(TKey key, ref TValue value);
    }

    public interface ICollection<T>: IEnumerable
    {
        public int Count { get; }
        public bool IsReadOnly { get; }
        public void Add(T item);
        public void Clear();
        public bool Contains(T item);
        public void CopyTo(T[] array, int arrayIndex);
        public bool Remove(T item);
    }

    [DefaultMemberAttribute(..)]
    public interface IDictionary<TKey,TValue>: ICollection
    {
        public ICollection<TKey> Keys { get; }
        public ICollection<TValue> Values { get; }
        public TValue this[TKey key] { get; set; }
        public void Add(TKey key, TValue value);
        public bool ContainsKey(TKey key);
        public bool Remove(TKey key);
        public bool TryGetValue(TKey key, ref TValue value);
    }

    public interface IEnumerable<T>: IEnumerable
    {
        public IEnumerator<T> GetEnumerator();
    }

    [DefaultMemberAttribute(..)]
    public interface IList<T>: ICollection
    {
        public T this[int index] { get; set; }
        public int IndexOf(T item);
        public void Insert(int index, T item);
        public void RemoveAt(int index);
    }

    [SerializableAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [DefaultMemberAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    public class List<T>: IList, IList
    {
        public List();
        public List(IEnumerable<T> collection);
        public List(int capacity);
        public int Capacity { get; set; }
        public int Count { get; }
        public T this[int index] { get; set; }
        public void Add(T item);
        public void AddRange(IEnumerable<T> collection);
        public ReadOnlyCollection<T> AsReadOnly();
        public int BinarySearch(int index, int count, T item, IComparer<T> comparer);
        public int BinarySearch(T item);
        public int BinarySearch(T item, IComparer<T> comparer);
        public void Clear();
        public bool Contains(T item);
        public List<TOutput> ConvertAll<TOutput>(Converter<T,TOutput> converter);
        public void CopyTo(int index, T[] array, int arrayIndex, int count);
        public void CopyTo(T[] array);
        public void CopyTo(T[] array, int arrayIndex);
        public bool Exists(Predicate<T> match);
        public T Find(Predicate<T> match);
        public List<T> FindAll(Predicate<T> match);
        public int FindIndex(int startIndex, int count, Predicate<T> match);
        public int FindIndex(int startIndex, Predicate<T> match);
        public int FindIndex(Predicate<T> match);
        public T FindLast(Predicate<T> match);
        public int FindLastIndex(int startIndex, int count, Predicate<T> match);
        public int FindLastIndex(int startIndex, Predicate<T> match);
        public int FindLastIndex(Predicate<T> match);
        public void ForEach(Action<T> action);
        public Enumerator<T> GetEnumerator();
        public List<T> GetRange(int index, int count);
        public int IndexOf(T item);
        public int IndexOf(T item, int index);
        public int IndexOf(T item, int index, int count);
        public void Insert(int index, T item);
        public void InsertRange(int index, IEnumerable<T> collection);
        public int LastIndexOf(T item);
        public int LastIndexOf(T item, int index);
        public int LastIndexOf(T item, int index, int count);
        public bool Remove(T item);
        public int RemoveAll(Predicate<T> match);
        public void RemoveAt(int index);
        public void RemoveRange(int index, int count);
        public void Reverse();
        public void Reverse(int index, int count);
        public void Sort();
        public void Sort(Comparison<T> comparison);
        public void Sort(IComparer<T> comparer);
        public void Sort(int index, int count, IComparer<T> comparer);
        public T[] ToArray();
        public void TrimExcess();
        public void TrimToSize();
        public bool TrueForAll(Predicate<T> match);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class KeyNotFoundException: SystemException, _Exception, ISerializable
    {
        public KeyNotFoundException();
        protected KeyNotFoundException(SerializationInfo info, StreamingContext context);
        public KeyNotFoundException(string message);
        public KeyNotFoundException(string message, Exception innerException);
    }

} 
namespace System.Collections.ObjectModel
{
    [SerializableAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    public class Collection<T>: IList, IList
    {
        public Collection();
        public Collection(IList<T> list);
        public int Count { get; }
        public T this[int index] { get; set; }
        public void Add(T item);
        public void Clear();
        protected virtual void ClearItems();
        public bool Contains(T item);
        public void CopyTo(T[] array, int index);
        public IEnumerator<T> GetEnumerator();
        public int IndexOf(T item);
        public void Insert(int index, T item);
        protected virtual void InsertItem(int index, T item);
        public bool Remove(T item);
        public void RemoveAt(int index);
        protected virtual void RemoveItem(int index);
        protected virtual void SetItem(int index, T item);
    }

    [SerializableAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    public abstract class KeyedCollection<TKey,TItem>: Collection, IList, IList
    {
        protected KeyedCollection();
        protected KeyedCollection(IEqualityComparer<TKey> comparer);
        protected KeyedCollection(IEqualityComparer<TKey> comparer, int dictionaryCreationThreshold);
        public IEqualityComparer<TKey> Comparer { get; }
        public TItem this[TKey key] { get; }
        protected void ChangeItemKey(TItem item, TKey newKey);
        protected override void ClearItems();
        public bool Contains(TKey key);
        protected abstract TKey GetKeyForItem(TItem item);
        protected override void InsertItem(int index, TItem item);
        public bool Remove(TKey key);
        protected override void RemoveItem(int index);
        protected override void SetItem(int index, TItem item);
    }

    [SerializableAttribute(..)]
    [DebuggerDisplayAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    [DebuggerTypeProxyAttribute(..)]
    public class ReadOnlyCollection<T>: IList, IList
    {
        public ReadOnlyCollection(IList<T> list);
        public int Count { get; }
        public T this[int index] { get; }
        public bool Contains(T value);
        public void CopyTo(T[] array, int index);
        public IEnumerator<T> GetEnumerator();
        public int IndexOf(T value);
    }

} 
namespace System.Configuration.Assemblies
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public struct AssemblyHash: ICloneable
    {
        public AssemblyHash(AssemblyHashAlgorithm algorithm, byte[] value);
        public AssemblyHash(byte[] value);
        public static readonly AssemblyHash Empty;
        public AssemblyHashAlgorithm Algorithm { get; set; }
        public object Clone();
        public byte[] GetValue();
        public void SetValue(byte[] value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum AssemblyHashAlgorithm
    {
        MD5,
        None,
        SHA1,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum AssemblyVersionCompatibility
    {
        SameDomain,
        SameMachine,
        SameProcess,
    }

} 
namespace System.Deployment.Internal
{
    [ComVisibleAttribute(..)]
    public abstract sealed class InternalActivationContextHelper
    {
        public static object GetActivationContextData(ActivationContext appInfo);
        public static object GetApplicationComponentManifest(ActivationContext appInfo);
        public static object GetDeploymentComponentManifest(ActivationContext appInfo);
        public static bool IsFirstRun(ActivationContext appInfo);
        public static void PrepareForExecution(ActivationContext appInfo);
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class InternalApplicationIdentityHelper
    {
        public static object GetInternalAppId(ApplicationIdentity id);
    }

} 
namespace System.Diagnostics
{
    [ComVisibleAttribute(..)]
    public sealed class Debugger
    {
        public Debugger();
        public static readonly string DefaultCategory;
        public static bool IsAttached { get; }
        public static void Break();
        public static bool IsLogging();
        public static bool Launch();
        public static void Log(int level, string category, string message);
    }

    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StackFrame
    {
        public StackFrame();
        public StackFrame(bool fNeedFileInfo);
        public StackFrame(int skipFrames);
        public StackFrame(int skipFrames, bool fNeedFileInfo);
        public StackFrame(string fileName, int lineNumber);
        public StackFrame(string fileName, int lineNumber, int colNumber);
        public const int OFFSET_UNKNOWN;
        public virtual int GetFileColumnNumber();
        public virtual int GetFileLineNumber();
        public virtual string GetFileName();
        public virtual int GetILOffset();
        public virtual MethodBase GetMethod();
        public virtual int GetNativeOffset();
        public override string ToString();
    }

    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StackTrace
    {
        public StackTrace();
        public StackTrace(bool fNeedFileInfo);
        public StackTrace(Exception e);
        public StackTrace(Exception e, bool fNeedFileInfo);
        public StackTrace(Exception e, int skipFrames);
        public StackTrace(Exception e, int skipFrames, bool fNeedFileInfo);
        public StackTrace(int skipFrames);
        public StackTrace(int skipFrames, bool fNeedFileInfo);
        public StackTrace(StackFrame frame);
        public StackTrace(Thread targetThread, bool needFileInfo);
        public const int METHODS_TO_SKIP;
        public virtual int FrameCount { get; }
        public virtual StackFrame GetFrame(int index);
        public virtual StackFrame[] GetFrames();
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public enum DebuggerBrowsableState
    {
        Collapsed,
        Never,
        RootHidden,
    }

    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum VisualizerUIType
    {
        DropDown,
        Modal,
        ToolWindow,
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ConditionalAttribute: Attribute, _Attribute
    {
        public ConditionalAttribute(string conditionString);
        public string ConditionString { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DebuggableAttribute: Attribute, _Attribute
    {
        public DebuggableAttribute(bool isJITTrackingEnabled, bool isJITOptimizerDisabled);
        public DebuggableAttribute(DebuggingModes modes);
        public DebuggingModes DebuggingFlags { get; }
        public bool IsJITOptimizerDisabled { get; }
        public bool IsJITTrackingEnabled { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DebuggerBrowsableAttribute: Attribute, _Attribute
    {
        public DebuggerBrowsableAttribute(DebuggerBrowsableState state);
        public DebuggerBrowsableState State { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DebuggerDisplayAttribute: Attribute, _Attribute
    {
        public DebuggerDisplayAttribute(string value);
        public string Name { get; set; }
        public Type Target { get; set; }
        public string TargetTypeName { get; set; }
        public string Type { get; set; }
        public string Value { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DebuggerHiddenAttribute: Attribute, _Attribute
    {
        public DebuggerHiddenAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DebuggerNonUserCodeAttribute: Attribute, _Attribute
    {
        public DebuggerNonUserCodeAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DebuggerStepperBoundaryAttribute: Attribute, _Attribute
    {
        public DebuggerStepperBoundaryAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DebuggerStepThroughAttribute: Attribute, _Attribute
    {
        public DebuggerStepThroughAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DebuggerTypeProxyAttribute: Attribute, _Attribute
    {
        public DebuggerTypeProxyAttribute(string typeName);
        public DebuggerTypeProxyAttribute(Type type);
        public string ProxyTypeName { get; }
        public Type Target { get; set; }
        public string TargetTypeName { get; set; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DebuggerVisualizerAttribute: Attribute, _Attribute
    {
        public DebuggerVisualizerAttribute(string visualizerTypeName);
        public DebuggerVisualizerAttribute(string visualizerTypeName, string visualizerObjectSourceTypeName);
        public DebuggerVisualizerAttribute(string visualizerTypeName, Type visualizerObjectSource);
        public DebuggerVisualizerAttribute(Type visualizer);
        public DebuggerVisualizerAttribute(Type visualizer, string visualizerObjectSourceTypeName);
        public DebuggerVisualizerAttribute(Type visualizer, Type visualizerObjectSource);
        public string Description { get; set; }
        public Type Target { get; set; }
        public string TargetTypeName { get; set; }
        public string VisualizerObjectSourceTypeName { get; }
        public string VisualizerTypeName { get; }
    }

} 
namespace System.Diagnostics.CodeAnalysis
{
    [ConditionalAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class SuppressMessageAttribute: Attribute, _Attribute
    {
        public SuppressMessageAttribute(string category, string checkId);
        public string Category { get; }
        public string CheckId { get; }
        public string Justification { get; set; }
        public string MessageId { get; set; }
        public string Scope { get; set; }
        public string Target { get; set; }
    }

} 
namespace System.Diagnostics.SymbolStore
{
    [ComVisibleAttribute(..)]
    public interface ISymbolBinder
    {
        public ISymbolReader GetReader(int importer, string filename, string searchPath);
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolBinder1
    {
        public ISymbolReader GetReader(IntPtr importer, string filename, string searchPath);
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolDocument
    {
        public Guid CheckSumAlgorithmId { get; }
        public Guid DocumentType { get; }
        public bool HasEmbeddedSource { get; }
        public Guid Language { get; }
        public Guid LanguageVendor { get; }
        public int SourceLength { get; }
        public string URL { get; }
        public int FindClosestLine(int line);
        public byte[] GetCheckSum();
        public byte[] GetSourceRange(int startLine, int startColumn, int endLine, int endColumn);
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolDocumentWriter
    {
        public void SetCheckSum(Guid algorithmId, byte[] checkSum);
        public void SetSource(byte[] source);
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolMethod
    {
        public ISymbolScope RootScope { get; }
        public int SequencePointCount { get; }
        public SymbolToken Token { get; }
        public ISymbolNamespace GetNamespace();
        public int GetOffset(ISymbolDocument document, int line, int column);
        public ISymbolVariable[] GetParameters();
        public int[] GetRanges(ISymbolDocument document, int line, int column);
        public ISymbolScope GetScope(int offset);
        public void GetSequencePoints(int[] offsets, ISymbolDocument[] documents, int[] lines, int[] columns, int[] endLines, int[] endColumns);
        public bool GetSourceStartEnd(ISymbolDocument[] docs, int[] lines, int[] columns);
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolNamespace
    {
        public string Name { get; }
        public ISymbolNamespace[] GetNamespaces();
        public ISymbolVariable[] GetVariables();
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolReader
    {
        public SymbolToken UserEntryPoint { get; }
        public ISymbolDocument GetDocument(string url, Guid language, Guid languageVendor, Guid documentType);
        public ISymbolDocument[] GetDocuments();
        public ISymbolVariable[] GetGlobalVariables();
        public ISymbolMethod GetMethod(SymbolToken method);
        public ISymbolMethod GetMethod(SymbolToken method, int version);
        public ISymbolMethod GetMethodFromDocumentPosition(ISymbolDocument document, int line, int column);
        public ISymbolNamespace[] GetNamespaces();
        public byte[] GetSymAttribute(SymbolToken parent, string name);
        public ISymbolVariable[] GetVariables(SymbolToken parent);
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolScope
    {
        public int EndOffset { get; }
        public ISymbolMethod Method { get; }
        public ISymbolScope Parent { get; }
        public int StartOffset { get; }
        public ISymbolScope[] GetChildren();
        public ISymbolVariable[] GetLocals();
        public ISymbolNamespace[] GetNamespaces();
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolVariable
    {
        public int AddressField1 { get; }
        public int AddressField2 { get; }
        public int AddressField3 { get; }
        public SymAddressKind AddressKind { get; }
        public object Attributes { get; }
        public int EndOffset { get; }
        public string Name { get; }
        public int StartOffset { get; }
        public byte[] GetSignature();
    }

    [ComVisibleAttribute(..)]
    public interface ISymbolWriter
    {
        public void Close();
        public void CloseMethod();
        public void CloseNamespace();
        public void CloseScope(int endOffset);
        public ISymbolDocumentWriter DefineDocument(string url, Guid language, Guid languageVendor, Guid documentType);
        public void DefineField(SymbolToken parent, string name, FieldAttributes attributes, byte[] signature, SymAddressKind addrKind, int addr1, int addr2, int addr3);
        public void DefineGlobalVariable(string name, FieldAttributes attributes, byte[] signature, SymAddressKind addrKind, int addr1, int addr2, int addr3);
        public void DefineLocalVariable(string name, FieldAttributes attributes, byte[] signature, SymAddressKind addrKind, int addr1, int addr2, int addr3, int startOffset, int endOffset);
        public void DefineParameter(string name, ParameterAttributes attributes, int sequence, SymAddressKind addrKind, int addr1, int addr2, int addr3);
        public void DefineSequencePoints(ISymbolDocumentWriter document, int[] offsets, int[] lines, int[] columns, int[] endLines, int[] endColumns);
        public void Initialize(IntPtr emitter, string filename, bool fFullBuild);
        public void OpenMethod(SymbolToken method);
        public void OpenNamespace(string name);
        public int OpenScope(int startOffset);
        public void SetMethodSourceRange(ISymbolDocumentWriter startDoc, int startLine, int startColumn, ISymbolDocumentWriter endDoc, int endLine, int endColumn);
        public void SetScopeRange(int scopeID, int startOffset, int endOffset);
        public void SetSymAttribute(SymbolToken parent, string name, byte[] data);
        public void SetUnderlyingWriter(IntPtr underlyingWriter);
        public void SetUserEntryPoint(SymbolToken entryMethod);
        public void UsingNamespace(string fullName);
    }

    [ComVisibleAttribute(..)]
    public struct SymbolToken
    {
        public SymbolToken(int val);
        public override bool Equals(object obj);
        public bool Equals(SymbolToken obj);
        public override int GetHashCode();
        public int GetToken();
        public static bool operator ==(SymbolToken a, SymbolToken b);
        public static bool operator !=(SymbolToken a, SymbolToken b);
    }

    [ComVisibleAttribute(..)]
    public class SymDocumentType
    {
        public SymDocumentType();
        public static readonly Guid Text;
    }

    [ComVisibleAttribute(..)]
    public class SymLanguageType
    {
        public SymLanguageType();
        public static readonly Guid Basic;
        public static readonly Guid C;
        public static readonly Guid Cobol;
        public static readonly Guid CPlusPlus;
        public static readonly Guid CSharp;
        public static readonly Guid ILAssembly;
        public static readonly Guid Java;
        public static readonly Guid JScript;
        public static readonly Guid MCPlusPlus;
        public static readonly Guid Pascal;
        public static readonly Guid SMC;
    }

    [ComVisibleAttribute(..)]
    public class SymLanguageVendor
    {
        public SymLanguageVendor();
        public static readonly Guid Microsoft;
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum SymAddressKind
    {
        BitField,
        ILOffset,
        NativeOffset,
        NativeRegister,
        NativeRegisterRegister,
        NativeRegisterRelative,
        NativeRegisterStack,
        NativeRVA,
        NativeSectionOffset,
        NativeStackRegister,
    }

} 
namespace System.Globalization
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Calendar: ICloneable
    {
        protected Calendar();
        public const int CurrentEra;
        public virtual CalendarAlgorithmType AlgorithmType { get; }
        public abstract int[] Eras { get; }
        public bool IsReadOnly { get; }
        public virtual DateTime MaxSupportedDateTime { get; }
        public virtual DateTime MinSupportedDateTime { get; }
        public virtual int TwoDigitYearMax { get; set; }
        public virtual DateTime AddDays(DateTime time, int days);
        public virtual DateTime AddHours(DateTime time, int hours);
        public virtual DateTime AddMilliseconds(DateTime time, double milliseconds);
        public virtual DateTime AddMinutes(DateTime time, int minutes);
        public abstract DateTime AddMonths(DateTime time, int months);
        public virtual DateTime AddSeconds(DateTime time, int seconds);
        public virtual DateTime AddWeeks(DateTime time, int weeks);
        public abstract DateTime AddYears(DateTime time, int years);
        public virtual object Clone();
        public abstract int GetDayOfMonth(DateTime time);
        public abstract DayOfWeek GetDayOfWeek(DateTime time);
        public abstract int GetDayOfYear(DateTime time);
        public virtual int GetDaysInMonth(int year, int month);
        public abstract int GetDaysInMonth(int year, int month, int era);
        public virtual int GetDaysInYear(int year);
        public abstract int GetDaysInYear(int year, int era);
        public abstract int GetEra(DateTime time);
        public virtual int GetHour(DateTime time);
        public virtual int GetLeapMonth(int year);
        public virtual int GetLeapMonth(int year, int era);
        public virtual double GetMilliseconds(DateTime time);
        public virtual int GetMinute(DateTime time);
        public abstract int GetMonth(DateTime time);
        public virtual int GetMonthsInYear(int year);
        public abstract int GetMonthsInYear(int year, int era);
        public virtual int GetSecond(DateTime time);
        public virtual int GetWeekOfYear(DateTime time, CalendarWeekRule rule, DayOfWeek firstDayOfWeek);
        public abstract int GetYear(DateTime time);
        public virtual bool IsLeapDay(int year, int month, int day);
        public abstract bool IsLeapDay(int year, int month, int day, int era);
        public virtual bool IsLeapMonth(int year, int month);
        public abstract bool IsLeapMonth(int year, int month, int era);
        public virtual bool IsLeapYear(int year);
        public abstract bool IsLeapYear(int year, int era);
        public static Calendar ReadOnly(Calendar calendar);
        public virtual DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond);
        public abstract DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public virtual int ToFourDigitYear(int year);
    }

    public sealed class CharUnicodeInfo
    {
        public static int GetDecimalDigitValue(char ch);
        public static int GetDecimalDigitValue(string s, int index);
        public static int GetDigitValue(char ch);
        public static int GetDigitValue(string s, int index);
        public static double GetNumericValue(char ch);
        public static double GetNumericValue(string s, int index);
        public static UnicodeCategory GetUnicodeCategory(char ch);
        public static UnicodeCategory GetUnicodeCategory(string s, int index);
    }

    [SerializableAttribute(..)]
    public class ChineseLunisolarCalendar: EastAsianLunisolarCalendar, ICloneable
    {
        public ChineseLunisolarCalendar();
        public const int ChineseEra;
        public override int GetEra(DateTime time);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CompareInfo: IDeserializationCallback
    {
        public int LCID { get; }
        public virtual string Name { get; }
        public virtual int Compare(string string1, int offset1, int length1, string string2, int offset2, int length2);
        public virtual int Compare(string string1, int offset1, int length1, string string2, int offset2, int length2, CompareOptions options);
        public virtual int Compare(string string1, int offset1, string string2, int offset2);
        public virtual int Compare(string string1, int offset1, string string2, int offset2, CompareOptions options);
        public virtual int Compare(string string1, string string2);
        public virtual int Compare(string string1, string string2, CompareOptions options);
        public override bool Equals(object value);
        public static CompareInfo GetCompareInfo(int culture);
        public static CompareInfo GetCompareInfo(int culture, Assembly assembly);
        public static CompareInfo GetCompareInfo(string name);
        public static CompareInfo GetCompareInfo(string name, Assembly assembly);
        public override int GetHashCode();
        public virtual SortKey GetSortKey(string source);
        public virtual SortKey GetSortKey(string source, CompareOptions options);
        public virtual int IndexOf(string source, char value);
        public virtual int IndexOf(string source, char value, CompareOptions options);
        public virtual int IndexOf(string source, char value, int startIndex);
        public virtual int IndexOf(string source, char value, int startIndex, CompareOptions options);
        public virtual int IndexOf(string source, char value, int startIndex, int count);
        public virtual int IndexOf(string source, char value, int startIndex, int count, CompareOptions options);
        public virtual int IndexOf(string source, string value);
        public virtual int IndexOf(string source, string value, CompareOptions options);
        public virtual int IndexOf(string source, string value, int startIndex);
        public virtual int IndexOf(string source, string value, int startIndex, CompareOptions options);
        public virtual int IndexOf(string source, string value, int startIndex, int count);
        public virtual int IndexOf(string source, string value, int startIndex, int count, CompareOptions options);
        public virtual bool IsPrefix(string source, string prefix);
        public virtual bool IsPrefix(string source, string prefix, CompareOptions options);
        public static bool IsSortable(char ch);
        public static bool IsSortable(string text);
        public virtual bool IsSuffix(string source, string suffix);
        public virtual bool IsSuffix(string source, string suffix, CompareOptions options);
        public virtual int LastIndexOf(string source, char value);
        public virtual int LastIndexOf(string source, char value, CompareOptions options);
        public virtual int LastIndexOf(string source, char value, int startIndex);
        public virtual int LastIndexOf(string source, char value, int startIndex, CompareOptions options);
        public virtual int LastIndexOf(string source, char value, int startIndex, int count);
        public virtual int LastIndexOf(string source, char value, int startIndex, int count, CompareOptions options);
        public virtual int LastIndexOf(string source, string value);
        public virtual int LastIndexOf(string source, string value, CompareOptions options);
        public virtual int LastIndexOf(string source, string value, int startIndex);
        public virtual int LastIndexOf(string source, string value, int startIndex, CompareOptions options);
        public virtual int LastIndexOf(string source, string value, int startIndex, int count);
        public virtual int LastIndexOf(string source, string value, int startIndex, int count, CompareOptions options);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CultureInfo: ICloneable, IFormatProvider
    {
        public CultureInfo(int culture);
        public CultureInfo(int culture, bool useUserOverride);
        public CultureInfo(string name);
        public CultureInfo(string name, bool useUserOverride);
        public virtual Calendar Calendar { get; }
        public virtual CompareInfo CompareInfo { get; }
        public CultureTypes CultureTypes { get; }
        public static CultureInfo CurrentCulture { get; }
        public static CultureInfo CurrentUICulture { get; }
        public virtual DateTimeFormatInfo DateTimeFormat { get; set; }
        public virtual string DisplayName { get; }
        public virtual string EnglishName { get; }
        public string IetfLanguageTag { get; }
        public static CultureInfo InstalledUICulture { get; }
        public static CultureInfo InvariantCulture { get; }
        public virtual bool IsNeutralCulture { get; }
        public bool IsReadOnly { get; }
        public virtual int KeyboardLayoutId { get; }
        public virtual int LCID { get; }
        public virtual string Name { get; }
        public virtual string NativeName { get; }
        public virtual NumberFormatInfo NumberFormat { get; set; }
        public virtual Calendar[] OptionalCalendars { get; }
        public virtual CultureInfo Parent { get; }
        public virtual TextInfo TextInfo { get; }
        public virtual string ThreeLetterISOLanguageName { get; }
        public virtual string ThreeLetterWindowsLanguageName { get; }
        public virtual string TwoLetterISOLanguageName { get; }
        public bool UseUserOverride { get; }
        public void ClearCachedData();
        public virtual object Clone();
        public static CultureInfo CreateSpecificCulture(string name);
        public override bool Equals(object value);
        public CultureInfo GetConsoleFallbackUICulture();
        public static CultureInfo GetCultureInfo(int culture);
        public static CultureInfo GetCultureInfo(string name);
        public static CultureInfo GetCultureInfo(string name, string altName);
        public static CultureInfo GetCultureInfoByIetfLanguageTag(string name);
        public static CultureInfo[] GetCultures(CultureTypes types);
        public virtual object GetFormat(Type formatType);
        public override int GetHashCode();
        public static CultureInfo ReadOnly(CultureInfo ci);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DateTimeFormatInfo: ICloneable, IFormatProvider
    {
        public DateTimeFormatInfo();
        public string[] AbbreviatedDayNames { get; set; }
        public string[] AbbreviatedMonthGenitiveNames { get; set; }
        public string[] AbbreviatedMonthNames { get; set; }
        public string AMDesignator { get; set; }
        public Calendar Calendar { get; set; }
        public CalendarWeekRule CalendarWeekRule { get; set; }
        public static DateTimeFormatInfo CurrentInfo { get; }
        public string DateSeparator { get; set; }
        public string[] DayNames { get; set; }
        public DayOfWeek FirstDayOfWeek { get; set; }
        public string FullDateTimePattern { get; set; }
        public static DateTimeFormatInfo InvariantInfo { get; }
        public bool IsReadOnly { get; }
        public string LongDatePattern { get; set; }
        public string LongTimePattern { get; set; }
        public string MonthDayPattern { get; set; }
        public string[] MonthGenitiveNames { get; set; }
        public string[] MonthNames { get; set; }
        public string NativeCalendarName { get; }
        public string PMDesignator { get; set; }
        public string RFC1123Pattern { get; }
        public string ShortDatePattern { get; set; }
        public string[] ShortestDayNames { get; set; }
        public string ShortTimePattern { get; set; }
        public string SortableDateTimePattern { get; }
        public string TimeSeparator { get; set; }
        public string UniversalSortableDateTimePattern { get; }
        public string YearMonthPattern { get; set; }
        public object Clone();
        public string GetAbbreviatedDayName(DayOfWeek dayofweek);
        public string GetAbbreviatedEraName(int era);
        public string GetAbbreviatedMonthName(int month);
        public string[] GetAllDateTimePatterns();
        public string[] GetAllDateTimePatterns(char format);
        public string GetDayName(DayOfWeek dayofweek);
        public int GetEra(string eraName);
        public string GetEraName(int era);
        public object GetFormat(Type formatType);
        public static DateTimeFormatInfo GetInstance(IFormatProvider provider);
        public string GetMonthName(int month);
        public string GetShortestDayName(DayOfWeek dayOfWeek);
        public static DateTimeFormatInfo ReadOnly(DateTimeFormatInfo dtfi);
        public void SetAllDateTimePatterns(string[] patterns, char format);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class DaylightTime
    {
        public DaylightTime(DateTime start, DateTime end, TimeSpan delta);
        public TimeSpan Delta { get; }
        public DateTime End { get; }
        public DateTime Start { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class EastAsianLunisolarCalendar: Calendar, ICloneable
    {
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public int GetCelestialStem(int sexagenaryYear);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public virtual int GetSexagenaryYear(DateTime time);
        public int GetTerrestrialBranch(int sexagenaryYear);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class GregorianCalendar: Calendar, ICloneable
    {
        public GregorianCalendar();
        public GregorianCalendar(GregorianCalendarTypes type);
        public const int ADEra;
        public virtual GregorianCalendarTypes CalendarType { get; set; }
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetWeekOfYear(DateTime time, CalendarWeekRule rule, DayOfWeek firstDayOfWeek);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class HebrewCalendar: Calendar, ICloneable
    {
        public HebrewCalendar();
        public static readonly int HebrewEra;
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class HijriCalendar: Calendar, ICloneable
    {
        public HijriCalendar();
        public static readonly int HijriEra;
        public int HijriAdjustment { get; set; }
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    public sealed class IdnMapping
    {
        public IdnMapping();
        public bool AllowUnassigned { get; set; }
        public bool UseStd3AsciiRules { get; set; }
        public override bool Equals(object obj);
        public string GetAscii(string unicode);
        public string GetAscii(string unicode, int index);
        public string GetAscii(string unicode, int index, int count);
        public override int GetHashCode();
        public string GetUnicode(string ascii);
        public string GetUnicode(string ascii, int index);
        public string GetUnicode(string ascii, int index, int count);
    }

    public class JalaaliCalendar: Calendar, ICloneable
    {
        public JalaaliCalendar();
        public static readonly int JalaaliEra;
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class JapaneseCalendar: Calendar, ICloneable
    {
        public JapaneseCalendar();
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetWeekOfYear(DateTime time, CalendarWeekRule rule, DayOfWeek firstDayOfWeek);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    public class JapaneseLunisolarCalendar: EastAsianLunisolarCalendar, ICloneable
    {
        public JapaneseLunisolarCalendar();
        public const int JapaneseEra;
        public override int GetEra(DateTime time);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class JulianCalendar: Calendar, ICloneable
    {
        public JulianCalendar();
        public static readonly int JulianEra;
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class KoreanCalendar: Calendar, ICloneable
    {
        public KoreanCalendar();
        public const int KoreanEra;
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetWeekOfYear(DateTime time, CalendarWeekRule rule, DayOfWeek firstDayOfWeek);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    public class KoreanLunisolarCalendar: EastAsianLunisolarCalendar, ICloneable
    {
        public KoreanLunisolarCalendar();
        public const int GregorianEra;
        public override int GetEra(DateTime time);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class NumberFormatInfo: ICloneable, IFormatProvider
    {
        public NumberFormatInfo();
        public int CurrencyDecimalDigits { get; set; }
        public string CurrencyDecimalSeparator { get; set; }
        public string CurrencyGroupSeparator { get; set; }
        public int[] CurrencyGroupSizes { get; set; }
        public int CurrencyNegativePattern { get; set; }
        public int CurrencyPositivePattern { get; set; }
        public string CurrencySymbol { get; set; }
        public static NumberFormatInfo CurrentInfo { get; }
        public DigitShapes DigitSubstitution { get; set; }
        public static NumberFormatInfo InvariantInfo { get; }
        public bool IsReadOnly { get; }
        public string NaNSymbol { get; set; }
        public string[] NativeDigits { get; set; }
        public string NegativeInfinitySymbol { get; set; }
        public string NegativeSign { get; set; }
        public int NumberDecimalDigits { get; set; }
        public string NumberDecimalSeparator { get; set; }
        public string NumberGroupSeparator { get; set; }
        public int[] NumberGroupSizes { get; set; }
        public int NumberNegativePattern { get; set; }
        public int PercentDecimalDigits { get; set; }
        public string PercentDecimalSeparator { get; set; }
        public string PercentGroupSeparator { get; set; }
        public int[] PercentGroupSizes { get; set; }
        public int PercentNegativePattern { get; set; }
        public int PercentPositivePattern { get; set; }
        public string PercentSymbol { get; set; }
        public string PerMilleSymbol { get; set; }
        public string PositiveInfinitySymbol { get; set; }
        public string PositiveSign { get; set; }
        public object Clone();
        public object GetFormat(Type formatType);
        public static NumberFormatInfo GetInstance(IFormatProvider formatProvider);
        public static NumberFormatInfo ReadOnly(NumberFormatInfo nfi);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class RegionInfo
    {
        public RegionInfo(int culture);
        public RegionInfo(string name);
        public virtual string CurrencyEnglishName { get; }
        public virtual string CurrencyNativeName { get; }
        public virtual string CurrencySymbol { get; }
        public static RegionInfo CurrentRegion { get; }
        public virtual string DisplayName { get; }
        public virtual string EnglishName { get; }
        public virtual int GeoId { get; }
        public virtual bool IsMetric { get; }
        public virtual string ISOCurrencySymbol { get; }
        public virtual string Name { get; }
        public virtual string NativeName { get; }
        public virtual string ThreeLetterISORegionName { get; }
        public virtual string ThreeLetterWindowsRegionName { get; }
        public virtual string TwoLetterISORegionName { get; }
        public override bool Equals(object value);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SortKey
    {
        public virtual byte[] KeyData { get; }
        public virtual string OriginalString { get; }
        public static int Compare(SortKey sortkey1, SortKey sortkey2);
        public override bool Equals(object value);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StringInfo
    {
        public StringInfo();
        public StringInfo(string value);
        public int LengthInTextElements { get; }
        public string String { get; set; }
        public override bool Equals(object value);
        public override int GetHashCode();
        public static string GetNextTextElement(string str);
        public static string GetNextTextElement(string str, int index);
        public static TextElementEnumerator GetTextElementEnumerator(string str);
        public static TextElementEnumerator GetTextElementEnumerator(string str, int index);
        public static int[] ParseCombiningCharacters(string str);
        public string SubstringByTextElements(int startingTextElement);
        public string SubstringByTextElements(int startingTextElement, int lengthInTextElements);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TaiwanCalendar: Calendar, ICloneable
    {
        public TaiwanCalendar();
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetWeekOfYear(DateTime time, CalendarWeekRule rule, DayOfWeek firstDayOfWeek);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    public class TaiwanLunisolarCalendar: EastAsianLunisolarCalendar, ICloneable
    {
        public TaiwanLunisolarCalendar();
        public override int GetEra(DateTime time);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TextElementEnumerator: IEnumerator
    {
        public object Current { get; }
        public int ElementIndex { get; }
        public string GetTextElement();
        public bool MoveNext();
        public void Reset();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TextInfo: ICloneable, IDeserializationCallback
    {
        public virtual int ANSICodePage { get; }
        public string CultureName { get; }
        public virtual int EBCDICCodePage { get; }
        public bool IsReadOnly { get; }
        public bool IsRightToLeft { get; }
        public int LCID { get; }
        public virtual string ListSeparator { get; set; }
        public virtual int MacCodePage { get; }
        public virtual int OEMCodePage { get; }
        public virtual object Clone();
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static TextInfo ReadOnly(TextInfo textInfo);
        public virtual char ToLower(char c);
        public virtual string ToLower(string str);
        public override string ToString();
        public string ToTitleCase(string str);
        public virtual char ToUpper(char c);
        public virtual string ToUpper(string str);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ThaiBuddhistCalendar: Calendar, ICloneable
    {
        public ThaiBuddhistCalendar();
        public const int ThaiBuddhistEra;
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetWeekOfYear(DateTime time, CalendarWeekRule rule, DayOfWeek firstDayOfWeek);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [SerializableAttribute(..)]
    public class UmAlQuraCalendar: Calendar, ICloneable
    {
        public UmAlQuraCalendar();
        public const int UmAlQuraEra;
        public override DateTime AddMonths(DateTime time, int months);
        public override DateTime AddYears(DateTime time, int years);
        public override int GetDayOfMonth(DateTime time);
        public override DayOfWeek GetDayOfWeek(DateTime time);
        public override int GetDayOfYear(DateTime time);
        public override int GetDaysInMonth(int year, int month, int era);
        public override int GetDaysInYear(int year, int era);
        public override int GetEra(DateTime time);
        public override int GetLeapMonth(int year, int era);
        public override int GetMonth(DateTime time);
        public override int GetMonthsInYear(int year, int era);
        public override int GetYear(DateTime time);
        public override bool IsLeapDay(int year, int month, int day, int era);
        public override bool IsLeapMonth(int year, int month, int era);
        public override bool IsLeapYear(int year, int era);
        public override DateTime ToDateTime(int year, int month, int day, int hour, int minute, int second, int millisecond, int era);
        public override int ToFourDigitYear(int year);
    }

    [ComVisibleAttribute(..)]
    public enum CalendarAlgorithmType
    {
        LunarCalendar,
        LunisolarCalendar,
        SolarCalendar,
        Unknown,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum CalendarWeekRule
    {
        FirstDay,
        FirstFourDayWeek,
        FirstFullWeek,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum CompareOptions
    {
        IgnoreCase,
        IgnoreKanaType,
        IgnoreNonSpace,
        IgnoreSymbols,
        IgnoreWidth,
        None,
        Ordinal,
        StringSort,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum CultureTypes
    {
        AllCultures,
        FrameworkCultures,
        InstalledWin32Cultures,
        NeutralCultures,
        ReplacementCultures,
        SpecificCultures,
        UserCustomCulture,
        WindowsOnlyCultures,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum DateTimeStyles
    {
        AdjustToUniversal,
        AllowInnerWhite,
        AllowLeadingWhite,
        AllowTrailingWhite,
        AllowWhiteSpaces,
        AssumeLocal,
        AssumeUniversal,
        NoCurrentDateDefault,
        None,
        RoundtripKind,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum DigitShapes
    {
        Context,
        NativeNational,
        None,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum GregorianCalendarTypes
    {
        Arabic,
        Localized,
        MiddleEastFrench,
        TransliteratedEnglish,
        TransliteratedFrench,
        USEnglish,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum NumberStyles
    {
        AllowCurrencySymbol,
        AllowDecimalPoint,
        AllowExponent,
        AllowHexSpecifier,
        AllowLeadingSign,
        AllowLeadingWhite,
        AllowParentheses,
        AllowThousands,
        AllowTrailingSign,
        AllowTrailingWhite,
        Any,
        Currency,
        Float,
        HexNumber,
        Integer,
        None,
        Number,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum UnicodeCategory
    {
        ClosePunctuation,
        ConnectorPunctuation,
        Control,
        CurrencySymbol,
        DashPunctuation,
        DecimalDigitNumber,
        EnclosingMark,
        FinalQuotePunctuation,
        Format,
        InitialQuotePunctuation,
        LetterNumber,
        LineSeparator,
        LowercaseLetter,
        MathSymbol,
        ModifierLetter,
        ModifierSymbol,
        NonSpacingMark,
        OpenPunctuation,
        OtherLetter,
        OtherNotAssigned,
        OtherNumber,
        OtherPunctuation,
        OtherSymbol,
        ParagraphSeparator,
        PrivateUse,
        SpaceSeparator,
        SpacingCombiningMark,
        Surrogate,
        TitlecaseLetter,
        UppercaseLetter,
    }

} 
namespace System.IO
{
    [ComVisibleAttribute(..)]
    public class BinaryReader: IDisposable
    {
        public BinaryReader(Stream input);
        public BinaryReader(Stream input, Encoding encoding);
        public virtual Stream BaseStream { get; }
        public virtual void Close();
        protected virtual void Dispose(bool disposing);
        protected virtual void FillBuffer(int numBytes);
        public virtual int PeekChar();
        public virtual int Read();
        public virtual int Read(byte[] buffer, int index, int count);
        public virtual int Read(char[] buffer, int index, int count);
        protected int Read7BitEncodedInt();
        public virtual bool ReadBoolean();
        public virtual byte ReadByte();
        public virtual byte[] ReadBytes(int count);
        public virtual char ReadChar();
        public virtual char[] ReadChars(int count);
        public virtual decimal ReadDecimal();
        public virtual double ReadDouble();
        public virtual short ReadInt16();
        public virtual int ReadInt32();
        public virtual long ReadInt64();
        public virtual sbyte ReadSByte();
        public virtual float ReadSingle();
        public virtual string ReadString();
        public virtual ushort ReadUInt16();
        public virtual uint ReadUInt32();
        public virtual ulong ReadUInt64();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class BinaryWriter: IDisposable
    {
        protected BinaryWriter();
        public BinaryWriter(Stream output);
        public BinaryWriter(Stream output, Encoding encoding);
        public static readonly BinaryWriter Null;
        protected Stream OutStream;
        public virtual Stream BaseStream { get; }
        public virtual void Close();
        protected virtual void Dispose(bool disposing);
        public virtual void Flush();
        public virtual long Seek(int offset, SeekOrigin origin);
        public virtual void Write(bool value);
        public virtual void Write(byte value);
        public virtual void Write(byte[] buffer);
        public virtual void Write(byte[] buffer, int index, int count);
        public virtual void Write(char ch);
        public virtual void Write(char[] chars);
        public virtual void Write(char[] chars, int index, int count);
        public virtual void Write(decimal value);
        public virtual void Write(double value);
        public virtual void Write(float value);
        public virtual void Write(int value);
        public virtual void Write(long value);
        public virtual void Write(sbyte value);
        public virtual void Write(short value);
        public virtual void Write(string value);
        public virtual void Write(uint value);
        public virtual void Write(ulong value);
        public virtual void Write(ushort value);
        protected void Write7BitEncodedInt(int value);
    }

    [ComVisibleAttribute(..)]
    public sealed class BufferedStream: Stream, IDisposable
    {
        public BufferedStream(Stream stream);
        public BufferedStream(Stream stream, int bufferSize);
        protected override void Dispose(bool disposing);
        public override void Flush();
        public override int Read(byte[] array, int offset, int count);
        public override int ReadByte();
        public override long Seek(long offset, SeekOrigin origin);
        public override void SetLength(long value);
        public override void Write(byte[] array, int offset, int count);
        public override void WriteByte(byte value);
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class Directory
    {
        public static DirectoryInfo CreateDirectory(string path);
        public static DirectoryInfo CreateDirectory(string path, DirectorySecurity directorySecurity);
        public static void Delete(string path);
        public static void Delete(string path, bool recursive);
        public static bool Exists(string path);
        public static DirectorySecurity GetAccessControl(string path);
        public static DirectorySecurity GetAccessControl(string path, AccessControlSections includeSections);
        public static DateTime GetCreationTime(string path);
        public static DateTime GetCreationTimeUtc(string path);
        public static string GetCurrentDirectory();
        public static string[] GetDirectories(string path);
        public static string[] GetDirectories(string path, string searchPattern);
        public static string[] GetDirectories(string path, string searchPattern, SearchOption searchOption);
        public static string GetDirectoryRoot(string path);
        public static string[] GetFiles(string path);
        public static string[] GetFiles(string path, string searchPattern);
        public static string[] GetFiles(string path, string searchPattern, SearchOption searchOption);
        public static string[] GetFileSystemEntries(string path);
        public static string[] GetFileSystemEntries(string path, string searchPattern);
        public static DateTime GetLastAccessTime(string path);
        public static DateTime GetLastAccessTimeUtc(string path);
        public static DateTime GetLastWriteTime(string path);
        public static DateTime GetLastWriteTimeUtc(string path);
        public static string[] GetLogicalDrives();
        public static DirectoryInfo GetParent(string path);
        public static void Move(string sourceDirName, string destDirName);
        public static void SetAccessControl(string path, DirectorySecurity directorySecurity);
        public static void SetCreationTime(string path, DateTime creationTime);
        public static void SetCreationTimeUtc(string path, DateTime creationTimeUtc);
        public static void SetCurrentDirectory(string path);
        public static void SetLastAccessTime(string path, DateTime lastAccessTime);
        public static void SetLastAccessTimeUtc(string path, DateTime lastAccessTimeUtc);
        public static void SetLastWriteTime(string path, DateTime lastWriteTime);
        public static void SetLastWriteTimeUtc(string path, DateTime lastWriteTimeUtc);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DirectoryInfo: FileSystemInfo, ISerializable
    {
        public DirectoryInfo(string path);
        public DirectoryInfo Parent { get; }
        public DirectoryInfo Root { get; }
        public void Create();
        public void Create(DirectorySecurity directorySecurity);
        public DirectoryInfo CreateSubdirectory(string path);
        public DirectoryInfo CreateSubdirectory(string path, DirectorySecurity directorySecurity);
        public override void Delete();
        public void Delete(bool recursive);
        public DirectorySecurity GetAccessControl();
        public DirectorySecurity GetAccessControl(AccessControlSections includeSections);
        public DirectoryInfo[] GetDirectories();
        public DirectoryInfo[] GetDirectories(string searchPattern);
        public DirectoryInfo[] GetDirectories(string searchPattern, SearchOption searchOption);
        public FileInfo[] GetFiles();
        public FileInfo[] GetFiles(string searchPattern);
        public FileInfo[] GetFiles(string searchPattern, SearchOption searchOption);
        public FileSystemInfo[] GetFileSystemInfos();
        public FileSystemInfo[] GetFileSystemInfos(string searchPattern);
        public void MoveTo(string destDirName);
        public void SetAccessControl(DirectorySecurity directorySecurity);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DriveInfo: ISerializable
    {
        public DriveInfo(string driveName);
        public long AvailableFreeSpace { get; }
        public string DriveFormat { get; }
        public DriveType DriveType { get; }
        public bool IsReady { get; }
        public string Name { get; }
        public DirectoryInfo RootDirectory { get; }
        public long TotalFreeSpace { get; }
        public long TotalSize { get; }
        public string VolumeLabel { get; set; }
        public static DriveInfo[] GetDrives();
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class File
    {
        public static void AppendAll(string path, string contents);
        public static void AppendAll(string path, string contents, Encoding encoding);
        public static void AppendAllText(string path, string contents);
        public static void AppendAllText(string path, string contents, Encoding encoding);
        public static StreamWriter AppendText(string path);
        public static void Copy(string sourceFileName, string destFileName);
        public static void Copy(string sourceFileName, string destFileName, bool overwrite);
        public static FileStream Create(string path);
        public static FileStream Create(string path, int bufferSize);
        public static FileStream Create(string path, int bufferSize, FileOptions options);
        public static FileStream Create(string path, int bufferSize, FileOptions options, FileSecurity fileSecurity);
        public static StreamWriter CreateText(string path);
        public static void Decrypt(string path);
        public static void Delete(string path);
        public static void Encrypt(string path);
        public static bool Exists(string path);
        public static FileSecurity GetAccessControl(string path);
        public static FileSecurity GetAccessControl(string path, AccessControlSections includeSections);
        public static FileAttributes GetAttributes(string path);
        public static DateTime GetCreationTime(string path);
        public static DateTime GetCreationTimeUtc(string path);
        public static DateTime GetLastAccessTime(string path);
        public static DateTime GetLastAccessTimeUtc(string path);
        public static DateTime GetLastWriteTime(string path);
        public static DateTime GetLastWriteTimeUtc(string path);
        public static void Move(string sourceFileName, string destFileName);
        public static FileStream Open(string path, FileMode mode);
        public static FileStream Open(string path, FileMode mode, FileAccess access);
        public static FileStream Open(string path, FileMode mode, FileAccess access, FileShare share);
        public static FileStream OpenRead(string path);
        public static StreamReader OpenText(string path);
        public static FileStream OpenWrite(string path);
        public static string ReadAll(string path);
        public static string ReadAll(string path, Encoding encoding);
        public static byte[] ReadAllBytes(string path);
        public static string[] ReadAllLines(string path);
        public static string[] ReadAllLines(string path, Encoding encoding);
        public static string ReadAllText(string path);
        public static string ReadAllText(string path, Encoding encoding);
        public static void Replace(string sourceFileName, string destinationFileName, string destinationBackupFileName);
        public static void Replace(string sourceFileName, string destinationFileName, string destinationBackupFileName, bool ignoreMetadataErrors);
        public static void SetAccessControl(string path, FileSecurity fileSecurity);
        public static void SetAttributes(string path, FileAttributes fileAttributes);
        public static void SetCreationTime(string path, DateTime creationTime);
        public static void SetCreationTimeUtc(string path, DateTime creationTimeUtc);
        public static void SetLastAccessTime(string path, DateTime lastAccessTime);
        public static void SetLastAccessTimeUtc(string path, DateTime lastAccessTimeUtc);
        public static void SetLastWriteTime(string path, DateTime lastWriteTime);
        public static void SetLastWriteTimeUtc(string path, DateTime lastWriteTimeUtc);
        public static void WriteAll(string path, string contents);
        public static void WriteAll(string path, string contents, Encoding encoding);
        public static void WriteAllBytes(string path, byte[] bytes);
        public static void WriteAllLines(string path, string[] contents);
        public static void WriteAllLines(string path, string[] contents, Encoding encoding);
        public static void WriteAllText(string path, string contents);
        public static void WriteAllText(string path, string contents, Encoding encoding);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class FileInfo: FileSystemInfo, ISerializable
    {
        public FileInfo(string fileName);
        public DirectoryInfo Directory { get; }
        public string DirectoryName { get; }
        public bool IsReadOnly { get; set; }
        public long Length { get; }
        public StreamWriter AppendText();
        public FileInfo CopyTo(string destFileName);
        public FileInfo CopyTo(string destFileName, bool overwrite);
        public FileStream Create();
        public StreamWriter CreateText();
        public void Decrypt();
        public override void Delete();
        public void Encrypt();
        public FileSecurity GetAccessControl();
        public FileSecurity GetAccessControl(AccessControlSections includeSections);
        public void MoveTo(string destFileName);
        public FileStream Open(FileMode mode);
        public FileStream Open(FileMode mode, FileAccess access);
        public FileStream Open(FileMode mode, FileAccess access, FileShare share);
        public FileStream OpenRead();
        public StreamReader OpenText();
        public FileStream OpenWrite();
        public FileInfo Replace(string destinationFileName, string destinationBackupFileName);
        public FileInfo Replace(string destinationFileName, string destinationBackupFileName, bool ignoreMetadataErrors);
        public void SetAccessControl(FileSecurity fileSecurity);
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public class FileStream: Stream, IDisposable
    {
        public FileStream(IntPtr handle, FileAccess access);
        public FileStream(IntPtr handle, FileAccess access, bool ownsHandle);
        public FileStream(IntPtr handle, FileAccess access, bool ownsHandle, int bufferSize);
        public FileStream(IntPtr handle, FileAccess access, bool ownsHandle, int bufferSize, bool isAsync);
        public FileStream(SafeFileHandle handle, FileAccess access);
        public FileStream(SafeFileHandle handle, FileAccess access, int bufferSize);
        public FileStream(SafeFileHandle handle, FileAccess access, int bufferSize, bool isAsync);
        public FileStream(string path, FileMode mode);
        public FileStream(string path, FileMode mode, FileAccess access);
        public FileStream(string path, FileMode mode, FileAccess access, FileShare share);
        public FileStream(string path, FileMode mode, FileAccess access, FileShare share, int bufferSize);
        public FileStream(string path, FileMode mode, FileAccess access, FileShare share, int bufferSize, bool useAsync);
        public FileStream(string path, FileMode mode, FileAccess access, FileShare share, int bufferSize, FileOptions options);
        public FileStream(string path, FileMode mode, FileSystemRights rights, FileShare share, int bufferSize, FileOptions options);
        public FileStream(string path, FileMode mode, FileSystemRights rights, FileShare share, int bufferSize, FileOptions options, FileSecurity fileSecurity);
        public virtual IntPtr Handle { get; }
        public virtual bool IsAsync { get; }
        public string Name { get; }
        public virtual SafeFileHandle SafeFileHandle { get; }
        public override IAsyncResult BeginRead(byte[] array, int offset, int numBytes, AsyncCallback userCallback, object stateObject);
        public override IAsyncResult BeginWrite(byte[] array, int offset, int numBytes, AsyncCallback userCallback, object stateObject);
        protected override void Dispose(bool disposing);
        public override int EndRead(IAsyncResult asyncResult);
        public override void EndWrite(IAsyncResult asyncResult);
        protected override void Finalize();
        public override void Flush();
        public FileSecurity GetAccessControl();
        public virtual void Lock(long position, long length);
        public override int Read(byte[] array, int offset, int count);
        public override int ReadByte();
        public override long Seek(long offset, SeekOrigin origin);
        public void SetAccessControl(FileSecurity fileSecurity);
        public override void SetLength(long value);
        public virtual void Unlock(long position, long length);
        public override void Write(byte[] array, int offset, int count);
        public override void WriteByte(byte value);
    }

    [FileIOPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class FileSystemInfo: MarshalByRefObject, ISerializable
    {
        protected FileSystemInfo();
        protected FileSystemInfo(SerializationInfo info, StreamingContext context);
        protected string FullPath;
        protected string OriginalPath;
        public FileAttributes Attributes { get; set; }
        public DateTime CreationTime { get; set; }
        public DateTime CreationTimeUtc { get; set; }
        public abstract bool Exists { get; }
        public string Extension { get; }
        public virtual string FullName { get; }
        public DateTime LastAccessTime { get; set; }
        public DateTime LastAccessTimeUtc { get; set; }
        public DateTime LastWriteTime { get; set; }
        public DateTime LastWriteTimeUtc { get; set; }
        public abstract string Name { get; }
        public abstract void Delete();
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public void Refresh();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MemoryStream: Stream, IDisposable
    {
        public MemoryStream();
        public MemoryStream(byte[] buffer);
        public MemoryStream(byte[] buffer, bool writable);
        public MemoryStream(byte[] buffer, int index, int count);
        public MemoryStream(byte[] buffer, int index, int count, bool writable);
        public MemoryStream(byte[] buffer, int index, int count, bool writable, bool publiclyVisible);
        public MemoryStream(int capacity);
        public virtual int Capacity { get; set; }
        protected override void Dispose(bool disposing);
        public override void Flush();
        public virtual byte[] GetBuffer();
        public override int Read(byte[] buffer, int offset, int count);
        public override int ReadByte();
        public override long Seek(long offset, SeekOrigin loc);
        public override void SetLength(long value);
        public virtual byte[] ToArray();
        public override void Write(byte[] buffer, int offset, int count);
        public override void WriteByte(byte value);
        public virtual void WriteTo(Stream stream);
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class Path
    {
        public static readonly char AltDirectorySeparatorChar;
        public static readonly char DirectorySeparatorChar;
        public static readonly char[] InvalidPathChars;
        public static readonly char PathSeparator;
        public static readonly char VolumeSeparatorChar;
        public static string ChangeExtension(string path, string extension);
        public static string Combine(string path1, string path2);
        public static string GetDirectoryName(string path);
        public static string GetExtension(string path);
        public static string GetFileName(string path);
        public static string GetFileNameWithoutExtension(string path);
        public static string GetFullPath(string path);
        public static char[] GetInvalidFileNameChars();
        public static char[] GetInvalidPathChars();
        public static string GetPathRoot(string path);
        public static string GetRandomFileName();
        public static string GetTempFileName();
        public static string GetTempPath();
        public static bool HasExtension(string path);
        public static bool IsPathRooted(string path);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Stream: MarshalByRefObject, IDisposable
    {
        protected Stream();
        public static readonly Stream Null;
        public abstract bool CanRead { get; }
        public abstract bool CanSeek { get; }
        public virtual bool CanTimeout { get; }
        public abstract bool CanWrite { get; }
        public abstract long Length { get; }
        public abstract long Position { get; set; }
        public virtual int ReadTimeout { get; set; }
        public virtual int WriteTimeout { get; set; }
        public virtual IAsyncResult BeginRead(byte[] buffer, int offset, int count, AsyncCallback callback, object state);
        public virtual IAsyncResult BeginWrite(byte[] buffer, int offset, int count, AsyncCallback callback, object state);
        public virtual void Close();
        protected virtual WaitHandle CreateWaitHandle();
        protected virtual void Dispose(bool disposing);
        public virtual int EndRead(IAsyncResult asyncResult);
        public virtual void EndWrite(IAsyncResult asyncResult);
        public abstract void Flush();
        public abstract int Read(byte[] buffer, int offset, int count);
        public virtual int ReadByte();
        public abstract long Seek(long offset, SeekOrigin origin);
        public abstract void SetLength(long value);
        public static Stream Synchronized(Stream stream);
        public abstract void Write(byte[] buffer, int offset, int count);
        public virtual void WriteByte(byte value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StreamReader: TextReader, IDisposable
    {
        public StreamReader(Stream stream);
        public StreamReader(Stream stream, bool detectEncodingFromByteOrderMarks);
        public StreamReader(Stream stream, Encoding encoding);
        public StreamReader(Stream stream, Encoding encoding, bool detectEncodingFromByteOrderMarks);
        public StreamReader(Stream stream, Encoding encoding, bool detectEncodingFromByteOrderMarks, int bufferSize);
        public StreamReader(string path);
        public StreamReader(string path, bool detectEncodingFromByteOrderMarks);
        public StreamReader(string path, Encoding encoding);
        public StreamReader(string path, Encoding encoding, bool detectEncodingFromByteOrderMarks);
        public StreamReader(string path, Encoding encoding, bool detectEncodingFromByteOrderMarks, int bufferSize);
        public static readonly StreamReader Null;
        public virtual Stream BaseStream { get; }
        public virtual Encoding CurrentEncoding { get; }
        public bool EndOfStream { get; }
        public override void Close();
        public void DiscardBufferedData();
        protected override void Dispose(bool disposing);
        public override int Peek();
        public override int Read();
        public override int Read(char[] buffer, int index, int count);
        public override string ReadLine();
        public override string ReadToEnd();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StreamWriter: TextWriter, IDisposable
    {
        public StreamWriter(Stream stream);
        public StreamWriter(Stream stream, Encoding encoding);
        public StreamWriter(Stream stream, Encoding encoding, int bufferSize);
        public StreamWriter(string path);
        public StreamWriter(string path, bool append);
        public StreamWriter(string path, bool append, Encoding encoding);
        public StreamWriter(string path, bool append, Encoding encoding, int bufferSize);
        public static readonly StreamWriter Null;
        public virtual bool AutoFlush { get; set; }
        public virtual Stream BaseStream { get; }
        public override void Close();
        protected override void Dispose(bool disposing);
        protected override void Finalize();
        public override void Flush();
        public override void Write(char value);
        public override void Write(char[] buffer);
        public override void Write(char[] buffer, int index, int count);
        public override void Write(string value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StringReader: TextReader, IDisposable
    {
        public StringReader(string s);
        public override void Close();
        protected override void Dispose(bool disposing);
        public override int Peek();
        public override int Read();
        public override int Read(char[] buffer, int index, int count);
        public override string ReadLine();
        public override string ReadToEnd();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StringWriter: TextWriter, IDisposable
    {
        public StringWriter();
        public StringWriter(IFormatProvider formatProvider);
        public StringWriter(StringBuilder sb);
        public StringWriter(StringBuilder sb, IFormatProvider formatProvider);
        public override void Close();
        protected override void Dispose(bool disposing);
        public virtual StringBuilder GetStringBuilder();
        public override string ToString();
        public override void Write(char value);
        public override void Write(char[] buffer, int index, int count);
        public override void Write(string value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class TextReader: MarshalByRefObject, IDisposable
    {
        protected TextReader();
        public static readonly TextReader Null;
        public virtual void Close();
        protected virtual void Dispose(bool disposing);
        public virtual int Peek();
        public virtual int Read();
        public virtual int Read(char[] buffer, int index, int count);
        public virtual int ReadBlock(char[] buffer, int index, int count);
        public virtual string ReadLine();
        public virtual string ReadToEnd();
        public static TextReader Synchronized(TextReader reader);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class TextWriter: MarshalByRefObject, IDisposable
    {
        protected TextWriter();
        protected TextWriter(IFormatProvider formatProvider);
        protected char[] CoreNewLine;
        public static readonly TextWriter Null;
        public abstract Encoding Encoding { get; }
        public virtual IFormatProvider FormatProvider { get; }
        public virtual string NewLine { get; set; }
        public virtual void Close();
        protected virtual void Dispose(bool disposing);
        public virtual void Flush();
        public static TextWriter Synchronized(TextWriter writer);
        public virtual void Write(bool value);
        public virtual void Write(char value);
        public virtual void Write(char[] buffer);
        public virtual void Write(char[] buffer, int index, int count);
        public virtual void Write(decimal value);
        public virtual void Write(double value);
        public virtual void Write(float value);
        public virtual void Write(int value);
        public virtual void Write(long value);
        public virtual void Write(object value);
        public virtual void Write(string value);
        public virtual void Write(string format, object arg0);
        public virtual void Write(string format, object arg0, object arg1);
        public virtual void Write(string format, object arg0, object arg1, object arg2);
        public virtual void Write(string format, params object[] arg);
        public virtual void Write(uint value);
        public virtual void Write(ulong value);
        public virtual void WriteLine();
        public virtual void WriteLine(bool value);
        public virtual void WriteLine(char value);
        public virtual void WriteLine(char[] buffer);
        public virtual void WriteLine(char[] buffer, int index, int count);
        public virtual void WriteLine(decimal value);
        public virtual void WriteLine(double value);
        public virtual void WriteLine(float value);
        public virtual void WriteLine(int value);
        public virtual void WriteLine(long value);
        public virtual void WriteLine(object value);
        public virtual void WriteLine(string value);
        public virtual void WriteLine(string format, object arg0);
        public virtual void WriteLine(string format, object arg0, object arg1);
        public virtual void WriteLine(string format, object arg0, object arg1, object arg2);
        public virtual void WriteLine(string format, params object[] arg);
        public virtual void WriteLine(uint value);
        public virtual void WriteLine(ulong value);
    }

    [CLSCompliantAttribute(..)]
    public class UnmanagedMemoryStream: Stream, IDisposable
    {
        protected UnmanagedMemoryStream();
        public UnmanagedMemoryStream(byte* pointer, long length);
        public UnmanagedMemoryStream(byte* pointer, long length, long capacity, FileAccess access);
        public long Capacity { get; }
        public byte* PositionPointer { get; set; }
        protected override void Dispose(bool disposing);
        public override void Flush();
        protected void Initialize(byte* pointer, long length, long capacity, FileAccess access);
        public override int Read(byte[] buffer, int offset, int count);
        public override int ReadByte();
        public override long Seek(long offset, SeekOrigin loc);
        public override void SetLength(long value);
        public override void Write(byte[] buffer, int offset, int count);
        public override void WriteByte(byte value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum DriveType
    {
        CDRom,
        Fixed,
        Network,
        NoRootDirectory,
        Ram,
        Removable,
        Unknown,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum FileAccess
    {
        Read,
        ReadWrite,
        Write,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FileAttributes
    {
        Archive,
        Compressed,
        Device,
        Directory,
        Encrypted,
        Hidden,
        Normal,
        NotContentIndexed,
        Offline,
        ReadOnly,
        ReparsePoint,
        SparseFile,
        System,
        Temporary,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FileMode
    {
        Append,
        Create,
        CreateNew,
        Open,
        OpenOrCreate,
        Truncate,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FileOptions
    {
        Asynchronous,
        DeleteOnClose,
        Encrypted,
        None,
        RandomAccess,
        SequentialScan,
        WriteThrough,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FileShare
    {
        Delete,
        Inheritable,
        None,
        Read,
        ReadWrite,
        Write,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum SearchOption
    {
        AllDirectories,
        TopDirectoryOnly,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum SeekOrigin
    {
        Begin,
        Current,
        End,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class DirectoryNotFoundException: IOException, _Exception, ISerializable
    {
        public DirectoryNotFoundException();
        protected DirectoryNotFoundException(SerializationInfo info, StreamingContext context);
        public DirectoryNotFoundException(string message);
        public DirectoryNotFoundException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class DriveNotFoundException: IOException, _Exception, ISerializable
    {
        public DriveNotFoundException();
        protected DriveNotFoundException(SerializationInfo info, StreamingContext context);
        public DriveNotFoundException(string message);
        public DriveNotFoundException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class EndOfStreamException: IOException, _Exception, ISerializable
    {
        public EndOfStreamException();
        protected EndOfStreamException(SerializationInfo info, StreamingContext context);
        public EndOfStreamException(string message);
        public EndOfStreamException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class FileLoadException: IOException, _Exception, ISerializable
    {
        public FileLoadException();
        protected FileLoadException(SerializationInfo info, StreamingContext context);
        public FileLoadException(string message);
        public FileLoadException(string message, Exception inner);
        public FileLoadException(string message, string fileName);
        public FileLoadException(string message, string fileName, Exception inner);
        public string FileName { get; }
        public string FusionLog { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class FileNotFoundException: IOException, _Exception, ISerializable
    {
        public FileNotFoundException();
        protected FileNotFoundException(SerializationInfo info, StreamingContext context);
        public FileNotFoundException(string message);
        public FileNotFoundException(string message, Exception innerException);
        public FileNotFoundException(string message, string fileName);
        public FileNotFoundException(string message, string fileName, Exception innerException);
        public string FileName { get; }
        public string FusionLog { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class IOException: SystemException, _Exception, ISerializable
    {
        public IOException();
        protected IOException(SerializationInfo info, StreamingContext context);
        public IOException(string message);
        public IOException(string message, Exception innerException);
        public IOException(string message, int hresult);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class PathTooLongException: IOException, _Exception, ISerializable
    {
        public PathTooLongException();
        protected PathTooLongException(SerializationInfo info, StreamingContext context);
        public PathTooLongException(string message);
        public PathTooLongException(string message, Exception innerException);
    }

} 
namespace System.IO.IsolatedStorage
{
    [ComVisibleAttribute(..)]
    public interface INormalizeForIsolatedStorage
    {
        public object Normalize();
    }

    [ComVisibleAttribute(..)]
    public abstract class IsolatedStorage: MarshalByRefObject
    {
        protected IsolatedStorage();
        public object ApplicationIdentity { get; }
        public object AssemblyIdentity { get; }
        public virtual ulong CurrentSize { get; }
        public object DomainIdentity { get; }
        public virtual ulong MaximumSize { get; }
        public IsolatedStorageScope Scope { get; }
        protected abstract IsolatedStoragePermission GetPermission(PermissionSet ps);
        protected void InitStore(IsolatedStorageScope scope, Type appEvidenceType);
        protected void InitStore(IsolatedStorageScope scope, Type domainEvidenceType, Type assemblyEvidenceType);
        public abstract void Remove();
    }

    [ComVisibleAttribute(..)]
    public sealed class IsolatedStorageFile: IsolatedStorage, IDisposable
    {
        public void Close();
        public void CreateDirectory(string dir);
        public void DeleteDirectory(string dir);
        public void DeleteFile(string file);
        public void Dispose();
        protected override void Finalize();
        public string[] GetDirectoryNames(string searchPattern);
        public static IEnumerator GetEnumerator(IsolatedStorageScope scope);
        public string[] GetFileNames(string searchPattern);
        public static IsolatedStorageFile GetMachineStoreForApplication();
        public static IsolatedStorageFile GetMachineStoreForAssembly();
        public static IsolatedStorageFile GetMachineStoreForDomain();
        protected override IsolatedStoragePermission GetPermission(PermissionSet ps);
        public static IsolatedStorageFile GetStore(IsolatedStorageScope scope, Evidence domainEvidence, Type domainEvidenceType, Evidence assemblyEvidence, Type assemblyEvidenceType);
        public static IsolatedStorageFile GetStore(IsolatedStorageScope scope, object applicationIdentity);
        public static IsolatedStorageFile GetStore(IsolatedStorageScope scope, object domainIdentity, object assemblyIdentity);
        public static IsolatedStorageFile GetStore(IsolatedStorageScope scope, Type applicationEvidenceType);
        public static IsolatedStorageFile GetStore(IsolatedStorageScope scope, Type domainEvidenceType, Type assemblyEvidenceType);
        public static IsolatedStorageFile GetUserStoreForApplication();
        public static IsolatedStorageFile GetUserStoreForAssembly();
        public static IsolatedStorageFile GetUserStoreForDomain();
        public override void Remove();
        public static void Remove(IsolatedStorageScope scope);
    }

    [ComVisibleAttribute(..)]
    public class IsolatedStorageFileStream: FileStream, IDisposable
    {
        public IsolatedStorageFileStream(string path, FileMode mode);
        public IsolatedStorageFileStream(string path, FileMode mode, FileAccess access);
        public IsolatedStorageFileStream(string path, FileMode mode, FileAccess access, FileShare share);
        public IsolatedStorageFileStream(string path, FileMode mode, FileAccess access, FileShare share, int bufferSize);
        public IsolatedStorageFileStream(string path, FileMode mode, FileAccess access, FileShare share, int bufferSize, IsolatedStorageFile isf);
        public IsolatedStorageFileStream(string path, FileMode mode, FileAccess access, FileShare share, IsolatedStorageFile isf);
        public IsolatedStorageFileStream(string path, FileMode mode, FileAccess access, IsolatedStorageFile isf);
        public IsolatedStorageFileStream(string path, FileMode mode, IsolatedStorageFile isf);
        public override IAsyncResult BeginRead(byte[] buffer, int offset, int numBytes, AsyncCallback userCallback, object stateObject);
        public override IAsyncResult BeginWrite(byte[] buffer, int offset, int numBytes, AsyncCallback userCallback, object stateObject);
        protected override void Dispose(bool disposing);
        public override int EndRead(IAsyncResult asyncResult);
        public override void EndWrite(IAsyncResult asyncResult);
        public override void Flush();
        public override int Read(byte[] buffer, int offset, int count);
        public override int ReadByte();
        public override long Seek(long offset, SeekOrigin origin);
        public override void SetLength(long value);
        public override void Write(byte[] buffer, int offset, int count);
        public override void WriteByte(byte value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum IsolatedStorageScope
    {
        Application,
        Assembly,
        Domain,
        Machine,
        None,
        Roaming,
        User,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class IsolatedStorageException: Exception, _Exception, ISerializable
    {
        public IsolatedStorageException();
        protected IsolatedStorageException(SerializationInfo info, StreamingContext context);
        public IsolatedStorageException(string message);
        public IsolatedStorageException(string message, Exception inner);
    }

} 
namespace System.Reflection
{
    [SerializableAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public class Assembly: _Assembly, ICustomAttributeProvider, IEvidenceFactory, ISerializable
    {
        public virtual string CodeBase { get; }
        public virtual MethodInfo EntryPoint { get; }
        public virtual string EscapedCodeBase { get; }
        public virtual Evidence Evidence { get; }
        public virtual string FullName { get; }
        public bool GlobalAssemblyCache { get; }
        public long HostContext { get; }
        public ImageFileMachine ImageFileMachine { get; }
        public virtual string ImageRuntimeVersion { get; }
        public virtual string Location { get; }
        public Module ManifestModule { get; }
        public int MetadataToken { get; }
        public PortableExecutableKinds PortableExecutableKinds { get; }
        public virtual bool ReflectionOnly { get; }
        public object CreateInstance(string typeName);
        public object CreateInstance(string typeName, bool ignoreCase);
        public object CreateInstance(string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes);
        public static string CreateQualifiedName(string assemblyName, string typeName);
        public static Assembly GetAssembly(Type type);
        public static Assembly GetCallingAssembly();
        public virtual object[] GetCustomAttributes(bool inherit);
        public virtual object[] GetCustomAttributes(Type attributeType, bool inherit);
        public static Assembly GetEntryAssembly();
        public static Assembly GetExecutingAssembly();
        public virtual Type[] GetExportedTypes();
        public virtual FileStream GetFile(string name);
        public virtual FileStream[] GetFiles();
        public virtual FileStream[] GetFiles(bool getResourceModules);
        public Module[] GetLoadedModules();
        public Module[] GetLoadedModules(bool getResourceModules);
        public virtual ManifestResourceInfo GetManifestResourceInfo(string resourceName);
        public virtual string[] GetManifestResourceNames();
        public virtual Stream GetManifestResourceStream(string name);
        public virtual Stream GetManifestResourceStream(Type type, string name);
        public Module GetModule(string name);
        public Module[] GetModules();
        public Module[] GetModules(bool getResourceModules);
        public virtual AssemblyName GetName();
        public virtual AssemblyName GetName(bool copiedName);
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public AssemblyName[] GetReferencedAssemblies();
        public Assembly GetSatelliteAssembly(CultureInfo culture);
        public Assembly GetSatelliteAssembly(CultureInfo culture, Version version);
        public virtual Type GetType(string name);
        public virtual Type GetType(string name, bool throwOnError);
        public Type GetType(string name, bool throwOnError, bool ignoreCase);
        public virtual Type[] GetTypes();
        public virtual bool IsDefined(Type attributeType, bool inherit);
        public static Assembly Load(AssemblyName assemblyRef);
        public static Assembly Load(AssemblyName assemblyRef, Evidence assemblySecurity);
        public static Assembly Load(byte[] rawAssembly);
        public static Assembly Load(byte[] rawAssembly, byte[] rawSymbolStore);
        public static Assembly Load(byte[] rawAssembly, byte[] rawSymbolStore, Evidence securityEvidence);
        public static Assembly Load(string assemblyString);
        public static Assembly Load(string assemblyString, Evidence assemblySecurity);
        public static Assembly LoadFile(string path);
        public static Assembly LoadFile(string path, Evidence securityEvidence);
        public static Assembly LoadFrom(string assemblyFile);
        public static Assembly LoadFrom(string assemblyFile, Evidence securityEvidence);
        public static Assembly LoadFrom(string assemblyFile, Evidence securityEvidence, byte[] hashValue, AssemblyHashAlgorithm hashAlgorithm);
        public Module LoadModule(string moduleName, byte[] rawModule);
        public Module LoadModule(string moduleName, byte[] rawModule, byte[] rawSymbolStore);
        public static Assembly LoadWithPartialName(string partialName);
        public static Assembly LoadWithPartialName(string partialName, Evidence securityEvidence);
        public static Assembly ReflectionOnlyLoad(byte[] rawAssembly);
        public static Assembly ReflectionOnlyLoad(string assemblyString);
        public static Assembly ReflectionOnlyLoadFrom(string assemblyFile);
        public override string ToString();
        public event ModuleResolveEventHandler ModuleResolve;
    }

    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public sealed class AssemblyName: _AssemblyName, ICloneable, IDeserializationCallback, ISerializable
    {
        public AssemblyName();
        public AssemblyName(string assemblyName);
        public string CodeBase { get; set; }
        public CultureInfo CultureInfo { get; set; }
        public string EscapedCodeBase { get; }
        public AssemblyNameFlags Flags { get; set; }
        public string FullName { get; }
        public AssemblyHashAlgorithm HashAlgorithm { get; set; }
        public StrongNameKeyPair KeyPair { get; set; }
        public string Name { get; set; }
        public ProcessorArchitecture ProcessorArchitecture { get; set; }
        public Version Version { get; set; }
        public AssemblyVersionCompatibility VersionCompatibility { get; set; }
        public object Clone();
        public static AssemblyName GetAssemblyName(string assemblyFile);
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public byte[] GetPublicKey();
        public byte[] GetPublicKeyToken();
        public void OnDeserialization(object sender);
        public static bool ReferenceMatchesDefinition(AssemblyName reference, AssemblyName definition);
        public void SetPublicKey(byte[] publicKey);
        public void SetPublicKeyToken(byte[] publicKeyToken);
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public class AssemblyNameProxy: MarshalByRefObject
    {
        public AssemblyNameProxy();
        public AssemblyName GetAssemblyName(string assemblyFile);
    }

    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Binder
    {
        protected Binder();
        public abstract FieldInfo BindToField(BindingFlags bindingAttr, FieldInfo[] match, object value, CultureInfo culture);
        public abstract MethodBase BindToMethod(BindingFlags bindingAttr, MethodBase[] match, ref object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] names, ref object state);
        public abstract object ChangeType(object value, Type type, CultureInfo culture);
        public abstract void ReorderArgumentArray(ref object[] args, object state);
        public abstract MethodBase SelectMethod(BindingFlags bindingAttr, MethodBase[] match, Type[] types, ParameterModifier[] modifiers);
        public abstract PropertyInfo SelectProperty(BindingFlags bindingAttr, PropertyInfo[] match, Type returnType, Type[] indexes, ParameterModifier[] modifiers);
    }

    [PermissionSetAttribute(..)]
    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public abstract class ConstructorInfo: MethodBase, _ConstructorInfo, _MemberInfo, _MethodBase, ICustomAttributeProvider
    {
        protected ConstructorInfo();
        public static readonly string ConstructorName;
        public static readonly string TypeConstructorName;
        public abstract object Invoke(BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public object Invoke(object[] parameters);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class CustomAttributeData
    {
        public ConstructorInfo Constructor { get; }
        public IList<CustomAttributeTypedArgument> ConstructorArguments { get; }
        public IList<CustomAttributeNamedArgument> NamedArguments { get; }
        public override bool Equals(object obj);
        public static IList<CustomAttributeData> GetCustomAttributes(Assembly target);
        public static IList<CustomAttributeData> GetCustomAttributes(MemberInfo target);
        public static IList<CustomAttributeData> GetCustomAttributes(Module target);
        public static IList<CustomAttributeData> GetCustomAttributes(ParameterInfo target);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct CustomAttributeNamedArgument
    {
        public MemberInfo MemberInfo { get; }
        public CustomAttributeTypedArgument TypedValue { get; }
        public override bool Equals(object obj);
        public override int GetHashCode();
        public override string ToString();
        public static bool operator ==(CustomAttributeNamedArgument left, CustomAttributeNamedArgument right);
        public static bool operator !=(CustomAttributeNamedArgument left, CustomAttributeNamedArgument right);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct CustomAttributeTypedArgument
    {
        public Type ArgumentType { get; }
        public object Value { get; }
        public override bool Equals(object obj);
        public override int GetHashCode();
        public override string ToString();
        public static bool operator ==(CustomAttributeTypedArgument left, CustomAttributeTypedArgument right);
        public static bool operator !=(CustomAttributeTypedArgument left, CustomAttributeTypedArgument right);
    }

    [PermissionSetAttribute(..)]
    [SerializableAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class EventInfo: MemberInfo, _EventInfo, _MemberInfo, ICustomAttributeProvider
    {
        protected EventInfo();
        public abstract EventAttributes Attributes { get; }
        public Type EventHandlerType { get; }
        public bool IsMulticast { get; }
        public bool IsSpecialName { get; }
        public void AddEventHandler(object target, Delegate handler);
        public MethodInfo GetAddMethod();
        public abstract MethodInfo GetAddMethod(bool nonPublic);
        public MethodInfo[] GetOtherMethods();
        public virtual MethodInfo[] GetOtherMethods(bool nonPublic);
        public MethodInfo GetRaiseMethod();
        public abstract MethodInfo GetRaiseMethod(bool nonPublic);
        public MethodInfo GetRemoveMethod();
        public abstract MethodInfo GetRemoveMethod(bool nonPublic);
        public void RemoveEventHandler(object target, Delegate handler);
    }

    [ComVisibleAttribute(..)]
    public sealed class ExceptionHandlingClause
    {
        public Type CatchType { get; }
        public int FilterOffset { get; }
        public ExceptionHandlingClauseOptions Flags { get; }
        public int HandlerLength { get; }
        public int HandlerOffset { get; }
        public int TryLength { get; }
        public int TryOffset { get; }
        public override string ToString();
    }

    [PermissionSetAttribute(..)]
    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public abstract class FieldInfo: MemberInfo, _FieldInfo, _MemberInfo, ICustomAttributeProvider
    {
        protected FieldInfo();
        public abstract FieldAttributes Attributes { get; }
        public abstract RuntimeFieldHandle FieldHandle { get; }
        public abstract Type FieldType { get; }
        public bool IsAssembly { get; }
        public bool IsFamily { get; }
        public bool IsFamilyAndAssembly { get; }
        public bool IsFamilyOrAssembly { get; }
        public bool IsInitOnly { get; }
        public bool IsLiteral { get; }
        public bool IsNotSerialized { get; }
        public bool IsPinvokeImpl { get; }
        public bool IsPrivate { get; }
        public bool IsPublic { get; }
        public bool IsSpecialName { get; }
        public bool IsStatic { get; }
        public virtual Type[] OptionalCustomModifiers { get; }
        public virtual Type[] RequiredCustomModifiers { get; }
        public static FieldInfo GetFieldFromHandle(RuntimeFieldHandle handle);
        public static FieldInfo GetFieldFromHandle(RuntimeFieldHandle handle, RuntimeTypeHandle declaringType);
        public virtual Type[] GetOptionalCustomModifiers();
        public virtual object GetRawConstantValue();
        public virtual Type[] GetRequiredCustomModifiers();
        public abstract object GetValue(object obj);
        public virtual object GetValueDirect(TypedReference obj);
        public void SetValue(object obj, object value);
        public abstract void SetValue(object obj, object value, BindingFlags invokeAttr, Binder binder, CultureInfo culture);
        public virtual void SetValueDirect(TypedReference obj, object value);
    }

    [ComVisibleAttribute(..)]
    public interface ICustomAttributeProvider
    {
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public bool IsDefined(Type attributeType, bool inherit);
    }

    [ComVisibleAttribute(..)]
    public struct InterfaceMapping
    {
        public MethodInfo[] InterfaceMethods;
        public Type InterfaceType;
        public MethodInfo[] TargetMethods;
        public Type TargetType;
    }

    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    public interface IReflect
    {
        public Type UnderlyingSystemType { get; }
        public FieldInfo GetField(string name, BindingFlags bindingAttr);
        public FieldInfo[] GetFields(BindingFlags bindingAttr);
        public MemberInfo[] GetMember(string name, BindingFlags bindingAttr);
        public MemberInfo[] GetMembers(BindingFlags bindingAttr);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr, Binder binder, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo[] GetMethods(BindingFlags bindingAttr);
        public PropertyInfo[] GetProperties(BindingFlags bindingAttr);
        public PropertyInfo GetProperty(string name, BindingFlags bindingAttr);
        public PropertyInfo GetProperty(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        public object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] namedParameters);
    }

    [ComVisibleAttribute(..)]
    public class LocalVariableInfo
    {
        public virtual bool IsPinned { get; }
        public virtual int LocalIndex { get; }
        public virtual Type LocalType { get; }
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public class ManifestResourceInfo
    {
        public virtual string FileName { get; }
        public virtual Assembly ReferencedAssembly { get; }
        public virtual ResourceLocation ResourceLocation { get; }
    }

    [PermissionSetAttribute(..)]
    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public abstract class MemberInfo: _MemberInfo, ICustomAttributeProvider
    {
        protected MemberInfo();
        public abstract Type DeclaringType { get; }
        public abstract MemberTypes MemberType { get; }
        public virtual int MetadataToken { get; }
        public virtual Module Module { get; }
        public abstract string Name { get; }
        public abstract Type ReflectedType { get; }
        public abstract object[] GetCustomAttributes(bool inherit);
        public abstract object[] GetCustomAttributes(Type attributeType, bool inherit);
        public abstract bool IsDefined(Type attributeType, bool inherit);
    }

    [PermissionSetAttribute(..)]
    [SerializableAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class MethodBase: MemberInfo, _MemberInfo, _MethodBase, ICustomAttributeProvider
    {
        protected MethodBase();
        public abstract MethodAttributes Attributes { get; }
        public virtual CallingConventions CallingConvention { get; }
        public virtual bool ContainsGenericParameters { get; }
        public virtual bool HasGenericArguments { get; }
        public bool IsAbstract { get; }
        public bool IsAssembly { get; }
        public bool IsConstructor { get; }
        public bool IsFamily { get; }
        public bool IsFamilyAndAssembly { get; }
        public bool IsFamilyOrAssembly { get; }
        public bool IsFinal { get; }
        public virtual bool IsGenericMethod { get; }
        public virtual bool IsGenericMethodDefinition { get; }
        public bool IsHideBySig { get; }
        public bool IsPrivate { get; }
        public bool IsPublic { get; }
        public bool IsSpecialName { get; }
        public bool IsStatic { get; }
        public bool IsVirtual { get; }
        public abstract RuntimeMethodHandle MethodHandle { get; }
        public virtual MethodInfo BindGenericParameters(params Type[] typeArguments);
        public static MethodBase GetCurrentMethod();
        public virtual Type[] GetGenericArguments();
        public MethodInfo GetGenericMethodDefinition();
        public virtual MethodBody GetMethodBody();
        public static MethodBase GetMethodFromHandle(RuntimeMethodHandle handle);
        public static MethodBase GetMethodFromHandle(RuntimeMethodHandle handle, RuntimeTypeHandle declaringType);
        public abstract MethodImplAttributes GetMethodImplementationFlags();
        public abstract ParameterInfo[] GetParameters();
        public abstract object Invoke(object obj, BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public object Invoke(object obj, object[] parameters);
        public MethodInfo MakeGenericMethod(params Type[] typeArguments);
    }

    [ComVisibleAttribute(..)]
    public sealed class MethodBody
    {
        public IList<ExceptionHandlingClause> ExceptionHandlingClauses { get; }
        public bool InitLocals { get; }
        public int LocalSignatureMetadataToken { get; }
        public IList<LocalVariableInfo> LocalVariables { get; }
        public int MaxStackSize { get; }
        public byte[] GetILAsByteArray();
    }

    [PermissionSetAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public abstract class MethodInfo: MethodBase, _MemberInfo, _MethodBase, _MethodInfo, ICustomAttributeProvider
    {
        protected MethodInfo();
        public virtual ParameterInfo ReturnParameter { get; }
        public virtual Type ReturnType { get; }
        public abstract ICustomAttributeProvider ReturnTypeCustomAttributes { get; }
        public override MethodInfo BindGenericParameters(params Type[] typeArguments);
        public abstract MethodInfo GetBaseDefinition();
        public override Type[] GetGenericArguments();
        public virtual MethodInfo GetGenericMethodDefinition();
        public virtual MethodInfo MakeGenericMethod(params Type[] typeArguments);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Missing: ISerializable
    {
        public static readonly Missing Value;
    }

    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public class Module: _Module, ICustomAttributeProvider, ISerializable
    {
        public static readonly TypeFilter FilterTypeName;
        public static readonly TypeFilter FilterTypeNameIgnoreCase;
        public Assembly Assembly { get; }
        public virtual string FullyQualifiedName { get; }
        public int MetadataToken { get; }
        public ModuleHandle ModuleHandle { get; }
        public Guid ModuleVersionId { get; }
        public Guid Mvid { get; }
        public string Name { get; }
        public string ScopeName { get; }
        public virtual Type[] FindTypes(TypeFilter filter, object filterCriteria);
        public virtual object[] GetCustomAttributes(bool inherit);
        public virtual object[] GetCustomAttributes(Type attributeType, bool inherit);
        public FieldInfo GetField(string name);
        public FieldInfo GetField(string name, BindingFlags bindingAttr);
        public FieldInfo[] GetFields();
        public FieldInfo[] GetFields(BindingFlags bindingFlags);
        public MethodInfo GetMethod(string name);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo GetMethod(string name, Type[] types);
        protected virtual MethodInfo GetMethodImpl(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo[] GetMethods();
        public MethodInfo[] GetMethods(BindingFlags bindingFlags);
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public void GetPEKind(ref PortableExecutableKinds peKind, ref ImageFileMachine machine);
        public X509Certificate GetSignerCertificate();
        public virtual Type GetType(string className);
        public virtual Type GetType(string className, bool ignoreCase);
        public virtual Type GetType(string className, bool throwOnError, bool ignoreCase);
        public virtual Type[] GetTypes();
        public virtual bool IsDefined(Type attributeType, bool inherit);
        public bool IsResource();
        public FieldInfo ResolveField(int metadataToken);
        public FieldInfo ResolveField(int metadataToken, Type[] genericTypeArguments, Type[] genericMethodArguments);
        public MemberInfo ResolveMember(int metadataToken);
        public MemberInfo ResolveMember(int metadataToken, Type[] genericTypeArguments, Type[] genericMethodArguments);
        public MethodBase ResolveMethod(int metadataToken);
        public MethodBase ResolveMethod(int metadataToken, Type[] genericTypeArguments, Type[] genericMethodArguments);
        public string ResolveString(int metadataToken);
        public Type ResolveType(int metadataToken);
        public Type ResolveType(int metadataToken, Type[] genericTypeArguments, Type[] genericMethodArguments);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ParameterInfo: _ParameterInfo, ICustomAttributeProvider
    {
        protected ParameterInfo();
        protected ParameterAttributes AttrsImpl;
        protected Type ClassImpl;
        protected object DefaultValueImpl;
        protected MemberInfo MemberImpl;
        protected string NameImpl;
        protected int PositionImpl;
        public virtual ParameterAttributes Attributes { get; }
        public virtual object DefaultValue { get; }
        public bool IsIn { get; }
        public bool IsLcid { get; }
        public bool IsOptional { get; }
        public bool IsOut { get; }
        public bool IsRetval { get; }
        public virtual MemberInfo Member { get; }
        public int MetadataToken { get; }
        public virtual string Name { get; }
        public virtual Type[] OptionalCustomModifiers { get; }
        public virtual Type ParameterType { get; }
        public virtual int Position { get; }
        public virtual object RawDefaultValue { get; }
        public virtual Type[] RequiredCustomModifiers { get; }
        public virtual object[] GetCustomAttributes(bool inherit);
        public virtual object[] GetCustomAttributes(Type attributeType, bool inherit);
        public virtual Type[] GetOptionalCustomModifiers();
        public virtual Type[] GetRequiredCustomModifiers();
        public virtual bool IsDefined(Type attributeType, bool inherit);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public struct ParameterModifier
    {
        public ParameterModifier(int parameterCount);
        public bool this[int index] { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public sealed class Pointer: ISerializable
    {
        public static object Box(void* ptr, Type type);
        public static void* Unbox(object ptr);
    }

    [PermissionSetAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public abstract class PropertyInfo: MemberInfo, _MemberInfo, _PropertyInfo, ICustomAttributeProvider
    {
        protected PropertyInfo();
        public abstract PropertyAttributes Attributes { get; }
        public abstract bool CanRead { get; }
        public abstract bool CanWrite { get; }
        public bool IsSpecialName { get; }
        public virtual Type[] OptionalCustomModifiers { get; }
        public abstract Type PropertyType { get; }
        public virtual Type[] RequiredCustomModifiers { get; }
        public MethodInfo[] GetAccessors();
        public abstract MethodInfo[] GetAccessors(bool nonPublic);
        public virtual object GetConstantValue();
        public MethodInfo GetGetMethod();
        public abstract MethodInfo GetGetMethod(bool nonPublic);
        public abstract ParameterInfo[] GetIndexParameters();
        public virtual Type[] GetOptionalCustomModifiers();
        public virtual object GetRawConstantValue();
        public virtual Type[] GetRequiredCustomModifiers();
        public MethodInfo GetSetMethod();
        public abstract MethodInfo GetSetMethod(bool nonPublic);
        public abstract object GetValue(object obj, BindingFlags invokeAttr, Binder binder, object[] index, CultureInfo culture);
        public virtual object GetValue(object obj, object[] index);
        public abstract void SetValue(object obj, object value, BindingFlags invokeAttr, Binder binder, object[] index, CultureInfo culture);
        public virtual void SetValue(object obj, object value, object[] index);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class StrongNameKeyPair: IDeserializationCallback, ISerializable
    {
        public StrongNameKeyPair(byte[] keyPairArray);
        public StrongNameKeyPair(FileStream keyPairFile);
        protected StrongNameKeyPair(SerializationInfo info, StreamingContext context);
        public StrongNameKeyPair(string keyPairContainer);
        public byte[] PublicKey { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TypeDelegator: Type, _MemberInfo, _Type, ICustomAttributeProvider, IReflect
    {
        protected TypeDelegator();
        public TypeDelegator(Type delegatingType);
        protected Type typeImpl;
        protected override TypeAttributes GetAttributeFlagsImpl();
        protected override ConstructorInfo GetConstructorImpl(BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override ConstructorInfo[] GetConstructors(BindingFlags bindingAttr);
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public override Type GetElementType();
        public override EventInfo GetEvent(string name, BindingFlags bindingAttr);
        public override EventInfo[] GetEvents();
        public override EventInfo[] GetEvents(BindingFlags bindingAttr);
        public override FieldInfo GetField(string name, BindingFlags bindingAttr);
        public override FieldInfo[] GetFields(BindingFlags bindingAttr);
        public override Type GetInterface(string name, bool ignoreCase);
        public override InterfaceMapping GetInterfaceMap(Type interfaceType);
        public override Type[] GetInterfaces();
        public override MemberInfo[] GetMember(string name, MemberTypes type, BindingFlags bindingAttr);
        public override MemberInfo[] GetMembers(BindingFlags bindingAttr);
        protected override MethodInfo GetMethodImpl(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override MethodInfo[] GetMethods(BindingFlags bindingAttr);
        public override Type GetNestedType(string name, BindingFlags bindingAttr);
        public override Type[] GetNestedTypes(BindingFlags bindingAttr);
        public override PropertyInfo[] GetProperties(BindingFlags bindingAttr);
        protected override PropertyInfo GetPropertyImpl(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        protected override bool HasElementTypeImpl();
        public override object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] namedParameters);
        protected override bool IsArrayImpl();
        protected override bool IsByRefImpl();
        protected override bool IsCOMObjectImpl();
        public override bool IsDefined(Type attributeType, bool inherit);
        protected override bool IsPointerImpl();
        protected override bool IsPrimitiveImpl();
        protected override bool IsValueTypeImpl();
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum AssemblyNameFlags
    {
        AppDomainPlatform,
        EnableJITcompileOptimizer,
        EnableJITcompileTracking,
        Library,
        LongevityMask,
        LongevityUnspecified,
        None,
        ProcessPlatform,
        PublicKey,
        Retargetable,
        SystemPlatform,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum BindingFlags
    {
        CreateInstance,
        DeclaredOnly,
        Default,
        ExactBinding,
        FlattenHierarchy,
        GetField,
        GetProperty,
        IgnoreCase,
        IgnoreReturn,
        Instance,
        InvokeMethod,
        NonPublic,
        OptionalParamBinding,
        Public,
        PutDispProperty,
        PutRefDispProperty,
        SetField,
        SetProperty,
        Static,
        SuppressChangeType,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum CallingConventions
    {
        Any,
        ExplicitThis,
        HasThis,
        Standard,
        VarArgs,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum EventAttributes
    {
        None,
        ReservedMask,
        RTSpecialName,
        SpecialName,
    }

    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ExceptionHandlingClauseOptions
    {
        Clause,
        Fault,
        Filter,
        Finally,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FieldAttributes
    {
        Assembly,
        FamANDAssem,
        Family,
        FamORAssem,
        FieldAccessMask,
        HasDefault,
        HasFieldMarshal,
        HasFieldRVA,
        InitOnly,
        Literal,
        NotSerialized,
        PinvokeImpl,
        Private,
        PrivateScope,
        Public,
        ReservedMask,
        RTSpecialName,
        SpecialName,
        Static,
    }

    [FlagsAttribute(..)]
    public enum GenericParameterAttributes
    {
        Contravariant,
        Covariant,
        DefaultConstructorConstraint,
        None,
        NonVariant,
        NoSpecialConstraint,
        NotNullableValueTypeConstraint,
        ReferenceTypeConstraint,
        SpecialConstraintMask,
        ValueTypeConstraint,
        VarianceMask,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ImageFileMachine
    {
        AMD64,
        I386,
        IA64,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum MemberTypes
    {
        All,
        Constructor,
        Custom,
        Event,
        Field,
        Method,
        NestedType,
        Property,
        TypeInfo,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum MethodAttributes
    {
        Abstract,
        Assembly,
        CheckAccessOnOverride,
        FamANDAssem,
        Family,
        FamORAssem,
        Final,
        HasSecurity,
        HideBySig,
        MemberAccessMask,
        NewSlot,
        PinvokeImpl,
        Private,
        PrivateScope,
        Public,
        RequireSecObject,
        ReservedMask,
        ReuseSlot,
        RTSpecialName,
        SpecialName,
        Static,
        UnmanagedExport,
        Virtual,
        VtableLayoutMask,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum MethodImplAttributes
    {
        CodeTypeMask,
        ForwardRef,
        IL,
        InternalCall,
        Managed,
        ManagedMask,
        MaxMethodImplVal,
        Native,
        NoInlining,
        OPTIL,
        PreserveSig,
        Runtime,
        Synchronized,
        Unmanaged,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ParameterAttributes
    {
        HasDefault,
        HasFieldMarshal,
        In,
        Lcid,
        None,
        Optional,
        Out,
        Reserved3,
        Reserved4,
        ReservedMask,
        Retval,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PortableExecutableKinds
    {
        ILOnly,
        NotAPortableExecutableImage,
        PE32Plus,
        Plus32Bit,
        Required32Bit,
        Unmanaged32Bit,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ProcessorArchitecture
    {
        Amd64,
        IA64,
        MSIL,
        None,
        X86,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum PropertyAttributes
    {
        HasDefault,
        None,
        Reserved2,
        Reserved3,
        Reserved4,
        ReservedMask,
        RTSpecialName,
        SpecialName,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum ResourceAttributes
    {
        Private,
        Public,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ResourceLocation
    {
        ContainedInAnotherAssembly,
        ContainedInManifestFile,
        Embedded,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum TypeAttributes
    {
        Abstract,
        AnsiClass,
        AutoClass,
        AutoLayout,
        BeforeFieldInit,
        Class,
        ClassSemanticsMask,
        CustomFormatClass,
        CustomFormatMask,
        ExplicitLayout,
        HasSecurity,
        Import,
        Interface,
        LayoutMask,
        NestedAssembly,
        NestedFamANDAssem,
        NestedFamily,
        NestedFamORAssem,
        NestedPrivate,
        NestedPublic,
        NotPublic,
        Public,
        ReservedMask,
        RTSpecialName,
        Sealed,
        SequentialLayout,
        Serializable,
        SpecialName,
        StringFormatMask,
        UnicodeClass,
        VisibilityMask,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate bool MemberFilter(MemberInfo m, object filterCriteria);

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate Module ModuleResolveEventHandler(object sender, ResolveEventArgs e);

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public delegate bool TypeFilter(Type m, object filterCriteria);

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyAlgorithmIdAttribute: Attribute, _Attribute
    {
        public AssemblyAlgorithmIdAttribute(AssemblyHashAlgorithm algorithmId);
        public AssemblyAlgorithmIdAttribute(uint algorithmId);
        public uint AlgorithmId { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyCompanyAttribute: Attribute, _Attribute
    {
        public AssemblyCompanyAttribute(string company);
        public string Company { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyConfigurationAttribute: Attribute, _Attribute
    {
        public AssemblyConfigurationAttribute(string configuration);
        public string Configuration { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyCopyrightAttribute: Attribute, _Attribute
    {
        public AssemblyCopyrightAttribute(string copyright);
        public string Copyright { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyCultureAttribute: Attribute, _Attribute
    {
        public AssemblyCultureAttribute(string culture);
        public string Culture { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyDefaultAliasAttribute: Attribute, _Attribute
    {
        public AssemblyDefaultAliasAttribute(string defaultAlias);
        public string DefaultAlias { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyDelaySignAttribute: Attribute, _Attribute
    {
        public AssemblyDelaySignAttribute(bool delaySign);
        public bool DelaySign { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyDescriptionAttribute: Attribute, _Attribute
    {
        public AssemblyDescriptionAttribute(string description);
        public string Description { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyFileVersionAttribute: Attribute, _Attribute
    {
        public AssemblyFileVersionAttribute(string version);
        public string Version { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyFlagsAttribute: Attribute, _Attribute
    {
        public AssemblyFlagsAttribute(AssemblyNameFlags assemblyFlags);
        public AssemblyFlagsAttribute(int assemblyFlags);
        public AssemblyFlagsAttribute(uint flags);
        public int AssemblyFlags { get; }
        public uint Flags { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyInformationalVersionAttribute: Attribute, _Attribute
    {
        public AssemblyInformationalVersionAttribute(string informationalVersion);
        public string InformationalVersion { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyKeyFileAttribute: Attribute, _Attribute
    {
        public AssemblyKeyFileAttribute(string keyFile);
        public string KeyFile { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyKeyNameAttribute: Attribute, _Attribute
    {
        public AssemblyKeyNameAttribute(string keyName);
        public string KeyName { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyProductAttribute: Attribute, _Attribute
    {
        public AssemblyProductAttribute(string product);
        public string Product { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyTitleAttribute: Attribute, _Attribute
    {
        public AssemblyTitleAttribute(string title);
        public string Title { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AssemblyTrademarkAttribute: Attribute, _Attribute
    {
        public AssemblyTrademarkAttribute(string trademark);
        public string Trademark { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyVersionAttribute: Attribute, _Attribute
    {
        public AssemblyVersionAttribute(string version);
        public string Version { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DefaultMemberAttribute: Attribute, _Attribute
    {
        public DefaultMemberAttribute(string memberName);
        public string MemberName { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ObfuscateAssemblyAttribute: Attribute, _Attribute
    {
        public ObfuscateAssemblyAttribute(bool assemblyIsPrivate);
        public bool AssemblyIsPrivate { get; }
        public bool Strip { get; set; }
        public bool StripAfterObfuscation { get; set; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ObfuscationAttribute: Attribute, _Attribute
    {
        public ObfuscationAttribute();
        public bool ApplyToMembers { get; set; }
        public bool Exclude { get; set; }
        public string Feature { get; set; }
        public bool Strip { get; set; }
        public bool StripAfterObfuscation { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AmbiguousMatchException: SystemException, _Exception, ISerializable
    {
        public AmbiguousMatchException();
        public AmbiguousMatchException(string message);
        public AmbiguousMatchException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CustomAttributeFormatException: FormatException, _Exception, ISerializable
    {
        public CustomAttributeFormatException();
        protected CustomAttributeFormatException(SerializationInfo info, StreamingContext context);
        public CustomAttributeFormatException(string message);
        public CustomAttributeFormatException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class InvalidFilterCriteriaException: ApplicationException, _Exception, ISerializable
    {
        public InvalidFilterCriteriaException();
        protected InvalidFilterCriteriaException(SerializationInfo info, StreamingContext context);
        public InvalidFilterCriteriaException(string message);
        public InvalidFilterCriteriaException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ReflectionTypeLoadException: SystemException, _Exception, ISerializable
    {
        public ReflectionTypeLoadException(Type[] classes, Exception[] exceptions);
        public ReflectionTypeLoadException(Type[] classes, Exception[] exceptions, string message);
        public Exception[] LoaderExceptions { get; }
        public Type[] Types { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TargetException: ApplicationException, _Exception, ISerializable
    {
        public TargetException();
        protected TargetException(SerializationInfo info, StreamingContext context);
        public TargetException(string message);
        public TargetException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class TargetInvocationException: ApplicationException, _Exception, ISerializable
    {
        public TargetInvocationException(Exception inner);
        public TargetInvocationException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class TargetParameterCountException: ApplicationException, _Exception, ISerializable
    {
        public TargetParameterCountException();
        public TargetParameterCountException(string message);
        public TargetParameterCountException(string message, Exception inner);
    }

} 
namespace System.Reflection.Emit
{
    [HostProtectionAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AssemblyBuilder: Assembly, _Assembly, _AssemblyBuilder, ICustomAttributeProvider, IEvidenceFactory, ISerializable
    {
        public void AddResourceFile(string name, string fileName);
        public void AddResourceFile(string name, string fileName, ResourceAttributes attribute);
        public ModuleBuilder DefineDynamicModule(string name);
        public ModuleBuilder DefineDynamicModule(string name, bool emitSymbolInfo);
        public ModuleBuilder DefineDynamicModule(string name, string fileName);
        public ModuleBuilder DefineDynamicModule(string name, string fileName, bool emitSymbolInfo);
        public IResourceWriter DefineResource(string name, string description, string fileName);
        public IResourceWriter DefineResource(string name, string description, string fileName, ResourceAttributes attribute);
        public void DefineUnmanagedResource(byte[] resource);
        public void DefineUnmanagedResource(string resourceFileName);
        public void DefineVersionInfoResource();
        public void DefineVersionInfoResource(string product, string productVersion, string company, string copyright, string trademark);
        public ModuleBuilder GetDynamicModule(string name);
        public override Type[] GetExportedTypes();
        public override FileStream GetFile(string name);
        public override FileStream[] GetFiles(bool getResourceModules);
        public override ManifestResourceInfo GetManifestResourceInfo(string resourceName);
        public override string[] GetManifestResourceNames();
        public override Stream GetManifestResourceStream(string name);
        public override Stream GetManifestResourceStream(Type type, string name);
        public void Save(string assemblyFileName);
        public void Save(string assemblyFileName, PortableExecutableKinds portableExecutableKind, ImageFileMachine imageFileMachine);
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetEntryPoint(MethodInfo entryMethod);
        public void SetEntryPoint(MethodInfo entryMethod, PEFileKinds fileKind);
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public sealed class ConstructorBuilder: ConstructorInfo, _ConstructorBuilder, _ConstructorInfo, _MemberInfo, _MethodBase, ICustomAttributeProvider
    {
        public bool InitLocals { get; set; }
        public Type ReturnType { get; }
        public string Signature { get; }
        public void AddDeclarativeSecurity(SecurityAction action, PermissionSet pset);
        public ParameterBuilder DefineParameter(int iSequence, ParameterAttributes attributes, string strParamName);
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public ILGenerator GetILGenerator();
        public ILGenerator GetILGenerator(int streamSize);
        public override MethodImplAttributes GetMethodImplementationFlags();
        public Module GetModule();
        public override ParameterInfo[] GetParameters();
        public MethodToken GetToken();
        public override object Invoke(BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public override object Invoke(object obj, BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public override bool IsDefined(Type attributeType, bool inherit);
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetImplementationFlags(MethodImplAttributes attributes);
        public void SetSymCustomAttribute(string name, byte[] data);
        public override string ToString();
    }

    [HostProtectionAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public class CustomAttributeBuilder: _CustomAttributeBuilder
    {
        public CustomAttributeBuilder(ConstructorInfo con, object[] constructorArgs);
        public CustomAttributeBuilder(ConstructorInfo con, object[] constructorArgs, FieldInfo[] namedFields, object[] fieldValues);
        public CustomAttributeBuilder(ConstructorInfo con, object[] constructorArgs, PropertyInfo[] namedProperties, object[] propertyValues);
        public CustomAttributeBuilder(ConstructorInfo con, object[] constructorArgs, PropertyInfo[] namedProperties, object[] propertyValues, FieldInfo[] namedFields, object[] fieldValues);
    }

    [ComVisibleAttribute(..)]
    public class DynamicILInfo
    {
        public DynamicMethod DynamicMethod { get; }
        public int GetTokenFor(byte[] signature);
        public int GetTokenFor(DynamicMethod method);
        public int GetTokenFor(DynamicMethod method, RuntimeTypeHandle[] varargsParameters);
        public int GetTokenFor(RuntimeFieldHandle field);
        public int GetTokenFor(RuntimeMethodHandle method);
        public int GetTokenFor(RuntimeMethodHandle method, RuntimeTypeHandle contextType);
        public int GetTokenFor(RuntimeMethodHandle method, RuntimeTypeHandle[] varargsParameters);
        public int GetTokenFor(RuntimeTypeHandle type);
        public int GetTokenFor(string literal);
        public void SetCode(byte* code, int codeSize, int maxStackSize);
        public void SetCode(byte[] code, int maxStackSize);
        public void SetExceptions(byte* exceptions, int exceptionsSize);
        public void SetExceptions(byte[] exceptions);
        public void SetLocalSignature(byte* localSignature, int signatureSize);
        public void SetLocalSignature(byte[] localSignature);
    }

    [ComVisibleAttribute(..)]
    public sealed class DynamicMethod: MethodInfo, _MemberInfo, _MethodBase, _MethodInfo, ICustomAttributeProvider
    {
        public DynamicMethod(string name, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes, Module m, bool skipVisibility);
        public DynamicMethod(string name, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes, Type owner, bool skipVisibility);
        public DynamicMethod(string name, Type returnType, Type[] parameterTypes, Module m);
        public DynamicMethod(string name, Type returnType, Type[] parameterTypes, Module m, bool skipVisibility);
        public DynamicMethod(string name, Type returnType, Type[] parameterTypes, Type owner);
        public DynamicMethod(string name, Type returnType, Type[] parameterTypes, Type owner, bool skipVisibility);
        public bool InitLocals { get; set; }
        public Delegate CreateDelegate(Type delegateType);
        public Delegate CreateDelegate(Type delegateType, object target);
        public ParameterBuilder DefineParameter(int position, ParameterAttributes attributes, string parameterName);
        protected override void Finalize();
        public override MethodInfo GetBaseDefinition();
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public DynamicILInfo GetDynamicILInfo();
        public ILGenerator GetILGenerator();
        public ILGenerator GetILGenerator(int streamSize);
        public override MethodImplAttributes GetMethodImplementationFlags();
        public override ParameterInfo[] GetParameters();
        public override object Invoke(object obj, BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public override bool IsDefined(Type attributeType, bool inherit);
        public override string ToString();
    }

    [HostProtectionAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class EnumBuilder: Type, _EnumBuilder, _MemberInfo, _Type, ICustomAttributeProvider, IReflect
    {
        public TypeToken TypeToken { get; }
        public FieldBuilder UnderlyingField { get; }
        public Type CreateType();
        public FieldBuilder DefineLiteral(string literalName, object literalValue);
        protected override TypeAttributes GetAttributeFlagsImpl();
        protected override ConstructorInfo GetConstructorImpl(BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override ConstructorInfo[] GetConstructors(BindingFlags bindingAttr);
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public override Type GetElementType();
        public override EventInfo GetEvent(string name, BindingFlags bindingAttr);
        public override EventInfo[] GetEvents();
        public override EventInfo[] GetEvents(BindingFlags bindingAttr);
        public override FieldInfo GetField(string name, BindingFlags bindingAttr);
        public override FieldInfo[] GetFields(BindingFlags bindingAttr);
        public override Type GetInterface(string name, bool ignoreCase);
        public override InterfaceMapping GetInterfaceMap(Type interfaceType);
        public override Type[] GetInterfaces();
        public override MemberInfo[] GetMember(string name, MemberTypes type, BindingFlags bindingAttr);
        public override MemberInfo[] GetMembers(BindingFlags bindingAttr);
        protected override MethodInfo GetMethodImpl(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override MethodInfo[] GetMethods(BindingFlags bindingAttr);
        public override Type GetNestedType(string name, BindingFlags bindingAttr);
        public override Type[] GetNestedTypes(BindingFlags bindingAttr);
        public override PropertyInfo[] GetProperties(BindingFlags bindingAttr);
        protected override PropertyInfo GetPropertyImpl(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        protected override bool HasElementTypeImpl();
        public override object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] namedParameters);
        protected override bool IsArrayImpl();
        protected override bool IsByRefImpl();
        protected override bool IsCOMObjectImpl();
        public override bool IsDefined(Type attributeType, bool inherit);
        protected override bool IsPointerImpl();
        protected override bool IsPrimitiveImpl();
        protected override bool IsValueTypeImpl();
        public override Type MakeArrayType();
        public override Type MakeArrayType(int rank);
        public override Type MakeByRefType();
        public override Type MakePointerType();
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
    }

    [HostProtectionAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class EventBuilder: _EventBuilder
    {
        public void AddOtherMethod(MethodBuilder mdBuilder);
        public EventToken GetEventToken();
        public void SetAddOnMethod(MethodBuilder mdBuilder);
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetRaiseMethod(MethodBuilder mdBuilder);
        public void SetRemoveOnMethod(MethodBuilder mdBuilder);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct EventToken
    {
        public static readonly EventToken Empty;
        public int Token { get; }
        public bool Equals(EventToken obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static bool operator ==(EventToken a, EventToken b);
        public static bool operator !=(EventToken a, EventToken b);
    }

    [HostProtectionAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class FieldBuilder: FieldInfo, _FieldBuilder, _FieldInfo, _MemberInfo, ICustomAttributeProvider
    {
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public FieldToken GetToken();
        public override object GetValue(object obj);
        public override bool IsDefined(Type attributeType, bool inherit);
        public void SetConstant(object defaultValue);
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetMarshal(UnmanagedMarshal unmanagedMarshal);
        public void SetOffset(int iOffset);
        public override void SetValue(object obj, object val, BindingFlags invokeAttr, Binder binder, CultureInfo culture);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct FieldToken
    {
        public static readonly FieldToken Empty;
        public int Token { get; }
        public bool Equals(FieldToken obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static bool operator ==(FieldToken a, FieldToken b);
        public static bool operator !=(FieldToken a, FieldToken b);
    }

    [ComVisibleAttribute(..)]
    public sealed class GenericTypeParameterBuilder: Type, _MemberInfo, _Type, ICustomAttributeProvider, IReflect
    {
        public override Type BindGenericParameters(params Type[] typeArguments);
        protected override TypeAttributes GetAttributeFlagsImpl();
        protected override ConstructorInfo GetConstructorImpl(BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override ConstructorInfo[] GetConstructors(BindingFlags bindingAttr);
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public override Type GetElementType();
        public override EventInfo GetEvent(string name, BindingFlags bindingAttr);
        public override EventInfo[] GetEvents();
        public override EventInfo[] GetEvents(BindingFlags bindingAttr);
        public override FieldInfo GetField(string name, BindingFlags bindingAttr);
        public override FieldInfo[] GetFields(BindingFlags bindingAttr);
        public override Type[] GetGenericArguments();
        public override Type GetGenericTypeDefinition();
        public override Type GetInterface(string name, bool ignoreCase);
        public override InterfaceMapping GetInterfaceMap(Type interfaceType);
        public override Type[] GetInterfaces();
        public override MemberInfo[] GetMember(string name, MemberTypes type, BindingFlags bindingAttr);
        public override MemberInfo[] GetMembers(BindingFlags bindingAttr);
        protected override MethodInfo GetMethodImpl(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override MethodInfo[] GetMethods(BindingFlags bindingAttr);
        public override Type GetNestedType(string name, BindingFlags bindingAttr);
        public override Type[] GetNestedTypes(BindingFlags bindingAttr);
        public override PropertyInfo[] GetProperties(BindingFlags bindingAttr);
        protected override PropertyInfo GetPropertyImpl(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        protected override bool HasElementTypeImpl();
        public override object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] namedParameters);
        protected override bool IsArrayImpl();
        public override bool IsAssignableFrom(Type c);
        protected override bool IsByRefImpl();
        protected override bool IsCOMObjectImpl();
        public override bool IsDefined(Type attributeType, bool inherit);
        protected override bool IsPointerImpl();
        protected override bool IsPrimitiveImpl();
        public override bool IsSubclassOf(Type c);
        protected override bool IsValueTypeImpl();
        public override Type MakeArrayType();
        public override Type MakeArrayType(int rank);
        public override Type MakeByRefType();
        public override Type MakeGenericType(params Type[] typeArguments);
        public override Type MakePointerType();
        public void SetBaseTypeConstraint(Type baseTypeConstraint);
        public void SetGenericParameterAttributes(GenericParameterAttributes genericParameterAttributes);
        public void SetInterfaceConstraints(params Type[] interfaceConstraints);
        public override string ToString();
    }

    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public class ILGenerator: _ILGenerator
    {
        public virtual void BeginCatchBlock(Type exceptionType);
        public virtual void BeginExceptFilterBlock();
        public virtual Label BeginExceptionBlock();
        public virtual void BeginFaultBlock();
        public virtual void BeginFinallyBlock();
        public virtual void BeginScope();
        public virtual LocalBuilder DeclareLocal(Type localType);
        public virtual LocalBuilder DeclareLocal(Type localType, bool pinned);
        public virtual Label DefineLabel();
        public virtual void Emit(OpCode opcode);
        public virtual void Emit(OpCode opcode, byte arg);
        public virtual void Emit(OpCode opcode, ConstructorInfo con);
        public virtual void Emit(OpCode opcode, double arg);
        public virtual void Emit(OpCode opcode, FieldInfo field);
        public virtual void Emit(OpCode opcode, float arg);
        public virtual void Emit(OpCode opcode, int arg);
        public virtual void Emit(OpCode opcode, Label label);
        public virtual void Emit(OpCode opcode, Label[] labels);
        public virtual void Emit(OpCode opcode, LocalBuilder local);
        public virtual void Emit(OpCode opcode, long arg);
        public virtual void Emit(OpCode opcode, MethodInfo meth);
        public void Emit(OpCode opcode, sbyte arg);
        public virtual void Emit(OpCode opcode, short arg);
        public virtual void Emit(OpCode opcode, SignatureHelper signature);
        public virtual void Emit(OpCode opcode, string str);
        public virtual void Emit(OpCode opcode, Type cls);
        public virtual void EmitCall(OpCode opcode, MethodInfo methodInfo, Type[] optionalParameterTypes);
        public virtual void EmitCalli(OpCode opcode, CallingConvention unmanagedCallConv, Type returnType, Type[] parameterTypes);
        public virtual void EmitCalli(OpCode opcode, CallingConventions callingConvention, Type returnType, Type[] parameterTypes, Type[] optionalParameterTypes);
        public virtual void EmitWriteLine(FieldInfo fld);
        public virtual void EmitWriteLine(LocalBuilder localBuilder);
        public virtual void EmitWriteLine(string value);
        public virtual void EndExceptionBlock();
        public virtual void EndScope();
        public virtual void MarkLabel(Label loc);
        public virtual void MarkSequencePoint(ISymbolDocumentWriter document, int startLine, int startColumn, int endLine, int endColumn);
        public virtual void ThrowException(Type excType);
        public virtual void UsingNamespace(string usingNamespace);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct Label
    {
        public bool Equals(Label obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static bool operator ==(Label a, Label b);
        public static bool operator !=(Label a, Label b);
    }

    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public sealed class LocalBuilder: LocalVariableInfo, _LocalBuilder
    {
        public void SetLocalSymInfo(string name);
        public void SetLocalSymInfo(string name, int startOffset, int endOffset);
    }

    [HostProtectionAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class MethodBuilder: MethodInfo, _MemberInfo, _MethodBase, _MethodBuilder, _MethodInfo, ICustomAttributeProvider
    {
        public bool InitLocals { get; set; }
        public string Signature { get; }
        public void AddDeclarativeSecurity(SecurityAction action, PermissionSet pset);
        public override MethodInfo BindGenericParameters(params Type[] typeArguments);
        public void CreateMethodBody(byte[] il, int count);
        public GenericTypeParameterBuilder[] DefineGenericParameters(params string[] names);
        public ParameterBuilder DefineParameter(int position, ParameterAttributes attributes, string strParamName);
        public override bool Equals(object obj);
        public override MethodInfo GetBaseDefinition();
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public override Type[] GetGenericArguments();
        public override MethodInfo GetGenericMethodDefinition();
        public override int GetHashCode();
        public ILGenerator GetILGenerator();
        public ILGenerator GetILGenerator(int size);
        public override MethodImplAttributes GetMethodImplementationFlags();
        public Module GetModule();
        public override ParameterInfo[] GetParameters();
        public MethodToken GetToken();
        public override object Invoke(object obj, BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public override bool IsDefined(Type attributeType, bool inherit);
        public override MethodInfo MakeGenericMethod(params Type[] typeArguments);
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetImplementationFlags(MethodImplAttributes attributes);
        public void SetMarshal(UnmanagedMarshal unmanagedMarshal);
        public void SetParameters(params Type[] parameterTypes);
        public void SetReturnType(Type returnType);
        public void SetSignature(Type returnType, Type[] returnTypeRequiredCustomModifiers, Type[] returnTypeOptionalCustomModifiers, Type[] parameterTypes, Type[][] parameterTypeRequiredCustomModifiers, Type[][] parameterTypeOptionalCustomModifiers);
        public void SetSymCustomAttribute(string name, byte[] data);
        public override string ToString();
    }

    [HostProtectionAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public sealed class MethodRental: _MethodRental
    {
        public const int JitImmediate;
        public const int JitOnDemand;
        public static void SwapMethodBody(Type cls, int methodtoken, IntPtr rgIL, int methodSize, int flags);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct MethodToken
    {
        public static readonly MethodToken Empty;
        public int Token { get; }
        public bool Equals(MethodToken obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static bool operator ==(MethodToken a, MethodToken b);
        public static bool operator !=(MethodToken a, MethodToken b);
    }

    [HostProtectionAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public class ModuleBuilder: Module, _Module, _ModuleBuilder, ICustomAttributeProvider, ISerializable
    {
        public void CreateGlobalFunctions();
        public ISymbolDocumentWriter DefineDocument(string url, Guid language, Guid languageVendor, Guid documentType);
        public EnumBuilder DefineEnum(string name, TypeAttributes visibility, Type underlyingType);
        public MethodBuilder DefineGlobalMethod(string name, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes);
        public MethodBuilder DefineGlobalMethod(string name, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] requiredReturnTypeCustomModifiers, Type[] optionalReturnTypeCustomModifiers, Type[] parameterTypes, Type[][] requiredParameterTypeCustomModifiers, Type[][] optionalParameterTypeCustomModifiers);
        public MethodBuilder DefineGlobalMethod(string name, MethodAttributes attributes, Type returnType, Type[] parameterTypes);
        public FieldBuilder DefineInitializedData(string name, byte[] data, FieldAttributes attributes);
        public void DefineManifestResource(string name, Stream stream, ResourceAttributes attribute);
        public MethodBuilder DefinePInvokeMethod(string name, string dllName, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes, CallingConvention nativeCallConv, CharSet nativeCharSet);
        public MethodBuilder DefinePInvokeMethod(string name, string dllName, string entryName, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes, CallingConvention nativeCallConv, CharSet nativeCharSet);
        public IResourceWriter DefineResource(string name, string description);
        public IResourceWriter DefineResource(string name, string description, ResourceAttributes attribute);
        public TypeBuilder DefineType(string name);
        public TypeBuilder DefineType(string name, TypeAttributes attr);
        public TypeBuilder DefineType(string name, TypeAttributes attr, Type parent);
        public TypeBuilder DefineType(string name, TypeAttributes attr, Type parent, int typesize);
        public TypeBuilder DefineType(string name, TypeAttributes attr, Type parent, PackingSize packsize);
        public TypeBuilder DefineType(string name, TypeAttributes attr, Type parent, PackingSize packingSize, int typesize);
        public TypeBuilder DefineType(string name, TypeAttributes attr, Type parent, Type[] interfaces);
        public FieldBuilder DefineUninitializedData(string name, int size, FieldAttributes attributes);
        public void DefineUnmanagedResource(byte[] resource);
        public void DefineUnmanagedResource(string resourceFileName);
        public MethodInfo GetArrayMethod(Type arrayClass, string methodName, CallingConventions callingConvention, Type returnType, Type[] parameterTypes);
        public MethodToken GetArrayMethodToken(Type arrayClass, string methodName, CallingConventions callingConvention, Type returnType, Type[] parameterTypes);
        public MethodToken GetConstructorToken(ConstructorInfo con);
        public FieldToken GetFieldToken(FieldInfo field);
        public MethodToken GetMethodToken(MethodInfo method);
        public SignatureToken GetSignatureToken(byte[] sigBytes, int sigLength);
        public SignatureToken GetSignatureToken(SignatureHelper sigHelper);
        public StringToken GetStringConstant(string str);
        public ISymbolWriter GetSymWriter();
        public override Type GetType(string className);
        public override Type GetType(string className, bool ignoreCase);
        public override Type GetType(string className, bool throwOnError, bool ignoreCase);
        public override Type[] GetTypes();
        public TypeToken GetTypeToken(string name);
        public TypeToken GetTypeToken(Type type);
        public bool IsTransient();
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetSymCustomAttribute(string name, byte[] data);
        public void SetUserEntryPoint(MethodInfo entryPoint);
    }

    [ComVisibleAttribute(..)]
    public struct OpCode
    {
        public FlowControl FlowControl { get; }
        public string Name { get; }
        public OpCodeType OpCodeType { get; }
        public OperandType OperandType { get; }
        public int Size { get; }
        public StackBehaviour StackBehaviourPop { get; }
        public StackBehaviour StackBehaviourPush { get; }
        public short Value { get; }
        public override bool Equals(object obj);
        public bool Equals(OpCode obj);
        public override int GetHashCode();
        public override string ToString();
        public static bool operator ==(OpCode a, OpCode b);
        public static bool operator !=(OpCode a, OpCode b);
    }

    [ComVisibleAttribute(..)]
    public class OpCodes
    {
        public static readonly OpCode Add;
        public static readonly OpCode Add_Ovf;
        public static readonly OpCode Add_Ovf_Un;
        public static readonly OpCode And;
        public static readonly OpCode Arglist;
        public static readonly OpCode Beq;
        public static readonly OpCode Beq_S;
        public static readonly OpCode Bge;
        public static readonly OpCode Bge_S;
        public static readonly OpCode Bge_Un;
        public static readonly OpCode Bge_Un_S;
        public static readonly OpCode Bgt;
        public static readonly OpCode Bgt_S;
        public static readonly OpCode Bgt_Un;
        public static readonly OpCode Bgt_Un_S;
        public static readonly OpCode Ble;
        public static readonly OpCode Ble_S;
        public static readonly OpCode Ble_Un;
        public static readonly OpCode Ble_Un_S;
        public static readonly OpCode Blt;
        public static readonly OpCode Blt_S;
        public static readonly OpCode Blt_Un;
        public static readonly OpCode Blt_Un_S;
        public static readonly OpCode Bne_Un;
        public static readonly OpCode Bne_Un_S;
        public static readonly OpCode Box;
        public static readonly OpCode Br;
        public static readonly OpCode Br_S;
        public static readonly OpCode Break;
        public static readonly OpCode Brfalse;
        public static readonly OpCode Brfalse_S;
        public static readonly OpCode Brtrue;
        public static readonly OpCode Brtrue_S;
        public static readonly OpCode Call;
        public static readonly OpCode Calli;
        public static readonly OpCode Callvirt;
        public static readonly OpCode Castclass;
        public static readonly OpCode Ceq;
        public static readonly OpCode Cgt;
        public static readonly OpCode Cgt_Un;
        public static readonly OpCode Ckfinite;
        public static readonly OpCode Clt;
        public static readonly OpCode Clt_Un;
        public static readonly OpCode Constrained;
        public static readonly OpCode Conv_I;
        public static readonly OpCode Conv_I1;
        public static readonly OpCode Conv_I2;
        public static readonly OpCode Conv_I4;
        public static readonly OpCode Conv_I8;
        public static readonly OpCode Conv_Ovf_I;
        public static readonly OpCode Conv_Ovf_I_Un;
        public static readonly OpCode Conv_Ovf_I1;
        public static readonly OpCode Conv_Ovf_I1_Un;
        public static readonly OpCode Conv_Ovf_I2;
        public static readonly OpCode Conv_Ovf_I2_Un;
        public static readonly OpCode Conv_Ovf_I4;
        public static readonly OpCode Conv_Ovf_I4_Un;
        public static readonly OpCode Conv_Ovf_I8;
        public static readonly OpCode Conv_Ovf_I8_Un;
        public static readonly OpCode Conv_Ovf_U;
        public static readonly OpCode Conv_Ovf_U_Un;
        public static readonly OpCode Conv_Ovf_U1;
        public static readonly OpCode Conv_Ovf_U1_Un;
        public static readonly OpCode Conv_Ovf_U2;
        public static readonly OpCode Conv_Ovf_U2_Un;
        public static readonly OpCode Conv_Ovf_U4;
        public static readonly OpCode Conv_Ovf_U4_Un;
        public static readonly OpCode Conv_Ovf_U8;
        public static readonly OpCode Conv_Ovf_U8_Un;
        public static readonly OpCode Conv_R_Un;
        public static readonly OpCode Conv_R4;
        public static readonly OpCode Conv_R8;
        public static readonly OpCode Conv_U;
        public static readonly OpCode Conv_U1;
        public static readonly OpCode Conv_U2;
        public static readonly OpCode Conv_U4;
        public static readonly OpCode Conv_U8;
        public static readonly OpCode Cpblk;
        public static readonly OpCode Cpobj;
        public static readonly OpCode Div;
        public static readonly OpCode Div_Un;
        public static readonly OpCode Dup;
        public static readonly OpCode Endfilter;
        public static readonly OpCode Endfinally;
        public static readonly OpCode Initblk;
        public static readonly OpCode Initobj;
        public static readonly OpCode Isinst;
        public static readonly OpCode Jmp;
        public static readonly OpCode Ldarg;
        public static readonly OpCode Ldarg_0;
        public static readonly OpCode Ldarg_1;
        public static readonly OpCode Ldarg_2;
        public static readonly OpCode Ldarg_3;
        public static readonly OpCode Ldarg_S;
        public static readonly OpCode Ldarga;
        public static readonly OpCode Ldarga_S;
        public static readonly OpCode Ldc_I4;
        public static readonly OpCode Ldc_I4_0;
        public static readonly OpCode Ldc_I4_1;
        public static readonly OpCode Ldc_I4_2;
        public static readonly OpCode Ldc_I4_3;
        public static readonly OpCode Ldc_I4_4;
        public static readonly OpCode Ldc_I4_5;
        public static readonly OpCode Ldc_I4_6;
        public static readonly OpCode Ldc_I4_7;
        public static readonly OpCode Ldc_I4_8;
        public static readonly OpCode Ldc_I4_M1;
        public static readonly OpCode Ldc_I4_S;
        public static readonly OpCode Ldc_I8;
        public static readonly OpCode Ldc_R4;
        public static readonly OpCode Ldc_R8;
        public static readonly OpCode Ldelem;
        public static readonly OpCode Ldelem_I;
        public static readonly OpCode Ldelem_I1;
        public static readonly OpCode Ldelem_I2;
        public static readonly OpCode Ldelem_I4;
        public static readonly OpCode Ldelem_I8;
        public static readonly OpCode Ldelem_R4;
        public static readonly OpCode Ldelem_R8;
        public static readonly OpCode Ldelem_Ref;
        public static readonly OpCode Ldelem_U1;
        public static readonly OpCode Ldelem_U2;
        public static readonly OpCode Ldelem_U4;
        public static readonly OpCode Ldelema;
        public static readonly OpCode Ldfld;
        public static readonly OpCode Ldflda;
        public static readonly OpCode Ldftn;
        public static readonly OpCode Ldind_I;
        public static readonly OpCode Ldind_I1;
        public static readonly OpCode Ldind_I2;
        public static readonly OpCode Ldind_I4;
        public static readonly OpCode Ldind_I8;
        public static readonly OpCode Ldind_R4;
        public static readonly OpCode Ldind_R8;
        public static readonly OpCode Ldind_Ref;
        public static readonly OpCode Ldind_U1;
        public static readonly OpCode Ldind_U2;
        public static readonly OpCode Ldind_U4;
        public static readonly OpCode Ldlen;
        public static readonly OpCode Ldloc;
        public static readonly OpCode Ldloc_0;
        public static readonly OpCode Ldloc_1;
        public static readonly OpCode Ldloc_2;
        public static readonly OpCode Ldloc_3;
        public static readonly OpCode Ldloc_S;
        public static readonly OpCode Ldloca;
        public static readonly OpCode Ldloca_S;
        public static readonly OpCode Ldnull;
        public static readonly OpCode Ldobj;
        public static readonly OpCode Ldsfld;
        public static readonly OpCode Ldsflda;
        public static readonly OpCode Ldstr;
        public static readonly OpCode Ldtoken;
        public static readonly OpCode Ldvirtftn;
        public static readonly OpCode Leave;
        public static readonly OpCode Leave_S;
        public static readonly OpCode Localloc;
        public static readonly OpCode Mkrefany;
        public static readonly OpCode Mul;
        public static readonly OpCode Mul_Ovf;
        public static readonly OpCode Mul_Ovf_Un;
        public static readonly OpCode Neg;
        public static readonly OpCode Newarr;
        public static readonly OpCode Newobj;
        public static readonly OpCode Nop;
        public static readonly OpCode Not;
        public static readonly OpCode Or;
        public static readonly OpCode Pop;
        public static readonly OpCode Prefix1;
        public static readonly OpCode Prefix2;
        public static readonly OpCode Prefix3;
        public static readonly OpCode Prefix4;
        public static readonly OpCode Prefix5;
        public static readonly OpCode Prefix6;
        public static readonly OpCode Prefix7;
        public static readonly OpCode Prefixref;
        public static readonly OpCode Readonly;
        public static readonly OpCode Refanytype;
        public static readonly OpCode Refanyval;
        public static readonly OpCode Rem;
        public static readonly OpCode Rem_Un;
        public static readonly OpCode Ret;
        public static readonly OpCode Rethrow;
        public static readonly OpCode Shl;
        public static readonly OpCode Shr;
        public static readonly OpCode Shr_Un;
        public static readonly OpCode Sizeof;
        public static readonly OpCode Starg;
        public static readonly OpCode Starg_S;
        public static readonly OpCode Stelem;
        public static readonly OpCode Stelem_I;
        public static readonly OpCode Stelem_I1;
        public static readonly OpCode Stelem_I2;
        public static readonly OpCode Stelem_I4;
        public static readonly OpCode Stelem_I8;
        public static readonly OpCode Stelem_R4;
        public static readonly OpCode Stelem_R8;
        public static readonly OpCode Stelem_Ref;
        public static readonly OpCode Stfld;
        public static readonly OpCode Stind_I;
        public static readonly OpCode Stind_I1;
        public static readonly OpCode Stind_I2;
        public static readonly OpCode Stind_I4;
        public static readonly OpCode Stind_I8;
        public static readonly OpCode Stind_R4;
        public static readonly OpCode Stind_R8;
        public static readonly OpCode Stind_Ref;
        public static readonly OpCode Stloc;
        public static readonly OpCode Stloc_0;
        public static readonly OpCode Stloc_1;
        public static readonly OpCode Stloc_2;
        public static readonly OpCode Stloc_3;
        public static readonly OpCode Stloc_S;
        public static readonly OpCode Stobj;
        public static readonly OpCode Stsfld;
        public static readonly OpCode Sub;
        public static readonly OpCode Sub_Ovf;
        public static readonly OpCode Sub_Ovf_Un;
        public static readonly OpCode Switch;
        public static readonly OpCode Tailcall;
        public static readonly OpCode Throw;
        public static readonly OpCode Unaligned;
        public static readonly OpCode Unbox;
        public static readonly OpCode Unbox_Any;
        public static readonly OpCode Volatile;
        public static readonly OpCode Xor;
        public static bool TakesSingleByteArgument(OpCode inst);
    }

    [ClassInterfaceAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ParameterBuilder: _ParameterBuilder
    {
        public virtual int Attributes { get; }
        public bool IsIn { get; }
        public bool IsOptional { get; }
        public bool IsOut { get; }
        public virtual int MetadataTokenInternal { get; }
        public virtual string Name { get; }
        public virtual int Position { get; }
        public virtual ParameterToken GetToken();
        public virtual void SetConstant(object defaultValue);
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public virtual void SetMarshal(UnmanagedMarshal unmanagedMarshal);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct ParameterToken
    {
        public static readonly ParameterToken Empty;
        public int Token { get; }
        public override bool Equals(object obj);
        public bool Equals(ParameterToken obj);
        public override int GetHashCode();
        public static bool operator ==(ParameterToken a, ParameterToken b);
        public static bool operator !=(ParameterToken a, ParameterToken b);
    }

    [HostProtectionAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public sealed class PropertyBuilder: PropertyInfo, _MemberInfo, _PropertyBuilder, _PropertyInfo, ICustomAttributeProvider
    {
        public PropertyToken PropertyToken { get; }
        public void AddOtherMethod(MethodBuilder mdBuilder);
        public override MethodInfo[] GetAccessors(bool nonPublic);
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public override MethodInfo GetGetMethod(bool nonPublic);
        public override ParameterInfo[] GetIndexParameters();
        public override MethodInfo GetSetMethod(bool nonPublic);
        public override object GetValue(object obj, BindingFlags invokeAttr, Binder binder, object[] index, CultureInfo culture);
        public override object GetValue(object obj, object[] index);
        public override bool IsDefined(Type attributeType, bool inherit);
        public void SetConstant(object defaultValue);
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetGetMethod(MethodBuilder mdBuilder);
        public void SetSetMethod(MethodBuilder mdBuilder);
        public override void SetValue(object obj, object value, BindingFlags invokeAttr, Binder binder, object[] index, CultureInfo culture);
        public override void SetValue(object obj, object value, object[] index);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct PropertyToken
    {
        public static readonly PropertyToken Empty;
        public int Token { get; }
        public override bool Equals(object obj);
        public bool Equals(PropertyToken obj);
        public override int GetHashCode();
        public static bool operator ==(PropertyToken a, PropertyToken b);
        public static bool operator !=(PropertyToken a, PropertyToken b);
    }

    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    public sealed class SignatureHelper: _SignatureHelper
    {
        public void AddArgument(Type clsArgument);
        public void AddArgument(Type argument, bool pinned);
        public void AddArgument(Type argument, Type[] requiredCustomModifiers, Type[] optionalCustomModifiers);
        public void AddArguments(Type[] arguments, Type[][] requiredCustomModifiers, Type[][] optionalCustomModifiers);
        public void AddSentinel();
        public override bool Equals(object obj);
        public static SignatureHelper GetFieldSigHelper(Module mod);
        public override int GetHashCode();
        public static SignatureHelper GetLocalVarSigHelper(Module mod);
        public static SignatureHelper GetMethodSigHelper(Module mod, CallingConvention unmanagedCallConv, Type returnType);
        public static SignatureHelper GetMethodSigHelper(Module mod, CallingConventions callingConvention, Type returnType);
        public static SignatureHelper GetMethodSigHelper(Module mod, Type returnType, Type[] parameterTypes);
        public static SignatureHelper GetPropertySigHelper(Module mod, Type returnType, Type[] parameterTypes);
        public static SignatureHelper GetPropertySigHelper(Module mod, Type returnType, Type[] requiredReturnTypeCustomModifiers, Type[] optionalReturnTypeCustomModifiers, Type[] parameterTypes, Type[][] requiredParameterTypeCustomModifiers, Type[][] optionalParameterTypeCustomModifiers);
        public byte[] GetSignature();
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public struct SignatureToken
    {
        public static readonly SignatureToken Empty;
        public int Token { get; }
        public override bool Equals(object obj);
        public bool Equals(SignatureToken obj);
        public override int GetHashCode();
        public static bool operator ==(SignatureToken a, SignatureToken b);
        public static bool operator !=(SignatureToken a, SignatureToken b);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct StringToken
    {
        public int Token { get; }
        public override bool Equals(object obj);
        public bool Equals(StringToken obj);
        public override int GetHashCode();
        public static bool operator ==(StringToken a, StringToken b);
        public static bool operator !=(StringToken a, StringToken b);
    }

    [HostProtectionAttribute(..)]
    [ComDefaultInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public sealed class TypeBuilder: Type, _MemberInfo, _Type, _TypeBuilder, ICustomAttributeProvider, IReflect
    {
        public const int UnspecifiedTypeSize;
        public PackingSize PackingSize { get; }
        public int Size { get; }
        public TypeToken TypeToken { get; }
        public void AddDeclarativeSecurity(SecurityAction action, PermissionSet pset);
        public void AddInterfaceImplementation(Type interfaceType);
        public override Type BindGenericParameters(params Type[] typeArguments);
        public Type CreateType();
        public ConstructorBuilder DefineConstructor(MethodAttributes attributes, CallingConventions callingConvention, Type[] parameterTypes);
        public ConstructorBuilder DefineConstructor(MethodAttributes attributes, CallingConventions callingConvention, Type[] parameterTypes, Type[][] requiredCustomModifiers, Type[][] optionalCustomModifiers);
        public ConstructorBuilder DefineDefaultConstructor(MethodAttributes attributes);
        public EventBuilder DefineEvent(string name, EventAttributes attributes, Type eventtype);
        public FieldBuilder DefineField(string fieldName, Type type, FieldAttributes attributes);
        public FieldBuilder DefineField(string fieldName, Type type, Type[] requiredCustomModifiers, Type[] optionalCustomModifiers, FieldAttributes attributes);
        public GenericTypeParameterBuilder[] DefineGenericParameters(params string[] names);
        public FieldBuilder DefineInitializedData(string name, byte[] data, FieldAttributes attributes);
        public MethodBuilder DefineMethod(string name, MethodAttributes attributes);
        public MethodBuilder DefineMethod(string name, MethodAttributes attributes, CallingConventions callingConvention);
        public MethodBuilder DefineMethod(string name, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes);
        public MethodBuilder DefineMethod(string name, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] returnTypeRequiredCustomModifiers, Type[] returnTypeOptionalCustomModifiers, Type[] parameterTypes, Type[][] parameterTypeRequiredCustomModifiers, Type[][] parameterTypeOptionalCustomModifiers);
        public MethodBuilder DefineMethod(string name, MethodAttributes attributes, Type returnType, Type[] parameterTypes);
        public void DefineMethodOverride(MethodInfo methodInfoBody, MethodInfo methodInfoDeclaration);
        public TypeBuilder DefineNestedType(string name);
        public TypeBuilder DefineNestedType(string name, TypeAttributes attr);
        public TypeBuilder DefineNestedType(string name, TypeAttributes attr, Type parent);
        public TypeBuilder DefineNestedType(string name, TypeAttributes attr, Type parent, int typeSize);
        public TypeBuilder DefineNestedType(string name, TypeAttributes attr, Type parent, PackingSize packSize);
        public TypeBuilder DefineNestedType(string name, TypeAttributes attr, Type parent, Type[] interfaces);
        public MethodBuilder DefinePInvokeMethod(string name, string dllName, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes, CallingConvention nativeCallConv, CharSet nativeCharSet);
        public MethodBuilder DefinePInvokeMethod(string name, string dllName, string entryName, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] parameterTypes, CallingConvention nativeCallConv, CharSet nativeCharSet);
        public MethodBuilder DefinePInvokeMethod(string name, string dllName, string entryName, MethodAttributes attributes, CallingConventions callingConvention, Type returnType, Type[] returnTypeRequiredCustomModifiers, Type[] returnTypeOptionalCustomModifiers, Type[] parameterTypes, Type[][] parameterTypeRequiredCustomModifiers, Type[][] parameterTypeOptionalCustomModifiers, CallingConvention nativeCallConv, CharSet nativeCharSet);
        public PropertyBuilder DefineProperty(string name, PropertyAttributes attributes, Type returnType, Type[] parameterTypes);
        public PropertyBuilder DefineProperty(string name, PropertyAttributes attributes, Type returnType, Type[] returnTypeRequiredCustomModifiers, Type[] returnTypeOptionalCustomModifiers, Type[] parameterTypes, Type[][] parameterTypeRequiredCustomModifiers, Type[][] parameterTypeOptionalCustomModifiers);
        public ConstructorBuilder DefineTypeInitializer();
        public FieldBuilder DefineUninitializedData(string name, int size, FieldAttributes attributes);
        protected override TypeAttributes GetAttributeFlagsImpl();
        public static ConstructorInfo GetConstructor(Type type, ConstructorInfo constructor);
        protected override ConstructorInfo GetConstructorImpl(BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override ConstructorInfo[] GetConstructors(BindingFlags bindingAttr);
        public override object[] GetCustomAttributes(bool inherit);
        public override object[] GetCustomAttributes(Type attributeType, bool inherit);
        public override Type GetElementType();
        public override EventInfo GetEvent(string name, BindingFlags bindingAttr);
        public override EventInfo[] GetEvents();
        public override EventInfo[] GetEvents(BindingFlags bindingAttr);
        public override FieldInfo GetField(string name, BindingFlags bindingAttr);
        public static FieldInfo GetField(Type type, FieldInfo field);
        public override FieldInfo[] GetFields(BindingFlags bindingAttr);
        public override Type[] GetGenericArguments();
        public override Type GetGenericTypeDefinition();
        public override Type GetInterface(string name, bool ignoreCase);
        public override InterfaceMapping GetInterfaceMap(Type interfaceType);
        public override Type[] GetInterfaces();
        public override MemberInfo[] GetMember(string name, MemberTypes type, BindingFlags bindingAttr);
        public override MemberInfo[] GetMembers(BindingFlags bindingAttr);
        public static MethodInfo GetMethod(Type type, MethodInfo method);
        protected override MethodInfo GetMethodImpl(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public override MethodInfo[] GetMethods(BindingFlags bindingAttr);
        public override Type GetNestedType(string name, BindingFlags bindingAttr);
        public override Type[] GetNestedTypes(BindingFlags bindingAttr);
        public override PropertyInfo[] GetProperties(BindingFlags bindingAttr);
        protected override PropertyInfo GetPropertyImpl(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        protected override bool HasElementTypeImpl();
        public override object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] namedParameters);
        protected override bool IsArrayImpl();
        public override bool IsAssignableFrom(Type c);
        protected override bool IsByRefImpl();
        protected override bool IsCOMObjectImpl();
        public bool IsCreated();
        public override bool IsDefined(Type attributeType, bool inherit);
        protected override bool IsPointerImpl();
        protected override bool IsPrimitiveImpl();
        public override bool IsSubclassOf(Type c);
        public override Type MakeArrayType();
        public override Type MakeArrayType(int rank);
        public override Type MakeByRefType();
        public override Type MakeGenericType(params Type[] typeArguments);
        public override Type MakePointerType();
        public void SetCustomAttribute(ConstructorInfo con, byte[] binaryAttribute);
        public void SetCustomAttribute(CustomAttributeBuilder customBuilder);
        public void SetParent(Type parent);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct TypeToken
    {
        public static readonly TypeToken Empty;
        public int Token { get; }
        public override bool Equals(object obj);
        public bool Equals(TypeToken obj);
        public override int GetHashCode();
        public static bool operator ==(TypeToken a, TypeToken b);
        public static bool operator !=(TypeToken a, TypeToken b);
    }

    [HostProtectionAttribute(..)]
    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UnmanagedMarshal
    {
        public UnmanagedType BaseType { get; }
        public int ElementCount { get; }
        public UnmanagedType GetUnmanagedType { get; }
        public Guid IIDGuid { get; }
        public static UnmanagedMarshal DefineByValArray(int elemCount);
        public static UnmanagedMarshal DefineByValTStr(int elemCount);
        public static UnmanagedMarshal DefineLPArray(UnmanagedType elemType);
        public static UnmanagedMarshal DefineSafeArray(UnmanagedType elemType);
        public static UnmanagedMarshal DefineUnmanagedMarshal(UnmanagedType unmanagedType);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum AssemblyBuilderAccess
    {
        ReflectionOnly,
        Run,
        RunAndSave,
        Save,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FlowControl
    {
        Branch,
        Break,
        Call,
        Cond_Branch,
        Meta,
        Next,
        Phi,
        Return,
        Throw,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum OpCodeType
    {
        Annotation,
        Macro,
        Nternal,
        Objmodel,
        Prefix,
        Primitive,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum OperandType
    {
        InlineBrTarget,
        InlineField,
        InlineI,
        InlineI8,
        InlineMethod,
        InlineNone,
        InlinePhi,
        InlineR,
        InlineSig,
        InlineString,
        InlineSwitch,
        InlineTok,
        InlineType,
        InlineVar,
        ShortInlineBrTarget,
        ShortInlineI,
        ShortInlineR,
        ShortInlineVar,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PackingSize
    {
        Size1,
        Size128,
        Size16,
        Size2,
        Size32,
        Size4,
        Size64,
        Size8,
        Unspecified,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PEFileKinds
    {
        ConsoleApplication,
        Dll,
        WindowApplication,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum StackBehaviour
    {
        Pop0,
        Pop1,
        Pop1_pop1,
        Popi,
        Popi_pop1,
        Popi_popi,
        Popi_popi_popi,
        Popi_popi8,
        Popi_popr4,
        Popi_popr8,
        Popref,
        Popref_pop1,
        Popref_popi,
        Popref_popi_pop1,
        Popref_popi_popi,
        Popref_popi_popi8,
        Popref_popi_popr4,
        Popref_popi_popr8,
        Popref_popi_popref,
        Push0,
        Push1,
        Push1_push1,
        Pushi,
        Pushi8,
        Pushr4,
        Pushr8,
        Pushref,
        Varpop,
        Varpush,
    }

} 
namespace System.Resources
{
    [ComVisibleAttribute(..)]
    public interface IResourceWriter: IDisposable
    {
        public void AddResource(string name, byte[] value);
        public void AddResource(string name, object value);
        public void AddResource(string name, string value);
        public void Close();
        public void Generate();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ResourceManager
    {
        protected ResourceManager();
        public ResourceManager(string baseName, Assembly assembly);
        public ResourceManager(string baseName, Assembly assembly, Type usingResourceSet);
        public ResourceManager(Type resourceSource);
        protected string BaseNameField;
        public static readonly int HeaderVersionNumber;
        public static readonly int MagicNumber;
        protected Assembly MainAssembly;
        protected Hashtable ResourceSets;
        public virtual string BaseName { get; }
        public virtual bool IgnoreCase { get; set; }
        public virtual Type ResourceSetType { get; }
        public static ResourceManager CreateFileBasedResourceManager(string baseName, string resourceDir, Type usingResourceSet);
        protected static CultureInfo GetNeutralResourcesLanguage(Assembly a);
        public virtual object GetObject(string name);
        public virtual object GetObject(string name, CultureInfo culture);
        protected virtual string GetResourceFileName(CultureInfo culture);
        public virtual ResourceSet GetResourceSet(CultureInfo culture, bool createIfNotExists, bool tryParents);
        protected static Version GetSatelliteContractVersion(Assembly a);
        public UnmanagedMemoryStream GetStream(string name);
        public UnmanagedMemoryStream GetStream(string name, CultureInfo culture);
        public virtual string GetString(string name);
        public virtual string GetString(string name, CultureInfo culture);
        protected virtual ResourceSet InternalGetResourceSet(CultureInfo culture, bool createIfNotExists, bool tryParents);
        public virtual void ReleaseAllResources();
    }

    [ComVisibleAttribute(..)]
    public sealed class ResourceWriter: IResourceWriter
    {
        public ResourceWriter(Stream stream);
        public ResourceWriter(string fileName);
        public void AddResource(string name, byte[] value);
        public void AddResource(string name, object value);
        public void AddResource(string name, string value);
        public void AddResourceData(string name, string typeName, byte[] serializedData);
        public void Close();
        public void Dispose();
        public void Generate();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum UltimateResourceFallbackLocation
    {
        MainAssembly,
        Satellite,
    }

    [ComVisibleAttribute(..)]
    public interface IResourceReader: IDisposable, IEnumerable
    {
        public void Close();
        public IDictionaryEnumerator GetEnumerator();
    }

    [ComVisibleAttribute(..)]
    public sealed class ResourceReader: IResourceReader
    {
        public ResourceReader(Stream stream);
        public ResourceReader(string fileName);
        public void Close();
        public IDictionaryEnumerator GetEnumerator();
        public void GetResourceData(string resourceName, ref string resourceType, ref byte[] resourceData);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ResourceSet: IDisposable, IEnumerable
    {
        protected ResourceSet();
        public ResourceSet(IResourceReader reader);
        public ResourceSet(Stream stream);
        public ResourceSet(string fileName);
        protected IResourceReader Reader;
        protected Hashtable Table;
        public virtual void Close();
        public void Dispose();
        protected virtual void Dispose(bool disposing);
        public virtual Type GetDefaultReader();
        public virtual Type GetDefaultWriter();
        public virtual IDictionaryEnumerator GetEnumerator();
        public virtual object GetObject(string name);
        public virtual object GetObject(string name, bool ignoreCase);
        public virtual string GetString(string name);
        public virtual string GetString(string name, bool ignoreCase);
        protected virtual void ReadResources();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class NeutralResourcesLanguageAttribute: Attribute, _Attribute
    {
        public NeutralResourcesLanguageAttribute(string cultureName);
        public NeutralResourcesLanguageAttribute(string cultureName, UltimateResourceFallbackLocation location);
        public string CultureName { get; }
        public UltimateResourceFallbackLocation Location { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class SatelliteContractVersionAttribute: Attribute, _Attribute
    {
        public SatelliteContractVersionAttribute(string version);
        public string Version { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MissingManifestResourceException: SystemException, _Exception, ISerializable
    {
        public MissingManifestResourceException();
        protected MissingManifestResourceException(SerializationInfo info, StreamingContext context);
        public MissingManifestResourceException(string message);
        public MissingManifestResourceException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MissingSatelliteAssemblyException: SystemException, _Exception, ISerializable
    {
        public MissingSatelliteAssemblyException();
        protected MissingSatelliteAssemblyException(SerializationInfo info, StreamingContext context);
        public MissingSatelliteAssemblyException(string message);
        public MissingSatelliteAssemblyException(string message, Exception inner);
        public MissingSatelliteAssemblyException(string message, string cultureName);
        public string CultureName { get; }
    }

} 
namespace System.Runtime
{
    public abstract sealed class GCSettings
    {
        public static bool IsServerGC { get; }
    }

    public sealed class MemoryFailPoint: IDisposable
    {
        public MemoryFailPoint(int sizeInMegabytes);
        public void Dispose();
    }

} 
namespace System.Runtime.CompilerServices
{
    [ComVisibleAttribute(..)]
    public class CallConvCdecl
    {
        public CallConvCdecl();
    }

    [ComVisibleAttribute(..)]
    public class CallConvFastcall
    {
        public CallConvFastcall();
    }

    [ComVisibleAttribute(..)]
    public class CallConvStdcall
    {
        public CallConvStdcall();
    }

    [ComVisibleAttribute(..)]
    public class CallConvThiscall
    {
        public CallConvThiscall();
    }

    public abstract sealed class CompilerMarshalOverride
    {
    }

    public abstract sealed class IsBoxed
    {
    }

    public abstract sealed class IsByValue
    {
    }

    public abstract sealed class IsConst
    {
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class IsCopyConstructed
    {
    }

    public abstract sealed class IsExplicitlyDereferenced
    {
    }

    public abstract sealed class IsImplicitlyDereferenced
    {
    }

    public abstract sealed class IsJitIntrinsic
    {
    }

    public abstract sealed class IsLong
    {
    }

    public abstract sealed class IsPinned
    {
    }

    public abstract sealed class IsSignUnspecifiedByte
    {
    }

    public abstract sealed class IsUdtReturn
    {
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class IsVolatile
    {
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class RuntimeHelpers
    {
        public static int OffsetToStringData { get; }
        public static bool Equals(object o1, object o2);
        public static void ExecuteCodeWithGuaranteedCleanup(TryCode code, CleanupCode backoutCode, object userData);
        public static int GetHashCode(object o);
        public static object GetObjectValue(object obj);
        public static void InitializeArray(Array array, RuntimeFieldHandle fldHandle);
        public static void PrepareConstrainedRegions();
        public static void PrepareConstrainedRegionsNoOP();
        public static void PrepareDelegate(Delegate d);
        public static void PrepareMethod(RuntimeMethodHandle method);
        public static void PrepareMethod(RuntimeMethodHandle method, RuntimeTypeHandle[] instantiation);
        public static void ProbeForSufficientStack();
        public static void RunClassConstructor(RuntimeTypeHandle type);
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum CompilationRelaxations
    {
        NoStringInterning,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum HomogenousFloatingPointAggregateOption
    {
        Double,
        Float,
    }

    [SerializableAttribute(..)]
    public enum LoadHint
    {
        Always,
        Default,
        Sometimes,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum MethodCodeType
    {
        IL,
        Native,
        OPTIL,
        Runtime,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum MethodImplOptions
    {
        ForwardRef,
        InternalCall,
        NoInlining,
        PreserveSig,
        Synchronized,
        Unmanaged,
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AccessedThroughPropertyAttribute: Attribute, _Attribute
    {
        public AccessedThroughPropertyAttribute(string propertyName);
        public string PropertyName { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class CompilationRelaxationsAttribute: Attribute, _Attribute
    {
        public CompilationRelaxationsAttribute(CompilationRelaxations relaxations);
        public CompilationRelaxationsAttribute(int relaxations);
        public int CompilationRelaxations { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class CompilerGeneratedAttribute: Attribute, _Attribute
    {
        public CompilerGeneratedAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CompilerGlobalScopeAttribute: Attribute, _Attribute
    {
        public CompilerGlobalScopeAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class CustomConstantAttribute: Attribute, _Attribute
    {
        protected CustomConstantAttribute();
        public abstract object Value { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DateTimeConstantAttribute: CustomConstantAttribute, _Attribute
    {
        public DateTimeConstantAttribute(long ticks);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DecimalConstantAttribute: Attribute, _Attribute
    {
        public DecimalConstantAttribute(byte scale, byte sign, int hi, int mid, int low);
        public DecimalConstantAttribute(byte scale, byte sign, uint hi, uint mid, uint low);
        public decimal Value { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DefaultDependencyAttribute: Attribute, _Attribute
    {
        public DefaultDependencyAttribute(LoadHint loadHintArgument);
        public LoadHint LoadHint { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class DependencyAttribute: Attribute, _Attribute
    {
        public DependencyAttribute(string dependentAssemblyArgument, LoadHint loadHintArgument);
        public string DependentAssembly { get; }
        public LoadHint LoadHint { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class DiscardableAttribute: Attribute, _Attribute
    {
        public DiscardableAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class FixedAddressValueTypeAttribute: Attribute, _Attribute
    {
        public FixedAddressValueTypeAttribute();
    }

    [AttributeUsageAttribute(..)]
    public sealed class FixedBufferAttribute: Attribute, _Attribute
    {
        public FixedBufferAttribute(Type elementType, int length);
        public Type ElementType { get; }
        public int Length { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class HasCopySemanticsAttribute: Attribute, _Attribute
    {
        public HasCopySemanticsAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class HomogenousFloatingPointAggregateAttribute: Attribute, _Attribute
    {
        public HomogenousFloatingPointAggregateAttribute();
        public HomogenousFloatingPointAggregateAttribute(HomogenousFloatingPointAggregateOption precision);
        public HomogenousFloatingPointAggregateOption Value { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class IDispatchConstantAttribute: CustomConstantAttribute, _Attribute
    {
        public IDispatchConstantAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class IndexerNameAttribute: Attribute, _Attribute
    {
        public IndexerNameAttribute(string indexerName);
    }

    [AttributeUsageAttribute(..)]
    public sealed class InternalsVisibleToAttribute: Attribute, _Attribute
    {
        public InternalsVisibleToAttribute(string assemblyName);
        public string AssemblyName { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class IUnknownConstantAttribute: CustomConstantAttribute, _Attribute
    {
        public IUnknownConstantAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class MethodImplAttribute: Attribute, _Attribute
    {
        public MethodImplAttribute();
        public MethodImplAttribute(MethodImplOptions methodImplOptions);
        public MethodImplAttribute(short value);
        public MethodCodeType MethodCodeType;
        public MethodImplOptions Value { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class NativeCppClassAttribute: Attribute, _Attribute
    {
        public NativeCppClassAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class NewConstraintAttribute: Attribute, _Attribute
    {
        public NewConstraintAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class RequiredAttributeAttribute: Attribute, _Attribute
    {
        public RequiredAttributeAttribute(Type requiredContract);
        public Type RequiredContract { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class ScopelessEnumAttribute: Attribute, _Attribute
    {
        public ScopelessEnumAttribute();
    }

    [AttributeUsageAttribute(..)]
    public sealed class SpecialNameAttribute: Attribute, _Attribute
    {
        public SpecialNameAttribute();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class StringFreezingAttribute: Attribute, _Attribute
    {
        public StringFreezingAttribute();
    }

    [AttributeUsageAttribute(..)]
    public sealed class TypeForwardedToAttribute: Attribute, _Attribute
    {
        public TypeForwardedToAttribute(Type destination);
        public Type Destination { get; }
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class UnsafeValueTypeAttribute: Attribute, _Attribute
    {
        public UnsafeValueTypeAttribute();
    }

} 
namespace System.Runtime.ConstrainedExecution
{
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class CriticalFinalizerObject
    {
        protected CriticalFinalizerObject();
        protected override void Finalize();
    }

    [SerializableAttribute(..)]
    public enum Cer
    {
        MayFail,
        None,
        Success,
    }

    [SerializableAttribute(..)]
    public enum Consistency
    {
        MayCorruptAppDomain,
        MayCorruptInstance,
        MayCorruptProcess,
        WillNotCorruptState,
    }

    [AttributeUsageAttribute(..)]
    public sealed class PrePrepareMethodAttribute: Attribute, _Attribute
    {
        public PrePrepareMethodAttribute();
    }

    [AttributeUsageAttribute(..)]
    public sealed class ReliabilityContractAttribute: Attribute, _Attribute
    {
        public ReliabilityContractAttribute();
        public ReliabilityContractAttribute(Consistency consistencyGuarantee, Cer cer);
        public Cer Cer { get; }
        public Consistency ConsistencyGuarantee { get; }
    }

} 
namespace System.Runtime.Hosting
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ActivationArguments
    {
        public ActivationArguments(ActivationContext activationData);
        public ActivationArguments(ActivationContext activationContext, string[] activationData);
        public ActivationArguments(ApplicationIdentity applicationIdentity);
        public ActivationArguments(ApplicationIdentity applicationIdentity, string[] activationData);
        public ActivationContext ActivationContext { get; }
        public string[] ActivationData { get; }
        public ApplicationIdentity ApplicationIdentity { get; }
    }

    [ComVisibleAttribute(..)]
    public class ApplicationActivator
    {
        public ApplicationActivator();
        public virtual ObjectHandle CreateInstance(ActivationContext activationContext);
        public virtual ObjectHandle CreateInstance(ActivationContext activationContext, string[] activationCustomData);
        protected static ObjectHandle CreateInstanceHelper(AppDomainSetup adSetup);
    }

} 
namespace System.Runtime.InteropServices
{
    [ComVisibleAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface _Activator
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _Assembly
    {
        public string CodeBase { get; }
        public MethodInfo EntryPoint { get; }
        public string EscapedCodeBase { get; }
        public Evidence Evidence { get; }
        public string FullName { get; }
        public bool GlobalAssemblyCache { get; }
        public string Location { get; }
        public object CreateInstance(string typeName);
        public object CreateInstance(string typeName, bool ignoreCase);
        public object CreateInstance(string typeName, bool ignoreCase, BindingFlags bindingAttr, Binder binder, object[] args, CultureInfo culture, object[] activationAttributes);
        public bool Equals(object other);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public Type[] GetExportedTypes();
        public FileStream GetFile(string name);
        public FileStream[] GetFiles();
        public FileStream[] GetFiles(bool getResourceModules);
        public int GetHashCode();
        public Module[] GetLoadedModules();
        public Module[] GetLoadedModules(bool getResourceModules);
        public ManifestResourceInfo GetManifestResourceInfo(string resourceName);
        public string[] GetManifestResourceNames();
        public Stream GetManifestResourceStream(string name);
        public Stream GetManifestResourceStream(Type type, string name);
        public Module GetModule(string name);
        public Module[] GetModules();
        public Module[] GetModules(bool getResourceModules);
        public AssemblyName GetName();
        public AssemblyName GetName(bool copiedName);
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public AssemblyName[] GetReferencedAssemblies();
        public Assembly GetSatelliteAssembly(CultureInfo culture);
        public Assembly GetSatelliteAssembly(CultureInfo culture, Version version);
        public Type GetType();
        public Type GetType(string name);
        public Type GetType(string name, bool throwOnError);
        public Type GetType(string name, bool throwOnError, bool ignoreCase);
        public Type[] GetTypes();
        public bool IsDefined(Type attributeType, bool inherit);
        public Module LoadModule(string moduleName, byte[] rawModule);
        public Module LoadModule(string moduleName, byte[] rawModule, byte[] rawSymbolStore);
        public string ToString();
        public event ModuleResolveEventHandler ModuleResolve;
    }

    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _AssemblyBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [TypeLibImportClassAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface _AssemblyName
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _Attribute
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface _ConstructorBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface _ConstructorInfo
    {
        public MethodAttributes Attributes { get; }
        public CallingConventions CallingConvention { get; }
        public Type DeclaringType { get; }
        public bool IsAbstract { get; }
        public bool IsAssembly { get; }
        public bool IsConstructor { get; }
        public bool IsFamily { get; }
        public bool IsFamilyAndAssembly { get; }
        public bool IsFamilyOrAssembly { get; }
        public bool IsFinal { get; }
        public bool IsHideBySig { get; }
        public bool IsPrivate { get; }
        public bool IsPublic { get; }
        public bool IsSpecialName { get; }
        public bool IsStatic { get; }
        public bool IsVirtual { get; }
        public MemberTypes MemberType { get; }
        public RuntimeMethodHandle MethodHandle { get; }
        public string Name { get; }
        public Type ReflectedType { get; }
        public bool Equals(object other);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public MethodImplAttributes GetMethodImplementationFlags();
        public ParameterInfo[] GetParameters();
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public object Invoke_2(object obj, BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public object Invoke_3(object obj, object[] parameters);
        public object Invoke_4(BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public object Invoke_5(object[] parameters);
        public bool IsDefined(Type attributeType, bool inherit);
        public string ToString();
    }

    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface _CustomAttributeBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface _EnumBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _EventBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [ComVisibleAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface _EventInfo
    {
        public EventAttributes Attributes { get; }
        public Type DeclaringType { get; }
        public Type EventHandlerType { get; }
        public bool IsMulticast { get; }
        public bool IsSpecialName { get; }
        public MemberTypes MemberType { get; }
        public string Name { get; }
        public Type ReflectedType { get; }
        public void AddEventHandler(object target, Delegate handler);
        public bool Equals(object other);
        public MethodInfo GetAddMethod();
        public MethodInfo GetAddMethod(bool nonPublic);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public MethodInfo GetRaiseMethod();
        public MethodInfo GetRaiseMethod(bool nonPublic);
        public MethodInfo GetRemoveMethod();
        public MethodInfo GetRemoveMethod(bool nonPublic);
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public bool IsDefined(Type attributeType, bool inherit);
        public void RemoveEventHandler(object target, Delegate handler);
        public string ToString();
    }

    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface _Exception
    {
        public string HelpLink { get; set; }
        public Exception InnerException { get; }
        public string Message { get; }
        public string Source { get; set; }
        public string StackTrace { get; }
        public MethodBase TargetSite { get; }
        public bool Equals(object obj);
        public Exception GetBaseException();
        public int GetHashCode();
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public Type GetType();
        public string ToString();
    }

    [InterfaceTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _FieldBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [InterfaceTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _FieldInfo
    {
        public FieldAttributes Attributes { get; }
        public Type DeclaringType { get; }
        public RuntimeFieldHandle FieldHandle { get; }
        public Type FieldType { get; }
        public bool IsAssembly { get; }
        public bool IsFamily { get; }
        public bool IsFamilyAndAssembly { get; }
        public bool IsFamilyOrAssembly { get; }
        public bool IsInitOnly { get; }
        public bool IsLiteral { get; }
        public bool IsNotSerialized { get; }
        public bool IsPinvokeImpl { get; }
        public bool IsPrivate { get; }
        public bool IsPublic { get; }
        public bool IsSpecialName { get; }
        public bool IsStatic { get; }
        public MemberTypes MemberType { get; }
        public string Name { get; }
        public Type ReflectedType { get; }
        public bool Equals(object other);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public object GetValue(object obj);
        public object GetValueDirect(TypedReference obj);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public bool IsDefined(Type attributeType, bool inherit);
        public void SetValue(object obj, object value);
        public void SetValue(object obj, object value, BindingFlags invokeAttr, Binder binder, CultureInfo culture);
        public void SetValueDirect(TypedReference obj, object value);
        public string ToString();
    }

    [TypeLibImportClassAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface _ILGenerator
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [TypeLibImportClassAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface _LocalBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface _MemberInfo
    {
        public Type DeclaringType { get; }
        public MemberTypes MemberType { get; }
        public string Name { get; }
        public Type ReflectedType { get; }
        public bool Equals(object other);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public bool IsDefined(Type attributeType, bool inherit);
        public string ToString();
    }

    [TypeLibImportClassAttribute(..)]
    [CLSCompliantAttribute(..)]
    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface _MethodBase
    {
        public MethodAttributes Attributes { get; }
        public CallingConventions CallingConvention { get; }
        public Type DeclaringType { get; }
        public bool IsAbstract { get; }
        public bool IsAssembly { get; }
        public bool IsConstructor { get; }
        public bool IsFamily { get; }
        public bool IsFamilyAndAssembly { get; }
        public bool IsFamilyOrAssembly { get; }
        public bool IsFinal { get; }
        public bool IsHideBySig { get; }
        public bool IsPrivate { get; }
        public bool IsPublic { get; }
        public bool IsSpecialName { get; }
        public bool IsStatic { get; }
        public bool IsVirtual { get; }
        public MemberTypes MemberType { get; }
        public RuntimeMethodHandle MethodHandle { get; }
        public string Name { get; }
        public Type ReflectedType { get; }
        public bool Equals(object other);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public MethodImplAttributes GetMethodImplementationFlags();
        public ParameterInfo[] GetParameters();
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public object Invoke(object obj, BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public object Invoke(object obj, object[] parameters);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public bool IsDefined(Type attributeType, bool inherit);
        public string ToString();
    }

    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface _MethodBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface _MethodInfo
    {
        public MethodAttributes Attributes { get; }
        public CallingConventions CallingConvention { get; }
        public Type DeclaringType { get; }
        public bool IsAbstract { get; }
        public bool IsAssembly { get; }
        public bool IsConstructor { get; }
        public bool IsFamily { get; }
        public bool IsFamilyAndAssembly { get; }
        public bool IsFamilyOrAssembly { get; }
        public bool IsFinal { get; }
        public bool IsHideBySig { get; }
        public bool IsPrivate { get; }
        public bool IsPublic { get; }
        public bool IsSpecialName { get; }
        public bool IsStatic { get; }
        public bool IsVirtual { get; }
        public MemberTypes MemberType { get; }
        public RuntimeMethodHandle MethodHandle { get; }
        public string Name { get; }
        public Type ReflectedType { get; }
        public Type ReturnType { get; }
        public ICustomAttributeProvider ReturnTypeCustomAttributes { get; }
        public bool Equals(object other);
        public MethodInfo GetBaseDefinition();
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public MethodImplAttributes GetMethodImplementationFlags();
        public ParameterInfo[] GetParameters();
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public object Invoke(object obj, BindingFlags invokeAttr, Binder binder, object[] parameters, CultureInfo culture);
        public object Invoke(object obj, object[] parameters);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public bool IsDefined(Type attributeType, bool inherit);
        public string ToString();
    }

    [CLSCompliantAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface _MethodRental
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _Module
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _ModuleBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _ParameterBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [ComVisibleAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface _ParameterInfo
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    [GuidAttribute(..)]
    public interface _PropertyBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _PropertyInfo
    {
        public PropertyAttributes Attributes { get; }
        public bool CanRead { get; }
        public bool CanWrite { get; }
        public Type DeclaringType { get; }
        public bool IsSpecialName { get; }
        public MemberTypes MemberType { get; }
        public string Name { get; }
        public Type PropertyType { get; }
        public Type ReflectedType { get; }
        public bool Equals(object other);
        public MethodInfo[] GetAccessors();
        public MethodInfo[] GetAccessors(bool nonPublic);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public MethodInfo GetGetMethod();
        public MethodInfo GetGetMethod(bool nonPublic);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public ParameterInfo[] GetIndexParameters();
        public MethodInfo GetSetMethod();
        public MethodInfo GetSetMethod(bool nonPublic);
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public object GetValue(object obj, BindingFlags invokeAttr, Binder binder, object[] index, CultureInfo culture);
        public object GetValue(object obj, object[] index);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public bool IsDefined(Type attributeType, bool inherit);
        public void SetValue(object obj, object value, BindingFlags invokeAttr, Binder binder, object[] index, CultureInfo culture);
        public void SetValue(object obj, object value, object[] index);
        public string ToString();
    }

    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    public interface _SignatureHelper
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [TypeLibImportClassAttribute(..)]
    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface _Thread
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [TypeLibImportClassAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    [GuidAttribute(..)]
    public interface _Type
    {
        public Assembly Assembly { get; }
        public string AssemblyQualifiedName { get; }
        public TypeAttributes Attributes { get; }
        public Type BaseType { get; }
        public Type DeclaringType { get; }
        public string FullName { get; }
        public Guid GUID { get; }
        public bool HasElementType { get; }
        public bool IsAbstract { get; }
        public bool IsAnsiClass { get; }
        public bool IsArray { get; }
        public bool IsAutoClass { get; }
        public bool IsAutoLayout { get; }
        public bool IsByRef { get; }
        public bool IsClass { get; }
        public bool IsCOMObject { get; }
        public bool IsContextful { get; }
        public bool IsEnum { get; }
        public bool IsExplicitLayout { get; }
        public bool IsImport { get; }
        public bool IsInterface { get; }
        public bool IsLayoutSequential { get; }
        public bool IsMarshalByRef { get; }
        public bool IsNestedAssembly { get; }
        public bool IsNestedFamANDAssem { get; }
        public bool IsNestedFamily { get; }
        public bool IsNestedFamORAssem { get; }
        public bool IsNestedPrivate { get; }
        public bool IsNestedPublic { get; }
        public bool IsNotPublic { get; }
        public bool IsPointer { get; }
        public bool IsPrimitive { get; }
        public bool IsPublic { get; }
        public bool IsSealed { get; }
        public bool IsSerializable { get; }
        public bool IsSpecialName { get; }
        public bool IsUnicodeClass { get; }
        public bool IsValueType { get; }
        public MemberTypes MemberType { get; }
        public Module Module { get; }
        public string Name { get; }
        public string Namespace { get; }
        public Type ReflectedType { get; }
        public RuntimeTypeHandle TypeHandle { get; }
        public ConstructorInfo TypeInitializer { get; }
        public Type UnderlyingSystemType { get; }
        public bool Equals(object other);
        public bool Equals(Type o);
        public Type[] FindInterfaces(TypeFilter filter, object filterCriteria);
        public MemberInfo[] FindMembers(MemberTypes memberType, BindingFlags bindingAttr, MemberFilter filter, object filterCriteria);
        public int GetArrayRank();
        public ConstructorInfo GetConstructor(BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public ConstructorInfo GetConstructor(BindingFlags bindingAttr, Binder binder, Type[] types, ParameterModifier[] modifiers);
        public ConstructorInfo GetConstructor(Type[] types);
        public ConstructorInfo[] GetConstructors();
        public ConstructorInfo[] GetConstructors(BindingFlags bindingAttr);
        public object[] GetCustomAttributes(bool inherit);
        public object[] GetCustomAttributes(Type attributeType, bool inherit);
        public MemberInfo[] GetDefaultMembers();
        public Type GetElementType();
        public EventInfo GetEvent(string name);
        public EventInfo GetEvent(string name, BindingFlags bindingAttr);
        public EventInfo[] GetEvents();
        public EventInfo[] GetEvents(BindingFlags bindingAttr);
        public FieldInfo GetField(string name);
        public FieldInfo GetField(string name, BindingFlags bindingAttr);
        public FieldInfo[] GetFields();
        public FieldInfo[] GetFields(BindingFlags bindingAttr);
        public int GetHashCode();
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public Type GetInterface(string name);
        public Type GetInterface(string name, bool ignoreCase);
        public InterfaceMapping GetInterfaceMap(Type interfaceType);
        public Type[] GetInterfaces();
        public MemberInfo[] GetMember(string name);
        public MemberInfo[] GetMember(string name, BindingFlags bindingAttr);
        public MemberInfo[] GetMember(string name, MemberTypes type, BindingFlags bindingAttr);
        public MemberInfo[] GetMembers();
        public MemberInfo[] GetMembers(BindingFlags bindingAttr);
        public MethodInfo GetMethod(string name);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr, Binder binder, CallingConventions callConvention, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo GetMethod(string name, BindingFlags bindingAttr, Binder binder, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo GetMethod(string name, Type[] types);
        public MethodInfo GetMethod(string name, Type[] types, ParameterModifier[] modifiers);
        public MethodInfo[] GetMethods();
        public MethodInfo[] GetMethods(BindingFlags bindingAttr);
        public Type GetNestedType(string name);
        public Type GetNestedType(string name, BindingFlags bindingAttr);
        public Type[] GetNestedTypes();
        public Type[] GetNestedTypes(BindingFlags bindingAttr);
        public PropertyInfo[] GetProperties();
        public PropertyInfo[] GetProperties(BindingFlags bindingAttr);
        public PropertyInfo GetProperty(string name);
        public PropertyInfo GetProperty(string name, BindingFlags bindingAttr);
        public PropertyInfo GetProperty(string name, BindingFlags bindingAttr, Binder binder, Type returnType, Type[] types, ParameterModifier[] modifiers);
        public PropertyInfo GetProperty(string name, Type returnType);
        public PropertyInfo GetProperty(string name, Type returnType, Type[] types);
        public PropertyInfo GetProperty(string name, Type returnType, Type[] types, ParameterModifier[] modifiers);
        public PropertyInfo GetProperty(string name, Type[] types);
        public Type GetType();
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
        public object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args);
        public object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, CultureInfo culture);
        public object InvokeMember(string name, BindingFlags invokeAttr, Binder binder, object target, object[] args, ParameterModifier[] modifiers, CultureInfo culture, string[] namedParameters);
        public bool IsAssignableFrom(Type c);
        public bool IsDefined(Type attributeType, bool inherit);
        public bool IsInstanceOfType(object o);
        public bool IsSubclassOf(Type c);
        public string ToString();
    }

    [InterfaceTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    [TypeLibImportClassAttribute(..)]
    [GuidAttribute(..)]
    [CLSCompliantAttribute(..)]
    public interface _TypeBuilder
    {
        public void GetIDsOfNames(ref Guid riid, IntPtr rgszNames, uint cNames, uint lcid, IntPtr rgDispId);
        public void GetTypeInfo(uint iTInfo, uint lcid, IntPtr ppTInfo);
        public void GetTypeInfoCount(ref uint pcTInfo);
        public void Invoke(uint dispIdMember, ref Guid riid, uint lcid, short wFlags, IntPtr pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, IntPtr puArgErr);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct ArrayWithOffset
    {
        public ArrayWithOffset(object array, int offset);
        public bool Equals(ArrayWithOffset obj);
        public override bool Equals(object obj);
        public object GetArray();
        public override int GetHashCode();
        public int GetOffset();
        public static bool operator ==(ArrayWithOffset a, ArrayWithOffset b);
        public static bool operator !=(ArrayWithOffset a, ArrayWithOffset b);
    }

    [ObsoleteAttribute(..)]
    public struct BIND_OPTS
    {
        public int cbStruct;
        public int dwTickCountDeadline;
        public int grfFlags;
        public int grfMode;
    }

    [ObsoleteAttribute(..)]
    public struct BINDPTR
    {
        public IntPtr lpfuncdesc;
        public IntPtr lptcomp;
        public IntPtr lpvardesc;
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class BStrWrapper
    {
        public BStrWrapper(string value);
        public string WrappedObject { get; }
    }

    [ObsoleteAttribute(..)]
    public struct CONNECTDATA
    {
        public int dwCookie;
        public object pUnk;
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    public abstract class CriticalHandle: CriticalFinalizerObject, IDisposable
    {
        protected CriticalHandle(IntPtr invalidHandleValue);
        protected IntPtr handle;
        public bool IsClosed { get; }
        public abstract bool IsInvalid { get; }
        public void Close();
        public void Dispose();
        protected virtual void Dispose(bool disposing);
        protected override void Finalize();
        protected abstract bool ReleaseHandle();
        protected void SetHandle(IntPtr handle);
        public void SetHandleAsInvalid();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class CurrencyWrapper
    {
        public CurrencyWrapper(decimal obj);
        public CurrencyWrapper(object obj);
        public decimal WrappedObject { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DispatchWrapper
    {
        public DispatchWrapper(object obj);
        public object WrappedObject { get; }
    }

    [ObsoleteAttribute(..)]
    public struct DISPPARAMS
    {
        public int cArgs;
        public int cNamedArgs;
        public IntPtr rgdispidNamedArgs;
        public IntPtr rgvarg;
    }

    [ObsoleteAttribute(..)]
    public struct ELEMDESC
    {
        public DESCUNION desc;
        public TYPEDESC tdesc;
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ErrorWrapper
    {
        public ErrorWrapper(Exception e);
        public ErrorWrapper(int errorCode);
        public ErrorWrapper(object errorCode);
        public int ErrorCode { get; }
    }

    [ObsoleteAttribute(..)]
    public struct EXCEPINFO
    {
        public string bstrDescription;
        public string bstrHelpFile;
        public string bstrSource;
        public int dwHelpContext;
        public IntPtr pfnDeferredFillIn;
        public IntPtr pvReserved;
        public short wCode;
        public short wReserved;
    }

    [ComVisibleAttribute(..)]
    public sealed class ExtensibleClassFactory
    {
        public static void RegisterObjectCreationCallback(ObjectCreationDelegate callback);
    }

    [ObsoleteAttribute(..)]
    public struct FILETIME
    {
        public int dwHighDateTime;
        public int dwLowDateTime;
    }

    [ObsoleteAttribute(..)]
    public struct FUNCDESC
    {
        public CALLCONV callconv;
        public short cParams;
        public short cParamsOpt;
        public short cScodes;
        public ELEMDESC elemdescFunc;
        public FUNCKIND funckind;
        public INVOKEKIND invkind;
        public IntPtr lprgelemdescParam;
        public IntPtr lprgscode;
        public int memid;
        public short oVft;
        public short wFuncFlags;
    }

    [ComVisibleAttribute(..)]
    public struct GCHandle
    {
        public bool IsAllocated { get; }
        public object Target { get; set; }
        public IntPtr AddrOfPinnedObject();
        public static GCHandle Alloc(object value);
        public static GCHandle Alloc(object value, GCHandleType type);
        public override bool Equals(object o);
        public void Free();
        public static GCHandle FromIntPtr(IntPtr value);
        public override int GetHashCode();
        public static IntPtr ToIntPtr(GCHandle value);
        public static bool operator ==(GCHandle a, GCHandle b);
        public static bool operator !=(GCHandle a, GCHandle b);
        public static explicit operator GCHandle(IntPtr value);
        public static explicit operator IntPtr(GCHandle value);
    }

    [ComVisibleAttribute(..)]
    public struct HandleRef
    {
        public HandleRef(object wrapper, IntPtr handle);
        public IntPtr Handle { get; }
        public object Wrapper { get; }
        public static IntPtr ToIntPtr(HandleRef value);
        public static explicit operator IntPtr(HandleRef value);
    }

    [ComVisibleAttribute(..)]
    public interface ICustomAdapter
    {
        public object GetUnderlyingObject();
    }

    [ComVisibleAttribute(..)]
    public interface ICustomFactory
    {
        public MarshalByRefObject CreateInstance(Type serverType);
    }

    [ComVisibleAttribute(..)]
    public interface ICustomMarshaler
    {
        public void CleanUpManagedData(object ManagedObj);
        public void CleanUpNativeData(IntPtr pNativeData);
        public int GetNativeDataSize();
        public IntPtr MarshalManagedToNative(object ManagedObj);
        public object MarshalNativeToManaged(IntPtr pNativeData);
    }

    [ObsoleteAttribute(..)]
    public struct IDLDESC
    {
        public int dwReserved;
        public IDLFLAG wIDLFlags;
    }

    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface IRegistrationServices
    {
        public Guid GetManagedCategoryGuid();
        public string GetProgIdForType(Type type);
        public Type[] GetRegistrableTypesInAssembly(Assembly assembly);
        public bool RegisterAssembly(Assembly assembly, AssemblyRegistrationFlags flags);
        public void RegisterTypeForComClients(Type type, ref Guid g);
        public bool TypeRepresentsComType(Type type);
        public bool TypeRequiresRegistration(Type type);
        public bool UnregisterAssembly(Assembly assembly);
    }

    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface ITypeLibConverter
    {
        public object ConvertAssemblyToTypeLib(Assembly assembly, string typeLibName, TypeLibExporterFlags flags, ITypeLibExporterNotifySink notifySink);
        public AssemblyBuilder ConvertTypeLibToAssembly(object typeLib, string asmFileName, int flags, ITypeLibImporterNotifySink notifySink, byte[] publicKey, StrongNameKeyPair keyPair, bool unsafeInterfaces);
        public AssemblyBuilder ConvertTypeLibToAssembly(object typeLib, string asmFileName, TypeLibImporterFlags flags, ITypeLibImporterNotifySink notifySink, byte[] publicKey, StrongNameKeyPair keyPair, string asmNamespace, Version asmVersion);
        public bool GetPrimaryInteropAssembly(Guid g, int major, int minor, int lcid, ref string asmName, ref string asmCodeBase);
    }

    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface ITypeLibExporterNameProvider
    {
        public string[] GetNames();
    }

    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface ITypeLibExporterNotifySink
    {
        public void ReportEvent(ExporterEventKind eventKind, int eventCode, string eventMsg);
        public object ResolveRef(Assembly assembly);
    }

    [InterfaceTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    public interface ITypeLibImporterNotifySink
    {
        public void ReportEvent(ImporterEventKind eventKind, int eventCode, string eventMsg);
        public Assembly ResolveRef(object typeLib);
    }

    [SuppressUnmanagedCodeSecurityAttribute(..)]
    public abstract sealed class Marshal
    {
        public static readonly int SystemDefaultCharSize;
        public static readonly int SystemMaxDBCSCharSize;
        public static int AddRef(IntPtr pUnk);
        public static IntPtr AllocCoTaskMem(int cb);
        public static IntPtr AllocHGlobal(int cb);
        public static IntPtr AllocHGlobal(IntPtr cb);
        public static object BindToMoniker(string monikerName);
        public static void ChangeWrapperHandleStrength(object otp, bool fIsWeak);
        public static void Copy(byte[] source, int startIndex, IntPtr destination, int length);
        public static void Copy(char[] source, int startIndex, IntPtr destination, int length);
        public static void Copy(double[] source, int startIndex, IntPtr destination, int length);
        public static void Copy(float[] source, int startIndex, IntPtr destination, int length);
        public static void Copy(int[] source, int startIndex, IntPtr destination, int length);
        public static void Copy(IntPtr source, byte[] destination, int startIndex, int length);
        public static void Copy(IntPtr source, char[] destination, int startIndex, int length);
        public static void Copy(IntPtr source, double[] destination, int startIndex, int length);
        public static void Copy(IntPtr source, float[] destination, int startIndex, int length);
        public static void Copy(IntPtr source, int[] destination, int startIndex, int length);
        public static void Copy(IntPtr source, IntPtr[] destination, int startIndex, int length);
        public static void Copy(IntPtr source, long[] destination, int startIndex, int length);
        public static void Copy(IntPtr source, short[] destination, int startIndex, int length);
        public static void Copy(IntPtr[] source, int startIndex, IntPtr destination, int length);
        public static void Copy(long[] source, int startIndex, IntPtr destination, int length);
        public static void Copy(short[] source, int startIndex, IntPtr destination, int length);
        public static IntPtr CreateAggregatedObject(IntPtr pOuter, object o);
        public static object CreateWrapperOfType(object o, Type t);
        public static void DestroyStructure(IntPtr ptr, Type structuretype);
        public static int FinalReleaseComObject(object o);
        public static void FreeBSTR(IntPtr ptr);
        public static void FreeCoTaskMem(IntPtr ptr);
        public static void FreeHGlobal(IntPtr hglobal);
        public static Guid GenerateGuidForType(Type type);
        public static string GenerateProgIdForType(Type type);
        public static object GetActiveObject(string progID);
        public static IntPtr GetComInterfaceForObject(object o, Type T);
        public static IntPtr GetComInterfaceForObjectInContext(object o, Type t);
        public static object GetComObjectData(object obj, object key);
        public static int GetComSlotForMethodInfo(MemberInfo m);
        public static Delegate GetDelegateForFunctionPointer(IntPtr ptr, Type t);
        public static int GetEndComSlot(Type t);
        public static int GetExceptionCode();
        public static Exception GetExceptionForHR(int errorCode);
        public static Exception GetExceptionForHR(int errorCode, IntPtr errorInfo);
        public static IntPtr GetExceptionPointers();
        public static IntPtr GetFunctionPointerForDelegate(Delegate d);
        public static IntPtr GetHINSTANCE(Module m);
        public static int GetHRForException(Exception e);
        public static int GetHRForLastWin32Error();
        public static IntPtr GetIDispatchForObject(object o);
        public static IntPtr GetIDispatchForObjectInContext(object o);
        public static IntPtr GetITypeInfoForType(Type t);
        public static IntPtr GetIUnknownForObject(object o);
        public static IntPtr GetIUnknownForObjectInContext(object o);
        public static int GetLastWin32Error();
        public static IntPtr GetManagedThunkForUnmanagedMethodPtr(IntPtr pfnMethodToWrap, IntPtr pbSignature, int cbSignature);
        public static MemberInfo GetMethodInfoForComSlot(Type t, int slot, ref ComMemberType memberType);
        public static void GetNativeVariantForObject(object obj, IntPtr pDstNativeVariant);
        public static object GetObjectForIUnknown(IntPtr pUnk);
        public static object GetObjectForNativeVariant(IntPtr pSrcNativeVariant);
        public static object[] GetObjectsForNativeVariants(IntPtr aSrcNativeVariant, int cVars);
        public static int GetStartComSlot(Type t);
        public static Thread GetThreadFromFiberCookie(int cookie);
        public static object GetTypedObjectForIUnknown(IntPtr pUnk, Type t);
        public static Type GetTypeForITypeInfo(IntPtr piTypeInfo);
        public static string GetTypeInfoName(ITypeInfo typeInfo);
        public static string GetTypeInfoName(UCOMITypeInfo pTI);
        public static Guid GetTypeLibGuid(ITypeLib typelib);
        public static Guid GetTypeLibGuid(UCOMITypeLib pTLB);
        public static Guid GetTypeLibGuidForAssembly(Assembly asm);
        public static int GetTypeLibLcid(ITypeLib typelib);
        public static int GetTypeLibLcid(UCOMITypeLib pTLB);
        public static string GetTypeLibName(ITypeLib typelib);
        public static string GetTypeLibName(UCOMITypeLib pTLB);
        public static void GetTypeLibVersionForAssembly(Assembly inputAssembly, ref int majorVersion, ref int minorVersion);
        public static object GetUniqueObjectForIUnknown(IntPtr unknown);
        public static IntPtr GetUnmanagedThunkForManagedMethodPtr(IntPtr pfnMethodToWrap, IntPtr pbSignature, int cbSignature);
        public static bool IsComObject(object o);
        public static bool IsTypeVisibleFromCom(Type t);
        public static int NumParamBytes(MethodInfo m);
        public static IntPtr OffsetOf(Type t, string fieldName);
        public static void Prelink(MethodInfo m);
        public static void PrelinkAll(Type c);
        public static string PtrToStringAnsi(IntPtr ptr);
        public static string PtrToStringAnsi(IntPtr ptr, int len);
        public static string PtrToStringAuto(IntPtr ptr);
        public static string PtrToStringAuto(IntPtr ptr, int len);
        public static string PtrToStringBSTR(IntPtr ptr);
        public static string PtrToStringUni(IntPtr ptr);
        public static string PtrToStringUni(IntPtr ptr, int len);
        public static void PtrToStructure(IntPtr ptr, object structure);
        public static object PtrToStructure(IntPtr ptr, Type structureType);
        public static int QueryInterface(IntPtr pUnk, ref Guid iid, ref IntPtr ppv);
        public static byte ReadByte(IntPtr ptr);
        public static byte ReadByte(IntPtr ptr, int ofs);
        public static byte ReadByte(object ptr, int ofs);
        public static short ReadInt16(IntPtr ptr);
        public static short ReadInt16(IntPtr ptr, int ofs);
        public static short ReadInt16(object ptr, int ofs);
        public static int ReadInt32(IntPtr ptr);
        public static int ReadInt32(IntPtr ptr, int ofs);
        public static int ReadInt32(object ptr, int ofs);
        public static long ReadInt64(IntPtr ptr);
        public static long ReadInt64(IntPtr ptr, int ofs);
        public static long ReadInt64(object ptr, int ofs);
        public static IntPtr ReadIntPtr(IntPtr ptr);
        public static IntPtr ReadIntPtr(IntPtr ptr, int ofs);
        public static IntPtr ReadIntPtr(object ptr, int ofs);
        public static IntPtr ReAllocCoTaskMem(IntPtr pv, int cb);
        public static IntPtr ReAllocHGlobal(IntPtr pv, IntPtr cb);
        public static int Release(IntPtr pUnk);
        public static int ReleaseComObject(object o);
        public static void ReleaseThreadCache();
        public static IntPtr SecureStringToBSTR(SecureString s);
        public static IntPtr SecureStringToCoTaskMemAnsi(SecureString s);
        public static IntPtr SecureStringToCoTaskMemUni(SecureString s);
        public static IntPtr SecureStringToCoTaskMemUnicode(SecureString s);
        public static IntPtr SecureStringToGlobalAllocAnsi(SecureString s);
        public static IntPtr SecureStringToGlobalAllocUni(SecureString s);
        public static IntPtr SecureStringToGlobalAllocUnicode(SecureString s);
        public static bool SetComObjectData(object obj, object key, object data);
        public static int SizeOf(object structure);
        public static int SizeOf(Type t);
        public static IntPtr StringToBSTR(string s);
        public static IntPtr StringToCoTaskMemAnsi(string s);
        public static IntPtr StringToCoTaskMemAuto(string s);
        public static IntPtr StringToCoTaskMemUni(string s);
        public static IntPtr StringToHGlobalAnsi(string s);
        public static IntPtr StringToHGlobalAuto(string s);
        public static IntPtr StringToHGlobalUni(string s);
        public static void StructureToPtr(object structure, IntPtr ptr, bool fDeleteOld);
        public static void ThrowExceptionForHR(int errorCode);
        public static void ThrowExceptionForHR(int errorCode, IntPtr errorInfo);
        public static IntPtr UnsafeAddrOfPinnedArrayElement(Array arr, int index);
        public static void WriteByte(IntPtr ptr, byte val);
        public static void WriteByte(IntPtr ptr, int ofs, byte val);
        public static void WriteByte(object ptr, int ofs, byte val);
        public static void WriteInt16(IntPtr ptr, char val);
        public static void WriteInt16(IntPtr ptr, int ofs, char val);
        public static void WriteInt16(IntPtr ptr, int ofs, short val);
        public static void WriteInt16(IntPtr ptr, short val);
        public static void WriteInt16(object ptr, int ofs, char val);
        public static void WriteInt16(object ptr, int ofs, short val);
        public static void WriteInt32(IntPtr ptr, int val);
        public static void WriteInt32(IntPtr ptr, int ofs, int val);
        public static void WriteInt32(object ptr, int ofs, int val);
        public static void WriteInt64(IntPtr ptr, int ofs, long val);
        public static void WriteInt64(IntPtr ptr, long val);
        public static void WriteInt64(object ptr, int ofs, long val);
        public static void WriteIntPtr(IntPtr ptr, int ofs, IntPtr val);
        public static void WriteIntPtr(IntPtr ptr, IntPtr val);
        public static void WriteIntPtr(object ptr, int ofs, IntPtr val);
        public static void ZeroFreeBSTR(IntPtr s);
        public static void ZeroFreeCoTaskMemAnsi(IntPtr s);
        public static void ZeroFreeCoTaskMemUni(IntPtr s);
        public static void ZeroFreeCoTaskMemUnicode(IntPtr s);
        public static void ZeroFreeGlobalAllocAnsi(IntPtr s);
        public static void ZeroFreeGlobalAllocUni(IntPtr s);
        public static void ZeroFreeGlobalAllocUnicode(IntPtr s);
    }

    [ObsoleteAttribute(..)]
    public struct PARAMDESC
    {
        public IntPtr lpVarValue;
        public PARAMFLAG wParamFlags;
    }

    [ClassInterfaceAttribute(..)]
    [GuidAttribute(..)]
    [ComVisibleAttribute(..)]
    public class RegistrationServices: IRegistrationServices
    {
        public RegistrationServices();
        public virtual Guid GetManagedCategoryGuid();
        public virtual string GetProgIdForType(Type type);
        public virtual Type[] GetRegistrableTypesInAssembly(Assembly assembly);
        public virtual bool RegisterAssembly(Assembly assembly, AssemblyRegistrationFlags flags);
        public virtual void RegisterTypeForComClients(Type type, ref Guid g);
        public virtual int RegisterTypeForComClients(Type type, RegistrationClassContext classContext, RegistrationConnectionType flags);
        public virtual int RegisterTypeForComClientsEx(Type type, RegistrationClassContext classContext, RegistrationConnectionType flags);
        public virtual bool TypeRepresentsComType(Type type);
        public virtual bool TypeRequiresRegistration(Type type);
        public virtual bool UnregisterAssembly(Assembly assembly);
        public virtual void UnregisterTypeForComClients(int cookie);
        public virtual void UnRegisterTypeForComClients(int cookie);
    }

    [ComVisibleAttribute(..)]
    public class RuntimeEnvironment
    {
        public RuntimeEnvironment();
        public static string SystemConfigurationFile { get; }
        public static bool FromGlobalAccessCache(Assembly a);
        public static string GetRuntimeDirectory();
        public static string GetSystemVersion();
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    public abstract class SafeHandle: CriticalFinalizerObject, IDisposable
    {
        protected SafeHandle(IntPtr invalidHandleValue, bool ownsHandle);
        protected IntPtr handle;
        public bool IsClosed { get; }
        public abstract bool IsInvalid { get; }
        public void Close();
        public void DangerousAddRef(ref bool success);
        public IntPtr DangerousGetHandle();
        public void DangerousRelease();
        public void Dispose();
        protected virtual void Dispose(bool disposing);
        protected override void Finalize();
        protected abstract bool ReleaseHandle();
        protected void SetHandle(IntPtr handle);
        public void SetHandleAsInvalid();
    }

    [ObsoleteAttribute(..)]
    public struct STATSTG
    {
        public FILETIME atime;
        public long cbSize;
        public Guid clsid;
        public FILETIME ctime;
        public int grfLocksSupported;
        public int grfMode;
        public int grfStateBits;
        public FILETIME mtime;
        public string pwcsName;
        public int reserved;
        public int type;
    }

    [ObsoleteAttribute(..)]
    public struct TYPEATTR
    {
        public short cbAlignment;
        public int cbSizeInstance;
        public short cbSizeVft;
        public short cFuncs;
        public short cImplTypes;
        public short cVars;
        public int dwReserved;
        public Guid guid;
        public IDLDESC idldescType;
        public int lcid;
        public IntPtr lpstrSchema;
        public const int MEMBER_ID_NIL;
        public int memidConstructor;
        public int memidDestructor;
        public TYPEDESC tdescAlias;
        public TYPEKIND typekind;
        public short wMajorVerNum;
        public short wMinorVerNum;
        public TYPEFLAGS wTypeFlags;
    }

    [ObsoleteAttribute(..)]
    public struct TYPEDESC
    {
        public IntPtr lpValue;
        public short vt;
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    public struct TYPELIBATTR
    {
        public Guid guid;
        public int lcid;
        public SYSKIND syskind;
        public LIBFLAGS wLibFlags;
        public short wMajorVerNum;
        public short wMinorVerNum;
    }

    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    [ClassInterfaceAttribute(..)]
    public sealed class TypeLibConverter: ITypeLibConverter
    {
        public TypeLibConverter();
        public object ConvertAssemblyToTypeLib(Assembly assembly, string strTypeLibName, TypeLibExporterFlags flags, ITypeLibExporterNotifySink notifySink);
        public AssemblyBuilder ConvertTypeLibToAssembly(object typeLib, string asmFileName, int flags, ITypeLibImporterNotifySink notifySink, byte[] publicKey, StrongNameKeyPair keyPair, bool unsafeInterfaces);
        public AssemblyBuilder ConvertTypeLibToAssembly(object typeLib, string asmFileName, TypeLibImporterFlags flags, ITypeLibImporterNotifySink notifySink, byte[] publicKey, StrongNameKeyPair keyPair, string asmNamespace, Version asmVersion);
        public bool GetPrimaryInteropAssembly(Guid g, int major, int minor, int lcid, ref string asmName, ref string asmCodeBase);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMIBindCtx
    {
        public void EnumObjectParam(ref UCOMIEnumString ppenum);
        public void GetBindOptions(ref BIND_OPTS pbindopts);
        public void GetObjectParam(string pszKey, ref object ppunk);
        public void GetRunningObjectTable(ref UCOMIRunningObjectTable pprot);
        public void RegisterObjectBound(object punk);
        public void RegisterObjectParam(string pszKey, object punk);
        public void ReleaseBoundObjects();
        public void RevokeObjectBound(object punk);
        public void RevokeObjectParam(string pszKey);
        public void SetBindOptions(ref BIND_OPTS pbindopts);
    }

    [ComImportAttribute(..)]
    [ObsoleteAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMIConnectionPoint
    {
        public void Advise(object pUnkSink, ref int pdwCookie);
        public void EnumConnections(ref UCOMIEnumConnections ppEnum);
        public void GetConnectionInterface(ref Guid pIID);
        public void GetConnectionPointContainer(ref UCOMIConnectionPointContainer ppCPC);
        public void Unadvise(int dwCookie);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [ObsoleteAttribute(..)]
    public interface UCOMIConnectionPointContainer
    {
        public void EnumConnectionPoints(ref UCOMIEnumConnectionPoints ppEnum);
        public void FindConnectionPoint(ref Guid riid, ref UCOMIConnectionPoint ppCP);
    }

    [ComImportAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface UCOMIEnumConnectionPoints
    {
        public void Clone(ref UCOMIEnumConnectionPoints ppenum);
        public int Next(int celt, UCOMIConnectionPoint[] rgelt, ref int pceltFetched);
        public int Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface UCOMIEnumConnections
    {
        public void Clone(ref UCOMIEnumConnections ppenum);
        public int Next(int celt, CONNECTDATA[] rgelt, ref int pceltFetched);
        public void Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ObsoleteAttribute(..)]
    public interface UCOMIEnumMoniker
    {
        public void Clone(ref UCOMIEnumMoniker ppenum);
        public int Next(int celt, UCOMIMoniker[] rgelt, ref int pceltFetched);
        public int Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMIEnumString
    {
        public void Clone(ref UCOMIEnumString ppenum);
        public int Next(int celt, string[] rgelt, ref int pceltFetched);
        public int Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    [ObsoleteAttribute(..)]
    public interface UCOMIEnumVARIANT
    {
        public void Clone(int ppenum);
        public int Next(int celt, int rgvar, int pceltFetched);
        public int Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMIMoniker
    {
        public void BindToObject(UCOMIBindCtx pbc, UCOMIMoniker pmkToLeft, ref Guid riidResult, ref object ppvResult);
        public void BindToStorage(UCOMIBindCtx pbc, UCOMIMoniker pmkToLeft, ref Guid riid, ref object ppvObj);
        public void CommonPrefixWith(UCOMIMoniker pmkOther, ref UCOMIMoniker ppmkPrefix);
        public void ComposeWith(UCOMIMoniker pmkRight, bool fOnlyIfNotGeneric, ref UCOMIMoniker ppmkComposite);
        public void Enum(bool fForward, ref UCOMIEnumMoniker ppenumMoniker);
        public void GetClassID(ref Guid pClassID);
        public void GetDisplayName(UCOMIBindCtx pbc, UCOMIMoniker pmkToLeft, ref string ppszDisplayName);
        public void GetSizeMax(ref long pcbSize);
        public void GetTimeOfLastChange(UCOMIBindCtx pbc, UCOMIMoniker pmkToLeft, ref FILETIME pFileTime);
        public void Hash(ref int pdwHash);
        public void Inverse(ref UCOMIMoniker ppmk);
        public int IsDirty();
        public void IsEqual(UCOMIMoniker pmkOtherMoniker);
        public void IsRunning(UCOMIBindCtx pbc, UCOMIMoniker pmkToLeft, UCOMIMoniker pmkNewlyRunning);
        public void IsSystemMoniker(ref int pdwMksys);
        public void Load(UCOMIStream pStm);
        public void ParseDisplayName(UCOMIBindCtx pbc, UCOMIMoniker pmkToLeft, string pszDisplayName, ref int pchEaten, ref UCOMIMoniker ppmkOut);
        public void Reduce(UCOMIBindCtx pbc, int dwReduceHowFar, ref UCOMIMoniker ppmkToLeft, ref UCOMIMoniker ppmkReduced);
        public void RelativePathTo(UCOMIMoniker pmkOther, ref UCOMIMoniker ppmkRelPath);
        public void Save(UCOMIStream pStm, bool fClearDirty);
    }

    [ComImportAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ObsoleteAttribute(..)]
    public interface UCOMIPersistFile
    {
        public void GetClassID(ref Guid pClassID);
        public void GetCurFile(ref string ppszFileName);
        public int IsDirty();
        public void Load(string pszFileName, int dwMode);
        public void Save(string pszFileName, bool fRemember);
        public void SaveCompleted(string pszFileName);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMIRunningObjectTable
    {
        public void EnumRunning(ref UCOMIEnumMoniker ppenumMoniker);
        public void GetObject(UCOMIMoniker pmkObjectName, ref object ppunkObject);
        public void GetTimeOfLastChange(UCOMIMoniker pmkObjectName, ref FILETIME pfiletime);
        public void IsRunning(UCOMIMoniker pmkObjectName);
        public void NoteChangeTime(int dwRegister, ref FILETIME pfiletime);
        public void Register(int grfFlags, object punkObject, UCOMIMoniker pmkObjectName, ref int pdwRegister);
        public void Revoke(int dwRegister);
    }

    [ComImportAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface UCOMIStream
    {
        public void Clone(ref UCOMIStream ppstm);
        public void Commit(int grfCommitFlags);
        public void CopyTo(UCOMIStream pstm, long cb, IntPtr pcbRead, IntPtr pcbWritten);
        public void LockRegion(long libOffset, long cb, int dwLockType);
        public void Read(byte[] pv, int cb, IntPtr pcbRead);
        public void Revert();
        public void Seek(long dlibMove, int dwOrigin, IntPtr plibNewPosition);
        public void SetSize(long libNewSize);
        public void Stat(ref STATSTG pstatstg, int grfStatFlag);
        public void UnlockRegion(long libOffset, long cb, int dwLockType);
        public void Write(byte[] pv, int cb, IntPtr pcbWritten);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ObsoleteAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMITypeComp
    {
        public void Bind(string szName, int lHashVal, short wFlags, ref UCOMITypeInfo ppTInfo, ref DESCKIND pDescKind, ref BINDPTR pBindPtr);
        public void BindType(string szName, int lHashVal, ref UCOMITypeInfo ppTInfo, ref UCOMITypeComp ppTComp);
    }

    [ComImportAttribute(..)]
    [ObsoleteAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMITypeInfo
    {
        public void AddressOfMember(int memid, INVOKEKIND invKind, ref IntPtr ppv);
        public void CreateInstance(object pUnkOuter, ref Guid riid, ref object ppvObj);
        public void GetContainingTypeLib(ref UCOMITypeLib ppTLB, ref int pIndex);
        public void GetDllEntry(int memid, INVOKEKIND invKind, ref string pBstrDllName, ref string pBstrName, ref short pwOrdinal);
        public void GetDocumentation(int index, ref string strName, ref string strDocString, ref int dwHelpContext, ref string strHelpFile);
        public void GetFuncDesc(int index, ref IntPtr ppFuncDesc);
        public void GetIDsOfNames(string[] rgszNames, int cNames, int[] pMemId);
        public void GetImplTypeFlags(int index, ref int pImplTypeFlags);
        public void GetMops(int memid, ref string pBstrMops);
        public void GetNames(int memid, string[] rgBstrNames, int cMaxNames, ref int pcNames);
        public void GetRefTypeInfo(int hRef, ref UCOMITypeInfo ppTI);
        public void GetRefTypeOfImplType(int index, ref int href);
        public void GetTypeAttr(ref IntPtr ppTypeAttr);
        public void GetTypeComp(ref UCOMITypeComp ppTComp);
        public void GetVarDesc(int index, ref IntPtr ppVarDesc);
        public void Invoke(object pvInstance, int memid, short wFlags, ref DISPPARAMS pDispParams, ref object pVarResult, ref EXCEPINFO pExcepInfo, ref int puArgErr);
        public void ReleaseFuncDesc(IntPtr pFuncDesc);
        public void ReleaseTypeAttr(IntPtr pTypeAttr);
        public void ReleaseVarDesc(IntPtr pVarDesc);
    }

    [ComImportAttribute(..)]
    [ObsoleteAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface UCOMITypeLib
    {
        public void FindName(string szNameBuf, int lHashVal, UCOMITypeInfo[] ppTInfo, int[] rgMemId, ref short pcFound);
        public void GetDocumentation(int index, ref string strName, ref string strDocString, ref int dwHelpContext, ref string strHelpFile);
        public void GetLibAttr(ref IntPtr ppTLibAttr);
        public void GetTypeComp(ref UCOMITypeComp ppTComp);
        public void GetTypeInfo(int index, ref UCOMITypeInfo ppTI);
        public int GetTypeInfoCount();
        public void GetTypeInfoOfGuid(ref Guid guid, ref UCOMITypeInfo ppTInfo);
        public void GetTypeInfoType(int index, ref TYPEKIND pTKind);
        public bool IsName(string szNameBuf, int lHashVal);
        public void ReleaseTLibAttr(IntPtr pTLibAttr);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UnknownWrapper
    {
        public UnknownWrapper(object obj);
        public object WrappedObject { get; }
    }

    [ObsoleteAttribute(..)]
    public struct VARDESC
    {
        public ELEMDESC elemdescVar;
        public string lpstrSchema;
        public int memid;
        public VarEnum varkind;
        public short wVarFlags;
    }

    [SerializableAttribute(..)]
    public sealed class VariantWrapper
    {
        public VariantWrapper(object obj);
        public object WrappedObject { get; }
    }

    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum AssemblyRegistrationFlags
    {
        None,
        SetCodeBase,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum CALLCONV
    {
        CC_CDECL,
        CC_MACPASCAL,
        CC_MAX,
        CC_MPWCDECL,
        CC_MPWPASCAL,
        CC_MSCPASCAL,
        CC_PASCAL,
        CC_RESERVED,
        CC_STDCALL,
        CC_SYSCALL,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum CallingConvention
    {
        Cdecl,
        FastCall,
        StdCall,
        ThisCall,
        Winapi,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum CharSet
    {
        Ansi,
        Auto,
        None,
        Unicode,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ClassInterfaceType
    {
        AutoDispatch,
        AutoDual,
        None,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ComInterfaceType
    {
        InterfaceIsDual,
        InterfaceIsIDispatch,
        InterfaceIsIUnknown,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ComMemberType
    {
        Method,
        PropGet,
        PropSet,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum DESCKIND
    {
        DESCKIND_FUNCDESC,
        DESCKIND_IMPLICITAPPOBJ,
        DESCKIND_MAX,
        DESCKIND_NONE,
        DESCKIND_TYPECOMP,
        DESCKIND_VARDESC,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ExporterEventKind
    {
        ERROR_REFTOINVALIDASSEMBLY,
        NOTIF_CONVERTWARNING,
        NOTIF_TYPECONVERTED,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum FUNCFLAGS
    {
        FUNCFLAG_FBINDABLE,
        FUNCFLAG_FDEFAULTBIND,
        FUNCFLAG_FDEFAULTCOLLELEM,
        FUNCFLAG_FDISPLAYBIND,
        FUNCFLAG_FHIDDEN,
        FUNCFLAG_FIMMEDIATEBIND,
        FUNCFLAG_FNONBROWSABLE,
        FUNCFLAG_FREPLACEABLE,
        FUNCFLAG_FREQUESTEDIT,
        FUNCFLAG_FRESTRICTED,
        FUNCFLAG_FSOURCE,
        FUNCFLAG_FUIDEFAULT,
        FUNCFLAG_FUSESGETLASTERROR,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum FUNCKIND
    {
        FUNC_DISPATCH,
        FUNC_NONVIRTUAL,
        FUNC_PUREVIRTUAL,
        FUNC_STATIC,
        FUNC_VIRTUAL,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum GCHandleType
    {
        Normal,
        Pinned,
        Weak,
        WeakTrackResurrection,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum IDispatchImplType
    {
        CompatibleImpl,
        InternalImpl,
        SystemDefinedImpl,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    [FlagsAttribute(..)]
    public enum IDLFLAG
    {
        IDLFLAG_FIN,
        IDLFLAG_FLCID,
        IDLFLAG_FOUT,
        IDLFLAG_FRETVAL,
        IDLFLAG_NONE,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum IMPLTYPEFLAGS
    {
        IMPLTYPEFLAG_FDEFAULT,
        IMPLTYPEFLAG_FDEFAULTVTABLE,
        IMPLTYPEFLAG_FRESTRICTED,
        IMPLTYPEFLAG_FSOURCE,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ImporterEventKind
    {
        ERROR_REFTOINVALIDTYPELIB,
        NOTIF_CONVERTWARNING,
        NOTIF_TYPECONVERTED,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum INVOKEKIND
    {
        INVOKE_FUNC,
        INVOKE_PROPERTYGET,
        INVOKE_PROPERTYPUT,
        INVOKE_PROPERTYPUTREF,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum LayoutKind
    {
        Auto,
        Explicit,
        Sequential,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum LIBFLAGS
    {
        LIBFLAG_FCONTROL,
        LIBFLAG_FHASDISKIMAGE,
        LIBFLAG_FHIDDEN,
        LIBFLAG_FRESTRICTED,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    [FlagsAttribute(..)]
    public enum PARAMFLAG
    {
        PARAMFLAG_FHASCUSTDATA,
        PARAMFLAG_FHASDEFAULT,
        PARAMFLAG_FIN,
        PARAMFLAG_FLCID,
        PARAMFLAG_FOPT,
        PARAMFLAG_FOUT,
        PARAMFLAG_FRETVAL,
        PARAMFLAG_NONE,
    }

    [FlagsAttribute(..)]
    public enum RegistrationClassContext
    {
        DisableActivateAsActivator,
        EnableActivateAsActivator,
        EnableCodeDownload,
        FromDefaultContext,
        InProcessHandler,
        InProcessHandler16,
        InProcessServer,
        InProcessServer16,
        InprocHandler,
        InprocHandler16,
        InprocServer,
        InprocServer16,
        LocalServer,
        NoCodeDownload,
        NoCustomMarshal,
        NoFailureLog,
        RemoteServer,
        Reserved1,
        Reserved2,
        Reserved3,
        Reserved4,
        Reserved5,
    }

    [FlagsAttribute(..)]
    public enum RegistrationConnectionType
    {
        MultipleUse,
        MultiSeparate,
        SingleUse,
        Surrogate,
        Suspended,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum SYSKIND
    {
        SYS_MAC,
        SYS_WIN16,
        SYS_WIN32,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    [FlagsAttribute(..)]
    public enum TYPEFLAGS
    {
        TYPEFLAG_FAGGREGATABLE,
        TYPEFLAG_FAPPOBJECT,
        TYPEFLAG_FCANCREATE,
        TYPEFLAG_FCONTROL,
        TYPEFLAG_FDISPATCHABLE,
        TYPEFLAG_FDUAL,
        TYPEFLAG_FHIDDEN,
        TYPEFLAG_FLICENSED,
        TYPEFLAG_FNONEXTENSIBLE,
        TYPEFLAG_FOLEAUTOMATION,
        TYPEFLAG_FPREDECLID,
        TYPEFLAG_FPROXY,
        TYPEFLAG_FREPLACEABLE,
        TYPEFLAG_FRESTRICTED,
        TYPEFLAG_FREVERSEBIND,
    }

    [SerializableAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum TYPEKIND
    {
        TKIND_ALIAS,
        TKIND_COCLASS,
        TKIND_DISPATCH,
        TKIND_ENUM,
        TKIND_INTERFACE,
        TKIND_MAX,
        TKIND_MODULE,
        TKIND_RECORD,
        TKIND_UNION,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum TypeLibExporterFlags
    {
        CallerResolvedReferences,
        ExportAs32Bit,
        ExportAs64Bit,
        None,
        OldNames,
        OnlyReferenceRegistered,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum TypeLibFuncFlags
    {
        FBindable,
        FDefaultBind,
        FDefaultCollelem,
        FDisplayBind,
        FHidden,
        FImmediateBind,
        FNonBrowsable,
        FReplaceable,
        FRequestEdit,
        FRestricted,
        FSource,
        FUiDefault,
        FUsesGetLastError,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum TypeLibImporterFlags
    {
        ImportAsAgnostic,
        ImportAsItanium,
        ImportAsX64,
        ImportAsX86,
        None,
        PreventClassMembers,
        PrimaryInteropAssembly,
        ReflectionOnlyLoading,
        SafeArrayAsSystemArray,
        SerializableValueClasses,
        TransformDispRetVals,
        UnsafeInterfaces,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum TypeLibTypeFlags
    {
        FAggregatable,
        FAppObject,
        FCanCreate,
        FControl,
        FDispatchable,
        FDual,
        FHidden,
        FLicensed,
        FNonExtensible,
        FOleAutomation,
        FPreDeclId,
        FReplaceable,
        FRestricted,
        FReverseBind,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum TypeLibVarFlags
    {
        FBindable,
        FDefaultBind,
        FDefaultCollelem,
        FDisplayBind,
        FHidden,
        FImmediateBind,
        FNonBrowsable,
        FReadOnly,
        FReplaceable,
        FRequestEdit,
        FRestricted,
        FSource,
        FUiDefault,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum UnmanagedType
    {
        AnsiBStr,
        AsAny,
        Bool,
        BStr,
        ByValArray,
        ByValTStr,
        Currency,
        CustomMarshaler,
        Error,
        FunctionPtr,
        I1,
        I2,
        I4,
        I8,
        IDispatch,
        Interface,
        IUnknown,
        LPArray,
        LPStr,
        LPStruct,
        LPTStr,
        LPWStr,
        R4,
        R8,
        SafeArray,
        Struct,
        SysInt,
        SysUInt,
        TBStr,
        U1,
        U2,
        U4,
        U8,
        VariantBool,
        VBByRefStr,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum VarEnum
    {
        VT_ARRAY,
        VT_BLOB,
        VT_BLOB_OBJECT,
        VT_BOOL,
        VT_BSTR,
        VT_BYREF,
        VT_CARRAY,
        VT_CF,
        VT_CLSID,
        VT_CY,
        VT_DATE,
        VT_DECIMAL,
        VT_DISPATCH,
        VT_EMPTY,
        VT_ERROR,
        VT_FILETIME,
        VT_HRESULT,
        VT_I1,
        VT_I2,
        VT_I4,
        VT_I8,
        VT_INT,
        VT_LPSTR,
        VT_LPWSTR,
        VT_NULL,
        VT_PTR,
        VT_R4,
        VT_R8,
        VT_RECORD,
        VT_SAFEARRAY,
        VT_STORAGE,
        VT_STORED_OBJECT,
        VT_STREAM,
        VT_STREAMED_OBJECT,
        VT_UI1,
        VT_UI2,
        VT_UI4,
        VT_UI8,
        VT_UINT,
        VT_UNKNOWN,
        VT_USERDEFINED,
        VT_VARIANT,
        VT_VECTOR,
        VT_VOID,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ObsoleteAttribute(..)]
    public enum VARFLAGS
    {
        VARFLAG_FBINDABLE,
        VARFLAG_FDEFAULTBIND,
        VARFLAG_FDEFAULTCOLLELEM,
        VARFLAG_FDISPLAYBIND,
        VARFLAG_FHIDDEN,
        VARFLAG_FIMMEDIATEBIND,
        VARFLAG_FNONBROWSABLE,
        VARFLAG_FREADONLY,
        VARFLAG_FREPLACEABLE,
        VARFLAG_FREQUESTEDIT,
        VARFLAG_FRESTRICTED,
        VARFLAG_FSOURCE,
        VARFLAG_FUIDEFAULT,
    }

    [ComVisibleAttribute(..)]
    public delegate IntPtr ObjectCreationDelegate(IntPtr aggregator);

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AutomationProxyAttribute: Attribute, _Attribute
    {
        public AutomationProxyAttribute(bool val);
        public bool Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class BestFitMappingAttribute: Attribute, _Attribute
    {
        public BestFitMappingAttribute(bool BestFitMapping);
        public bool ThrowOnUnmappableChar;
        public bool BestFitMapping { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ClassInterfaceAttribute: Attribute, _Attribute
    {
        public ClassInterfaceAttribute(ClassInterfaceType classInterfaceType);
        public ClassInterfaceAttribute(short classInterfaceType);
        public ClassInterfaceType Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class CoClassAttribute: Attribute, _Attribute
    {
        public CoClassAttribute(Type coClass);
        public Type CoClass { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class ComAliasNameAttribute: Attribute, _Attribute
    {
        public ComAliasNameAttribute(string alias);
        public string Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComCompatibleVersionAttribute: Attribute, _Attribute
    {
        public ComCompatibleVersionAttribute(int major, int minor, int build, int revision);
        public int BuildNumber { get; }
        public int MajorVersion { get; }
        public int MinorVersion { get; }
        public int RevisionNumber { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComConversionLossAttribute: Attribute, _Attribute
    {
        public ComConversionLossAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComDefaultInterfaceAttribute: Attribute, _Attribute
    {
        public ComDefaultInterfaceAttribute(Type defaultInterface);
        public Type Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComEventInterfaceAttribute: Attribute, _Attribute
    {
        public ComEventInterfaceAttribute(Type SourceInterface, Type EventProvider);
        public Type EventProvider { get; }
        public Type SourceInterface { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComImportAttribute: Attribute, _Attribute
    {
        public ComImportAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComRegisterFunctionAttribute: Attribute, _Attribute
    {
        public ComRegisterFunctionAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComSourceInterfacesAttribute: Attribute, _Attribute
    {
        public ComSourceInterfacesAttribute(string sourceInterfaces);
        public ComSourceInterfacesAttribute(Type sourceInterface);
        public ComSourceInterfacesAttribute(Type sourceInterface1, Type sourceInterface2);
        public ComSourceInterfacesAttribute(Type sourceInterface1, Type sourceInterface2, Type sourceInterface3);
        public ComSourceInterfacesAttribute(Type sourceInterface1, Type sourceInterface2, Type sourceInterface3, Type sourceInterface4);
        public string Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComUnregisterFunctionAttribute: Attribute, _Attribute
    {
        public ComUnregisterFunctionAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ComVisibleAttribute: Attribute, _Attribute
    {
        public ComVisibleAttribute(bool visibility);
        public bool Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DefaultCharSetAttribute: Attribute, _Attribute
    {
        public DefaultCharSetAttribute(CharSet charSet);
        public CharSet CharSet { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DispIdAttribute: Attribute, _Attribute
    {
        public DispIdAttribute(int dispId);
        public int Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class DllImportAttribute: Attribute, _Attribute
    {
        public DllImportAttribute(string dllName);
        public bool BestFitMapping;
        public CallingConvention CallingConvention;
        public CharSet CharSet;
        public string EntryPoint;
        public bool ExactSpelling;
        public bool PreserveSig;
        public bool SetLastError;
        public bool ThrowOnUnmappableChar;
        public string Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class FieldOffsetAttribute: Attribute, _Attribute
    {
        public FieldOffsetAttribute(int offset);
        public int Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class GuidAttribute: Attribute, _Attribute
    {
        public GuidAttribute(string guid);
        public string Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public sealed class IDispatchImplAttribute: Attribute, _Attribute
    {
        public IDispatchImplAttribute(IDispatchImplType implType);
        public IDispatchImplAttribute(short implType);
        public IDispatchImplType Value { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class ImportedFromTypeLibAttribute: Attribute, _Attribute
    {
        public ImportedFromTypeLibAttribute(string tlbFile);
        public string Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class InAttribute: Attribute, _Attribute
    {
        public InAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class InterfaceTypeAttribute: Attribute, _Attribute
    {
        public InterfaceTypeAttribute(ComInterfaceType interfaceType);
        public InterfaceTypeAttribute(short interfaceType);
        public ComInterfaceType Value { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class LCIDConversionAttribute: Attribute, _Attribute
    {
        public LCIDConversionAttribute(int lcid);
        public int Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class MarshalAsAttribute: Attribute, _Attribute
    {
        public MarshalAsAttribute(short unmanagedType);
        public MarshalAsAttribute(UnmanagedType unmanagedType);
        public UnmanagedType ArraySubType;
        public int IidParameterIndex;
        public string MarshalCookie;
        public string MarshalType;
        public Type MarshalTypeRef;
        public VarEnum SafeArraySubType;
        public Type SafeArrayUserDefinedSubType;
        public int SizeConst;
        public short SizeParamIndex;
        public UnmanagedType Value { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class OptionalAttribute: Attribute, _Attribute
    {
        public OptionalAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class OutAttribute: Attribute, _Attribute
    {
        public OutAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class PreserveSigAttribute: Attribute, _Attribute
    {
        public PreserveSigAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class PrimaryInteropAssemblyAttribute: Attribute, _Attribute
    {
        public PrimaryInteropAssemblyAttribute(int major, int minor);
        public int MajorVersion { get; }
        public int MinorVersion { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ProgIdAttribute: Attribute, _Attribute
    {
        public ProgIdAttribute(string progId);
        public string Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ObsoleteAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SetWin32ContextInIDispatchAttribute: Attribute, _Attribute
    {
        public SetWin32ContextInIDispatchAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class StructLayoutAttribute: Attribute, _Attribute
    {
        public StructLayoutAttribute(LayoutKind layoutKind);
        public StructLayoutAttribute(short layoutKind);
        public CharSet CharSet;
        public int Pack;
        public int Size;
        public LayoutKind Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class TypeLibFuncAttribute: Attribute, _Attribute
    {
        public TypeLibFuncAttribute(short flags);
        public TypeLibFuncAttribute(TypeLibFuncFlags flags);
        public TypeLibFuncFlags Value { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class TypeLibImportClassAttribute: Attribute, _Attribute
    {
        public TypeLibImportClassAttribute(Type importClass);
        public string Value { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class TypeLibTypeAttribute: Attribute, _Attribute
    {
        public TypeLibTypeAttribute(short flags);
        public TypeLibTypeAttribute(TypeLibTypeFlags flags);
        public TypeLibTypeFlags Value { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class TypeLibVarAttribute: Attribute, _Attribute
    {
        public TypeLibVarAttribute(short flags);
        public TypeLibVarAttribute(TypeLibVarFlags flags);
        public TypeLibVarFlags Value { get; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class TypeLibVersionAttribute: Attribute, _Attribute
    {
        public TypeLibVersionAttribute(int major, int minor);
        public int MajorVersion { get; }
        public int MinorVersion { get; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UnmanagedFunctionPointerAttribute: Attribute, _Attribute
    {
        public UnmanagedFunctionPointerAttribute(CallingConvention callingConvention);
        public bool BestFitMapping;
        public CharSet CharSet;
        public bool SetLastError;
        public bool ThrowOnUnmappableChar;
        public CallingConvention CallingConvention { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class COMException: ExternalException, _Exception, ISerializable
    {
        public COMException();
        protected COMException(SerializationInfo info, StreamingContext context);
        public COMException(string message);
        public COMException(string message, Exception inner);
        public COMException(string message, int errorCode);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public class ComObjectInUseException: SystemException, _Exception, ISerializable
    {
        public ComObjectInUseException();
        protected ComObjectInUseException(SerializationInfo info, StreamingContext context);
        public ComObjectInUseException(string message);
        public ComObjectInUseException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ExternalException: SystemException, _Exception, ISerializable
    {
        public ExternalException();
        protected ExternalException(SerializationInfo info, StreamingContext context);
        public ExternalException(string message);
        public ExternalException(string message, Exception inner);
        public ExternalException(string message, int errorCode);
        public virtual int ErrorCode { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class InvalidComObjectException: SystemException, _Exception, ISerializable
    {
        public InvalidComObjectException();
        protected InvalidComObjectException(SerializationInfo info, StreamingContext context);
        public InvalidComObjectException(string message);
        public InvalidComObjectException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class InvalidOleVariantTypeException: SystemException, _Exception, ISerializable
    {
        public InvalidOleVariantTypeException();
        protected InvalidOleVariantTypeException(SerializationInfo info, StreamingContext context);
        public InvalidOleVariantTypeException(string message);
        public InvalidOleVariantTypeException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MarshalDirectiveException: SystemException, _Exception, ISerializable
    {
        public MarshalDirectiveException();
        protected MarshalDirectiveException(SerializationInfo info, StreamingContext context);
        public MarshalDirectiveException(string message);
        public MarshalDirectiveException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SafeArrayRankMismatchException: SystemException, _Exception, ISerializable
    {
        public SafeArrayRankMismatchException();
        protected SafeArrayRankMismatchException(SerializationInfo info, StreamingContext context);
        public SafeArrayRankMismatchException(string message);
        public SafeArrayRankMismatchException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SafeArrayTypeMismatchException: SystemException, _Exception, ISerializable
    {
        public SafeArrayTypeMismatchException();
        protected SafeArrayTypeMismatchException(SerializationInfo info, StreamingContext context);
        public SafeArrayTypeMismatchException(string message);
        public SafeArrayTypeMismatchException(string message, Exception inner);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SEHException: ExternalException, _Exception, ISerializable
    {
        public SEHException();
        protected SEHException(SerializationInfo info, StreamingContext context);
        public SEHException(string message);
        public SEHException(string message, Exception inner);
        public virtual bool CanResume();
    }

} 
namespace System.Runtime.InteropServices.ComTypes
{
    public struct BIND_OPTS
    {
        public int cbStruct;
        public int dwTickCountDeadline;
        public int grfFlags;
        public int grfMode;
    }

    public struct BINDPTR
    {
        public IntPtr lpfuncdesc;
        public IntPtr lptcomp;
        public IntPtr lpvardesc;
    }

    public struct CONNECTDATA
    {
        public int dwCookie;
        public object pUnk;
    }

    public struct DISPPARAMS
    {
        public int cArgs;
        public int cNamedArgs;
        public IntPtr rgdispidNamedArgs;
        public IntPtr rgvarg;
    }

    public struct ELEMDESC
    {
        public DESCUNION desc;
        public TYPEDESC tdesc;
    }

    public struct EXCEPINFO
    {
        public string bstrDescription;
        public string bstrHelpFile;
        public string bstrSource;
        public int dwHelpContext;
        public IntPtr pfnDeferredFillIn;
        public IntPtr pvReserved;
        public int scode;
        public short wCode;
        public short wReserved;
    }

    public struct FILETIME
    {
        public int dwHighDateTime;
        public int dwLowDateTime;
    }

    public struct FUNCDESC
    {
        public CALLCONV callconv;
        public short cParams;
        public short cParamsOpt;
        public short cScodes;
        public ELEMDESC elemdescFunc;
        public FUNCKIND funckind;
        public INVOKEKIND invkind;
        public IntPtr lprgelemdescParam;
        public IntPtr lprgscode;
        public int memid;
        public short oVft;
        public short wFuncFlags;
    }

    [ComImportAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface IBindCtx
    {
        public void EnumObjectParam(ref IEnumString ppenum);
        public void GetBindOptions(ref BIND_OPTS pbindopts);
        public void GetObjectParam(string pszKey, ref object ppunk);
        public void GetRunningObjectTable(ref IRunningObjectTable pprot);
        public void RegisterObjectBound(object punk);
        public void RegisterObjectParam(string pszKey, object punk);
        public void ReleaseBoundObjects();
        public void RevokeObjectBound(object punk);
        public int RevokeObjectParam(string pszKey);
        public void SetBindOptions(ref BIND_OPTS pbindopts);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IConnectionPoint
    {
        public void Advise(object pUnkSink, ref int pdwCookie);
        public void EnumConnections(ref IEnumConnections ppEnum);
        public void GetConnectionInterface(ref Guid pIID);
        public void GetConnectionPointContainer(ref IConnectionPointContainer ppCPC);
        public void Unadvise(int dwCookie);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IConnectionPointContainer
    {
        public void EnumConnectionPoints(ref IEnumConnectionPoints ppEnum);
        public void FindConnectionPoint(ref Guid riid, ref IConnectionPoint ppCP);
    }

    public struct IDLDESC
    {
        public IntPtr dwReserved;
        public IDLFLAG wIDLFlags;
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IEnumConnectionPoints
    {
        public void Clone(ref IEnumConnectionPoints ppenum);
        public int Next(int celt, IConnectionPoint[] rgelt, IntPtr pceltFetched);
        public void Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IEnumConnections
    {
        public void Clone(ref IEnumConnections ppenum);
        public int Next(int celt, CONNECTDATA[] rgelt, IntPtr pceltFetched);
        public void Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface IEnumMoniker
    {
        public void Clone(ref IEnumMoniker ppenum);
        public int Next(int celt, IMoniker[] rgelt, IntPtr pceltFetched);
        public void Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IEnumString
    {
        public void Clone(ref IEnumString ppenum);
        public int Next(int celt, string[] rgelt, IntPtr pceltFetched);
        public void Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface IEnumVARIANT
    {
        public IEnumVARIANT Clone();
        public int Next(int celt, object[] rgVar, IntPtr pceltFetched);
        public int Reset();
        public int Skip(int celt);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IMoniker
    {
        public void BindToObject(IBindCtx pbc, IMoniker pmkToLeft, ref Guid riidResult, ref object ppvResult);
        public void BindToStorage(IBindCtx pbc, IMoniker pmkToLeft, ref Guid riid, ref object ppvObj);
        public void CommonPrefixWith(IMoniker pmkOther, ref IMoniker ppmkPrefix);
        public void ComposeWith(IMoniker pmkRight, bool fOnlyIfNotGeneric, ref IMoniker ppmkComposite);
        public void Enum(bool fForward, ref IEnumMoniker ppenumMoniker);
        public void GetClassID(ref Guid pClassID);
        public void GetDisplayName(IBindCtx pbc, IMoniker pmkToLeft, ref string ppszDisplayName);
        public void GetSizeMax(ref long pcbSize);
        public void GetTimeOfLastChange(IBindCtx pbc, IMoniker pmkToLeft, ref FILETIME pFileTime);
        public void Hash(ref int pdwHash);
        public void Inverse(ref IMoniker ppmk);
        public int IsDirty();
        public int IsEqual(IMoniker pmkOtherMoniker);
        public int IsRunning(IBindCtx pbc, IMoniker pmkToLeft, IMoniker pmkNewlyRunning);
        public int IsSystemMoniker(ref int pdwMksys);
        public void Load(IStream pStm);
        public void ParseDisplayName(IBindCtx pbc, IMoniker pmkToLeft, string pszDisplayName, ref int pchEaten, ref IMoniker ppmkOut);
        public void Reduce(IBindCtx pbc, int dwReduceHowFar, ref IMoniker ppmkToLeft, ref IMoniker ppmkReduced);
        public void RelativePathTo(IMoniker pmkOther, ref IMoniker ppmkRelPath);
        public void Save(IStream pStm, bool fClearDirty);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IPersistFile
    {
        public void GetClassID(ref Guid pClassID);
        public void GetCurFile(ref string ppszFileName);
        public int IsDirty();
        public void Load(string pszFileName, int dwMode);
        public void Save(string pszFileName, bool fRemember);
        public void SaveCompleted(string pszFileName);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IRunningObjectTable
    {
        public void EnumRunning(ref IEnumMoniker ppenumMoniker);
        public int GetObject(IMoniker pmkObjectName, ref object ppunkObject);
        public int GetTimeOfLastChange(IMoniker pmkObjectName, ref FILETIME pfiletime);
        public int IsRunning(IMoniker pmkObjectName);
        public void NoteChangeTime(int dwRegister, ref FILETIME pfiletime);
        public int Register(int grfFlags, object punkObject, IMoniker pmkObjectName);
        public void Revoke(int dwRegister);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface IStream
    {
        public void Clone(ref IStream ppstm);
        public void Commit(int grfCommitFlags);
        public void CopyTo(IStream pstm, long cb, IntPtr pcbRead, IntPtr pcbWritten);
        public void LockRegion(long libOffset, long cb, int dwLockType);
        public void Read(byte[] pv, int cb, IntPtr pcbRead);
        public void Revert();
        public void Seek(long dlibMove, int dwOrigin, IntPtr plibNewPosition);
        public void SetSize(long libNewSize);
        public void Stat(ref STATSTG pstatstg, int grfStatFlag);
        public void UnlockRegion(long libOffset, long cb, int dwLockType);
        public void Write(byte[] pv, int cb, IntPtr pcbWritten);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface ITypeComp
    {
        public void Bind(string szName, int lHashVal, short wFlags, ref ITypeInfo ppTInfo, ref DESCKIND pDescKind, ref BINDPTR pBindPtr);
        public void BindType(string szName, int lHashVal, ref ITypeInfo ppTInfo, ref ITypeComp ppTComp);
    }

    [ComImportAttribute(..)]
    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    public interface ITypeInfo
    {
        public void AddressOfMember(int memid, INVOKEKIND invKind, ref IntPtr ppv);
        public void CreateInstance(object pUnkOuter, ref Guid riid, ref object ppvObj);
        public void GetContainingTypeLib(ref ITypeLib ppTLB, ref int pIndex);
        public void GetDllEntry(int memid, INVOKEKIND invKind, IntPtr pBstrDllName, IntPtr pBstrName, IntPtr pwOrdinal);
        public void GetDocumentation(int index, ref string strName, ref string strDocString, ref int dwHelpContext, ref string strHelpFile);
        public void GetFuncDesc(int index, ref IntPtr ppFuncDesc);
        public void GetIDsOfNames(string[] rgszNames, int cNames, int[] pMemId);
        public void GetImplTypeFlags(int index, ref IMPLTYPEFLAGS pImplTypeFlags);
        public void GetMops(int memid, ref string pBstrMops);
        public void GetNames(int memid, string[] rgBstrNames, int cMaxNames, ref int pcNames);
        public void GetRefTypeInfo(int hRef, ref ITypeInfo ppTI);
        public void GetRefTypeOfImplType(int index, ref int href);
        public void GetTypeAttr(ref IntPtr ppTypeAttr);
        public void GetTypeComp(ref ITypeComp ppTComp);
        public void GetVarDesc(int index, ref IntPtr ppVarDesc);
        public void Invoke(object pvInstance, int memid, short wFlags, ref DISPPARAMS pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, ref int puArgErr);
        public void ReleaseFuncDesc(IntPtr pFuncDesc);
        public void ReleaseTypeAttr(IntPtr pTypeAttr);
        public void ReleaseVarDesc(IntPtr pVarDesc);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface ITypeInfo2: ITypeInfo
    {
        public void AddressOfMember(int memid, INVOKEKIND invKind, ref IntPtr ppv);
        public void CreateInstance(object pUnkOuter, ref Guid riid, ref object ppvObj);
        public void GetAllCustData(IntPtr pCustData);
        public void GetAllFuncCustData(int index, IntPtr pCustData);
        public void GetAllImplTypeCustData(int index, IntPtr pCustData);
        public void GetAllParamCustData(int indexFunc, int indexParam, IntPtr pCustData);
        public void GetAllVarCustData(int index, IntPtr pCustData);
        public void GetContainingTypeLib(ref ITypeLib ppTLB, ref int pIndex);
        public void GetCustData(ref Guid guid, ref object pVarVal);
        public void GetDllEntry(int memid, INVOKEKIND invKind, IntPtr pBstrDllName, IntPtr pBstrName, IntPtr pwOrdinal);
        public void GetDocumentation(int index, ref string strName, ref string strDocString, ref int dwHelpContext, ref string strHelpFile);
        public void GetDocumentation2(int memid, ref string pbstrHelpString, ref int pdwHelpStringContext, ref string pbstrHelpStringDll);
        public void GetFuncCustData(int index, ref Guid guid, ref object pVarVal);
        public void GetFuncDesc(int index, ref IntPtr ppFuncDesc);
        public void GetFuncIndexOfMemId(int memid, INVOKEKIND invKind, ref int pFuncIndex);
        public void GetIDsOfNames(string[] rgszNames, int cNames, int[] pMemId);
        public void GetImplTypeCustData(int index, ref Guid guid, ref object pVarVal);
        public void GetImplTypeFlags(int index, ref IMPLTYPEFLAGS pImplTypeFlags);
        public void GetMops(int memid, ref string pBstrMops);
        public void GetNames(int memid, string[] rgBstrNames, int cMaxNames, ref int pcNames);
        public void GetParamCustData(int indexFunc, int indexParam, ref Guid guid, ref object pVarVal);
        public void GetRefTypeInfo(int hRef, ref ITypeInfo ppTI);
        public void GetRefTypeOfImplType(int index, ref int href);
        public void GetTypeAttr(ref IntPtr ppTypeAttr);
        public void GetTypeComp(ref ITypeComp ppTComp);
        public void GetTypeFlags(ref int pTypeFlags);
        public void GetTypeKind(ref TYPEKIND pTypeKind);
        public void GetVarCustData(int index, ref Guid guid, ref object pVarVal);
        public void GetVarDesc(int index, ref IntPtr ppVarDesc);
        public void GetVarIndexOfMemId(int memid, ref int pVarIndex);
        public void Invoke(object pvInstance, int memid, short wFlags, ref DISPPARAMS pDispParams, IntPtr pVarResult, IntPtr pExcepInfo, ref int puArgErr);
        public void ReleaseFuncDesc(IntPtr pFuncDesc);
        public void ReleaseTypeAttr(IntPtr pTypeAttr);
        public void ReleaseVarDesc(IntPtr pVarDesc);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface ITypeLib
    {
        public void FindName(string szNameBuf, int lHashVal, ITypeInfo[] ppTInfo, int[] rgMemId, ref short pcFound);
        public void GetDocumentation(int index, ref string strName, ref string strDocString, ref int dwHelpContext, ref string strHelpFile);
        public void GetLibAttr(ref IntPtr ppTLibAttr);
        public void GetTypeComp(ref ITypeComp ppTComp);
        public void GetTypeInfo(int index, ref ITypeInfo ppTI);
        public int GetTypeInfoCount();
        public void GetTypeInfoOfGuid(ref Guid guid, ref ITypeInfo ppTInfo);
        public void GetTypeInfoType(int index, ref TYPEKIND pTKind);
        public bool IsName(string szNameBuf, int lHashVal);
        public void ReleaseTLibAttr(IntPtr pTLibAttr);
    }

    [ComImportAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [GuidAttribute(..)]
    public interface ITypeLib2: ITypeLib
    {
        public void FindName(string szNameBuf, int lHashVal, ITypeInfo[] ppTInfo, int[] rgMemId, ref short pcFound);
        public void GetAllCustData(IntPtr pCustData);
        public void GetCustData(ref Guid guid, ref object pVarVal);
        public void GetDocumentation(int index, ref string strName, ref string strDocString, ref int dwHelpContext, ref string strHelpFile);
        public void GetDocumentation2(int index, ref string pbstrHelpString, ref int pdwHelpStringContext, ref string pbstrHelpStringDll);
        public void GetLibAttr(ref IntPtr ppTLibAttr);
        public void GetLibStatistics(IntPtr pcUniqueNames, ref int pcchUniqueNames);
        public void GetTypeComp(ref ITypeComp ppTComp);
        public void GetTypeInfo(int index, ref ITypeInfo ppTI);
        public int GetTypeInfoCount();
        public void GetTypeInfoOfGuid(ref Guid guid, ref ITypeInfo ppTInfo);
        public void GetTypeInfoType(int index, ref TYPEKIND pTKind);
        public bool IsName(string szNameBuf, int lHashVal);
        public void ReleaseTLibAttr(IntPtr pTLibAttr);
    }

    public struct PARAMDESC
    {
        public IntPtr lpVarValue;
        public PARAMFLAG wParamFlags;
    }

    public struct STATSTG
    {
        public FILETIME atime;
        public long cbSize;
        public Guid clsid;
        public FILETIME ctime;
        public int grfLocksSupported;
        public int grfMode;
        public int grfStateBits;
        public FILETIME mtime;
        public string pwcsName;
        public int reserved;
        public int type;
    }

    public struct TYPEATTR
    {
        public short cbAlignment;
        public int cbSizeInstance;
        public short cbSizeVft;
        public short cFuncs;
        public short cImplTypes;
        public short cVars;
        public int dwReserved;
        public Guid guid;
        public IDLDESC idldescType;
        public int lcid;
        public IntPtr lpstrSchema;
        public const int MEMBER_ID_NIL;
        public int memidConstructor;
        public int memidDestructor;
        public TYPEDESC tdescAlias;
        public TYPEKIND typekind;
        public short wMajorVerNum;
        public short wMinorVerNum;
        public TYPEFLAGS wTypeFlags;
    }

    public struct TYPEDESC
    {
        public IntPtr lpValue;
        public short vt;
    }

    [SerializableAttribute(..)]
    public struct TYPELIBATTR
    {
        public Guid guid;
        public int lcid;
        public SYSKIND syskind;
        public LIBFLAGS wLibFlags;
        public short wMajorVerNum;
        public short wMinorVerNum;
    }

    public struct VARDESC
    {
        public DESCUNION desc;
        public ELEMDESC elemdescVar;
        public string lpstrSchema;
        public int memid;
        public VARKIND varkind;
        public short wVarFlags;
    }

    [SerializableAttribute(..)]
    public enum CALLCONV
    {
        CC_CDECL,
        CC_MACPASCAL,
        CC_MAX,
        CC_MPWCDECL,
        CC_MPWPASCAL,
        CC_MSCPASCAL,
        CC_PASCAL,
        CC_RESERVED,
        CC_STDCALL,
        CC_SYSCALL,
    }

    [SerializableAttribute(..)]
    public enum DESCKIND
    {
        DESCKIND_FUNCDESC,
        DESCKIND_IMPLICITAPPOBJ,
        DESCKIND_MAX,
        DESCKIND_NONE,
        DESCKIND_TYPECOMP,
        DESCKIND_VARDESC,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum FUNCFLAGS
    {
        FUNCFLAG_FBINDABLE,
        FUNCFLAG_FDEFAULTBIND,
        FUNCFLAG_FDEFAULTCOLLELEM,
        FUNCFLAG_FDISPLAYBIND,
        FUNCFLAG_FHIDDEN,
        FUNCFLAG_FIMMEDIATEBIND,
        FUNCFLAG_FNONBROWSABLE,
        FUNCFLAG_FREPLACEABLE,
        FUNCFLAG_FREQUESTEDIT,
        FUNCFLAG_FRESTRICTED,
        FUNCFLAG_FSOURCE,
        FUNCFLAG_FUIDEFAULT,
        FUNCFLAG_FUSESGETLASTERROR,
    }

    [SerializableAttribute(..)]
    public enum FUNCKIND
    {
        FUNC_DISPATCH,
        FUNC_NONVIRTUAL,
        FUNC_PUREVIRTUAL,
        FUNC_STATIC,
        FUNC_VIRTUAL,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum IDLFLAG
    {
        IDLFLAG_FIN,
        IDLFLAG_FLCID,
        IDLFLAG_FOUT,
        IDLFLAG_FRETVAL,
        IDLFLAG_NONE,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum IMPLTYPEFLAGS
    {
        IMPLTYPEFLAG_FDEFAULT,
        IMPLTYPEFLAG_FDEFAULTVTABLE,
        IMPLTYPEFLAG_FRESTRICTED,
        IMPLTYPEFLAG_FSOURCE,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum INVOKEKIND
    {
        INVOKE_FUNC,
        INVOKE_PROPERTYGET,
        INVOKE_PROPERTYPUT,
        INVOKE_PROPERTYPUTREF,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum LIBFLAGS
    {
        LIBFLAG_FCONTROL,
        LIBFLAG_FHASDISKIMAGE,
        LIBFLAG_FHIDDEN,
        LIBFLAG_FRESTRICTED,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum PARAMFLAG
    {
        PARAMFLAG_FHASCUSTDATA,
        PARAMFLAG_FHASDEFAULT,
        PARAMFLAG_FIN,
        PARAMFLAG_FLCID,
        PARAMFLAG_FOPT,
        PARAMFLAG_FOUT,
        PARAMFLAG_FRETVAL,
        PARAMFLAG_NONE,
    }

    [SerializableAttribute(..)]
    public enum SYSKIND
    {
        SYS_MAC,
        SYS_WIN16,
        SYS_WIN32,
        SYS_WIN64,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum TYPEFLAGS
    {
        TYPEFLAG_FAGGREGATABLE,
        TYPEFLAG_FAPPOBJECT,
        TYPEFLAG_FCANCREATE,
        TYPEFLAG_FCONTROL,
        TYPEFLAG_FDISPATCHABLE,
        TYPEFLAG_FDUAL,
        TYPEFLAG_FHIDDEN,
        TYPEFLAG_FLICENSED,
        TYPEFLAG_FNONEXTENSIBLE,
        TYPEFLAG_FOLEAUTOMATION,
        TYPEFLAG_FPREDECLID,
        TYPEFLAG_FPROXY,
        TYPEFLAG_FREPLACEABLE,
        TYPEFLAG_FRESTRICTED,
        TYPEFLAG_FREVERSEBIND,
    }

    [SerializableAttribute(..)]
    public enum TYPEKIND
    {
        TKIND_ALIAS,
        TKIND_COCLASS,
        TKIND_DISPATCH,
        TKIND_ENUM,
        TKIND_INTERFACE,
        TKIND_MAX,
        TKIND_MODULE,
        TKIND_RECORD,
        TKIND_UNION,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    public enum VARFLAGS
    {
        VARFLAG_FBINDABLE,
        VARFLAG_FDEFAULTBIND,
        VARFLAG_FDEFAULTCOLLELEM,
        VARFLAG_FDISPLAYBIND,
        VARFLAG_FHIDDEN,
        VARFLAG_FIMMEDIATEBIND,
        VARFLAG_FNONBROWSABLE,
        VARFLAG_FREADONLY,
        VARFLAG_FREPLACEABLE,
        VARFLAG_FREQUESTEDIT,
        VARFLAG_FRESTRICTED,
        VARFLAG_FSOURCE,
        VARFLAG_FUIDEFAULT,
    }

    [SerializableAttribute(..)]
    public enum VARKIND
    {
        VAR_CONST,
        VAR_DISPATCH,
        VAR_PERINSTANCE,
        VAR_STATIC,
    }

} 
namespace System.Runtime.InteropServices.Expando
{
    [ComVisibleAttribute(..)]
    [GuidAttribute(..)]
    public interface IExpando: IReflect
    {
        public FieldInfo AddField(string name);
        public MethodInfo AddMethod(string name, Delegate method);
        public PropertyInfo AddProperty(string name);
        public void RemoveMember(MemberInfo m);
    }

} 
namespace System.Runtime.Remoting
{
    [ComVisibleAttribute(..)]
    public class ActivatedClientTypeEntry: TypeEntry
    {
        public ActivatedClientTypeEntry(string typeName, string assemblyName, string appUrl);
        public ActivatedClientTypeEntry(Type type, string appUrl);
        public string ApplicationUrl { get; }
        public IContextAttribute[] ContextAttributes { get; set; }
        public Type ObjectType { get; }
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public class ActivatedServiceTypeEntry: TypeEntry
    {
        public ActivatedServiceTypeEntry(string typeName, string assemblyName);
        public ActivatedServiceTypeEntry(Type type);
        public IContextAttribute[] ContextAttributes { get; set; }
        public Type ObjectType { get; }
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public interface IChannelInfo
    {
        public object[] ChannelData { get; set; }
    }

    [ComVisibleAttribute(..)]
    public interface IEnvoyInfo
    {
        public IMessageSink EnvoySinks { get; set; }
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class InternalRemotingServices
    {
        public InternalRemotingServices();
        public static void DebugOutChnl(string s);
        public static SoapAttribute GetCachedSoapAttribute(object reflectionObject);
        public static void RemotingAssert(bool condition, string message);
        public static void RemotingTrace(params object[] messages);
        public static void SetServerIdentity(MethodCall m, object srvID);
    }

    [GuidAttribute(..)]
    [InterfaceTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface IObjectHandle
    {
        public object Unwrap();
    }

    [ComVisibleAttribute(..)]
    public interface IRemotingTypeInfo
    {
        public string TypeName { get; set; }
        public bool CanCastTo(Type fromType, object o);
    }

    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ObjectHandle: MarshalByRefObject, IObjectHandle
    {
        public ObjectHandle(object o);
        public override object InitializeLifetimeService();
        public object Unwrap();
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ObjRef: IObjectReference, ISerializable
    {
        public ObjRef();
        public ObjRef(MarshalByRefObject o, Type requestedType);
        protected ObjRef(SerializationInfo info, StreamingContext context);
        public virtual IChannelInfo ChannelInfo { get; set; }
        public virtual IEnvoyInfo EnvoyInfo { get; set; }
        public virtual IRemotingTypeInfo TypeInfo { get; set; }
        public virtual string URI { get; set; }
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public virtual object GetRealObject(StreamingContext context);
        public bool IsFromThisAppDomain();
        public bool IsFromThisProcess();
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class RemotingConfiguration
    {
        public static string ApplicationId { get; }
        public static string ApplicationName { get; set; }
        public static CustomErrorsModes CustomErrorsMode { get; set; }
        public static string ProcessId { get; }
        public static void Configure(string filename);
        public static bool CustomErrorsEnabled(bool isLocalRequest);
        public static ActivatedClientTypeEntry[] GetRegisteredActivatedClientTypes();
        public static ActivatedServiceTypeEntry[] GetRegisteredActivatedServiceTypes();
        public static WellKnownClientTypeEntry[] GetRegisteredWellKnownClientTypes();
        public static WellKnownServiceTypeEntry[] GetRegisteredWellKnownServiceTypes();
        public static bool IsActivationAllowed(Type svrType);
        public static ActivatedClientTypeEntry IsRemotelyActivatedClientType(string typeName, string assemblyName);
        public static ActivatedClientTypeEntry IsRemotelyActivatedClientType(Type svrType);
        public static WellKnownClientTypeEntry IsWellKnownClientType(string typeName, string assemblyName);
        public static WellKnownClientTypeEntry IsWellKnownClientType(Type svrType);
        public static void RegisterActivatedClientType(ActivatedClientTypeEntry entry);
        public static void RegisterActivatedClientType(Type type, string appUrl);
        public static void RegisterActivatedServiceType(ActivatedServiceTypeEntry entry);
        public static void RegisterActivatedServiceType(Type type);
        public static void RegisterWellKnownClientType(Type type, string objectUrl);
        public static void RegisterWellKnownClientType(WellKnownClientTypeEntry entry);
        public static void RegisterWellKnownServiceType(Type type, string objectUri, WellKnownObjectMode mode);
        public static void RegisterWellKnownServiceType(WellKnownServiceTypeEntry entry);
    }

    [ComVisibleAttribute(..)]
    public sealed class RemotingServices
    {
        public static object Connect(Type classToProxy, string url);
        public static object Connect(Type classToProxy, string url, object data);
        public static bool Disconnect(MarshalByRefObject obj);
        public static IMethodReturnMessage ExecuteMessage(MarshalByRefObject target, IMethodCallMessage reqMsg);
        public static IMessageSink GetEnvoyChainForProxy(MarshalByRefObject obj);
        public static object GetLifetimeService(MarshalByRefObject obj);
        public static MethodBase GetMethodBaseFromMethodMessage(IMethodMessage msg);
        public static void GetObjectData(object obj, SerializationInfo info, StreamingContext context);
        public static string GetObjectUri(MarshalByRefObject obj);
        public static ObjRef GetObjRefForProxy(MarshalByRefObject obj);
        public static RealProxy GetRealProxy(object proxy);
        public static Type GetServerTypeForUri(string URI);
        public static string GetSessionIdForMethodMessage(IMethodMessage msg);
        public static bool IsMethodOverloaded(IMethodMessage msg);
        public static bool IsObjectOutOfAppDomain(object tp);
        public static bool IsObjectOutOfContext(object tp);
        public static bool IsOneWay(MethodBase method);
        public static bool IsTransparentProxy(object proxy);
        public static void LogRemotingStage(int stage);
        public static ObjRef Marshal(MarshalByRefObject Obj);
        public static ObjRef Marshal(MarshalByRefObject Obj, string URI);
        public static ObjRef Marshal(MarshalByRefObject Obj, string ObjURI, Type RequestedType);
        public static void SetObjectUriForMarshal(MarshalByRefObject obj, string uri);
        public static object Unmarshal(ObjRef objectRef);
        public static object Unmarshal(ObjRef objectRef, bool fRefine);
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SoapServices
    {
        public static string XmlNsForClrType { get; }
        public static string XmlNsForClrTypeWithAssembly { get; }
        public static string XmlNsForClrTypeWithNs { get; }
        public static string XmlNsForClrTypeWithNsAndAssembly { get; }
        public static string CodeXmlNamespaceForClrTypeNamespace(string typeNamespace, string assemblyName);
        public static bool DecodeXmlNamespaceForClrTypeNamespace(string inNamespace, ref string typeNamespace, ref string assemblyName);
        public static void GetInteropFieldTypeAndNameFromXmlAttribute(Type containingType, string xmlAttribute, string xmlNamespace, ref Type type, ref string name);
        public static void GetInteropFieldTypeAndNameFromXmlElement(Type containingType, string xmlElement, string xmlNamespace, ref Type type, ref string name);
        public static Type GetInteropTypeFromXmlElement(string xmlElement, string xmlNamespace);
        public static Type GetInteropTypeFromXmlType(string xmlType, string xmlTypeNamespace);
        public static string GetSoapActionFromMethodBase(MethodBase mb);
        public static bool GetTypeAndMethodNameFromSoapAction(string soapAction, ref string typeName, ref string methodName);
        public static bool GetXmlElementForInteropType(Type type, ref string xmlElement, ref string xmlNamespace);
        public static string GetXmlNamespaceForMethodCall(MethodBase mb);
        public static string GetXmlNamespaceForMethodResponse(MethodBase mb);
        public static bool GetXmlTypeForInteropType(Type type, ref string xmlType, ref string xmlTypeNamespace);
        public static bool IsClrTypeNamespace(string namespaceString);
        public static bool IsSoapActionValidForMethodBase(string soapAction, MethodBase mb);
        public static void PreLoad(Assembly assembly);
        public static void PreLoad(Type type);
        public static void RegisterInteropXmlElement(string xmlElement, string xmlNamespace, Type type);
        public static void RegisterInteropXmlType(string xmlType, string xmlTypeNamespace, Type type);
        public static void RegisterSoapActionForMethodBase(MethodBase mb);
        public static void RegisterSoapActionForMethodBase(MethodBase mb, string soapAction);
    }

    [ComVisibleAttribute(..)]
    public class TypeEntry
    {
        protected TypeEntry();
        public string AssemblyName { get; set; }
        public string TypeName { get; set; }
    }

    [ComVisibleAttribute(..)]
    public class WellKnownClientTypeEntry: TypeEntry
    {
        public WellKnownClientTypeEntry(string typeName, string assemblyName, string objectUrl);
        public WellKnownClientTypeEntry(Type type, string objectUrl);
        public string ApplicationUrl { get; set; }
        public Type ObjectType { get; }
        public string ObjectUrl { get; }
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public class WellKnownServiceTypeEntry: TypeEntry
    {
        public WellKnownServiceTypeEntry(string typeName, string assemblyName, string objectUri, WellKnownObjectMode mode);
        public WellKnownServiceTypeEntry(Type type, string objectUri, WellKnownObjectMode mode);
        public IContextAttribute[] ContextAttributes { get; set; }
        public WellKnownObjectMode Mode { get; }
        public Type ObjectType { get; }
        public string ObjectUri { get; }
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public enum CustomErrorsModes
    {
        Off,
        On,
        RemoteOnly,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum WellKnownObjectMode
    {
        SingleCall,
        Singleton,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class RemotingException: SystemException, _Exception, ISerializable
    {
        public RemotingException();
        protected RemotingException(SerializationInfo info, StreamingContext context);
        public RemotingException(string message);
        public RemotingException(string message, Exception InnerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class RemotingTimeoutException: RemotingException, _Exception, ISerializable
    {
        public RemotingTimeoutException();
        public RemotingTimeoutException(string message);
        public RemotingTimeoutException(string message, Exception InnerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ServerException: SystemException, _Exception, ISerializable
    {
        public ServerException();
        public ServerException(string message);
        public ServerException(string message, Exception InnerException);
    }

} 
namespace System.Runtime.Remoting.Activation
{
    [ComVisibleAttribute(..)]
    public interface IActivator
    {
        public ActivatorLevel Level { get; }
        public IActivator NextActivator { get; set; }
        public IConstructionReturnMessage Activate(IConstructionCallMessage msg);
    }

    [ComVisibleAttribute(..)]
    public interface IConstructionCallMessage: IMethodCallMessage
    {
        public Type ActivationType { get; }
        public string ActivationTypeName { get; }
        public IActivator Activator { get; set; }
        public object[] CallSiteActivationAttributes { get; }
        public IList ContextProperties { get; }
    }

    [ComVisibleAttribute(..)]
    public interface IConstructionReturnMessage: IMethodReturnMessage
    {
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ActivatorLevel
    {
        AppDomain,
        Construction,
        Context,
        Machine,
        Process,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class UrlAttribute: ContextAttribute, _Attribute, IContextAttribute, IContextProperty
    {
        public UrlAttribute(string callsiteURL);
        public string UrlValue { get; }
        public override bool Equals(object o);
        public override int GetHashCode();
        public override void GetPropertiesForNewContext(IConstructionCallMessage ctorMsg);
        public override bool IsContextOK(Context ctx, IConstructionCallMessage msg);
    }

} 
namespace System.Runtime.Remoting.Channels
{
    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ChannelDataStore: IChannelDataStore
    {
        public ChannelDataStore(string[] channelURIs);
        public string[] ChannelUris { get; set; }
        public object this[object key] { get; set; }
    }

    [ComVisibleAttribute(..)]
    public sealed class ChannelServices
    {
        public static IChannel[] RegisteredChannels { get; }
        public static IMessageCtrl AsyncDispatchMessage(IMessage msg, IMessageSink replySink);
        public static IServerChannelSink CreateServerChannelSinkChain(IServerChannelSinkProvider provider, IChannelReceiver channel);
        public static ServerProcessing DispatchMessage(IServerChannelSinkStack sinkStack, IMessage msg, ref IMessage replyMsg);
        public static IChannel GetChannel(string name);
        public static IDictionary GetChannelSinkProperties(object obj);
        public static string[] GetUrlsForObject(MarshalByRefObject obj);
        public static void RegisterChannel(IChannel chnl);
        public static IMessage SyncDispatchMessage(IMessage msg);
        public static void UnregisterChannel(IChannel chnl);
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ClientChannelSinkStack: IClientChannelSinkStack
    {
        public ClientChannelSinkStack();
        public ClientChannelSinkStack(IMessageSink replySink);
        public void AsyncProcessResponse(ITransportHeaders headers, Stream stream);
        public void DispatchException(Exception e);
        public void DispatchReplyMessage(IMessage msg);
        public object Pop(IClientChannelSink sink);
        public void Push(IClientChannelSink sink, object state);
    }

    [ComVisibleAttribute(..)]
    public interface IChannel
    {
        public string ChannelName { get; }
        public int ChannelPriority { get; }
        public string Parse(string url, ref string objectURI);
    }

    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface IChannelDataStore
    {
        public string[] ChannelUris { get; }
        public object this[object key] { get; set; }
    }

    [ComVisibleAttribute(..)]
    public interface IChannelReceiver: IChannel
    {
        public object ChannelData { get; }
        public string[] GetUrlsForUri(string objectURI);
        public void StartListening(object data);
        public void StopListening(object data);
    }

    [ComVisibleAttribute(..)]
    public interface IChannelReceiverHook
    {
        public string ChannelScheme { get; }
        public IServerChannelSink ChannelSinkChain { get; }
        public bool WantsToListen { get; }
        public void AddHookChannelUri(string channelUri);
    }

    [ComVisibleAttribute(..)]
    public interface IChannelSender: IChannel
    {
        public IMessageSink CreateMessageSink(string url, object remoteChannelData, ref string objectURI);
    }

    [ComVisibleAttribute(..)]
    public interface IChannelSinkBase
    {
        public IDictionary Properties { get; }
    }

    [ComVisibleAttribute(..)]
    public interface IClientChannelSink: IChannelSinkBase
    {
        public IClientChannelSink NextChannelSink { get; }
        public void AsyncProcessRequest(IClientChannelSinkStack sinkStack, IMessage msg, ITransportHeaders headers, Stream stream);
        public void AsyncProcessResponse(IClientResponseChannelSinkStack sinkStack, object state, ITransportHeaders headers, Stream stream);
        public Stream GetRequestStream(IMessage msg, ITransportHeaders headers);
        public void ProcessMessage(IMessage msg, ITransportHeaders requestHeaders, Stream requestStream, ref ITransportHeaders responseHeaders, ref Stream responseStream);
    }

    [ComVisibleAttribute(..)]
    public interface IClientChannelSinkProvider
    {
        public IClientChannelSinkProvider Next { get; set; }
        public IClientChannelSink CreateSink(IChannelSender channel, string url, object remoteChannelData);
    }

    [ComVisibleAttribute(..)]
    public interface IClientChannelSinkStack: IClientResponseChannelSinkStack
    {
        public object Pop(IClientChannelSink sink);
        public void Push(IClientChannelSink sink, object state);
    }

    [ComVisibleAttribute(..)]
    public interface IClientFormatterSink: IClientChannelSink, IMessageSink
    {
    }

    [ComVisibleAttribute(..)]
    public interface IClientFormatterSinkProvider: IClientChannelSinkProvider
    {
    }

    [ComVisibleAttribute(..)]
    public interface IClientResponseChannelSinkStack
    {
        public void AsyncProcessResponse(ITransportHeaders headers, Stream stream);
        public void DispatchException(Exception e);
        public void DispatchReplyMessage(IMessage msg);
    }

    [ComVisibleAttribute(..)]
    public interface IServerChannelSink: IChannelSinkBase
    {
        public IServerChannelSink NextChannelSink { get; }
        public void AsyncProcessResponse(IServerResponseChannelSinkStack sinkStack, object state, IMessage msg, ITransportHeaders headers, Stream stream);
        public Stream GetResponseStream(IServerResponseChannelSinkStack sinkStack, object state, IMessage msg, ITransportHeaders headers);
        public ServerProcessing ProcessMessage(IServerChannelSinkStack sinkStack, IMessage requestMsg, ITransportHeaders requestHeaders, Stream requestStream, ref IMessage responseMsg, ref ITransportHeaders responseHeaders, ref Stream responseStream);
    }

    [ComVisibleAttribute(..)]
    public interface IServerChannelSinkProvider
    {
        public IServerChannelSinkProvider Next { get; set; }
        public IServerChannelSink CreateSink(IChannelReceiver channel);
        public void GetChannelData(IChannelDataStore channelData);
    }

    [ComVisibleAttribute(..)]
    public interface IServerChannelSinkStack: IServerResponseChannelSinkStack
    {
        public object Pop(IServerChannelSink sink);
        public void Push(IServerChannelSink sink, object state);
        public void ServerCallback(IAsyncResult ar);
        public void Store(IServerChannelSink sink, object state);
        public void StoreAndDispatch(IServerChannelSink sink, object state);
    }

    [ComVisibleAttribute(..)]
    public interface IServerFormatterSinkProvider: IServerChannelSinkProvider
    {
    }

    [ComVisibleAttribute(..)]
    public interface IServerResponseChannelSinkStack
    {
        public void AsyncProcessResponse(IMessage msg, ITransportHeaders headers, Stream stream);
        public Stream GetResponseStream(IMessage msg, ITransportHeaders headers);
    }

    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public interface ITransportHeaders
    {
        public object this[object key] { get; set; }
        public IEnumerator GetEnumerator();
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ServerChannelSinkStack: IServerChannelSinkStack
    {
        public ServerChannelSinkStack();
        public void AsyncProcessResponse(IMessage msg, ITransportHeaders headers, Stream stream);
        public Stream GetResponseStream(IMessage msg, ITransportHeaders headers);
        public object Pop(IServerChannelSink sink);
        public void Push(IServerChannelSink sink, object state);
        public void ServerCallback(IAsyncResult ar);
        public void Store(IServerChannelSink sink, object state);
        public void StoreAndDispatch(IServerChannelSink sink, object state);
    }

    [ComVisibleAttribute(..)]
    public class SinkProviderData
    {
        public SinkProviderData(string name);
        public IList Children { get; }
        public string Name { get; }
        public IDictionary Properties { get; }
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public class TransportHeaders: ITransportHeaders
    {
        public TransportHeaders();
        public object this[object key] { get; set; }
        public IEnumerator GetEnumerator();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ServerProcessing
    {
        Async,
        Complete,
        OneWay,
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public abstract class BaseChannelObjectWithProperties: IDictionary
    {
        protected BaseChannelObjectWithProperties();
        public virtual int Count { get; }
        public virtual bool IsFixedSize { get; }
        public virtual bool IsReadOnly { get; }
        public virtual bool IsSynchronized { get; }
        public virtual ICollection Keys { get; }
        public virtual IDictionary Properties { get; }
        public virtual object SyncRoot { get; }
        public virtual ICollection Values { get; }
        public virtual object this[object key] { get; set; }
        public virtual void Add(object key, object value);
        public virtual void Clear();
        public virtual bool Contains(object key);
        public virtual void CopyTo(Array array, int index);
        public virtual IDictionaryEnumerator GetEnumerator();
        public virtual void Remove(object key);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public abstract class BaseChannelSinkWithProperties: BaseChannelObjectWithProperties, IDictionary
    {
        protected BaseChannelSinkWithProperties();
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public abstract class BaseChannelWithProperties: BaseChannelObjectWithProperties, IDictionary
    {
        protected BaseChannelWithProperties();
        protected IChannelSinkBase SinksWithProperties;
    }

} 
namespace System.Runtime.Remoting.Contexts
{
    [ComVisibleAttribute(..)]
    public class Context
    {
        public Context();
        public virtual int ContextID { get; }
        public virtual IContextProperty[] ContextProperties { get; }
        public static Context DefaultContext { get; }
        public static LocalDataStoreSlot AllocateDataSlot();
        public static LocalDataStoreSlot AllocateNamedDataSlot(string name);
        public void DoCallBack(CrossContextDelegate deleg);
        protected override void Finalize();
        public static void FreeNamedDataSlot(string name);
        public virtual void Freeze();
        public static object GetData(LocalDataStoreSlot slot);
        public static LocalDataStoreSlot GetNamedDataSlot(string name);
        public virtual IContextProperty GetProperty(string name);
        public static bool RegisterDynamicProperty(IDynamicProperty prop, ContextBoundObject obj, Context ctx);
        public static void SetData(LocalDataStoreSlot slot, object data);
        public virtual void SetProperty(IContextProperty prop);
        public override string ToString();
        public static bool UnregisterDynamicProperty(string name, ContextBoundObject obj, Context ctx);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ContextProperty
    {
        public virtual string Name { get; }
        public virtual object Property { get; }
    }

    [ComVisibleAttribute(..)]
    public interface IContextAttribute
    {
        public void GetPropertiesForNewContext(IConstructionCallMessage msg);
        public bool IsContextOK(Context ctx, IConstructionCallMessage msg);
    }

    [ComVisibleAttribute(..)]
    public interface IContextProperty
    {
        public string Name { get; }
        public void Freeze(Context newContext);
        public bool IsNewContextOK(Context newCtx);
    }

    [ComVisibleAttribute(..)]
    public interface IContextPropertyActivator
    {
        public void CollectFromClientContext(IConstructionCallMessage msg);
        public void CollectFromServerContext(IConstructionReturnMessage msg);
        public bool DeliverClientContextToServerContext(IConstructionCallMessage msg);
        public bool DeliverServerContextToClientContext(IConstructionReturnMessage msg);
        public bool IsOKToActivate(IConstructionCallMessage msg);
    }

    [ComVisibleAttribute(..)]
    public interface IContributeClientContextSink
    {
        public IMessageSink GetClientContextSink(IMessageSink nextSink);
    }

    [ComVisibleAttribute(..)]
    public interface IContributeDynamicSink
    {
        public IDynamicMessageSink GetDynamicSink();
    }

    [ComVisibleAttribute(..)]
    public interface IContributeEnvoySink
    {
        public IMessageSink GetEnvoySink(MarshalByRefObject obj, IMessageSink nextSink);
    }

    [ComVisibleAttribute(..)]
    public interface IContributeObjectSink
    {
        public IMessageSink GetObjectSink(MarshalByRefObject obj, IMessageSink nextSink);
    }

    [ComVisibleAttribute(..)]
    public interface IContributeServerContextSink
    {
        public IMessageSink GetServerContextSink(IMessageSink nextSink);
    }

    [ComVisibleAttribute(..)]
    public interface IDynamicMessageSink
    {
        public void ProcessMessageFinish(IMessage replyMsg, bool bCliSide, bool bAsync);
        public void ProcessMessageStart(IMessage reqMsg, bool bCliSide, bool bAsync);
    }

    [ComVisibleAttribute(..)]
    public interface IDynamicProperty
    {
        public string Name { get; }
    }

    [ComVisibleAttribute(..)]
    public delegate void CrossContextDelegate();

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class ContextAttribute: Attribute, _Attribute, IContextAttribute, IContextProperty
    {
        public ContextAttribute(string name);
        protected string AttributeName;
        public virtual string Name { get; }
        public override bool Equals(object o);
        public virtual void Freeze(Context newContext);
        public override int GetHashCode();
        public virtual void GetPropertiesForNewContext(IConstructionCallMessage ctorMsg);
        public virtual bool IsContextOK(Context ctx, IConstructionCallMessage ctorMsg);
        public virtual bool IsNewContextOK(Context newCtx);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SynchronizationAttribute: ContextAttribute, _Attribute, IContextAttribute, IContextProperty, IContributeClientContextSink, IContributeServerContextSink
    {
        public SynchronizationAttribute();
        public SynchronizationAttribute(bool reEntrant);
        public SynchronizationAttribute(int flag);
        public SynchronizationAttribute(int flag, bool reEntrant);
        public const int NOT_SUPPORTED;
        public const int REQUIRED;
        public const int REQUIRES_NEW;
        public const int SUPPORTED;
        public virtual bool IsReEntrant { get; }
        public virtual bool Locked { get; set; }
        public virtual IMessageSink GetClientContextSink(IMessageSink nextSink);
        public override void GetPropertiesForNewContext(IConstructionCallMessage ctorMsg);
        public virtual IMessageSink GetServerContextSink(IMessageSink nextSink);
        public override bool IsContextOK(Context ctx, IConstructionCallMessage msg);
    }

} 
namespace System.Runtime.Remoting.Lifetime
{
    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ClientSponsor: MarshalByRefObject, ISponsor
    {
        public ClientSponsor();
        public ClientSponsor(TimeSpan renewalTime);
        public TimeSpan RenewalTime { get; set; }
        public void Close();
        protected override void Finalize();
        public override object InitializeLifetimeService();
        public bool Register(MarshalByRefObject obj);
        public TimeSpan Renewal(ILease lease);
        public void Unregister(MarshalByRefObject obj);
    }

    [ComVisibleAttribute(..)]
    public interface ILease
    {
        public TimeSpan CurrentLeaseTime { get; }
        public LeaseState CurrentState { get; }
        public TimeSpan InitialLeaseTime { get; set; }
        public TimeSpan RenewOnCallTime { get; set; }
        public TimeSpan SponsorshipTimeout { get; set; }
        public void Register(ISponsor obj);
        public void Register(ISponsor obj, TimeSpan renewalTime);
        public TimeSpan Renew(TimeSpan renewalTime);
        public void Unregister(ISponsor obj);
    }

    [ComVisibleAttribute(..)]
    public interface ISponsor
    {
        public TimeSpan Renewal(ILease lease);
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class LifetimeServices
    {
        public LifetimeServices();
        public static TimeSpan LeaseManagerPollTime { get; set; }
        public static TimeSpan LeaseTime { get; set; }
        public static TimeSpan RenewOnCallTime { get; set; }
        public static TimeSpan SponsorshipTimeout { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum LeaseState
    {
        Active,
        Expired,
        Initial,
        Null,
        Renewing,
    }

} 
namespace System.Runtime.Remoting.Messaging
{
    [ComVisibleAttribute(..)]
    public class AsyncResult: IAsyncResult, IMessageSink
    {
        public virtual object AsyncDelegate { get; }
        public virtual object AsyncState { get; }
        public virtual WaitHandle AsyncWaitHandle { get; }
        public virtual bool CompletedSynchronously { get; }
        public bool EndInvokeCalled { get; set; }
        public virtual bool IsCompleted { get; }
        public IMessageSink NextSink { get; }
        public virtual IMessageCtrl AsyncProcessMessage(IMessage msg, IMessageSink replySink);
        public virtual IMessage GetReplyMessage();
        public virtual void SetMessageCtrl(IMessageCtrl mc);
        public virtual IMessage SyncProcessMessage(IMessage msg);
    }

    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class CallContext
    {
        public static object HostContext { get; set; }
        public static void FreeNamedDataSlot(string name);
        public static object GetData(string name);
        public static Header[] GetHeaders();
        public static object LogicalGetData(string name);
        public static void LogicalSetData(string name, object data);
        public static void SetData(string name, object data);
        public static void SetHeaders(Header[] headers);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public class ConstructionCall: MethodCall, IConstructionCallMessage, IInternalMessage, ISerializable, ISerializationRootObject
    {
        public ConstructionCall(Header[] headers);
        public ConstructionCall(IMessage m);
        public Type ActivationType { get; }
        public string ActivationTypeName { get; }
        public IActivator Activator { get; set; }
        public object[] CallSiteActivationAttributes { get; }
        public IList ContextProperties { get; }
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ConstructionResponse: MethodResponse, IConstructionReturnMessage, IInternalMessage, ISerializable, ISerializationRootObject
    {
        public ConstructionResponse(Header[] h, IMethodCallMessage mcm);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class Header
    {
        public Header(string _Name, object _Value);
        public Header(string _Name, object _Value, bool _MustUnderstand);
        public Header(string _Name, object _Value, bool _MustUnderstand, string _HeaderNamespace);
        public string HeaderNamespace;
        public bool MustUnderstand;
        public string Name;
        public object Value;
    }

    [ComVisibleAttribute(..)]
    public interface ILogicalThreadAffinative
    {
    }

    [ComVisibleAttribute(..)]
    public interface IMessage
    {
        public IDictionary Properties { get; }
    }

    [ComVisibleAttribute(..)]
    public interface IMessageCtrl
    {
        public void Cancel(int msToCancel);
    }

    [ComVisibleAttribute(..)]
    public interface IMessageSink
    {
        public IMessageSink NextSink { get; }
        public IMessageCtrl AsyncProcessMessage(IMessage msg, IMessageSink replySink);
        public IMessage SyncProcessMessage(IMessage msg);
    }

    [ComVisibleAttribute(..)]
    public interface IMethodCallMessage: IMethodMessage
    {
        public int InArgCount { get; }
        public object[] InArgs { get; }
        public object GetInArg(int argNum);
        public string GetInArgName(int index);
    }

    [ComVisibleAttribute(..)]
    public interface IMethodMessage: IMessage
    {
        public int ArgCount { get; }
        public object[] Args { get; }
        public bool HasVarArgs { get; }
        public LogicalCallContext LogicalCallContext { get; }
        public MethodBase MethodBase { get; }
        public string MethodName { get; }
        public object MethodSignature { get; }
        public string TypeName { get; }
        public string Uri { get; }
        public object GetArg(int argNum);
        public string GetArgName(int index);
    }

    [ComVisibleAttribute(..)]
    public interface IMethodReturnMessage: IMethodMessage
    {
        public Exception Exception { get; }
        public int OutArgCount { get; }
        public object[] OutArgs { get; }
        public object ReturnValue { get; }
        public object GetOutArg(int argNum);
        public string GetOutArgName(int index);
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class InternalMessageWrapper
    {
        public InternalMessageWrapper(IMessage msg);
        protected IMessage WrappedMessage;
    }

    [ComVisibleAttribute(..)]
    public interface IRemotingFormatter: IFormatter
    {
        public object Deserialize(Stream serializationStream, HeaderHandler handler);
        public void Serialize(Stream serializationStream, object graph, Header[] headers);
    }

    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class LogicalCallContext: ICloneable, ISerializable
    {
        public bool HasInfo { get; }
        public object Clone();
        public void FreeNamedDataSlot(string name);
        public object GetData(string name);
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public void SetData(string name, object data);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public class MethodCall: IInternalMessage, IMethodCallMessage, ISerializable, ISerializationRootObject
    {
        public MethodCall(Header[] h1);
        public MethodCall(IMessage msg);
        protected IDictionary ExternalProperties;
        protected IDictionary InternalProperties;
        public int ArgCount { get; }
        public object[] Args { get; }
        public bool HasVarArgs { get; }
        public int InArgCount { get; }
        public object[] InArgs { get; }
        public LogicalCallContext LogicalCallContext { get; }
        public MethodBase MethodBase { get; }
        public string MethodName { get; }
        public object MethodSignature { get; }
        public virtual IDictionary Properties { get; }
        public string TypeName { get; }
        public string Uri { get; set; }
        public object GetArg(int argNum);
        public string GetArgName(int index);
        public object GetInArg(int argNum);
        public string GetInArgName(int index);
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public virtual object HeaderHandler(Header[] h);
        public virtual void Init();
        public void ResolveMethod();
        public void RootSetObjectData(SerializationInfo info, StreamingContext ctx);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MethodCallMessageWrapper: InternalMessageWrapper, IMethodCallMessage
    {
        public MethodCallMessageWrapper(IMethodCallMessage msg);
        public virtual int ArgCount { get; }
        public virtual object[] Args { get; set; }
        public virtual bool HasVarArgs { get; }
        public virtual int InArgCount { get; }
        public virtual object[] InArgs { get; }
        public virtual LogicalCallContext LogicalCallContext { get; }
        public virtual MethodBase MethodBase { get; }
        public virtual string MethodName { get; }
        public virtual object MethodSignature { get; }
        public virtual IDictionary Properties { get; }
        public virtual string TypeName { get; }
        public virtual string Uri { get; set; }
        public virtual object GetArg(int argNum);
        public virtual string GetArgName(int index);
        public virtual object GetInArg(int argNum);
        public virtual string GetInArgName(int index);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public class MethodResponse: IInternalMessage, IMethodReturnMessage, ISerializable, ISerializationRootObject
    {
        public MethodResponse(Header[] h1, IMethodCallMessage mcm);
        protected IDictionary ExternalProperties;
        protected IDictionary InternalProperties;
        public int ArgCount { get; }
        public object[] Args { get; }
        public Exception Exception { get; }
        public bool HasVarArgs { get; }
        public LogicalCallContext LogicalCallContext { get; }
        public MethodBase MethodBase { get; }
        public string MethodName { get; }
        public object MethodSignature { get; }
        public int OutArgCount { get; }
        public object[] OutArgs { get; }
        public virtual IDictionary Properties { get; }
        public object ReturnValue { get; }
        public string TypeName { get; }
        public string Uri { get; set; }
        public object GetArg(int argNum);
        public string GetArgName(int index);
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public object GetOutArg(int argNum);
        public string GetOutArgName(int index);
        public virtual object HeaderHandler(Header[] h);
        public void RootSetObjectData(SerializationInfo info, StreamingContext ctx);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class MethodReturnMessageWrapper: InternalMessageWrapper, IMethodReturnMessage
    {
        public MethodReturnMessageWrapper(IMethodReturnMessage msg);
        public virtual int ArgCount { get; }
        public virtual object[] Args { get; set; }
        public virtual Exception Exception { get; set; }
        public virtual bool HasVarArgs { get; }
        public virtual LogicalCallContext LogicalCallContext { get; }
        public virtual MethodBase MethodBase { get; }
        public virtual string MethodName { get; }
        public virtual object MethodSignature { get; }
        public virtual int OutArgCount { get; }
        public virtual object[] OutArgs { get; }
        public virtual IDictionary Properties { get; }
        public virtual object ReturnValue { get; set; }
        public virtual string TypeName { get; }
        public string Uri { get; set; }
        public virtual object GetArg(int argNum);
        public virtual string GetArgName(int index);
        public virtual object GetOutArg(int argNum);
        public virtual string GetOutArgName(int index);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class RemotingSurrogateSelector: ISurrogateSelector
    {
        public RemotingSurrogateSelector();
        public MessageSurrogateFilter Filter { get; set; }
        public virtual void ChainSelector(ISurrogateSelector selector);
        public virtual ISurrogateSelector GetNextSelector();
        public object GetRootObject();
        public virtual ISerializationSurrogate GetSurrogate(Type type, StreamingContext context, ref ISurrogateSelector ssout);
        public void SetRootObject(object obj);
        public virtual void UseSoapFormat();
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ReturnMessage: IMethodReturnMessage
    {
        public ReturnMessage(Exception e, IMethodCallMessage mcm);
        public ReturnMessage(object ret, object[] outArgs, int outArgsCount, LogicalCallContext callCtx, IMethodCallMessage mcm);
        public int ArgCount { get; }
        public object[] Args { get; }
        public Exception Exception { get; }
        public bool HasVarArgs { get; }
        public LogicalCallContext LogicalCallContext { get; }
        public MethodBase MethodBase { get; }
        public string MethodName { get; }
        public object MethodSignature { get; }
        public int OutArgCount { get; }
        public object[] OutArgs { get; }
        public virtual IDictionary Properties { get; }
        public virtual object ReturnValue { get; }
        public string TypeName { get; }
        public string Uri { get; set; }
        public object GetArg(int argNum);
        public string GetArgName(int index);
        public object GetOutArg(int argNum);
        public string GetOutArgName(int index);
    }

    [ComVisibleAttribute(..)]
    public delegate object HeaderHandler(Header[] headers);

    [ComVisibleAttribute(..)]
    public delegate bool MessageSurrogateFilter(string key, object value);

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class OneWayAttribute: Attribute, _Attribute
    {
        public OneWayAttribute();
    }

} 
namespace System.Runtime.Remoting.Metadata
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum SoapOption
    {
        AlwaysIncludeTypes,
        EmbedAll,
        None,
        Option1,
        Option2,
        XsdString,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum XmlFieldOrderOption
    {
        All,
        Choice,
        Sequence,
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class SoapAttribute: Attribute, _Attribute
    {
        public SoapAttribute();
        protected string ProtXmlNamespace;
        protected object ReflectInfo;
        public virtual bool Embedded { get; set; }
        public virtual bool UseAttribute { get; set; }
        public virtual string XmlNamespace { get; set; }
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class SoapFieldAttribute: SoapAttribute, _Attribute
    {
        public SoapFieldAttribute();
        public int Order { get; set; }
        public string XmlElementName { get; set; }
        public bool IsInteropXmlElement();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class SoapMethodAttribute: SoapAttribute, _Attribute
    {
        public SoapMethodAttribute();
        public string ResponseXmlElementName { get; set; }
        public string ResponseXmlNamespace { get; set; }
        public string ReturnXmlElementName { get; set; }
        public string SoapAction { get; set; }
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapParameterAttribute: SoapAttribute, _Attribute
    {
        public SoapParameterAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class SoapTypeAttribute: SoapAttribute, _Attribute
    {
        public SoapTypeAttribute();
        public SoapOption SoapOptions { get; set; }
        public string XmlElementName { get; set; }
        public XmlFieldOrderOption XmlFieldOrder { get; set; }
        public string XmlTypeName { get; set; }
        public string XmlTypeNamespace { get; set; }
    }

} 
namespace System.Runtime.Remoting.Metadata.W3cXsd2001
{
    [ComVisibleAttribute(..)]
    public interface ISoapXsd
    {
        public string GetXsdType();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapAnyUri: ISoapXsd
    {
        public SoapAnyUri();
        public SoapAnyUri(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapAnyUri Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapBase64Binary: ISoapXsd
    {
        public SoapBase64Binary();
        public SoapBase64Binary(byte[] value);
        public byte[] Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapBase64Binary Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapDate: ISoapXsd
    {
        public SoapDate();
        public SoapDate(DateTime value);
        public SoapDate(DateTime value, int sign);
        public int Sign { get; set; }
        public DateTime Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapDate Parse(string value);
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public sealed class SoapDateTime
    {
        public SoapDateTime();
        public static string XsdType { get; }
        public static DateTime Parse(string value);
        public static string ToString(DateTime value);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapDay: ISoapXsd
    {
        public SoapDay();
        public SoapDay(DateTime value);
        public DateTime Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapDay Parse(string value);
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public sealed class SoapDuration
    {
        public SoapDuration();
        public static string XsdType { get; }
        public static TimeSpan Parse(string value);
        public static string ToString(TimeSpan timeSpan);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapEntities: ISoapXsd
    {
        public SoapEntities();
        public SoapEntities(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapEntities Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapEntity: ISoapXsd
    {
        public SoapEntity();
        public SoapEntity(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapEntity Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapHexBinary: ISoapXsd
    {
        public SoapHexBinary();
        public SoapHexBinary(byte[] value);
        public byte[] Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapHexBinary Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapId: ISoapXsd
    {
        public SoapId();
        public SoapId(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapId Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapIdref: ISoapXsd
    {
        public SoapIdref();
        public SoapIdref(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapIdref Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapIdrefs: ISoapXsd
    {
        public SoapIdrefs();
        public SoapIdrefs(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapIdrefs Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapInteger: ISoapXsd
    {
        public SoapInteger();
        public SoapInteger(decimal value);
        public decimal Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapInteger Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapLanguage: ISoapXsd
    {
        public SoapLanguage();
        public SoapLanguage(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapLanguage Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapMonth: ISoapXsd
    {
        public SoapMonth();
        public SoapMonth(DateTime value);
        public DateTime Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapMonth Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapMonthDay: ISoapXsd
    {
        public SoapMonthDay();
        public SoapMonthDay(DateTime value);
        public DateTime Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapMonthDay Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapName: ISoapXsd
    {
        public SoapName();
        public SoapName(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapName Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNcName: ISoapXsd
    {
        public SoapNcName();
        public SoapNcName(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNcName Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNegativeInteger: ISoapXsd
    {
        public SoapNegativeInteger();
        public SoapNegativeInteger(decimal value);
        public decimal Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNegativeInteger Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNmtoken: ISoapXsd
    {
        public SoapNmtoken();
        public SoapNmtoken(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNmtoken Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNmtokens: ISoapXsd
    {
        public SoapNmtokens();
        public SoapNmtokens(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNmtokens Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNonNegativeInteger: ISoapXsd
    {
        public SoapNonNegativeInteger();
        public SoapNonNegativeInteger(decimal value);
        public decimal Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNonNegativeInteger Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNonPositiveInteger: ISoapXsd
    {
        public SoapNonPositiveInteger();
        public SoapNonPositiveInteger(decimal value);
        public decimal Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNonPositiveInteger Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNormalizedString: ISoapXsd
    {
        public SoapNormalizedString();
        public SoapNormalizedString(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNormalizedString Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapNotation: ISoapXsd
    {
        public SoapNotation();
        public SoapNotation(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapNotation Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapPositiveInteger: ISoapXsd
    {
        public SoapPositiveInteger();
        public SoapPositiveInteger(decimal value);
        public decimal Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapPositiveInteger Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapQName: ISoapXsd
    {
        public SoapQName();
        public SoapQName(string value);
        public SoapQName(string key, string name);
        public SoapQName(string key, string name, string namespaceValue);
        public string Key { get; set; }
        public string Name { get; set; }
        public string Namespace { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapQName Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapTime: ISoapXsd
    {
        public SoapTime();
        public SoapTime(DateTime value);
        public DateTime Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapTime Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapToken: ISoapXsd
    {
        public SoapToken();
        public SoapToken(string value);
        public string Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapToken Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapYear: ISoapXsd
    {
        public SoapYear();
        public SoapYear(DateTime value);
        public SoapYear(DateTime value, int sign);
        public int Sign { get; set; }
        public DateTime Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapYear Parse(string value);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapYearMonth: ISoapXsd
    {
        public SoapYearMonth();
        public SoapYearMonth(DateTime value);
        public SoapYearMonth(DateTime value, int sign);
        public int Sign { get; set; }
        public DateTime Value { get; set; }
        public static string XsdType { get; }
        public string GetXsdType();
        public static SoapYearMonth Parse(string value);
        public override string ToString();
    }

} 
namespace System.Runtime.Remoting.Proxies
{
    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class RealProxy
    {
        protected RealProxy();
        protected RealProxy(Type classToProxy);
        protected RealProxy(Type classToProxy, IntPtr stub, object stubData);
        protected void AttachServer(MarshalByRefObject s);
        public virtual ObjRef CreateObjRef(Type requestedType);
        protected MarshalByRefObject DetachServer();
        public virtual IntPtr GetCOMIUnknown(bool fIsMarshalled);
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context);
        public Type GetProxiedType();
        public static object GetStubData(RealProxy rp);
        public virtual object GetTransparentProxy();
        protected MarshalByRefObject GetUnwrappedServer();
        public IConstructionReturnMessage InitializeServerObject(IConstructionCallMessage ctorMsg);
        public abstract IMessage Invoke(IMessage msg);
        public virtual void SetCOMIUnknown(IntPtr i);
        public static void SetStubData(RealProxy rp, object stubData);
        public virtual IntPtr SupportsInterface(ref Guid iid);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public class ProxyAttribute: Attribute, _Attribute, IContextAttribute
    {
        public ProxyAttribute();
        public virtual MarshalByRefObject CreateInstance(Type serverType);
        public virtual RealProxy CreateProxy(ObjRef objRef, Type serverType, object serverObject, Context serverContext);
        public void GetPropertiesForNewContext(IConstructionCallMessage msg);
        public bool IsContextOK(Context ctx, IConstructionCallMessage msg);
    }

} 
namespace System.Runtime.Remoting.Services
{
    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class EnterpriseServicesHelper
    {
        public EnterpriseServicesHelper();
        public static IConstructionReturnMessage CreateConstructionReturnMessage(IConstructionCallMessage ctorMsg, MarshalByRefObject retObj);
        public static void SwitchWrappers(RealProxy oldcp, RealProxy newcp);
        public static object WrapIUnknownWithComObject(IntPtr punk);
    }

    [ComVisibleAttribute(..)]
    public interface ITrackingHandler
    {
        public void DisconnectedObject(object obj);
        public void MarshaledObject(object obj, ObjRef or);
        public void UnmarshaledObject(object obj, ObjRef or);
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class TrackingServices
    {
        public TrackingServices();
        public static ITrackingHandler[] RegisteredHandlers { get; }
        public static void RegisterTrackingHandler(ITrackingHandler handler);
        public static void UnregisterTrackingHandler(ITrackingHandler handler);
    }

} 
namespace System.Runtime.Serialization
{
    [SerializableAttribute(..)]
    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Formatter: IFormatter
    {
        protected Formatter();
        protected ObjectIDGenerator m_idGenerator;
        protected Queue m_objectQueue;
        public abstract SerializationBinder Binder { get; set; }
        public abstract StreamingContext Context { get; set; }
        public abstract ISurrogateSelector SurrogateSelector { get; set; }
        public abstract object Deserialize(Stream serializationStream);
        protected virtual object GetNext(ref long objID);
        protected virtual long Schedule(object obj);
        public abstract void Serialize(Stream serializationStream, object graph);
        protected abstract void WriteArray(object obj, string name, Type memberType);
        protected abstract void WriteBoolean(bool val, string name);
        protected abstract void WriteByte(byte val, string name);
        protected abstract void WriteChar(char val, string name);
        protected abstract void WriteDateTime(DateTime val, string name);
        protected abstract void WriteDecimal(decimal val, string name);
        protected abstract void WriteDouble(double val, string name);
        protected abstract void WriteInt16(short val, string name);
        protected abstract void WriteInt32(int val, string name);
        protected abstract void WriteInt64(long val, string name);
        protected virtual void WriteMember(string memberName, object data);
        protected abstract void WriteObjectRef(object obj, string name, Type memberType);
        protected abstract void WriteSByte(sbyte val, string name);
        protected abstract void WriteSingle(float val, string name);
        protected abstract void WriteTimeSpan(TimeSpan val, string name);
        protected abstract void WriteUInt16(ushort val, string name);
        protected abstract void WriteUInt32(uint val, string name);
        protected abstract void WriteUInt64(ulong val, string name);
        protected abstract void WriteValueType(object obj, string name, Type memberType);
    }

    [ComVisibleAttribute(..)]
    public class FormatterConverter: IFormatterConverter
    {
        public FormatterConverter();
        public object Convert(object value, Type type);
        public object Convert(object value, TypeCode typeCode);
        public bool ToBoolean(object value);
        public byte ToByte(object value);
        public char ToChar(object value);
        public DateTime ToDateTime(object value);
        public decimal ToDecimal(object value);
        public double ToDouble(object value);
        public short ToInt16(object value);
        public int ToInt32(object value);
        public long ToInt64(object value);
        public sbyte ToSByte(object value);
        public float ToSingle(object value);
        public string ToString(object value);
        public ushort ToUInt16(object value);
        public uint ToUInt32(object value);
        public ulong ToUInt64(object value);
    }

    [ComVisibleAttribute(..)]
    public sealed class FormatterServices
    {
        public static void CheckTypeSecurity(Type t, TypeFilterLevel securityLevel);
        public static object[] GetObjectData(object obj, MemberInfo[] members);
        public static object GetSafeUninitializedObject(Type type);
        public static MemberInfo[] GetSerializableMembers(Type type);
        public static MemberInfo[] GetSerializableMembers(Type type, StreamingContext context);
        public static Type GetTypeFromAssembly(Assembly assem, string name);
        public static object GetUninitializedObject(Type type);
        public static object PopulateObjectMembers(object obj, MemberInfo[] members, object[] data);
    }

    [ComVisibleAttribute(..)]
    public interface IDeserializationCallback
    {
        public void OnDeserialization(object sender);
    }

    [ComVisibleAttribute(..)]
    public interface IFormatter
    {
        public SerializationBinder Binder { get; set; }
        public StreamingContext Context { get; set; }
        public ISurrogateSelector SurrogateSelector { get; set; }
        public object Deserialize(Stream serializationStream);
        public void Serialize(Stream serializationStream, object graph);
    }

    [CLSCompliantAttribute(..)]
    [ComVisibleAttribute(..)]
    public interface IFormatterConverter
    {
        public object Convert(object value, Type type);
        public object Convert(object value, TypeCode typeCode);
        public bool ToBoolean(object value);
        public byte ToByte(object value);
        public char ToChar(object value);
        public DateTime ToDateTime(object value);
        public decimal ToDecimal(object value);
        public double ToDouble(object value);
        public short ToInt16(object value);
        public int ToInt32(object value);
        public long ToInt64(object value);
        public sbyte ToSByte(object value);
        public float ToSingle(object value);
        public string ToString(object value);
        public ushort ToUInt16(object value);
        public uint ToUInt32(object value);
        public ulong ToUInt64(object value);
    }

    [ComVisibleAttribute(..)]
    public interface IObjectReference
    {
        public object GetRealObject(StreamingContext context);
    }

    [ComVisibleAttribute(..)]
    public interface ISerializable
    {
        public void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [ComVisibleAttribute(..)]
    public interface ISerializationSurrogate
    {
        public void GetObjectData(object obj, SerializationInfo info, StreamingContext context);
        public object SetObjectData(object obj, SerializationInfo info, StreamingContext context, ISurrogateSelector selector);
    }

    [ComVisibleAttribute(..)]
    public interface ISurrogateSelector
    {
        public void ChainSelector(ISurrogateSelector selector);
        public ISurrogateSelector GetNextSelector();
        public ISerializationSurrogate GetSurrogate(Type type, StreamingContext context, ref ISurrogateSelector selector);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ObjectIDGenerator
    {
        public ObjectIDGenerator();
        public virtual long GetId(object obj, ref bool firstTime);
        public virtual long HasId(object obj, ref bool firstTime);
    }

    [ComVisibleAttribute(..)]
    public class ObjectManager
    {
        public ObjectManager(ISurrogateSelector selector, StreamingContext context);
        public virtual void DoFixups();
        public virtual object GetObject(long objectID);
        public virtual void RaiseDeserializationEvent();
        public void RaiseOnDeserializingEvent(object obj);
        public virtual void RecordArrayElementFixup(long arrayToBeFixed, int index, long objectRequired);
        public virtual void RecordArrayElementFixup(long arrayToBeFixed, int[] indices, long objectRequired);
        public virtual void RecordDelayedFixup(long objectToBeFixed, string memberName, long objectRequired);
        public virtual void RecordFixup(long objectToBeFixed, MemberInfo member, long objectRequired);
        public virtual void RegisterObject(object obj, long objectID);
        public void RegisterObject(object obj, long objectID, SerializationInfo info);
        public void RegisterObject(object obj, long objectID, SerializationInfo info, long idOfContainingObj, MemberInfo member);
        public void RegisterObject(object obj, long objectID, SerializationInfo info, long idOfContainingObj, MemberInfo member, int[] arrayIndex);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class SerializationBinder
    {
        protected SerializationBinder();
        public abstract Type BindToType(string assemblyName, string typeName);
    }

    [ComVisibleAttribute(..)]
    public struct SerializationEntry
    {
        public string Name { get; }
        public Type ObjectType { get; }
        public object Value { get; }
    }

    [ComVisibleAttribute(..)]
    public sealed class SerializationInfo
    {
        public SerializationInfo(Type type, IFormatterConverter converter);
        public string AssemblyName { get; set; }
        public string FullTypeName { get; set; }
        public int MemberCount { get; }
        public void AddValue(string name, bool value);
        public void AddValue(string name, byte value);
        public void AddValue(string name, char value);
        public void AddValue(string name, DateTime value);
        public void AddValue(string name, decimal value);
        public void AddValue(string name, double value);
        public void AddValue(string name, float value);
        public void AddValue(string name, int value);
        public void AddValue(string name, long value);
        public void AddValue(string name, object value);
        public void AddValue(string name, object value, Type type);
        public void AddValue(string name, sbyte value);
        public void AddValue(string name, short value);
        public void AddValue(string name, uint value);
        public void AddValue(string name, ulong value);
        public void AddValue(string name, ushort value);
        public bool GetBoolean(string name);
        public byte GetByte(string name);
        public char GetChar(string name);
        public DateTime GetDateTime(string name);
        public decimal GetDecimal(string name);
        public double GetDouble(string name);
        public SerializationInfoEnumerator GetEnumerator();
        public short GetInt16(string name);
        public int GetInt32(string name);
        public long GetInt64(string name);
        public sbyte GetSByte(string name);
        public float GetSingle(string name);
        public string GetString(string name);
        public ushort GetUInt16(string name);
        public uint GetUInt32(string name);
        public ulong GetUInt64(string name);
        public object GetValue(string name, Type type);
        public void SetType(Type type);
    }

    [ComVisibleAttribute(..)]
    public sealed class SerializationInfoEnumerator: IEnumerator
    {
        public SerializationEntry Current { get; }
        public string Name { get; }
        public Type ObjectType { get; }
        public object Value { get; }
        public bool MoveNext();
        public void Reset();
    }

    public sealed class SerializationObjectManager
    {
        public SerializationObjectManager(StreamingContext context);
        public void RaiseOnSerializedEvent();
        public void RegisterObject(object obj);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct StreamingContext
    {
        public StreamingContext(StreamingContextStates state);
        public StreamingContext(StreamingContextStates state, object additional);
        public object Context { get; }
        public StreamingContextStates State { get; }
        public override bool Equals(object obj);
        public override int GetHashCode();
    }

    [ComVisibleAttribute(..)]
    public class SurrogateSelector: ISurrogateSelector
    {
        public SurrogateSelector();
        public virtual void AddSurrogate(Type type, StreamingContext context, ISerializationSurrogate surrogate);
        public virtual void ChainSelector(ISurrogateSelector selector);
        public virtual ISurrogateSelector GetNextSelector();
        public virtual ISerializationSurrogate GetSurrogate(Type type, StreamingContext context, ref ISurrogateSelector selector);
        public virtual void RemoveSurrogate(Type type, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum StreamingContextStates
    {
        All,
        Clone,
        CrossAppDomain,
        CrossMachine,
        CrossProcess,
        File,
        Other,
        Persistence,
        Remoting,
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class OnDeserializedAttribute: Attribute, _Attribute
    {
        public OnDeserializedAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class OnDeserializingAttribute: Attribute, _Attribute
    {
        public OnDeserializingAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class OnSerializedAttribute: Attribute, _Attribute
    {
        public OnSerializedAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class OnSerializingAttribute: Attribute, _Attribute
    {
        public OnSerializingAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class OptionalFieldAttribute: Attribute, _Attribute
    {
        public OptionalFieldAttribute();
        public int VersionAdded { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SerializationException: SystemException, _Exception, ISerializable
    {
        public SerializationException();
        protected SerializationException(SerializationInfo info, StreamingContext context);
        public SerializationException(string message);
        public SerializationException(string message, Exception innerException);
    }

} 
namespace System.Runtime.Serialization.Formatters
{
    [ComVisibleAttribute(..)]
    public interface IFieldInfo
    {
        public string[] FieldNames { get; set; }
        public Type[] FieldTypes { get; set; }
    }

    [StrongNameIdentityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class InternalRM
    {
        public InternalRM();
        public static void InfoSoap(params object[] messages);
        public static bool SoapCheckEnabled();
    }

    [StrongNameIdentityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class InternalST
    {
        public static void InfoSoap(params object[] messages);
        public static Assembly LoadAssemblyFromString(string assemblyString);
        public static void SerializationSetValue(FieldInfo fi, object target, object value);
        public static void Soap(params object[] messages);
        public static void SoapAssert(bool condition, string message);
        public static bool SoapCheckEnabled();
    }

    [ComVisibleAttribute(..)]
    public interface ISoapMessage
    {
        public Header[] Headers { get; set; }
        public string MethodName { get; set; }
        public string[] ParamNames { get; set; }
        public Type[] ParamTypes { get; set; }
        public object[] ParamValues { get; set; }
        public string XmlNameSpace { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [SoapTypeAttribute(..)]
    public sealed class ServerFault
    {
        public ServerFault(string exceptionType, string message, string stackTrace);
        public string ExceptionMessage { get; set; }
        public string ExceptionType { get; set; }
        public string StackTrace { get; set; }
    }

    [SerializableAttribute(..)]
    [SoapTypeAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SoapFault: ISerializable
    {
        public SoapFault();
        public SoapFault(string faultCode, string faultString, string faultActor, ServerFault serverFault);
        public object Detail { get; set; }
        public string FaultActor { get; set; }
        public string FaultCode { get; set; }
        public string FaultString { get; set; }
        public void GetObjectData(SerializationInfo info, StreamingContext context);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SoapMessage: ISoapMessage
    {
        public SoapMessage();
        public Header[] Headers { get; set; }
        public string MethodName { get; set; }
        public string[] ParamNames { get; set; }
        public Type[] ParamTypes { get; set; }
        public object[] ParamValues { get; set; }
        public string XmlNameSpace { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FormatterAssemblyStyle
    {
        Full,
        Simple,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FormatterTypeStyle
    {
        TypesAlways,
        TypesWhenNeeded,
        XsdString,
    }

    [ComVisibleAttribute(..)]
    public enum TypeFilterLevel
    {
        Full,
        Low,
    }

} 
namespace System.Runtime.Serialization.Formatters.Binary
{
    [ComVisibleAttribute(..)]
    public sealed class BinaryFormatter: IRemotingFormatter
    {
        public BinaryFormatter();
        public BinaryFormatter(ISurrogateSelector selector, StreamingContext context);
        public FormatterAssemblyStyle AssemblyFormat { get; set; }
        public SerializationBinder Binder { get; set; }
        public StreamingContext Context { get; set; }
        public TypeFilterLevel FilterLevel { get; set; }
        public ISurrogateSelector SurrogateSelector { get; set; }
        public FormatterTypeStyle TypeFormat { get; set; }
        public object Deserialize(Stream serializationStream);
        public object Deserialize(Stream serializationStream, HeaderHandler handler);
        public object DeserializeMethodResponse(Stream serializationStream, HeaderHandler handler, IMethodCallMessage methodCallMessage);
        public void Serialize(Stream serializationStream, object graph);
        public void Serialize(Stream serializationStream, object graph, Header[] headers);
        public object UnsafeDeserialize(Stream serializationStream, HeaderHandler handler);
        public object UnsafeDeserializeMethodResponse(Stream serializationStream, HeaderHandler handler, IMethodCallMessage methodCallMessage);
    }

} 
namespace System.Runtime.Versioning
{
    public abstract sealed class VersioningHelper
    {
        public static string MakeVersionSafeName(string name, ResourceScope from, ResourceScope to);
        public static string MakeVersionSafeName(string name, ResourceScope from, ResourceScope to, Type type);
    }

    [FlagsAttribute(..)]
    public enum ResourceScope
    {
        AppDomain,
        Assembly,
        Library,
        Machine,
        None,
        Private,
        Process,
    }

    [AttributeUsageAttribute(..)]
    [ConditionalAttribute(..)]
    public sealed class ResourceConsumptionAttribute: Attribute, _Attribute
    {
        public ResourceConsumptionAttribute(ResourceScope resourceScope);
        public ResourceConsumptionAttribute(ResourceScope resourceScope, ResourceScope consumptionScope);
        public ResourceScope ConsumptionScope { get; }
        public ResourceScope ResourceScope { get; }
    }

    [ConditionalAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class ResourceExposureAttribute: Attribute, _Attribute
    {
        public ResourceExposureAttribute(ResourceScope exposureLevel);
        public ResourceScope ResourceExposureLevel { get; }
    }

} 
namespace System.Security
{
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class CodeAccessPermission: IPermission, IStackWalk
    {
        protected CodeAccessPermission();
        public void Assert();
        public abstract IPermission Copy();
        public void Demand();
        public void Deny();
        public override bool Equals(object obj);
        public abstract void FromXml(SecurityElement elem);
        public override int GetHashCode();
        public abstract IPermission Intersect(IPermission target);
        public abstract bool IsSubsetOf(IPermission target);
        public void PermitOnly();
        public static void RevertAll();
        public static void RevertAssert();
        public static void RevertDeny();
        public static void RevertPermitOnly();
        public override string ToString();
        public abstract SecurityElement ToXml();
        public virtual IPermission Union(IPermission other);
    }

    [SecurityPermissionAttribute(..)]
    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class HostSecurityManager
    {
        public HostSecurityManager();
        public virtual PolicyLevel DomainPolicy { get; }
        public virtual HostSecurityManagerOptions Flags { get; }
        public virtual ApplicationTrust DetermineApplicationTrust(Evidence applicationEvidence, Evidence activatorEvidence, TrustManagerContext context);
        public virtual Evidence ProvideAppDomainEvidence(Evidence inputEvidence);
        public virtual Evidence ProvideAssemblyEvidence(Assembly loadedAssembly, Evidence inputEvidence);
        public virtual PermissionSet ResolvePolicy(Evidence evidence);
    }

    [ComVisibleAttribute(..)]
    public interface IEvidenceFactory
    {
        public Evidence Evidence { get; }
    }

    [ComVisibleAttribute(..)]
    public interface IPermission: ISecurityEncodable
    {
        public IPermission Copy();
        public void Demand();
        public IPermission Intersect(IPermission target);
        public bool IsSubsetOf(IPermission target);
        public IPermission Union(IPermission target);
    }

    [ComVisibleAttribute(..)]
    public interface ISecurityEncodable
    {
        public void FromXml(SecurityElement e);
        public SecurityElement ToXml();
    }

    [ComVisibleAttribute(..)]
    public interface ISecurityPolicyEncodable
    {
        public void FromXml(SecurityElement e, PolicyLevel level);
        public SecurityElement ToXml(PolicyLevel level);
    }

    [ComVisibleAttribute(..)]
    public interface IStackWalk
    {
        public void Assert();
        public void Demand();
        public void Deny();
        public void PermitOnly();
    }

    public sealed class SecureString: CriticalFinalizerObject, IDisposable
    {
        public SecureString();
        public SecureString(char* value, int length);
        public int Length { get; }
        public void AppendChar(char c);
        public void Clear();
        public SecureString Copy();
        public void Dispose();
        public void InsertAt(int index, char c);
        public bool IsReadOnly();
        public void MakeReadOnly();
        public void RemoveAt(int index);
        public void SetAt(int index, char c);
    }

    public sealed class SecurityContext
    {
        public static SecurityContext Capture();
        public SecurityContext CreateCopy();
        public static bool IsFlowSuppressed();
        public static bool IsWindowsIdentityFlowSuppressed();
        public static void RestoreFlow();
        public static void Run(SecurityContext securityContext, ContextCallback callback, object state);
        public static AsyncFlowControl SuppressFlow();
        public static AsyncFlowControl SuppressFlowWindowsIdentity();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SecurityElement: ISecurityElementFactory
    {
        public SecurityElement(string tag);
        public SecurityElement(string tag, string text);
        public Hashtable Attributes { get; set; }
        public ArrayList Children { get; set; }
        public string Tag { get; set; }
        public string Text { get; set; }
        public void AddAttribute(string name, string value);
        public void AddChild(SecurityElement child);
        public string Attribute(string name);
        public SecurityElement Copy();
        public bool Equal(SecurityElement other);
        public static string Escape(string str);
        public static SecurityElement FromString(string xml);
        public static bool IsValidAttributeName(string name);
        public static bool IsValidAttributeValue(string value);
        public static bool IsValidTag(string tag);
        public static bool IsValidText(string text);
        public SecurityElement SearchForChildByTag(string tag);
        public string SearchForTextOfTag(string tag);
        public override string ToString();
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class SecurityManager
    {
        public static bool CheckExecutionRights { get; set; }
        public static bool SecurityEnabled { get; set; }
        public static void GetZoneAndOrigin(ref ArrayList zone, ref ArrayList origin);
        public static bool IsGranted(IPermission perm);
        public static PolicyLevel LoadPolicyLevelFromFile(string path, PolicyLevelType type);
        public static PolicyLevel LoadPolicyLevelFromString(string str, PolicyLevelType type);
        public static IEnumerator PolicyHierarchy();
        public static PermissionSet ResolvePolicy(Evidence evidence);
        public static PermissionSet ResolvePolicy(Evidence evidence, PermissionSet reqdPset, PermissionSet optPset, PermissionSet denyPset, ref PermissionSet denied);
        public static PermissionSet ResolvePolicy(Evidence[] evidences);
        public static IEnumerator ResolvePolicyGroups(Evidence evidence);
        public static PermissionSet ResolveSystemPolicy(Evidence evidence);
        public static void SavePolicy();
        public static void SavePolicyLevel(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum HostSecurityManagerOptions
    {
        AllFlags,
        HostAppDomainEvidence,
        HostAssemblyEvidence,
        HostDetermineApplicationTrust,
        HostPolicyLevel,
        HostResolvePolicy,
        None,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PolicyLevelType
    {
        AppDomain,
        Enterprise,
        Machine,
        User,
    }

    public enum SecurityCriticalScope
    {
        Everything,
        Explicit,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum SecurityZone
    {
        Internet,
        Intranet,
        MyComputer,
        NoZone,
        Trusted,
        Untrusted,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class NamedPermissionSet: PermissionSet, ICollection, IDeserializationCallback, ISecurityEncodable, IStackWalk
    {
        public NamedPermissionSet(NamedPermissionSet permSet);
        public NamedPermissionSet(string name);
        public NamedPermissionSet(string name, PermissionSet permSet);
        public NamedPermissionSet(string name, PermissionState state);
        public string Description { get; set; }
        public string Name { get; set; }
        public override PermissionSet Copy();
        public NamedPermissionSet Copy(string name);
        public override bool Equals(object obj);
        public override void FromXml(SecurityElement et);
        public override int GetHashCode();
        public override SecurityElement ToXml();
    }

    [StrongNameIdentityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class PermissionSet: ICollection, IDeserializationCallback, ISecurityEncodable, IStackWalk
    {
        public PermissionSet(PermissionSet permSet);
        public PermissionSet(PermissionState state);
        public virtual int Count { get; }
        public virtual bool IsReadOnly { get; }
        public virtual bool IsSynchronized { get; }
        public virtual object SyncRoot { get; }
        public IPermission AddPermission(IPermission perm);
        public void Assert();
        public bool ContainsNonCodeAccessPermissions();
        public static byte[] ConvertPermissionSet(string inFormat, byte[] inData, string outFormat);
        public virtual PermissionSet Copy();
        public virtual void CopyTo(Array array, int index);
        public void Demand();
        public void Deny();
        public override bool Equals(object obj);
        public virtual void FromXml(SecurityElement et);
        public IEnumerator GetEnumerator();
        public override int GetHashCode();
        public IPermission GetPermission(Type permClass);
        public PermissionSet Intersect(PermissionSet other);
        public bool IsEmpty();
        public bool IsSubsetOf(PermissionSet target);
        public bool IsUnrestricted();
        public void PermitOnly();
        public IPermission RemovePermission(Type permClass);
        public static void RevertAssert();
        public IPermission SetPermission(IPermission perm);
        public override string ToString();
        public virtual SecurityElement ToXml();
        public PermissionSet Union(PermissionSet other);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [ObsoleteAttribute(..)]
    public sealed class PermissionSetCollection: ICollection
    {
        public PermissionSetCollection();
        public int Count { get; }
        public bool IsSynchronized { get; }
        public IList PermissionSets { get; }
        public object SyncRoot { get; }
        public void Add(PermissionSet permSet);
        public PermissionSetCollection Copy();
        public void CopyTo(PermissionSet[] array, int index);
        public void Demand();
        public void FromXml(SecurityElement el);
        public IEnumerator GetEnumerator();
        public PermissionSet GetSet(int index);
        public void RemoveSet(int index);
        public override string ToString();
        public SecurityElement ToXml();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class AllowPartiallyTrustedCallersAttribute: Attribute, _Attribute
    {
        public AllowPartiallyTrustedCallersAttribute();
    }

    [AttributeUsageAttribute(..)]
    public sealed class SecurityCriticalAttribute: Attribute, _Attribute
    {
        public SecurityCriticalAttribute();
        public SecurityCriticalAttribute(SecurityCriticalScope scope);
        public SecurityCriticalScope Scope { get; }
    }

    [AttributeUsageAttribute(..)]
    public sealed class SecurityTransparentAttribute: Attribute, _Attribute
    {
        public SecurityTransparentAttribute();
    }

    [AttributeUsageAttribute(..)]
    public sealed class SecurityTreatAsSafeAttribute: Attribute, _Attribute
    {
        public SecurityTreatAsSafeAttribute();
    }

    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SuppressUnmanagedCodeSecurityAttribute: Attribute, _Attribute
    {
        public SuppressUnmanagedCodeSecurityAttribute();
    }

    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class UnverifiableCodeAttribute: Attribute, _Attribute
    {
        public UnverifiableCodeAttribute();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class HostProtectionException: SystemException, _Exception, ISerializable
    {
        public HostProtectionException();
        protected HostProtectionException(SerializationInfo info, StreamingContext context);
        public HostProtectionException(string message);
        public HostProtectionException(string message, Exception e);
        public HostProtectionException(string message, HostProtectionResource protectedResources, HostProtectionResource demandedResources);
        public HostProtectionResource DemandedResources { get; }
        public HostProtectionResource ProtectedResources { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SecurityException: SystemException, _Exception, ISerializable
    {
        public SecurityException();
        protected SecurityException(SerializationInfo info, StreamingContext context);
        public SecurityException(string message);
        public SecurityException(string message, AssemblyName assemblyName, PermissionSet grant, PermissionSet refused, MethodInfo method, SecurityAction action, object demanded, IPermission permThatFailed, Evidence evidence);
        public SecurityException(string message, Exception inner);
        public SecurityException(string message, object deny, object permitOnly, MethodInfo method, object demanded, IPermission permThatFailed);
        public SecurityException(string message, Type type);
        public SecurityException(string message, Type type, string state);
        public SecurityAction Action { get; set; }
        public object Demanded { get; set; }
        public object DenySetInstance { get; set; }
        public AssemblyName FailedAssemblyInfo { get; set; }
        public IPermission FirstPermissionThatFailed { get; set; }
        public string GrantedSet { get; set; }
        public MethodInfo Method { get; set; }
        public string PermissionState { get; set; }
        public Type PermissionType { get; set; }
        public object PermitOnlySetInstance { get; set; }
        public string RefusedSet { get; set; }
        public string Url { get; set; }
        public SecurityZone Zone { get; set; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class VerificationException: SystemException, _Exception, ISerializable
    {
        public VerificationException();
        protected VerificationException(SerializationInfo info, StreamingContext context);
        public VerificationException(string message);
        public VerificationException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class XmlSyntaxException: SystemException, _Exception, ISerializable
    {
        public XmlSyntaxException();
        public XmlSyntaxException(int lineNumber);
        public XmlSyntaxException(int lineNumber, string message);
        public XmlSyntaxException(string message);
        public XmlSyntaxException(string message, Exception inner);
    }

} 
namespace System.Security.AccessControl
{
    public abstract class AccessRule: AuthorizationRule
    {
        protected AccessRule(IdentityReference identity, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public AccessControlType AccessControlType { get; }
    }

    public sealed class AceEnumerator: IEnumerator
    {
        public GenericAce Current { get; }
        public bool MoveNext();
        public void Reset();
    }

    public abstract class AuditRule: AuthorizationRule
    {
        protected AuditRule(IdentityReference identity, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags auditFlags);
        public AuditFlags AuditFlags { get; }
    }

    public abstract class AuthorizationRule
    {
        protected AuthorizationRule(IdentityReference identity, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public IdentityReference IdentityReference { get; }
        public InheritanceFlags InheritanceFlags { get; }
        public bool IsInherited { get; }
        public PropagationFlags PropagationFlags { get; }
    }

    public sealed class CommonAce: QualifiedAce
    {
        public CommonAce(AceFlags flags, AceQualifier qualifier, int accessMask, SecurityIdentifier sid, bool isCallback, byte[] opaque);
        public override void GetBinaryForm(byte[] binaryForm, int offset);
        public static int MaxOpaqueLength(bool isCallback);
    }

    [PermissionSetAttribute(..)]
    public abstract class CommonObjectSecurity: ObjectSecurity
    {
        protected CommonObjectSecurity(bool isContainer);
        protected void AddAccessRule(AccessRule rule);
        protected void AddAuditRule(AuditRule rule);
        public AuthorizationRuleCollection GetAccessRules(bool includeExplicit, bool includeInherited, Type targetType);
        public AuthorizationRuleCollection GetAuditRules(bool includeExplicit, bool includeInherited, Type targetType);
        protected override bool ModifyAccess(AccessControlModification modification, AccessRule rule, ref bool modified);
        protected override bool ModifyAudit(AccessControlModification modification, AuditRule rule, ref bool modified);
        protected bool RemoveAccessRule(AccessRule rule);
        protected void RemoveAccessRuleAll(AccessRule rule);
        protected void RemoveAccessRuleSpecific(AccessRule rule);
        protected bool RemoveAuditRule(AuditRule rule);
        protected void RemoveAuditRuleAll(AuditRule rule);
        protected void RemoveAuditRuleSpecific(AuditRule rule);
        protected void ResetAccessRule(AccessRule rule);
        protected void SetAccessRule(AccessRule rule);
        protected void SetAuditRule(AuditRule rule);
    }

    public sealed class CommonSecurityDescriptor: GenericSecurityDescriptor
    {
        public CommonSecurityDescriptor(bool isContainer, bool isDS, byte[] binaryForm, int offset);
        public CommonSecurityDescriptor(bool isContainer, bool isDS, ControlFlags flags, SecurityIdentifier owner, SecurityIdentifier group, SystemAcl systemAcl, DiscretionaryAcl discretionaryAcl);
        public CommonSecurityDescriptor(bool isContainer, bool isDS, RawSecurityDescriptor rawSecurityDescriptor);
        public CommonSecurityDescriptor(bool isContainer, bool isDS, string sddlForm);
        public DiscretionaryAcl DiscretionaryAcl { get; set; }
        public bool IsContainer { get; }
        public bool IsDiscretionaryAclCanonical { get; }
        public bool IsDS { get; }
        public bool IsSystemAclCanonical { get; }
        public SystemAcl SystemAcl { get; set; }
        public void PurgeAccessControl(SecurityIdentifier sid);
        public void PurgeAudit(SecurityIdentifier sid);
        public void SetDiscretionaryAclProtection(bool isProtected, bool preserveInheritance);
        public void SetSystemAclProtection(bool isProtected, bool preserveInheritance);
    }

    public sealed class CompoundAce: KnownAce
    {
        public CompoundAce(AceFlags flags, int accessMask, CompoundAceType compoundAceType, SecurityIdentifier sid);
        public CompoundAceType CompoundAceType { get; set; }
        public override void GetBinaryForm(byte[] binaryForm, int offset);
    }

    public sealed class CryptoKeyAccessRule: AccessRule
    {
        public CryptoKeyAccessRule(IdentityReference identity, CryptoKeyRights cryptoKeyRights, AccessControlType type);
        public CryptoKeyAccessRule(string identity, CryptoKeyRights cryptoKeyRights, AccessControlType type);
        public CryptoKeyRights CryptoKeyRights { get; }
    }

    public sealed class CryptoKeyAuditRule: AuditRule
    {
        public CryptoKeyAuditRule(IdentityReference identity, CryptoKeyRights cryptoKeyRights, AuditFlags flags);
        public CryptoKeyAuditRule(string identity, CryptoKeyRights cryptoKeyRights, AuditFlags flags);
        public CryptoKeyRights CryptoKeyRights { get; }
    }

    public sealed class CryptoKeySecurity: NativeObjectSecurity
    {
        public CryptoKeySecurity();
        public CryptoKeySecurity(CommonSecurityDescriptor securityDescriptor);
        public sealed override AccessRule AccessRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public void AddAccessRule(CryptoKeyAccessRule rule);
        public void AddAuditRule(CryptoKeyAuditRule rule);
        public sealed override AuditRule AuditRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public bool RemoveAccessRule(CryptoKeyAccessRule rule);
        public void RemoveAccessRuleAll(CryptoKeyAccessRule rule);
        public void RemoveAccessRuleSpecific(CryptoKeyAccessRule rule);
        public bool RemoveAuditRule(CryptoKeyAuditRule rule);
        public void RemoveAuditRuleAll(CryptoKeyAuditRule rule);
        public void RemoveAuditRuleSpecific(CryptoKeyAuditRule rule);
        public void ResetAccessRule(CryptoKeyAccessRule rule);
        public void SetAccessRule(CryptoKeyAccessRule rule);
        public void SetAuditRule(CryptoKeyAuditRule rule);
    }

    public sealed class CustomAce: GenericAce
    {
        public CustomAce(AceType type, AceFlags flags, byte[] opaque);
        public static readonly int MaxOpaqueLength;
        public int OpaqueLength { get; }
        public override void GetBinaryForm(byte[] binaryForm, int offset);
        public byte[] GetOpaque();
        public void SetOpaque(byte[] opaque);
    }

    public abstract class DirectoryObjectSecurity: ObjectSecurity
    {
        protected DirectoryObjectSecurity();
        protected DirectoryObjectSecurity(CommonSecurityDescriptor securityDescriptor);
        public virtual AccessRule AccessRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type, Guid objectType, Guid inheritedObjectType);
        protected void AddAccessRule(ObjectAccessRule rule);
        protected void AddAuditRule(ObjectAuditRule rule);
        public virtual AuditRule AuditRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags, Guid objectType, Guid inheritedObjectType);
        public AuthorizationRuleCollection GetAccessRules(bool includeExplicit, bool includeInherited, Type targetType);
        public AuthorizationRuleCollection GetAuditRules(bool includeExplicit, bool includeInherited, Type targetType);
        protected override bool ModifyAccess(AccessControlModification modification, AccessRule rule, ref bool modified);
        protected override bool ModifyAudit(AccessControlModification modification, AuditRule rule, ref bool modified);
        protected bool RemoveAccessRule(ObjectAccessRule rule);
        protected void RemoveAccessRuleAll(ObjectAccessRule rule);
        protected void RemoveAccessRuleSpecific(ObjectAccessRule rule);
        protected bool RemoveAuditRule(ObjectAuditRule rule);
        protected void RemoveAuditRuleAll(ObjectAuditRule rule);
        protected void RemoveAuditRuleSpecific(ObjectAuditRule rule);
        protected void ResetAccessRule(ObjectAccessRule rule);
        protected void SetAccessRule(ObjectAccessRule rule);
        protected void SetAuditRule(ObjectAuditRule rule);
    }

    public sealed class DirectorySecurity: FileSystemSecurity
    {
        public DirectorySecurity();
        public DirectorySecurity(string name, AccessControlSections includeSections);
    }

    public sealed class EventWaitHandleAccessRule: AccessRule
    {
        public EventWaitHandleAccessRule(IdentityReference identity, EventWaitHandleRights eventRights, AccessControlType type);
        public EventWaitHandleAccessRule(string identity, EventWaitHandleRights eventRights, AccessControlType type);
        public EventWaitHandleRights EventWaitHandleRights { get; }
    }

    public sealed class EventWaitHandleAuditRule: AuditRule
    {
        public EventWaitHandleAuditRule(IdentityReference identity, EventWaitHandleRights eventRights, AuditFlags flags);
        public EventWaitHandleRights EventWaitHandleRights { get; }
    }

    public sealed class EventWaitHandleSecurity: NativeObjectSecurity
    {
        public EventWaitHandleSecurity();
        public override AccessRule AccessRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public void AddAccessRule(EventWaitHandleAccessRule rule);
        public void AddAuditRule(EventWaitHandleAuditRule rule);
        public override AuditRule AuditRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public bool RemoveAccessRule(EventWaitHandleAccessRule rule);
        public void RemoveAccessRuleAll(EventWaitHandleAccessRule rule);
        public void RemoveAccessRuleSpecific(EventWaitHandleAccessRule rule);
        public bool RemoveAuditRule(EventWaitHandleAuditRule rule);
        public void RemoveAuditRuleAll(EventWaitHandleAuditRule rule);
        public void RemoveAuditRuleSpecific(EventWaitHandleAuditRule rule);
        public void ResetAccessRule(EventWaitHandleAccessRule rule);
        public void SetAccessRule(EventWaitHandleAccessRule rule);
        public void SetAuditRule(EventWaitHandleAuditRule rule);
    }

    public sealed class FileSecurity: FileSystemSecurity
    {
        public FileSecurity();
        public FileSecurity(string fileName, AccessControlSections includeSections);
    }

    public sealed class FileSystemAccessRule: AccessRule
    {
        public FileSystemAccessRule(IdentityReference identity, FileSystemRights fileSystemRights, AccessControlType type);
        public FileSystemAccessRule(IdentityReference identity, FileSystemRights fileSystemRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public FileSystemAccessRule(string identity, FileSystemRights fileSystemRights, AccessControlType type);
        public FileSystemAccessRule(string identity, FileSystemRights fileSystemRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public FileSystemRights FileSystemRights { get; }
    }

    public sealed class FileSystemAuditRule: AuditRule
    {
        public FileSystemAuditRule(IdentityReference identity, FileSystemRights fileSystemRights, AuditFlags flags);
        public FileSystemAuditRule(IdentityReference identity, FileSystemRights fileSystemRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public FileSystemAuditRule(string identity, FileSystemRights fileSystemRights, AuditFlags flags);
        public FileSystemAuditRule(string identity, FileSystemRights fileSystemRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public FileSystemRights FileSystemRights { get; }
    }

    public abstract class FileSystemSecurity: NativeObjectSecurity
    {
        public sealed override AccessRule AccessRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public void AddAccessRule(FileSystemAccessRule rule);
        public void AddAuditRule(FileSystemAuditRule rule);
        public sealed override AuditRule AuditRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public bool RemoveAccessRule(FileSystemAccessRule rule);
        public void RemoveAccessRuleAll(FileSystemAccessRule rule);
        public void RemoveAccessRuleSpecific(FileSystemAccessRule rule);
        public bool RemoveAuditRule(FileSystemAuditRule rule);
        public void RemoveAuditRuleAll(FileSystemAuditRule rule);
        public void RemoveAuditRuleSpecific(FileSystemAuditRule rule);
        public void ResetAccessRule(FileSystemAccessRule rule);
        public void SetAccessRule(FileSystemAccessRule rule);
        public void SetAuditRule(FileSystemAuditRule rule);
    }

    public abstract class GenericAce
    {
        public AceFlags AceFlags { get; set; }
        public AceType AceType { get; }
        public AuditFlags AuditFlags { get; }
        public abstract int BinaryLength { get; }
        public InheritanceFlags InheritanceFlags { get; }
        public bool IsInherited { get; }
        public PropagationFlags PropagationFlags { get; }
        public GenericAce Copy();
        public static GenericAce CreateFromBinaryForm(byte[] binaryForm, int offset);
        public sealed override bool Equals(object o);
        public abstract void GetBinaryForm(byte[] binaryForm, int offset);
        public sealed override int GetHashCode();
        public static bool operator ==(GenericAce left, GenericAce right);
        public static bool operator !=(GenericAce left, GenericAce right);
    }

    public abstract class GenericSecurityDescriptor
    {
        protected GenericSecurityDescriptor();
        public int BinaryLength { get; }
        public abstract ControlFlags ControlFlags { get; }
        public abstract SecurityIdentifier Group { get; set; }
        public abstract SecurityIdentifier Owner { get; set; }
        public static byte Revision { get; }
        public void GetBinaryForm(byte[] binaryForm, int offset);
        public string GetSddlForm(AccessControlSections includeSections);
        public static bool IsSddlConversionSupported();
    }

    public abstract class KnownAce: GenericAce
    {
        public int AccessMask { get; set; }
        public SecurityIdentifier SecurityIdentifier { get; set; }
    }

    public sealed class MutexAccessRule: AccessRule
    {
        public MutexAccessRule(IdentityReference identity, MutexRights eventRights, AccessControlType type);
        public MutexAccessRule(string identity, MutexRights eventRights, AccessControlType type);
        public MutexRights MutexRights { get; }
    }

    public sealed class MutexAuditRule: AuditRule
    {
        public MutexAuditRule(IdentityReference identity, MutexRights eventRights, AuditFlags flags);
        public MutexRights MutexRights { get; }
    }

    public sealed class MutexSecurity: NativeObjectSecurity
    {
        public MutexSecurity();
        public MutexSecurity(string name, AccessControlSections includeSections);
        public override AccessRule AccessRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public void AddAccessRule(MutexAccessRule rule);
        public void AddAuditRule(MutexAuditRule rule);
        public override AuditRule AuditRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public bool RemoveAccessRule(MutexAccessRule rule);
        public void RemoveAccessRuleAll(MutexAccessRule rule);
        public void RemoveAccessRuleSpecific(MutexAccessRule rule);
        public bool RemoveAuditRule(MutexAuditRule rule);
        public void RemoveAuditRuleAll(MutexAuditRule rule);
        public void RemoveAuditRuleSpecific(MutexAuditRule rule);
        public void ResetAccessRule(MutexAccessRule rule);
        public void SetAccessRule(MutexAccessRule rule);
        public void SetAuditRule(MutexAuditRule rule);
    }

    public abstract class NativeObjectSecurity: CommonObjectSecurity
    {
        protected NativeObjectSecurity(bool isContainer, ResourceType resourceType);
        protected NativeObjectSecurity(bool isContainer, ResourceType resourceType, SafeHandle handle, AccessControlSections includeSections);
        protected NativeObjectSecurity(bool isContainer, ResourceType resourceType, SafeHandle handle, AccessControlSections includeSections, ExceptionFromErrorCode exceptionFromErrorCode, object exceptionContext);
        protected NativeObjectSecurity(bool isContainer, ResourceType resourceType, string name, AccessControlSections includeSections);
        protected NativeObjectSecurity(bool isContainer, ResourceType resourceType, string name, AccessControlSections includeSections, ExceptionFromErrorCode exceptionFromErrorCode, object exceptionContext);
        protected sealed override void Persist(SafeHandle handle, AccessControlSections includeSections);
        protected void Persist(SafeHandle handle, AccessControlSections includeSections, object exceptionContext);
        protected sealed override void Persist(string name, AccessControlSections includeSections);
        protected void Persist(string name, AccessControlSections includeSections, object exceptionContext);
    }

    public abstract class ObjectAccessRule: AccessRule
    {
        protected ObjectAccessRule(IdentityReference identity, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, Guid objectType, Guid inheritedObjectType, AccessControlType type);
        public Guid InheritedObjectType { get; }
        public ObjectAceFlags ObjectFlags { get; }
        public Guid ObjectType { get; }
    }

    public sealed class ObjectAce: QualifiedAce
    {
        public ObjectAce(AceFlags aceFlags, AceQualifier qualifier, int accessMask, SecurityIdentifier sid, ObjectAceFlags flags, Guid type, Guid inheritedType, bool isCallback, byte[] opaque);
        public Guid InheritedObjectAceType { get; set; }
        public ObjectAceFlags ObjectAceFlags { get; set; }
        public Guid ObjectAceType { get; set; }
        public override void GetBinaryForm(byte[] binaryForm, int offset);
        public static int MaxOpaqueLength(bool isCallback);
    }

    public abstract class ObjectAuditRule: AuditRule
    {
        protected ObjectAuditRule(IdentityReference identity, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, Guid objectType, Guid inheritedObjectType, AuditFlags auditFlags);
        public Guid InheritedObjectType { get; }
        public ObjectAceFlags ObjectFlags { get; }
        public Guid ObjectType { get; }
    }

    public abstract class ObjectSecurity
    {
        protected ObjectSecurity(bool isContainer, bool isDS);
        public abstract Type AccessRightType { get; }
        public abstract Type AccessRuleType { get; }
        public bool AreAccessRulesCanonical { get; }
        public bool AreAccessRulesProtected { get; }
        public bool AreAuditRulesCanonical { get; }
        public bool AreAuditRulesProtected { get; }
        public abstract Type AuditRuleType { get; }
        public abstract AccessRule AccessRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public abstract AuditRule AuditRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public IdentityReference GetGroup(Type targetType);
        public IdentityReference GetOwner(Type targetType);
        public byte[] GetSecurityDescriptorBinaryForm();
        public string GetSecurityDescriptorSddlForm(AccessControlSections includeSections);
        public static bool IsSddlConversionSupported();
        protected abstract bool ModifyAccess(AccessControlModification modification, AccessRule rule, ref bool modified);
        public bool ModifyAccessRule(AccessControlModification modification, AccessRule rule, ref bool modified);
        protected abstract bool ModifyAudit(AccessControlModification modification, AuditRule rule, ref bool modified);
        public bool ModifyAuditRule(AccessControlModification modification, AuditRule rule, ref bool modified);
        protected virtual void Persist(bool enableOwnershipPrivilege, string name, AccessControlSections includeSections);
        protected virtual void Persist(SafeHandle handle, AccessControlSections includeSections);
        protected virtual void Persist(string name, AccessControlSections includeSections);
        public void PurgeAccessRules(IdentityReference identity);
        public void PurgeAuditRules(IdentityReference identity);
        protected void ReadLock();
        protected void ReadUnlock();
        public void SetAccessRuleProtection(bool isProtected, bool preserveInheritance);
        public void SetAuditRuleProtection(bool isProtected, bool preserveInheritance);
        public void SetGroup(IdentityReference identity);
        public void SetOwner(IdentityReference identity);
        public void SetSecurityDescriptorBinaryForm(byte[] binaryForm);
        public void SetSecurityDescriptorBinaryForm(byte[] binaryForm, AccessControlSections includeSections);
        public void SetSecurityDescriptorSddlForm(string sddlForm);
        public void SetSecurityDescriptorSddlForm(string sddlForm, AccessControlSections includeSections);
        protected void WriteLock();
        protected void WriteUnlock();
    }

    public abstract class QualifiedAce: KnownAce
    {
        public AceQualifier AceQualifier { get; }
        public bool IsCallback { get; }
        public int OpaqueLength { get; }
        public byte[] GetOpaque();
        public void SetOpaque(byte[] opaque);
    }

    public sealed class RawSecurityDescriptor: GenericSecurityDescriptor
    {
        public RawSecurityDescriptor(byte[] binaryForm, int offset);
        public RawSecurityDescriptor(ControlFlags flags, SecurityIdentifier owner, SecurityIdentifier group, RawAcl systemAcl, RawAcl discretionaryAcl);
        public RawSecurityDescriptor(string sddlForm);
        public RawAcl DiscretionaryAcl { get; set; }
        public byte ResourceManagerControl { get; set; }
        public RawAcl SystemAcl { get; set; }
        public void SetFlags(ControlFlags flags);
    }

    public sealed class RegistryAccessRule: AccessRule
    {
        public RegistryAccessRule(IdentityReference identity, RegistryRights registryRights, AccessControlType type);
        public RegistryAccessRule(IdentityReference identity, RegistryRights registryRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public RegistryAccessRule(string identity, RegistryRights registryRights, AccessControlType type);
        public RegistryAccessRule(string identity, RegistryRights registryRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public RegistryRights RegistryRights { get; }
    }

    public sealed class RegistryAuditRule: AuditRule
    {
        public RegistryAuditRule(IdentityReference identity, RegistryRights registryRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public RegistryAuditRule(string identity, RegistryRights registryRights, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public RegistryRights RegistryRights { get; }
    }

    public sealed class RegistrySecurity: NativeObjectSecurity
    {
        public RegistrySecurity();
        public override AccessRule AccessRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AccessControlType type);
        public void AddAccessRule(RegistryAccessRule rule);
        public void AddAuditRule(RegistryAuditRule rule);
        public override AuditRule AuditRuleFactory(IdentityReference identityReference, int accessMask, bool isInherited, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, AuditFlags flags);
        public bool RemoveAccessRule(RegistryAccessRule rule);
        public void RemoveAccessRuleAll(RegistryAccessRule rule);
        public void RemoveAccessRuleSpecific(RegistryAccessRule rule);
        public bool RemoveAuditRule(RegistryAuditRule rule);
        public void RemoveAuditRuleAll(RegistryAuditRule rule);
        public void RemoveAuditRuleSpecific(RegistryAuditRule rule);
        public void ResetAccessRule(RegistryAccessRule rule);
        public void SetAccessRule(RegistryAccessRule rule);
        public void SetAuditRule(RegistryAuditRule rule);
    }

    [FlagsAttribute(..)]
    public enum AccessControlActions
    {
        Change,
        None,
        View,
    }

    public enum AccessControlModification
    {
        Add,
        Remove,
        RemoveAll,
        RemoveSpecific,
        Reset,
        Set,
    }

    [FlagsAttribute(..)]
    public enum AccessControlSections
    {
        Access,
        All,
        Audit,
        Group,
        None,
        Owner,
    }

    public enum AccessControlType
    {
        Allow,
        Deny,
    }

    [FlagsAttribute(..)]
    public enum AceFlags
    {
        AuditFlags,
        ContainerInherit,
        FailedAccess,
        InheritanceFlags,
        Inherited,
        InheritOnly,
        None,
        NoPropagateInherit,
        ObjectInherit,
        SuccessfulAccess,
    }

    public enum AceQualifier
    {
        AccessAllowed,
        AccessDenied,
        SystemAlarm,
        SystemAudit,
    }

    public enum AceType
    {
        AccessAllowed,
        AccessAllowedCallback,
        AccessAllowedCallbackObject,
        AccessAllowedCompound,
        AccessAllowedObject,
        AccessDenied,
        AccessDeniedCallback,
        AccessDeniedCallbackObject,
        AccessDeniedObject,
        MaxDefinedAceType,
        SystemAlarm,
        SystemAlarmCallback,
        SystemAlarmCallbackObject,
        SystemAlarmObject,
        SystemAudit,
        SystemAuditCallback,
        SystemAuditCallbackObject,
        SystemAuditObject,
    }

    [FlagsAttribute(..)]
    public enum AuditFlags
    {
        Failure,
        None,
        Success,
    }

    public enum CompoundAceType
    {
        Impersonation,
    }

    [FlagsAttribute(..)]
    public enum ControlFlags
    {
        DiscretionaryAclAutoInherited,
        DiscretionaryAclAutoInheritRequired,
        DiscretionaryAclDefaulted,
        DiscretionaryAclPresent,
        DiscretionaryAclProtected,
        DiscretionaryAclUntrusted,
        GroupDefaulted,
        None,
        OwnerDefaulted,
        RMControlValid,
        SelfRelative,
        ServerSecurity,
        SystemAclAutoInherited,
        SystemAclAutoInheritRequired,
        SystemAclDefaulted,
        SystemAclPresent,
        SystemAclProtected,
    }

    [FlagsAttribute(..)]
    public enum CryptoKeyRights
    {
        ChangePermissions,
        Delete,
        FullControl,
        ReadAttributes,
        ReadData,
        ReadExtendedAttributes,
        ReadPermissions,
        Synchronize,
        TakeOwnership,
        WriteAttributes,
        WriteData,
        WriteExtendedAttributes,
    }

    [FlagsAttribute(..)]
    public enum EventWaitHandleRights
    {
        ChangePermissions,
        Delete,
        FullControl,
        Modify,
        ReadPermissions,
        Synchronize,
        TakeOwnership,
    }

    [FlagsAttribute(..)]
    public enum FileSystemRights
    {
        AppendData,
        ChangePermissions,
        CreateDirectories,
        CreateFiles,
        Delete,
        DeleteSubdirectoriesAndFiles,
        ExecuteFile,
        FullControl,
        ListDirectory,
        Modify,
        Read,
        ReadAndExecute,
        ReadAttributes,
        ReadData,
        ReadExtendedAttributes,
        ReadPermissions,
        Synchronize,
        TakeOwnership,
        Traverse,
        Write,
        WriteAttributes,
        WriteData,
        WriteExtendedAttributes,
    }

    [FlagsAttribute(..)]
    public enum InheritanceFlags
    {
        ContainerInherit,
        None,
        ObjectInherit,
    }

    [FlagsAttribute(..)]
    public enum MutexRights
    {
        ChangePermissions,
        Delete,
        FullControl,
        Modify,
        ReadPermissions,
        Synchronize,
        TakeOwnership,
    }

    [FlagsAttribute(..)]
    public enum ObjectAceFlags
    {
        InheritedObjectAceTypePresent,
        None,
        ObjectAceTypePresent,
    }

    [FlagsAttribute(..)]
    public enum PropagationFlags
    {
        InheritOnly,
        None,
        NoPropagateInherit,
    }

    [FlagsAttribute(..)]
    public enum RegistryRights
    {
        ChangePermissions,
        CreateLink,
        CreateSubKey,
        Delete,
        EnumerateSubKeys,
        ExecuteKey,
        FullControl,
        Notify,
        QueryValues,
        ReadKey,
        ReadPermissions,
        SetValue,
        TakeOwnership,
        WriteKey,
    }

    public enum ResourceType
    {
        DSObject,
        DSObjectAll,
        FileObject,
        KernelObject,
        LMShare,
        Printer,
        ProviderDefined,
        RegistryKey,
        RegistryWow6432Key,
        Service,
        Unknown,
        WindowObject,
        WmiGuidObject,
    }

    [FlagsAttribute(..)]
    public enum SecurityInfos
    {
        DiscretionaryAcl,
        Group,
        Owner,
        SystemAcl,
    }

    [DefaultMemberAttribute(..)]
    public sealed class AuthorizationRuleCollection: ReadOnlyCollectionBase, ICollection
    {
        public AuthorizationRule this[int index] { get; }
        public void CopyTo(AuthorizationRule[] rules, int index);
    }

    [DefaultMemberAttribute(..)]
    public abstract class CommonAcl: GenericAcl, ICollection
    {
        public bool IsCanonical { get; }
        public bool IsContainer { get; }
        public bool IsDS { get; }
        public sealed override void GetBinaryForm(byte[] binaryForm, int offset);
        public void Purge(SecurityIdentifier sid);
        public void RemoveInheritedAces();
    }

    [DefaultMemberAttribute(..)]
    public sealed class DiscretionaryAcl: CommonAcl, ICollection
    {
        public DiscretionaryAcl(bool isContainer, bool isDS, byte revision, int capacity);
        public DiscretionaryAcl(bool isContainer, bool isDS, int capacity);
        public DiscretionaryAcl(bool isContainer, bool isDS, RawAcl rawAcl);
        public void AddAccess(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public void AddAccess(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
        public bool RemoveAccess(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public bool RemoveAccess(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
        public void RemoveAccessSpecific(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public void RemoveAccessSpecific(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
        public void SetAccess(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public void SetAccess(AccessControlType accessType, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
    }

    [DefaultMemberAttribute(..)]
    public abstract class GenericAcl: ICollection
    {
        protected GenericAcl();
        public static readonly byte AclRevision;
        public static readonly byte AclRevisionDS;
        public static readonly int MaxBinaryLength;
        public abstract int BinaryLength { get; }
        public abstract int Count { get; }
        public bool IsSynchronized { get; }
        public abstract byte Revision { get; }
        public object SyncRoot { get; }
        public abstract GenericAce this[int index] { get; set; }
        public void CopyTo(GenericAce[] array, int index);
        public abstract void GetBinaryForm(byte[] binaryForm, int offset);
        public AceEnumerator GetEnumerator();
    }

    [DefaultMemberAttribute(..)]
    public sealed class RawAcl: GenericAcl, ICollection
    {
        public RawAcl(byte revision, int capacity);
        public RawAcl(byte[] binaryForm, int offset);
        public override void GetBinaryForm(byte[] binaryForm, int offset);
        public void InsertAce(int index, GenericAce ace);
        public void RemoveAce(int index);
    }

    [DefaultMemberAttribute(..)]
    public sealed class SystemAcl: CommonAcl, ICollection
    {
        public SystemAcl(bool isContainer, bool isDS, byte revision, int capacity);
        public SystemAcl(bool isContainer, bool isDS, int capacity);
        public SystemAcl(bool isContainer, bool isDS, RawAcl rawAcl);
        public void AddAudit(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public void AddAudit(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
        public bool RemoveAudit(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public bool RemoveAudit(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
        public void RemoveAuditSpecific(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public void RemoveAuditSpecific(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
        public void SetAudit(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags);
        public void SetAudit(AuditFlags auditFlags, SecurityIdentifier sid, int accessMask, InheritanceFlags inheritanceFlags, PropagationFlags propagationFlags, ObjectAceFlags objectFlags, Guid objectType, Guid inheritedObjectType);
    }

    [SerializableAttribute(..)]
    public sealed class PrivilegeNotHeldException: UnauthorizedAccessException, _Exception, ISerializable
    {
        public PrivilegeNotHeldException();
        public PrivilegeNotHeldException(string privilege);
        public PrivilegeNotHeldException(string privilege, Exception inner);
        public string PrivilegeName { get; }
        public override void GetObjectData(SerializationInfo info, StreamingContext context);
    }

} 
namespace System.Security.Cryptography
{
    [ComVisibleAttribute(..)]
    public abstract class AsymmetricAlgorithm: IDisposable
    {
        protected AsymmetricAlgorithm();
        protected int KeySizeValue;
        protected KeySizes[] LegalKeySizesValue;
        public abstract string KeyExchangeAlgorithm { get; }
        public virtual int KeySize { get; set; }
        public virtual KeySizes[] LegalKeySizes { get; }
        public abstract string SignatureAlgorithm { get; }
        public void Clear();
        public static AsymmetricAlgorithm Create();
        public static AsymmetricAlgorithm Create(string algName);
        protected abstract void Dispose(bool disposing);
        public abstract void FromXmlString(string xmlString);
        public abstract string ToXmlString(bool includePrivateParameters);
    }

    [ComVisibleAttribute(..)]
    public abstract class AsymmetricKeyExchangeDeformatter
    {
        protected AsymmetricKeyExchangeDeformatter();
        public abstract string Parameters { get; set; }
        public abstract byte[] DecryptKeyExchange(byte[] rgb);
        public abstract void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public abstract class AsymmetricKeyExchangeFormatter
    {
        protected AsymmetricKeyExchangeFormatter();
        public abstract string Parameters { get; }
        public abstract byte[] CreateKeyExchange(byte[] data);
        public abstract byte[] CreateKeyExchange(byte[] data, Type symAlgType);
        public abstract void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public abstract class AsymmetricSignatureDeformatter
    {
        protected AsymmetricSignatureDeformatter();
        public abstract void SetHashAlgorithm(string strName);
        public abstract void SetKey(AsymmetricAlgorithm key);
        public abstract bool VerifySignature(byte[] rgbHash, byte[] rgbSignature);
        public virtual bool VerifySignature(HashAlgorithm hash, byte[] rgbSignature);
    }

    [ComVisibleAttribute(..)]
    public abstract class AsymmetricSignatureFormatter
    {
        protected AsymmetricSignatureFormatter();
        public abstract byte[] CreateSignature(byte[] rgbHash);
        public virtual byte[] CreateSignature(HashAlgorithm hash);
        public abstract void SetHashAlgorithm(string strName);
        public abstract void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public sealed class CryptoAPITransform: ICryptoTransform
    {
        public bool CanReuseTransform { get; }
        public bool CanTransformMultipleBlocks { get; }
        public int InputBlockSize { get; }
        public IntPtr KeyHandle { get; }
        public int OutputBlockSize { get; }
        public void Clear();
        public void Reset();
        public int TransformBlock(byte[] inputBuffer, int inputOffset, int inputCount, byte[] outputBuffer, int outputOffset);
        public byte[] TransformFinalBlock(byte[] inputBuffer, int inputOffset, int inputCount);
    }

    [ComVisibleAttribute(..)]
    public class CryptoConfig
    {
        public CryptoConfig();
        public static object CreateFromName(string name);
        public static object CreateFromName(string name, params object[] args);
        public static byte[] EncodeOID(string str);
        public static string MapNameToOID(string name);
    }

    [ComVisibleAttribute(..)]
    public class CryptoStream: Stream, IDisposable
    {
        public CryptoStream(Stream stream, ICryptoTransform transform, CryptoStreamMode mode);
        public void Clear();
        protected override void Dispose(bool disposing);
        public override void Flush();
        public void FlushFinalBlock();
        public override int Read(byte[] buffer, int offset, int count);
        public override long Seek(long offset, SeekOrigin origin);
        public override void SetLength(long value);
        public override void Write(byte[] buffer, int offset, int count);
    }

    [ComVisibleAttribute(..)]
    public sealed class CspKeyContainerInfo
    {
        public CspKeyContainerInfo(CspParameters parameters);
        public bool Accessible { get; }
        public CryptoKeySecurity CryptoKeySecurity { get; }
        public bool Exportable { get; }
        public bool HardwareDevice { get; }
        public string KeyContainerName { get; }
        public KeyNumber KeyNumber { get; }
        public bool MachineKeyStore { get; }
        public bool Protected { get; }
        public string ProviderName { get; }
        public int ProviderType { get; }
        public bool RandomlyGenerated { get; }
        public bool Removable { get; }
        public string UniqueKeyContainerName { get; }
    }

    [ComVisibleAttribute(..)]
    public sealed class CspParameters
    {
        public CspParameters();
        public CspParameters(int dwTypeIn);
        public CspParameters(int dwTypeIn, string strProviderNameIn);
        public CspParameters(int dwTypeIn, string strProviderNameIn, string strContainerNameIn);
        public CspParameters(int providerType, string providerName, string keyContainerName, CryptoKeySecurity cryptoKeySecurity, IntPtr parentWindowHandle);
        public CspParameters(int providerType, string providerName, string keyContainerName, CryptoKeySecurity cryptoKeySecurity, SecureString keyPassword);
        public string KeyContainerName;
        public int KeyNumber;
        public string ProviderName;
        public int ProviderType;
        public CryptoKeySecurity CryptoKeySecurity { get; set; }
        public CspProviderFlags Flags { get; set; }
        public SecureString KeyPassword { get; set; }
        public IntPtr ParentWindowHandle { get; set; }
    }

    [ComVisibleAttribute(..)]
    public abstract class DeriveBytes
    {
        protected DeriveBytes();
        public abstract byte[] GetBytes(int cb);
        public abstract void Reset();
    }

    [ComVisibleAttribute(..)]
    public abstract class DES: SymmetricAlgorithm, IDisposable
    {
        protected DES();
        public static DES Create();
        public static DES Create(string algName);
        public static bool IsSemiWeakKey(byte[] rgbKey);
        public static bool IsWeakKey(byte[] rgbKey);
    }

    [ComVisibleAttribute(..)]
    public sealed class DESCryptoServiceProvider: DES, IDisposable
    {
        public DESCryptoServiceProvider();
        public override ICryptoTransform CreateDecryptor(byte[] rgbKey, byte[] rgbIV);
        public override ICryptoTransform CreateEncryptor(byte[] rgbKey, byte[] rgbIV);
        public override void GenerateIV();
        public override void GenerateKey();
    }

    [ComVisibleAttribute(..)]
    public abstract class DSA: AsymmetricAlgorithm, IDisposable
    {
        protected DSA();
        public static DSA Create();
        public static DSA Create(string algName);
        public abstract byte[] CreateSignature(byte[] rgbHash);
        public abstract DSAParameters ExportParameters(bool includePrivateParameters);
        public override void FromXmlString(string xmlString);
        public abstract void ImportParameters(DSAParameters parameters);
        public override string ToXmlString(bool includePrivateParameters);
        public abstract bool VerifySignature(byte[] rgbHash, byte[] rgbSignature);
    }

    [ComVisibleAttribute(..)]
    public sealed class DSACryptoServiceProvider: DSA, ICspAsymmetricAlgorithm, IDisposable
    {
        public DSACryptoServiceProvider();
        public DSACryptoServiceProvider(CspParameters parameters);
        public DSACryptoServiceProvider(int dwKeySize);
        public DSACryptoServiceProvider(int dwKeySize, CspParameters parameters);
        public CspKeyContainerInfo CspKeyContainerInfo { get; }
        public bool PersistKeyInCsp { get; set; }
        public bool PublicOnly { get; }
        public static bool UseMachineKeyStore { get; set; }
        public override byte[] CreateSignature(byte[] rgbHash);
        protected override void Dispose(bool disposing);
        public byte[] ExportCspBlob(bool includePrivateParameters);
        public override DSAParameters ExportParameters(bool includePrivateParameters);
        public void ImportCspBlob(byte[] keyBlob);
        public override void ImportParameters(DSAParameters parameters);
        public byte[] SignData(byte[] buffer);
        public byte[] SignData(byte[] buffer, int offset, int count);
        public byte[] SignData(Stream inputStream);
        public byte[] SignHash(byte[] rgbHash, string str);
        public bool VerifyData(byte[] rgbData, byte[] rgbSignature);
        public bool VerifyHash(byte[] rgbHash, string str, byte[] rgbSignature);
        public override bool VerifySignature(byte[] rgbHash, byte[] rgbSignature);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct DSAParameters
    {
        public int Counter;
        public byte[] G;
        public byte[] J;
        public byte[] P;
        public byte[] Q;
        public byte[] Seed;
        public byte[] X;
        public byte[] Y;
    }

    [ComVisibleAttribute(..)]
    public class DSASignatureDeformatter: AsymmetricSignatureDeformatter
    {
        public DSASignatureDeformatter();
        public DSASignatureDeformatter(AsymmetricAlgorithm key);
        public override void SetHashAlgorithm(string strName);
        public override void SetKey(AsymmetricAlgorithm key);
        public override bool VerifySignature(byte[] rgbHash, byte[] rgbSignature);
    }

    [ComVisibleAttribute(..)]
    public class DSASignatureFormatter: AsymmetricSignatureFormatter
    {
        public DSASignatureFormatter();
        public DSASignatureFormatter(AsymmetricAlgorithm key);
        public override byte[] CreateSignature(byte[] rgbHash);
        public override void SetHashAlgorithm(string strName);
        public override void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public class FromBase64Transform: ICryptoTransform
    {
        public FromBase64Transform();
        public FromBase64Transform(FromBase64TransformMode whitespaces);
        public virtual bool CanReuseTransform { get; }
        public bool CanTransformMultipleBlocks { get; }
        public int InputBlockSize { get; }
        public int OutputBlockSize { get; }
        public void Clear();
        protected virtual void Dispose(bool disposing);
        protected override void Finalize();
        public int TransformBlock(byte[] inputBuffer, int inputOffset, int inputCount, byte[] outputBuffer, int outputOffset);
        public byte[] TransformFinalBlock(byte[] inputBuffer, int inputOffset, int inputCount);
    }

    [ComVisibleAttribute(..)]
    public abstract class HashAlgorithm: ICryptoTransform
    {
        protected HashAlgorithm();
        protected int HashSizeValue;
        protected byte[] HashValue;
        protected int State;
        public virtual bool CanReuseTransform { get; }
        public virtual bool CanTransformMultipleBlocks { get; }
        public virtual byte[] Hash { get; }
        public virtual int HashSize { get; }
        public virtual int InputBlockSize { get; }
        public virtual int OutputBlockSize { get; }
        public void Clear();
        public byte[] ComputeHash(byte[] buffer);
        public byte[] ComputeHash(byte[] buffer, int offset, int count);
        public byte[] ComputeHash(Stream inputStream);
        public static HashAlgorithm Create();
        public static HashAlgorithm Create(string hashName);
        protected virtual void Dispose(bool disposing);
        protected abstract void HashCore(byte[] array, int ibStart, int cbSize);
        protected abstract byte[] HashFinal();
        public abstract void Initialize();
        public int TransformBlock(byte[] inputBuffer, int inputOffset, int inputCount, byte[] outputBuffer, int outputOffset);
        public byte[] TransformFinalBlock(byte[] inputBuffer, int inputOffset, int inputCount);
    }

    [ComVisibleAttribute(..)]
    public abstract class HMAC: KeyedHashAlgorithm, ICryptoTransform
    {
        protected HMAC();
        public string HashName { get; set; }
        public static HMAC Create();
        public static HMAC Create(string algorithmName);
        protected override void Dispose(bool disposing);
        protected override void HashCore(byte[] rgb, int ib, int cb);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public class HMACMD5: HMAC, ICryptoTransform
    {
        public HMACMD5();
        public HMACMD5(byte[] key);
    }

    [ComVisibleAttribute(..)]
    public class HMACRIPEMD160: HMAC, ICryptoTransform
    {
        public HMACRIPEMD160();
        public HMACRIPEMD160(byte[] key);
    }

    [ComVisibleAttribute(..)]
    public class HMACSHA1: HMAC, ICryptoTransform
    {
        public HMACSHA1();
        public HMACSHA1(byte[] key);
    }

    [ComVisibleAttribute(..)]
    public class HMACSHA256: HMAC, ICryptoTransform
    {
        public HMACSHA256();
        public HMACSHA256(byte[] key);
    }

    [ComVisibleAttribute(..)]
    public class HMACSHA384: HMAC, ICryptoTransform
    {
        public HMACSHA384();
        public HMACSHA384(byte[] key);
    }

    [ComVisibleAttribute(..)]
    public class HMACSHA512: HMAC, ICryptoTransform
    {
        public HMACSHA512();
        public HMACSHA512(byte[] key);
    }

    [ComVisibleAttribute(..)]
    public interface ICryptoTransform: IDisposable
    {
        public bool CanReuseTransform { get; }
        public bool CanTransformMultipleBlocks { get; }
        public int InputBlockSize { get; }
        public int OutputBlockSize { get; }
        public int TransformBlock(byte[] inputBuffer, int inputOffset, int inputCount, byte[] outputBuffer, int outputOffset);
        public byte[] TransformFinalBlock(byte[] inputBuffer, int inputOffset, int inputCount);
    }

    [ComVisibleAttribute(..)]
    public interface ICspAsymmetricAlgorithm
    {
        public CspKeyContainerInfo CspKeyContainerInfo { get; }
        public byte[] ExportCspBlob(bool includePrivateParameters);
        public void ImportCspBlob(byte[] rawData);
    }

    [ComVisibleAttribute(..)]
    public abstract class KeyedHashAlgorithm: HashAlgorithm, ICryptoTransform
    {
        protected KeyedHashAlgorithm();
        protected byte[] KeyValue;
        public virtual byte[] Key { get; set; }
        public static KeyedHashAlgorithm Create();
        public static KeyedHashAlgorithm Create(string algName);
        protected override void Dispose(bool disposing);
    }

    [ComVisibleAttribute(..)]
    public sealed class KeySizes
    {
        public KeySizes(int minSize, int maxSize, int skipSize);
        public int MaxSize { get; }
        public int MinSize { get; }
        public int SkipSize { get; }
    }

    [ComVisibleAttribute(..)]
    public class MACTripleDES: KeyedHashAlgorithm, ICryptoTransform
    {
        public MACTripleDES();
        public MACTripleDES(byte[] rgbKey);
        public MACTripleDES(string strTripleDES, byte[] rgbKey);
        public PaddingMode Padding { get; set; }
        protected override void Dispose(bool disposing);
        protected override void HashCore(byte[] rgbData, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public abstract class MaskGenerationMethod
    {
        protected MaskGenerationMethod();
        public abstract byte[] GenerateMask(byte[] rgbSeed, int cbReturn);
    }

    [ComVisibleAttribute(..)]
    public abstract class MD5: HashAlgorithm, ICryptoTransform
    {
        protected MD5();
        public static MD5 Create();
        public static MD5 Create(string algName);
    }

    [ComVisibleAttribute(..)]
    public sealed class MD5CryptoServiceProvider: MD5, ICryptoTransform
    {
        public MD5CryptoServiceProvider();
        protected override void Dispose(bool disposing);
        protected override void HashCore(byte[] rgb, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public class PasswordDeriveBytes: DeriveBytes
    {
        public PasswordDeriveBytes(byte[] password, byte[] salt);
        public PasswordDeriveBytes(byte[] password, byte[] salt, CspParameters cspParams);
        public PasswordDeriveBytes(byte[] password, byte[] salt, string hashName, int iterations);
        public PasswordDeriveBytes(byte[] password, byte[] salt, string hashName, int iterations, CspParameters cspParams);
        public PasswordDeriveBytes(string strPassword, byte[] rgbSalt);
        public PasswordDeriveBytes(string strPassword, byte[] rgbSalt, CspParameters cspParams);
        public PasswordDeriveBytes(string strPassword, byte[] rgbSalt, string strHashName, int iterations);
        public PasswordDeriveBytes(string strPassword, byte[] rgbSalt, string strHashName, int iterations, CspParameters cspParams);
        public string HashName { get; set; }
        public int IterationCount { get; set; }
        public byte[] Salt { get; set; }
        public byte[] CryptDeriveKey(string algname, string alghashname, int keySize, byte[] rgbIV);
        public override byte[] GetBytes(int cb);
        public override void Reset();
    }

    [ComVisibleAttribute(..)]
    public class PKCS1MaskGenerationMethod: MaskGenerationMethod
    {
        public PKCS1MaskGenerationMethod();
        public string HashName { get; set; }
        public override byte[] GenerateMask(byte[] rgbSeed, int cbReturn);
    }

    [ComVisibleAttribute(..)]
    public abstract class RandomNumberGenerator
    {
        protected RandomNumberGenerator();
        public static RandomNumberGenerator Create();
        public static RandomNumberGenerator Create(string rngName);
        public abstract void GetBytes(byte[] data);
        public abstract void GetNonZeroBytes(byte[] data);
    }

    [ComVisibleAttribute(..)]
    public abstract class RC2: SymmetricAlgorithm, IDisposable
    {
        protected RC2();
        protected int EffectiveKeySizeValue;
        public virtual int EffectiveKeySize { get; set; }
        public static RC2 Create();
        public static RC2 Create(string AlgName);
    }

    [ComVisibleAttribute(..)]
    public sealed class RC2CryptoServiceProvider: RC2, IDisposable
    {
        public RC2CryptoServiceProvider();
        public bool UseSalt { get; set; }
        public override ICryptoTransform CreateDecryptor(byte[] rgbKey, byte[] rgbIV);
        public override ICryptoTransform CreateEncryptor(byte[] rgbKey, byte[] rgbIV);
        public override void GenerateIV();
        public override void GenerateKey();
    }

    [ComVisibleAttribute(..)]
    public class Rfc2898DeriveBytes: DeriveBytes
    {
        public Rfc2898DeriveBytes(byte[] password, byte[] salt, int iterations);
        public Rfc2898DeriveBytes(string password, byte[] salt);
        public Rfc2898DeriveBytes(string password, byte[] salt, int iterations);
        public Rfc2898DeriveBytes(string password, int saltSize);
        public Rfc2898DeriveBytes(string password, int saltSize, int iterations);
        public int IterationCount { get; set; }
        public byte[] Salt { get; set; }
        public override byte[] GetBytes(int cb);
        public override void Reset();
    }

    [ComVisibleAttribute(..)]
    public abstract class Rijndael: SymmetricAlgorithm, IDisposable
    {
        protected Rijndael();
        public static Rijndael Create();
        public static Rijndael Create(string algName);
    }

    [ComVisibleAttribute(..)]
    public sealed class RijndaelManaged: Rijndael, IDisposable
    {
        public RijndaelManaged();
        public override ICryptoTransform CreateDecryptor(byte[] rgbKey, byte[] rgbIV);
        public override ICryptoTransform CreateEncryptor(byte[] rgbKey, byte[] rgbIV);
        public override void GenerateIV();
        public override void GenerateKey();
    }

    [ComVisibleAttribute(..)]
    public sealed class RijndaelManagedTransform: ICryptoTransform
    {
        public int BlockSizeValue { get; }
        public bool CanReuseTransform { get; }
        public bool CanTransformMultipleBlocks { get; }
        public int InputBlockSize { get; }
        public int OutputBlockSize { get; }
        public void Clear();
        public void Reset();
        public int TransformBlock(byte[] inputBuffer, int inputOffset, int inputCount, byte[] outputBuffer, int outputOffset);
        public byte[] TransformFinalBlock(byte[] inputBuffer, int inputOffset, int inputCount);
    }

    [ComVisibleAttribute(..)]
    public abstract class RIPEMD160: HashAlgorithm, ICryptoTransform
    {
        protected RIPEMD160();
        public static RIPEMD160 Create();
        public static RIPEMD160 Create(string hashName);
    }

    [ComVisibleAttribute(..)]
    public class RIPEMD160Managed: RIPEMD160, ICryptoTransform
    {
        public RIPEMD160Managed();
        protected override void HashCore(byte[] rgb, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public sealed class RNGCryptoServiceProvider: RandomNumberGenerator
    {
        public RNGCryptoServiceProvider();
        public RNGCryptoServiceProvider(byte[] rgb);
        public RNGCryptoServiceProvider(CspParameters cspParams);
        public RNGCryptoServiceProvider(string str);
        public override void GetBytes(byte[] data);
        public override void GetNonZeroBytes(byte[] data);
    }

    [ComVisibleAttribute(..)]
    public abstract class RSA: AsymmetricAlgorithm, IDisposable
    {
        protected RSA();
        public static RSA Create();
        public static RSA Create(string algName);
        public abstract byte[] DecryptValue(byte[] rgb);
        public abstract byte[] EncryptValue(byte[] rgb);
        public abstract RSAParameters ExportParameters(bool includePrivateParameters);
        public override void FromXmlString(string xmlString);
        public abstract void ImportParameters(RSAParameters parameters);
        public override string ToXmlString(bool includePrivateParameters);
    }

    [ComVisibleAttribute(..)]
    public sealed class RSACryptoServiceProvider: RSA, ICspAsymmetricAlgorithm, IDisposable
    {
        public RSACryptoServiceProvider();
        public RSACryptoServiceProvider(CspParameters parameters);
        public RSACryptoServiceProvider(int dwKeySize);
        public RSACryptoServiceProvider(int dwKeySize, CspParameters parameters);
        public CspKeyContainerInfo CspKeyContainerInfo { get; }
        public bool PersistKeyInCsp { get; set; }
        public bool PublicOnly { get; }
        public static bool UseMachineKeyStore { get; set; }
        public byte[] Decrypt(byte[] rgb, bool fOAEP);
        public override byte[] DecryptValue(byte[] rgb);
        protected override void Dispose(bool disposing);
        public byte[] Encrypt(byte[] rgb, bool fOAEP);
        public override byte[] EncryptValue(byte[] rgb);
        public byte[] ExportCspBlob(bool includePrivateParameters);
        public override RSAParameters ExportParameters(bool includePrivateParameters);
        public void ImportCspBlob(byte[] keyBlob);
        public override void ImportParameters(RSAParameters parameters);
        public byte[] SignData(byte[] buffer, int offset, int count, object halg);
        public byte[] SignData(byte[] buffer, object halg);
        public byte[] SignData(Stream inputStream, object halg);
        public byte[] SignHash(byte[] rgbHash, string str);
        public bool VerifyData(byte[] buffer, object halg, byte[] signature);
        public bool VerifyHash(byte[] rgbHash, string str, byte[] rgbSignature);
    }

    [ComVisibleAttribute(..)]
    public class RSAOAEPKeyExchangeDeformatter: AsymmetricKeyExchangeDeformatter
    {
        public RSAOAEPKeyExchangeDeformatter();
        public RSAOAEPKeyExchangeDeformatter(AsymmetricAlgorithm key);
        public override byte[] DecryptKeyExchange(byte[] rgbData);
        public override void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public class RSAOAEPKeyExchangeFormatter: AsymmetricKeyExchangeFormatter
    {
        public RSAOAEPKeyExchangeFormatter();
        public RSAOAEPKeyExchangeFormatter(AsymmetricAlgorithm key);
        public byte[] Parameter { get; set; }
        public RandomNumberGenerator Rng { get; set; }
        public override byte[] CreateKeyExchange(byte[] rgbData);
        public override byte[] CreateKeyExchange(byte[] rgbData, Type symAlgType);
        public override void SetKey(AsymmetricAlgorithm key);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public struct RSAParameters
    {
        public byte[] D;
        public byte[] DP;
        public byte[] DQ;
        public byte[] Exponent;
        public byte[] InverseQ;
        public byte[] Modulus;
        public byte[] P;
        public byte[] Q;
    }

    [ComVisibleAttribute(..)]
    public class RSAPKCS1KeyExchangeDeformatter: AsymmetricKeyExchangeDeformatter
    {
        public RSAPKCS1KeyExchangeDeformatter();
        public RSAPKCS1KeyExchangeDeformatter(AsymmetricAlgorithm key);
        public RandomNumberGenerator RNG { get; set; }
        public override byte[] DecryptKeyExchange(byte[] rgbIn);
        public override void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public class RSAPKCS1KeyExchangeFormatter: AsymmetricKeyExchangeFormatter
    {
        public RSAPKCS1KeyExchangeFormatter();
        public RSAPKCS1KeyExchangeFormatter(AsymmetricAlgorithm key);
        public RandomNumberGenerator Rng { get; set; }
        public override byte[] CreateKeyExchange(byte[] rgbData);
        public override byte[] CreateKeyExchange(byte[] rgbData, Type symAlgType);
        public override void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public class RSAPKCS1SignatureDeformatter: AsymmetricSignatureDeformatter
    {
        public RSAPKCS1SignatureDeformatter();
        public RSAPKCS1SignatureDeformatter(AsymmetricAlgorithm key);
        public override void SetHashAlgorithm(string strName);
        public override void SetKey(AsymmetricAlgorithm key);
        public override bool VerifySignature(byte[] rgbHash, byte[] rgbSignature);
    }

    [ComVisibleAttribute(..)]
    public class RSAPKCS1SignatureFormatter: AsymmetricSignatureFormatter
    {
        public RSAPKCS1SignatureFormatter();
        public RSAPKCS1SignatureFormatter(AsymmetricAlgorithm key);
        public override byte[] CreateSignature(byte[] rgbHash);
        public override void SetHashAlgorithm(string strName);
        public override void SetKey(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public abstract class SHA1: HashAlgorithm, ICryptoTransform
    {
        protected SHA1();
        public static SHA1 Create();
        public static SHA1 Create(string hashName);
    }

    [ComVisibleAttribute(..)]
    public sealed class SHA1CryptoServiceProvider: SHA1, ICryptoTransform
    {
        public SHA1CryptoServiceProvider();
        protected override void Dispose(bool disposing);
        protected override void HashCore(byte[] rgb, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public class SHA1Managed: SHA1, ICryptoTransform
    {
        public SHA1Managed();
        protected override void HashCore(byte[] rgb, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public abstract class SHA256: HashAlgorithm, ICryptoTransform
    {
        protected SHA256();
        public static SHA256 Create();
        public static SHA256 Create(string hashName);
    }

    [ComVisibleAttribute(..)]
    public class SHA256Managed: SHA256, ICryptoTransform
    {
        public SHA256Managed();
        protected override void HashCore(byte[] rgb, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public abstract class SHA384: HashAlgorithm, ICryptoTransform
    {
        protected SHA384();
        public static SHA384 Create();
        public static SHA384 Create(string hashName);
    }

    [ComVisibleAttribute(..)]
    public class SHA384Managed: SHA384, ICryptoTransform
    {
        public SHA384Managed();
        protected override void HashCore(byte[] rgb, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public abstract class SHA512: HashAlgorithm, ICryptoTransform
    {
        protected SHA512();
        public static SHA512 Create();
        public static SHA512 Create(string hashName);
    }

    [ComVisibleAttribute(..)]
    public class SHA512Managed: SHA512, ICryptoTransform
    {
        public SHA512Managed();
        protected override void HashCore(byte[] rgb, int ibStart, int cbSize);
        protected override byte[] HashFinal();
        public override void Initialize();
    }

    [ComVisibleAttribute(..)]
    public class SignatureDescription
    {
        public SignatureDescription();
        public SignatureDescription(SecurityElement el);
        public string DeformatterAlgorithm { get; set; }
        public string DigestAlgorithm { get; set; }
        public string FormatterAlgorithm { get; set; }
        public string KeyAlgorithm { get; set; }
        public virtual AsymmetricSignatureDeformatter CreateDeformatter(AsymmetricAlgorithm key);
        public virtual HashAlgorithm CreateDigest();
        public virtual AsymmetricSignatureFormatter CreateFormatter(AsymmetricAlgorithm key);
    }

    [ComVisibleAttribute(..)]
    public abstract class SymmetricAlgorithm: IDisposable
    {
        protected SymmetricAlgorithm();
        protected int BlockSizeValue;
        protected int FeedbackSizeValue;
        protected byte[] IVValue;
        protected int KeySizeValue;
        protected byte[] KeyValue;
        protected KeySizes[] LegalBlockSizesValue;
        protected KeySizes[] LegalKeySizesValue;
        protected CipherMode ModeValue;
        protected PaddingMode PaddingValue;
        public virtual int BlockSize { get; set; }
        public virtual int FeedbackSize { get; set; }
        public virtual byte[] IV { get; set; }
        public virtual byte[] Key { get; set; }
        public virtual int KeySize { get; set; }
        public virtual KeySizes[] LegalBlockSizes { get; }
        public virtual KeySizes[] LegalKeySizes { get; }
        public virtual CipherMode Mode { get; set; }
        public virtual PaddingMode Padding { get; set; }
        public void Clear();
        public static SymmetricAlgorithm Create();
        public static SymmetricAlgorithm Create(string algName);
        public virtual ICryptoTransform CreateDecryptor();
        public abstract ICryptoTransform CreateDecryptor(byte[] rgbKey, byte[] rgbIV);
        public virtual ICryptoTransform CreateEncryptor();
        public abstract ICryptoTransform CreateEncryptor(byte[] rgbKey, byte[] rgbIV);
        protected virtual void Dispose(bool disposing);
        public abstract void GenerateIV();
        public abstract void GenerateKey();
        public bool ValidKeySize(int bitLength);
    }

    [ComVisibleAttribute(..)]
    public class ToBase64Transform: ICryptoTransform
    {
        public ToBase64Transform();
        public virtual bool CanReuseTransform { get; }
        public bool CanTransformMultipleBlocks { get; }
        public int InputBlockSize { get; }
        public int OutputBlockSize { get; }
        public void Clear();
        protected virtual void Dispose(bool disposing);
        protected override void Finalize();
        public int TransformBlock(byte[] inputBuffer, int inputOffset, int inputCount, byte[] outputBuffer, int outputOffset);
        public byte[] TransformFinalBlock(byte[] inputBuffer, int inputOffset, int inputCount);
    }

    [ComVisibleAttribute(..)]
    public abstract class TripleDES: SymmetricAlgorithm, IDisposable
    {
        protected TripleDES();
        public static TripleDES Create();
        public static TripleDES Create(string str);
        public static bool IsWeakKey(byte[] rgbKey);
    }

    [ComVisibleAttribute(..)]
    public sealed class TripleDESCryptoServiceProvider: TripleDES, IDisposable
    {
        public TripleDESCryptoServiceProvider();
        public override ICryptoTransform CreateDecryptor(byte[] rgbKey, byte[] rgbIV);
        public override ICryptoTransform CreateEncryptor(byte[] rgbKey, byte[] rgbIV);
        public override void GenerateIV();
        public override void GenerateKey();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum CipherMode
    {
        CBC,
        CFB,
        CTS,
        ECB,
        OFB,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum CryptoStreamMode
    {
        Read,
        Write,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum CspProviderFlags
    {
        NoFlags,
        NoPrompt,
        UseArchivableKey,
        UseDefaultKeyContainer,
        UseExistingKey,
        UseMachineKeyStore,
        UseNonExportableKey,
        UseUserProtectedKey,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FromBase64TransformMode
    {
        DoNotIgnoreWhiteSpaces,
        IgnoreWhiteSpaces,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum KeyNumber
    {
        Exchange,
        Signature,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PaddingMode
    {
        ANSIX923,
        ISO10126,
        None,
        PKCS7,
        Zeros,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CryptographicException: SystemException, _Exception, ISerializable
    {
        public CryptographicException();
        public CryptographicException(int hr);
        protected CryptographicException(SerializationInfo info, StreamingContext context);
        public CryptographicException(string message);
        public CryptographicException(string message, Exception inner);
        public CryptographicException(string format, string insert);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CryptographicUnexpectedOperationException: CryptographicException, _Exception, ISerializable
    {
        public CryptographicUnexpectedOperationException();
        protected CryptographicUnexpectedOperationException(SerializationInfo info, StreamingContext context);
        public CryptographicUnexpectedOperationException(string message);
        public CryptographicUnexpectedOperationException(string message, Exception inner);
        public CryptographicUnexpectedOperationException(string format, string insert);
    }

} 
namespace System.Security.Cryptography.X509Certificates
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class X509Certificate: IDeserializationCallback, ISerializable
    {
        public X509Certificate();
        public X509Certificate(byte[] data);
        public X509Certificate(byte[] rawData, SecureString password);
        public X509Certificate(byte[] rawData, SecureString password, X509KeyStorageFlags keyStorageFlags);
        public X509Certificate(byte[] rawData, string password);
        public X509Certificate(byte[] rawData, string password, X509KeyStorageFlags keyStorageFlags);
        public X509Certificate(IntPtr handle);
        public X509Certificate(SerializationInfo info, StreamingContext context);
        public X509Certificate(string fileName);
        public X509Certificate(string fileName, SecureString password);
        public X509Certificate(string fileName, SecureString password, X509KeyStorageFlags keyStorageFlags);
        public X509Certificate(string fileName, string password);
        public X509Certificate(string fileName, string password, X509KeyStorageFlags keyStorageFlags);
        public X509Certificate(X509Certificate cert);
        public IntPtr Handle { get; }
        public string Issuer { get; }
        public string Subject { get; }
        public static X509Certificate CreateFromCertFile(string filename);
        public static X509Certificate CreateFromSignedFile(string filename);
        public override bool Equals(object obj);
        public virtual bool Equals(X509Certificate other);
        public virtual byte[] Export(X509ContentType contentType);
        public virtual byte[] Export(X509ContentType contentType, SecureString password);
        public virtual byte[] Export(X509ContentType contentType, string password);
        public virtual byte[] GetCertHash();
        public virtual string GetCertHashString();
        public virtual string GetEffectiveDateString();
        public virtual string GetExpirationDateString();
        public virtual string GetFormat();
        public override int GetHashCode();
        public virtual string GetIssuerName();
        public virtual string GetKeyAlgorithm();
        public virtual byte[] GetKeyAlgorithmParameters();
        public virtual string GetKeyAlgorithmParametersString();
        public virtual string GetName();
        public virtual byte[] GetPublicKey();
        public virtual string GetPublicKeyString();
        public virtual byte[] GetRawCertData();
        public virtual string GetRawCertDataString();
        public virtual byte[] GetSerialNumber();
        public virtual string GetSerialNumberString();
        public virtual void Import(byte[] rawData);
        public virtual void Import(byte[] rawData, SecureString password, X509KeyStorageFlags keyStorageFlags);
        public virtual void Import(byte[] rawData, string password, X509KeyStorageFlags keyStorageFlags);
        public virtual void Import(string fileName);
        public virtual void Import(string fileName, SecureString password, X509KeyStorageFlags keyStorageFlags);
        public virtual void Import(string fileName, string password, X509KeyStorageFlags keyStorageFlags);
        public virtual void Reset();
        public override string ToString();
        public virtual string ToString(bool fVerbose);
    }

    [ComVisibleAttribute(..)]
    public enum X509ContentType
    {
        Authenticode,
        Cert,
        Pfx,
        Pkcs12,
        Pkcs7,
        SerializedCert,
        SerializedStore,
        Unknown,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum X509KeyStorageFlags
    {
        DefaultKeySet,
        Exportable,
        MachineKeySet,
        PersistKeySet,
        UserKeySet,
        UserProtected,
    }

} 
namespace System.Security.Permissions
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class EnvironmentPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public EnvironmentPermission(EnvironmentPermissionAccess flag, string pathList);
        public EnvironmentPermission(PermissionState state);
        public void AddPathList(EnvironmentPermissionAccess flag, string pathList);
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public string GetPathList(EnvironmentPermissionAccess flag);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public void SetPathList(EnvironmentPermissionAccess flag, string pathList);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission other);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class FileDialogPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public FileDialogPermission(FileDialogPermissionAccess access);
        public FileDialogPermission(PermissionState state);
        public FileDialogPermissionAccess Access { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class FileIOPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public FileIOPermission(FileIOPermissionAccess access, AccessControlActions control, string path);
        public FileIOPermission(FileIOPermissionAccess access, AccessControlActions control, string[] pathList);
        public FileIOPermission(FileIOPermissionAccess access, string path);
        public FileIOPermission(FileIOPermissionAccess access, string[] pathList);
        public FileIOPermission(PermissionState state);
        public FileIOPermissionAccess AllFiles { get; set; }
        public FileIOPermissionAccess AllLocalFiles { get; set; }
        public void AddPathList(FileIOPermissionAccess access, string path);
        public void AddPathList(FileIOPermissionAccess access, string[] pathList);
        public override IPermission Copy();
        public override bool Equals(object obj);
        public override void FromXml(SecurityElement esd);
        public override int GetHashCode();
        public string[] GetPathList(FileIOPermissionAccess access);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public void SetPathList(FileIOPermissionAccess access, string path);
        public void SetPathList(FileIOPermissionAccess access, string[] pathList);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission other);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class GacIdentityPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk
    {
        public GacIdentityPermission();
        public GacIdentityPermission(PermissionState state);
        public override IPermission Copy();
        public override void FromXml(SecurityElement securityElement);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class IsolatedStorageFilePermission: IsolatedStoragePermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public IsolatedStorageFilePermission(PermissionState state);
        public override IPermission Copy();
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SecurityPermissionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class IsolatedStoragePermission: CodeAccessPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        protected IsolatedStoragePermission(PermissionState state);
        public IsolatedStorageContainment UsageAllowed { get; set; }
        public long UserQuota { get; set; }
        public override void FromXml(SecurityElement esd);
        public bool IsUnrestricted();
        public override SecurityElement ToXml();
    }

    [ComVisibleAttribute(..)]
    public interface IUnrestrictedPermission
    {
        public bool IsUnrestricted();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class KeyContainerPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public KeyContainerPermission(KeyContainerPermissionFlags flags);
        public KeyContainerPermission(KeyContainerPermissionFlags flags, KeyContainerPermissionAccessEntry[] accessList);
        public KeyContainerPermission(PermissionState state);
        public KeyContainerPermissionAccessEntryCollection AccessEntries { get; }
        public KeyContainerPermissionFlags Flags { get; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement securityElement);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class KeyContainerPermissionAccessEntry
    {
        public KeyContainerPermissionAccessEntry(CspParameters parameters, KeyContainerPermissionFlags flags);
        public KeyContainerPermissionAccessEntry(string keyContainerName, KeyContainerPermissionFlags flags);
        public KeyContainerPermissionAccessEntry(string keyStore, string providerName, int providerType, string keyContainerName, int keySpec, KeyContainerPermissionFlags flags);
        public KeyContainerPermissionFlags Flags { get; set; }
        public string KeyContainerName { get; set; }
        public int KeySpec { get; set; }
        public string KeyStore { get; set; }
        public string ProviderName { get; set; }
        public int ProviderType { get; set; }
        public override bool Equals(object o);
        public override int GetHashCode();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class KeyContainerPermissionAccessEntryEnumerator: IEnumerator
    {
        public KeyContainerPermissionAccessEntry Current { get; }
        public bool MoveNext();
        public void Reset();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class PrincipalPermission: IBuiltInPermission, IPermission, IUnrestrictedPermission
    {
        public PrincipalPermission(PermissionState state);
        public PrincipalPermission(string name, string role);
        public PrincipalPermission(string name, string role, bool isAuthenticated);
        public IPermission Copy();
        public void Demand();
        public override bool Equals(object obj);
        public void FromXml(SecurityElement elem);
        public override int GetHashCode();
        public IPermission Intersect(IPermission target);
        public bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public override string ToString();
        public SecurityElement ToXml();
        public IPermission Union(IPermission other);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class PublisherIdentityPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk
    {
        public PublisherIdentityPermission(PermissionState state);
        public PublisherIdentityPermission(X509Certificate certificate);
        public X509Certificate Certificate { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ReflectionPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public ReflectionPermission(PermissionState state);
        public ReflectionPermission(ReflectionPermissionFlag flag);
        public ReflectionPermissionFlag Flags { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission other);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class RegistryPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public RegistryPermission(PermissionState state);
        public RegistryPermission(RegistryPermissionAccess access, AccessControlActions control, string pathList);
        public RegistryPermission(RegistryPermissionAccess access, string pathList);
        public void AddPathList(RegistryPermissionAccess access, AccessControlActions control, string pathList);
        public void AddPathList(RegistryPermissionAccess access, string pathList);
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public string GetPathList(RegistryPermissionAccess access);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public void SetPathList(RegistryPermissionAccess access, string pathList);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission other);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SecurityPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public SecurityPermission(PermissionState state);
        public SecurityPermission(SecurityPermissionFlag flag);
        public SecurityPermissionFlag Flags { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SiteIdentityPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk
    {
        public SiteIdentityPermission(PermissionState state);
        public SiteIdentityPermission(string site);
        public string Site { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class StrongNameIdentityPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk
    {
        public StrongNameIdentityPermission(PermissionState state);
        public StrongNameIdentityPermission(StrongNamePublicKeyBlob blob, string name, Version version);
        public string Name { get; set; }
        public StrongNamePublicKeyBlob PublicKey { get; set; }
        public Version Version { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement e);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class StrongNamePublicKeyBlob
    {
        public StrongNamePublicKeyBlob(byte[] publicKey);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UIPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk, IUnrestrictedPermission
    {
        public UIPermission(PermissionState state);
        public UIPermission(UIPermissionClipboard clipboardFlag);
        public UIPermission(UIPermissionWindow windowFlag);
        public UIPermission(UIPermissionWindow windowFlag, UIPermissionClipboard clipboardFlag);
        public UIPermissionClipboard Clipboard { get; set; }
        public UIPermissionWindow Window { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public bool IsUnrestricted();
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UrlIdentityPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk
    {
        public UrlIdentityPermission(PermissionState state);
        public UrlIdentityPermission(string site);
        public string Url { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ZoneIdentityPermission: CodeAccessPermission, IBuiltInPermission, IPermission, IStackWalk
    {
        public ZoneIdentityPermission(PermissionState state);
        public ZoneIdentityPermission(SecurityZone zone);
        public SecurityZone SecurityZone { get; set; }
        public override IPermission Copy();
        public override void FromXml(SecurityElement esd);
        public override IPermission Intersect(IPermission target);
        public override bool IsSubsetOf(IPermission target);
        public override SecurityElement ToXml();
        public override IPermission Union(IPermission target);
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum EnvironmentPermissionAccess
    {
        AllAccess,
        NoAccess,
        Read,
        Write,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum FileDialogPermissionAccess
    {
        None,
        Open,
        OpenSave,
        Save,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum FileIOPermissionAccess
    {
        AllAccess,
        Append,
        NoAccess,
        PathDiscovery,
        Read,
        Write,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum HostProtectionResource
    {
        All,
        ExternalProcessMgmt,
        ExternalThreading,
        MayLeakOnAbort,
        None,
        SecurityInfrastructure,
        SelfAffectingProcessMgmt,
        SelfAffectingThreading,
        SharedState,
        Synchronization,
        UI,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum IsolatedStorageContainment
    {
        AdministerIsolatedStorageByUser,
        ApplicationIsolationByMachine,
        ApplicationIsolationByRoamingUser,
        ApplicationIsolationByUser,
        AssemblyIsolationByMachine,
        AssemblyIsolationByRoamingUser,
        AssemblyIsolationByUser,
        DomainIsolationByMachine,
        DomainIsolationByRoamingUser,
        DomainIsolationByUser,
        None,
        UnrestrictedIsolatedStorage,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum KeyContainerPermissionFlags
    {
        AllFlags,
        ChangeAcl,
        Create,
        Decrypt,
        Delete,
        Export,
        Import,
        NoFlags,
        Open,
        Sign,
        ViewAcl,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PermissionState
    {
        None,
        Unrestricted,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ReflectionPermissionFlag
    {
        AllFlags,
        MemberAccess,
        NoFlags,
        ReflectionEmit,
        TypeInformation,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum RegistryPermissionAccess
    {
        AllAccess,
        Create,
        NoAccess,
        Read,
        Write,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum SecurityAction
    {
        Assert,
        Demand,
        DemandChoice,
        Deny,
        InheritanceDemand,
        InheritanceDemandChoice,
        LinkDemand,
        LinkDemandChoice,
        PermitOnly,
        RequestMinimum,
        RequestOptional,
        RequestRefuse,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum SecurityPermissionFlag
    {
        AllFlags,
        Assertion,
        BindingRedirects,
        ControlAppDomain,
        ControlDomainPolicy,
        ControlEvidence,
        ControlPolicy,
        ControlPrincipal,
        ControlThread,
        Execution,
        Infrastructure,
        NoFlags,
        RemotingConfiguration,
        SerializationFormatter,
        SkipVerification,
        UnmanagedCode,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum UIPermissionClipboard
    {
        AllClipboard,
        NoClipboard,
        OwnClipboard,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum UIPermissionWindow
    {
        AllWindows,
        NoWindows,
        SafeSubWindows,
        SafeTopLevelWindows,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public sealed class KeyContainerPermissionAccessEntryCollection: ICollection
    {
        public int Count { get; }
        public bool IsSynchronized { get; }
        public object SyncRoot { get; }
        public KeyContainerPermissionAccessEntry this[int index] { get; }
        public int Add(KeyContainerPermissionAccessEntry accessEntry);
        public void Clear();
        public void CopyTo(KeyContainerPermissionAccessEntry[] array, int index);
        public KeyContainerPermissionAccessEntryEnumerator GetEnumerator();
        public int IndexOf(KeyContainerPermissionAccessEntry accessEntry);
        public void Remove(KeyContainerPermissionAccessEntry accessEntry);
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class CodeAccessSecurityAttribute: SecurityAttribute, _Attribute
    {
        protected CodeAccessSecurityAttribute(SecurityAction action);
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class EnvironmentPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public EnvironmentPermissionAttribute(SecurityAction action);
        public string All { get; set; }
        public string Read { get; set; }
        public string Write { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class FileDialogPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public FileDialogPermissionAttribute(SecurityAction action);
        public bool Open { get; set; }
        public bool Save { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class FileIOPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public FileIOPermissionAttribute(SecurityAction action);
        public string All { get; set; }
        public FileIOPermissionAccess AllFiles { get; set; }
        public FileIOPermissionAccess AllLocalFiles { get; set; }
        public string Append { get; set; }
        public string ChangeAccessControl { get; set; }
        public string PathDiscovery { get; set; }
        public string Read { get; set; }
        public string ViewAccessControl { get; set; }
        public string ViewAndModify { get; set; }
        public string Write { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class GacIdentityPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public GacIdentityPermissionAttribute(SecurityAction action);
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class HostProtectionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public HostProtectionAttribute();
        public HostProtectionAttribute(SecurityAction action);
        public bool ExternalProcessMgmt { get; set; }
        public bool ExternalThreading { get; set; }
        public bool MayLeakOnAbort { get; set; }
        public HostProtectionResource Resources { get; set; }
        public bool SecurityInfrastructure { get; set; }
        public bool SelfAffectingProcessMgmt { get; set; }
        public bool SelfAffectingThreading { get; set; }
        public bool SharedState { get; set; }
        public bool Synchronization { get; set; }
        public bool UI { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class IsolatedStorageFilePermissionAttribute: IsolatedStoragePermissionAttribute, _Attribute
    {
        public IsolatedStorageFilePermissionAttribute(SecurityAction action);
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public abstract class IsolatedStoragePermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        protected IsolatedStoragePermissionAttribute(SecurityAction action);
        public IsolatedStorageContainment UsageAllowed { get; set; }
        public long UserQuota { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class KeyContainerPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public KeyContainerPermissionAttribute(SecurityAction action);
        public KeyContainerPermissionFlags Flags { get; set; }
        public string KeyContainerName { get; set; }
        public int KeySpec { get; set; }
        public string KeyStore { get; set; }
        public string ProviderName { get; set; }
        public int ProviderType { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class PermissionSetAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public PermissionSetAttribute(SecurityAction action);
        public string File { get; set; }
        public string Hex { get; set; }
        public string Name { get; set; }
        public bool UnicodeEncoded { get; set; }
        public string XML { get; set; }
        public override IPermission CreatePermission();
        public PermissionSet CreatePermissionSet();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class PrincipalPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public PrincipalPermissionAttribute(SecurityAction action);
        public bool Authenticated { get; set; }
        public string Name { get; set; }
        public string Role { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public sealed class PublisherIdentityPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public PublisherIdentityPermissionAttribute(SecurityAction action);
        public string CertFile { get; set; }
        public string SignedFile { get; set; }
        public string X509Certificate { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ReflectionPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public ReflectionPermissionAttribute(SecurityAction action);
        public ReflectionPermissionFlag Flags { get; set; }
        public bool MemberAccess { get; set; }
        public bool ReflectionEmit { get; set; }
        public bool TypeInformation { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class RegistryPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public RegistryPermissionAttribute(SecurityAction action);
        public string All { get; set; }
        public string ChangeAccessControl { get; set; }
        public string Create { get; set; }
        public string Read { get; set; }
        public string ViewAccessControl { get; set; }
        public string ViewAndModify { get; set; }
        public string Write { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [AttributeUsageAttribute(..)]
    public abstract class SecurityAttribute: Attribute, _Attribute
    {
        protected SecurityAttribute(SecurityAction action);
        public SecurityAction Action { get; set; }
        public bool Unrestricted { get; set; }
        public abstract IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SecurityPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public SecurityPermissionAttribute(SecurityAction action);
        public bool Assertion { get; set; }
        public bool BindingRedirects { get; set; }
        public bool ControlAppDomain { get; set; }
        public bool ControlDomainPolicy { get; set; }
        public bool ControlEvidence { get; set; }
        public bool ControlPolicy { get; set; }
        public bool ControlPrincipal { get; set; }
        public bool ControlThread { get; set; }
        public bool Execution { get; set; }
        public SecurityPermissionFlag Flags { get; set; }
        public bool Infrastructure { get; set; }
        public bool RemotingConfiguration { get; set; }
        public bool SerializationFormatter { get; set; }
        public bool SkipVerification { get; set; }
        public bool UnmanagedCode { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SiteIdentityPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public SiteIdentityPermissionAttribute(SecurityAction action);
        public string Site { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class StrongNameIdentityPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public StrongNameIdentityPermissionAttribute(SecurityAction action);
        public string Name { get; set; }
        public string PublicKey { get; set; }
        public string Version { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UIPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public UIPermissionAttribute(SecurityAction action);
        public UIPermissionClipboard Clipboard { get; set; }
        public UIPermissionWindow Window { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UrlIdentityPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public UrlIdentityPermissionAttribute(SecurityAction action);
        public string Url { get; set; }
        public override IPermission CreatePermission();
    }

    [SerializableAttribute(..)]
    [AttributeUsageAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ZoneIdentityPermissionAttribute: CodeAccessSecurityAttribute, _Attribute
    {
        public ZoneIdentityPermissionAttribute(SecurityAction action);
        public SecurityZone Zone { get; set; }
        public override IPermission CreatePermission();
    }

} 
namespace System.Security.Policy
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AllMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public AllMembershipCondition();
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ApplicationDirectory: IBuiltInEvidence
    {
        public ApplicationDirectory(string name);
        public string Directory { get; }
        public object Copy();
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ApplicationDirectoryMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public ApplicationDirectoryMembershipCondition();
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SecurityPermissionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ApplicationSecurityInfo
    {
        public ApplicationSecurityInfo(ActivationContext activationContext);
        public Evidence ApplicationEvidence { get; set; }
        public ApplicationId ApplicationId { get; set; }
        public PermissionSet DefaultRequestSet { get; set; }
        public ApplicationId DeploymentId { get; set; }
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class ApplicationSecurityManager
    {
        public static IApplicationTrustManager ApplicationTrustManager { get; }
        public static ApplicationTrustCollection UserApplicationTrusts { get; }
        public static bool DetermineApplicationTrust(ActivationContext activationContext, TrustManagerContext context);
    }

    [ComVisibleAttribute(..)]
    public sealed class ApplicationTrust: ISecurityEncodable
    {
        public ApplicationTrust();
        public ApplicationTrust(ApplicationIdentity applicationIdentity);
        public ApplicationIdentity ApplicationIdentity { get; set; }
        public PolicyStatement DefaultGrantSet { get; set; }
        public object ExtraInfo { get; set; }
        public bool IsApplicationTrustedToRun { get; set; }
        public bool Persist { get; set; }
        public void FromXml(SecurityElement element);
        public SecurityElement ToXml();
    }

    [ComVisibleAttribute(..)]
    public sealed class ApplicationTrustEnumerator: IEnumerator
    {
        public ApplicationTrust Current { get; }
        public bool MoveNext();
        public void Reset();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class CodeConnectAccess
    {
        public CodeConnectAccess(string allowScheme, int allowPort);
        public static readonly string AnyScheme;
        public static readonly int DefaultPort;
        public static readonly int OriginPort;
        public static readonly string OriginScheme;
        public int Port { get; }
        public string Scheme { get; }
        public static CodeConnectAccess CreateAnySchemeAccess(int allowPort);
        public static CodeConnectAccess CreateOriginSchemeAccess(int allowPort);
        public override bool Equals(object o);
        public override int GetHashCode();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class CodeGroup
    {
        protected CodeGroup(IMembershipCondition membershipCondition, PolicyStatement policy);
        public virtual string AttributeString { get; }
        public IList Children { get; set; }
        public string Description { get; set; }
        public IMembershipCondition MembershipCondition { get; set; }
        public abstract string MergeLogic { get; }
        public string Name { get; set; }
        public virtual string PermissionSetName { get; }
        public PolicyStatement PolicyStatement { get; set; }
        public void AddChild(CodeGroup group);
        public abstract CodeGroup Copy();
        protected virtual void CreateXml(SecurityElement element, PolicyLevel level);
        public bool Equals(CodeGroup cg, bool compareChildren);
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        protected virtual void ParseXml(SecurityElement e, PolicyLevel level);
        public void RemoveChild(CodeGroup group);
        public abstract PolicyStatement Resolve(Evidence evidence);
        public abstract CodeGroup ResolveMatchingCodeGroups(Evidence evidence);
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class FileCodeGroup: CodeGroup, IUnionSemanticCodeGroup
    {
        public FileCodeGroup(IMembershipCondition membershipCondition, FileIOPermissionAccess access);
        public override CodeGroup Copy();
        protected override void CreateXml(SecurityElement element, PolicyLevel level);
        public override bool Equals(object o);
        public override int GetHashCode();
        protected override void ParseXml(SecurityElement e, PolicyLevel level);
        public override PolicyStatement Resolve(Evidence evidence);
        public override CodeGroup ResolveMatchingCodeGroups(Evidence evidence);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class FirstMatchCodeGroup: CodeGroup
    {
        public FirstMatchCodeGroup(IMembershipCondition membershipCondition, PolicyStatement policy);
        public override CodeGroup Copy();
        public override PolicyStatement Resolve(Evidence evidence);
        public override CodeGroup ResolveMatchingCodeGroups(Evidence evidence);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class GacInstalled: IBuiltInEvidence, IIdentityPermissionFactory
    {
        public GacInstalled();
        public object Copy();
        public IPermission CreateIdentityPermission(Evidence evidence);
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class GacMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public GacMembershipCondition();
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Hash: IBuiltInEvidence, ISerializable
    {
        public Hash(Assembly assembly);
        public byte[] MD5 { get; }
        public byte[] SHA1 { get; }
        public static Hash CreateMD5(byte[] md5);
        public static Hash CreateSHA1(byte[] sha1);
        public byte[] GenerateHash(HashAlgorithm hashAlg);
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class HashMembershipCondition: IDeserializationCallback, IMembershipCondition, ISerializable
    {
        public HashMembershipCondition(HashAlgorithm hashAlg, byte[] value);
        public HashAlgorithm HashAlgorithm { get; set; }
        public byte[] HashValue { get; set; }
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [ComVisibleAttribute(..)]
    public interface IApplicationTrustManager: ISecurityEncodable
    {
        public ApplicationTrust DetermineApplicationTrust(ActivationContext activationContext, TrustManagerContext context);
    }

    [ComVisibleAttribute(..)]
    public interface IIdentityPermissionFactory
    {
        public IPermission CreateIdentityPermission(Evidence evidence);
    }

    [ComVisibleAttribute(..)]
    public interface IMembershipCondition: ISecurityEncodable, ISecurityPolicyEncodable
    {
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public bool Equals(object obj);
        public string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class NetCodeGroup: CodeGroup, IUnionSemanticCodeGroup
    {
        public NetCodeGroup(IMembershipCondition membershipCondition);
        public static readonly string AbsentOriginScheme;
        public static readonly string AnyOtherOriginScheme;
        public void AddConnectAccess(string originScheme, CodeConnectAccess connectAccess);
        public override CodeGroup Copy();
        protected override void CreateXml(SecurityElement element, PolicyLevel level);
        public override bool Equals(object o);
        public DictionaryEntry[] GetConnectAccessRules();
        public override int GetHashCode();
        protected override void ParseXml(SecurityElement e, PolicyLevel level);
        public void ResetConnectAccess();
        public override PolicyStatement Resolve(Evidence evidence);
        public override CodeGroup ResolveMatchingCodeGroups(Evidence evidence);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class PermissionRequestEvidence: IBuiltInEvidence
    {
        public PermissionRequestEvidence(PermissionSet request, PermissionSet optional, PermissionSet denied);
        public PermissionSet DeniedPermissions { get; }
        public PermissionSet OptionalPermissions { get; }
        public PermissionSet RequestedPermissions { get; }
        public PermissionRequestEvidence Copy();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class PolicyLevel
    {
        public IList FullTrustAssemblies { get; }
        public string Label { get; }
        public IList NamedPermissionSets { get; }
        public CodeGroup RootCodeGroup { get; set; }
        public string StoreLocation { get; }
        public PolicyLevelType Type { get; }
        public void AddFullTrustAssembly(StrongName sn);
        public void AddFullTrustAssembly(StrongNameMembershipCondition snMC);
        public void AddNamedPermissionSet(NamedPermissionSet permSet);
        public NamedPermissionSet ChangeNamedPermissionSet(string name, PermissionSet pSet);
        public static PolicyLevel CreateAppDomainLevel();
        public void FromXml(SecurityElement e);
        public NamedPermissionSet GetNamedPermissionSet(string name);
        public void Recover();
        public void RemoveFullTrustAssembly(StrongName sn);
        public void RemoveFullTrustAssembly(StrongNameMembershipCondition snMC);
        public NamedPermissionSet RemoveNamedPermissionSet(NamedPermissionSet permSet);
        public NamedPermissionSet RemoveNamedPermissionSet(string name);
        public void Reset();
        public PolicyStatement Resolve(Evidence evidence);
        public CodeGroup ResolveMatchingCodeGroups(Evidence evidence);
        public SecurityElement ToXml();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class PolicyStatement: ISecurityEncodable, ISecurityPolicyEncodable
    {
        public PolicyStatement(PermissionSet permSet);
        public PolicyStatement(PermissionSet permSet, PolicyStatementAttribute attributes);
        public PolicyStatementAttribute Attributes { get; set; }
        public string AttributeString { get; }
        public PermissionSet PermissionSet { get; set; }
        public PolicyStatement Copy();
        public override bool Equals(object obj);
        public void FromXml(SecurityElement et);
        public void FromXml(SecurityElement et, PolicyLevel level);
        public override int GetHashCode();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Publisher: IBuiltInEvidence, IIdentityPermissionFactory
    {
        public Publisher(X509Certificate cert);
        public X509Certificate Certificate { get; }
        public object Copy();
        public IPermission CreateIdentityPermission(Evidence evidence);
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class PublisherMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public PublisherMembershipCondition(X509Certificate certificate);
        public X509Certificate Certificate { get; set; }
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Site: IBuiltInEvidence, IIdentityPermissionFactory
    {
        public Site(string name);
        public string Name { get; }
        public object Copy();
        public static Site CreateFromUrl(string url);
        public IPermission CreateIdentityPermission(Evidence evidence);
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class SiteMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public SiteMembershipCondition(string site);
        public string Site { get; set; }
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class StrongName: IBuiltInEvidence, IIdentityPermissionFactory
    {
        public StrongName(StrongNamePublicKeyBlob blob, string name, Version version);
        public string Name { get; }
        public StrongNamePublicKeyBlob PublicKey { get; }
        public Version Version { get; }
        public object Copy();
        public IPermission CreateIdentityPermission(Evidence evidence);
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class StrongNameMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public StrongNameMembershipCondition(StrongNamePublicKeyBlob blob, string name, Version version);
        public string Name { get; set; }
        public StrongNamePublicKeyBlob PublicKey { get; set; }
        public Version Version { get; set; }
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [ComVisibleAttribute(..)]
    public class TrustManagerContext
    {
        public TrustManagerContext();
        public TrustManagerContext(TrustManagerUIContext uiContext);
        public virtual bool IgnorePersistedDecision { get; set; }
        public virtual bool KeepAlive { get; set; }
        public virtual bool NoPrompt { get; set; }
        public virtual bool Persist { get; set; }
        public virtual ApplicationIdentity PreviousApplicationIdentity { get; set; }
        public virtual TrustManagerUIContext UIContext { get; set; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UnionCodeGroup: CodeGroup, IUnionSemanticCodeGroup
    {
        public UnionCodeGroup(IMembershipCondition membershipCondition, PolicyStatement policy);
        public override CodeGroup Copy();
        public override PolicyStatement Resolve(Evidence evidence);
        public override CodeGroup ResolveMatchingCodeGroups(Evidence evidence);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Url: IBuiltInEvidence, IIdentityPermissionFactory
    {
        public Url(string name);
        public string Value { get; }
        public object Copy();
        public IPermission CreateIdentityPermission(Evidence evidence);
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class UrlMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public UrlMembershipCondition(string url);
        public string Url { get; set; }
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Zone: IBuiltInEvidence, IIdentityPermissionFactory
    {
        public Zone(SecurityZone zone);
        public SecurityZone SecurityZone { get; }
        public object Copy();
        public static Zone CreateFromUrl(string url);
        public IPermission CreateIdentityPermission(Evidence evidence);
        public override bool Equals(object o);
        public override int GetHashCode();
        public override string ToString();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ZoneMembershipCondition: IConstantMembershipCondition, IMembershipCondition
    {
        public ZoneMembershipCondition(SecurityZone zone);
        public SecurityZone SecurityZone { get; set; }
        public bool Check(Evidence evidence);
        public IMembershipCondition Copy();
        public override bool Equals(object o);
        public void FromXml(SecurityElement e);
        public void FromXml(SecurityElement e, PolicyLevel level);
        public override int GetHashCode();
        public override string ToString();
        public SecurityElement ToXml();
        public SecurityElement ToXml(PolicyLevel level);
    }

    [ComVisibleAttribute(..)]
    public enum ApplicationVersionMatch
    {
        MatchAllVersions,
        MatchExactVersion,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PolicyStatementAttribute
    {
        All,
        Exclusive,
        LevelFinal,
        Nothing,
    }

    [ComVisibleAttribute(..)]
    public enum TrustManagerUIContext
    {
        Install,
        Run,
        Upgrade,
    }

    [SecurityPermissionAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ApplicationTrustCollection: ICollection
    {
        public ApplicationTrustCollection();
        public int Count { get; }
        public bool IsSynchronized { get; }
        public object SyncRoot { get; }
        public ApplicationTrust this[int index] { get; }
        public ApplicationTrust this[string appFullName] { get; }
        public int Add(ApplicationTrust trust);
        public void AddRange(ApplicationTrust[] trusts);
        public void AddRange(ApplicationTrustCollection trusts);
        public void Clear();
        public void CopyTo(ApplicationTrust[] array, int index);
        public ApplicationTrustCollection Find(ApplicationIdentity applicationIdentity, ApplicationVersionMatch versionMatch);
        public ApplicationTrustEnumerator GetEnumerator();
        public void Remove(ApplicationIdentity applicationIdentity, ApplicationVersionMatch versionMatch);
        public void Remove(ApplicationTrust trust);
        public void RemoveRange(ApplicationTrust[] trusts);
        public void RemoveRange(ApplicationTrustCollection trusts);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Evidence: ICollection
    {
        public Evidence();
        public Evidence(Evidence evidence);
        public Evidence(object[] hostEvidence, object[] assemblyEvidence);
        public int Count { get; }
        public bool IsReadOnly { get; }
        public bool IsSynchronized { get; }
        public bool Locked { get; set; }
        public object SyncRoot { get; }
        public void AddAssembly(object id);
        public void AddHost(object id);
        public void Clear();
        public void CopyTo(Array array, int index);
        public override bool Equals(object obj);
        public IEnumerator GetAssemblyEnumerator();
        public IEnumerator GetEnumerator();
        public override int GetHashCode();
        public IEnumerator GetHostEnumerator();
        public void Merge(Evidence evidence);
        public void RemoveType(Type t);
    }

    [ComVisibleAttribute(..)]
    public class ProvideAssemblyEvidenceEventArgs: EventArgs
    {
        public ProvideAssemblyEvidenceEventArgs(Assembly assembly, Evidence evidence);
        public Assembly Assembly { get; }
        public Evidence Evidence { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class PolicyException: SystemException, _Exception, ISerializable
    {
        public PolicyException();
        protected PolicyException(SerializationInfo info, StreamingContext context);
        public PolicyException(string message);
        public PolicyException(string message, Exception exception);
    }

} 
namespace System.Security.Principal
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class GenericIdentity: IIdentity
    {
        public GenericIdentity(string name);
        public GenericIdentity(string name, string type);
        public virtual string AuthenticationType { get; }
        public virtual bool IsAuthenticated { get; }
        public virtual string Name { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class GenericPrincipal: IPrincipal
    {
        public GenericPrincipal(IIdentity identity, string[] roles);
        public virtual IIdentity Identity { get; }
        public virtual bool IsInRole(string role);
    }

    [ComVisibleAttribute(..)]
    public abstract class IdentityReference
    {
        public abstract string Value { get; }
        public abstract override bool Equals(object o);
        public abstract override int GetHashCode();
        public abstract bool IsValidTargetType(Type targetType);
        public abstract override string ToString();
        public abstract IdentityReference Translate(Type targetType);
        public static bool operator ==(IdentityReference left, IdentityReference right);
        public static bool operator !=(IdentityReference left, IdentityReference right);
    }

    [ComVisibleAttribute(..)]
    public interface IIdentity
    {
        public string AuthenticationType { get; }
        public bool IsAuthenticated { get; }
        public string Name { get; }
    }

    [ComVisibleAttribute(..)]
    public interface IPrincipal
    {
        public IIdentity Identity { get; }
        public bool IsInRole(string role);
    }

    [ComVisibleAttribute(..)]
    public sealed class NTAccount: IdentityReference
    {
        public NTAccount(string name);
        public NTAccount(string domainName, string accountName);
        public override bool Equals(object o);
        public override int GetHashCode();
        public override bool IsValidTargetType(Type targetType);
        public override string ToString();
        public override IdentityReference Translate(Type targetType);
        public static bool operator ==(NTAccount left, NTAccount right);
        public static bool operator !=(NTAccount left, NTAccount right);
    }

    [ComVisibleAttribute(..)]
    public sealed class SecurityIdentifier: IdentityReference, IComparable
    {
        public SecurityIdentifier(byte[] binaryForm, int offset);
        public SecurityIdentifier(string sddlForm);
        public SecurityIdentifier(WellKnownSidType sidType, SecurityIdentifier domainSid);
        public static readonly int MaxBinaryLength;
        public static readonly int MinBinaryLength;
        public SecurityIdentifier AccountDomainSid { get; }
        public int BinaryLength { get; }
        public int CompareTo(SecurityIdentifier sid);
        public override bool Equals(object o);
        public bool Equals(SecurityIdentifier sid);
        public void GetBinaryForm(byte[] binaryForm, int offset);
        public override int GetHashCode();
        public bool IsAccountSid();
        public bool IsEqualDomainSid(SecurityIdentifier sid);
        public override bool IsValidTargetType(Type targetType);
        public bool IsWellKnown(WellKnownSidType type);
        public override string ToString();
        public override IdentityReference Translate(Type targetType);
        public static bool operator ==(SecurityIdentifier left, SecurityIdentifier right);
        public static bool operator !=(SecurityIdentifier left, SecurityIdentifier right);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class WindowsIdentity: IDeserializationCallback, IDisposable, IIdentity, ISerializable
    {
        public WindowsIdentity(IntPtr userToken);
        public WindowsIdentity(IntPtr userToken, string type);
        public WindowsIdentity(IntPtr userToken, string type, WindowsAccountType acctType);
        public WindowsIdentity(IntPtr userToken, string type, WindowsAccountType acctType, bool isAuthenticated);
        public WindowsIdentity(SerializationInfo info, StreamingContext context);
        public WindowsIdentity(string sUserPrincipalName);
        public WindowsIdentity(string sUserPrincipalName, string type);
        public string AuthenticationType { get; }
        public IdentityReferenceCollection Groups { get; }
        public TokenImpersonationLevel ImpersonationLevel { get; }
        public virtual bool IsAnonymous { get; }
        public virtual bool IsAuthenticated { get; }
        public virtual bool IsGuest { get; }
        public virtual bool IsSystem { get; }
        public virtual string Name { get; }
        public SecurityIdentifier Owner { get; }
        public virtual IntPtr Token { get; }
        public SecurityIdentifier User { get; }
        public void Dispose();
        protected virtual void Dispose(bool disposing);
        public static WindowsIdentity GetAnonymous();
        public static WindowsIdentity GetCurrent();
        public static WindowsIdentity GetCurrent(bool ifImpersonating);
        public static WindowsIdentity GetCurrent(TokenAccessLevels desiredAccess);
        public virtual WindowsImpersonationContext Impersonate();
        public static WindowsImpersonationContext Impersonate(IntPtr userToken);
    }

    [ComVisibleAttribute(..)]
    public class WindowsImpersonationContext: IDisposable
    {
        public void Dispose();
        protected virtual void Dispose(bool disposing);
        public void Undo();
    }

    [HostProtectionAttribute(..)]
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class WindowsPrincipal: IPrincipal
    {
        public WindowsPrincipal(WindowsIdentity ntIdentity);
        public virtual IIdentity Identity { get; }
        public virtual bool IsInRole(int rid);
        public virtual bool IsInRole(SecurityIdentifier sid);
        public virtual bool IsInRole(string role);
        public virtual bool IsInRole(WindowsBuiltInRole role);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum PrincipalPolicy
    {
        NoPrincipal,
        UnauthenticatedPrincipal,
        WindowsPrincipal,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    [FlagsAttribute(..)]
    public enum TokenAccessLevels
    {
        AdjustDefault,
        AdjustGroups,
        AdjustPrivileges,
        AdjustSessionId,
        AllAccess,
        AssignPrimary,
        Duplicate,
        Impersonate,
        MaximumAllowed,
        Query,
        QuerySource,
        Read,
        Write,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum TokenImpersonationLevel
    {
        Anonymous,
        Delegation,
        Identification,
        Impersonation,
        None,
    }

    [ComVisibleAttribute(..)]
    public enum WellKnownSidType
    {
        AccountAdministratorSid,
        AccountCertAdminsSid,
        AccountComputersSid,
        AccountControllersSid,
        AccountDomainAdminsSid,
        AccountDomainGuestsSid,
        AccountDomainUsersSid,
        AccountEnterpriseAdminsSid,
        AccountGuestSid,
        AccountKrbtgtSid,
        AccountPolicyAdminsSid,
        AccountRasAndIasServersSid,
        AccountSchemaAdminsSid,
        AnonymousSid,
        AuthenticatedUserSid,
        BatchSid,
        BuiltinAccountOperatorsSid,
        BuiltinAdministratorsSid,
        BuiltinAuthorizationAccessSid,
        BuiltinBackupOperatorsSid,
        BuiltinDomainSid,
        BuiltinGuestsSid,
        BuiltinIncomingForestTrustBuildersSid,
        BuiltinNetworkConfigurationOperatorsSid,
        BuiltinPerformanceLoggingUsersSid,
        BuiltinPerformanceMonitoringUsersSid,
        BuiltinPowerUsersSid,
        BuiltinPreWindows2000CompatibleAccessSid,
        BuiltinPrintOperatorsSid,
        BuiltinRemoteDesktopUsersSid,
        BuiltinReplicatorSid,
        BuiltinSystemOperatorsSid,
        BuiltinUsersSid,
        CreatorGroupServerSid,
        CreatorGroupSid,
        CreatorOwnerServerSid,
        CreatorOwnerSid,
        DialupSid,
        DigestAuthenticationSid,
        EnterpriseControllersSid,
        InteractiveSid,
        LocalServiceSid,
        LocalSid,
        LocalSystemSid,
        LogonIdsSid,
        MaxDefined,
        NetworkServiceSid,
        NetworkSid,
        NTAuthoritySid,
        NtlmAuthenticationSid,
        NullSid,
        OtherOrganizationSid,
        ProxySid,
        RemoteLogonIdSid,
        RestrictedCodeSid,
        SChannelAuthenticationSid,
        SelfSid,
        ServiceSid,
        TerminalServerSid,
        ThisOrganizationSid,
        WinBuiltinTerminalServerLicenseServersSid,
        WorldSid,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum WindowsAccountType
    {
        Anonymous,
        Guest,
        Normal,
        System,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum WindowsBuiltInRole
    {
        AccountOperator,
        Administrator,
        BackupOperator,
        Guest,
        PowerUser,
        PrintOperator,
        Replicator,
        SystemOperator,
        User,
    }

    [ComVisibleAttribute(..)]
    [DefaultMemberAttribute(..)]
    public class IdentityReferenceCollection: ICollection
    {
        public IdentityReferenceCollection();
        public IdentityReferenceCollection(int capacity);
        public int Count { get; }
        public bool IsReadOnly { get; }
        public IdentityReference this[int index] { get; set; }
        public void Add(IdentityReference identity);
        public void Clear();
        public bool Contains(IdentityReference identity);
        public void CopyTo(IdentityReference[] array, int offset);
        public IEnumerator<IdentityReference> GetEnumerator();
        public bool Remove(IdentityReference identity);
        public IdentityReferenceCollection Translate(Type targetType);
        public IdentityReferenceCollection Translate(Type targetType, bool forceSuccess);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class IdentityNotMappedException: SystemException, _Exception, ISerializable
    {
        public IdentityNotMappedException();
        public IdentityNotMappedException(string message);
        public IdentityNotMappedException(string message, Exception inner);
        public IdentityReferenceCollection UnmappedIdentities { get; }
        public override void GetObjectData(SerializationInfo serializationInfo, StreamingContext streamingContext);
    }

} 
namespace System.Text
{
    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ASCIIEncoding: Encoding, ICloneable
    {
        public ASCIIEncoding();
        public override int GetByteCount(char* chars, int count);
        public override int GetByteCount(char[] chars, int index, int count);
        public override int GetByteCount(string chars);
        public override int GetBytes(char* chars, int charCount, byte* bytes, int byteCount);
        public override int GetBytes(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetBytes(string chars, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetCharCount(byte* bytes, int count);
        public override int GetCharCount(byte[] bytes, int index, int count);
        public override int GetChars(byte* bytes, int byteCount, char* chars, int charCount);
        public override int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex);
        public override Decoder GetDecoder();
        public override Encoder GetEncoder();
        public override int GetMaxByteCount(int charCount);
        public override int GetMaxCharCount(int byteCount);
        public override string GetString(byte[] bytes, int byteIndex, int byteCount);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Decoder
    {
        protected Decoder();
        public DecoderFallback Fallback { get; set; }
        public DecoderFallbackBuffer FallbackBuffer { get; }
        public virtual void Convert(byte* bytes, int byteCount, char* chars, int charCount, bool flush, ref int bytesUsed, ref int charsUsed, ref bool completed);
        public virtual void Convert(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex, int charCount, bool flush, ref int bytesUsed, ref int charsUsed, ref bool completed);
        public virtual int GetCharCount(byte* bytes, int count, bool flush);
        public abstract int GetCharCount(byte[] bytes, int index, int count);
        public virtual int GetCharCount(byte[] bytes, int index, int count, bool flush);
        public virtual int GetChars(byte* bytes, int byteCount, char* chars, int charCount, bool flush);
        public abstract int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex);
        public virtual int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex, bool flush);
        public virtual void Reset();
    }

    [SerializableAttribute(..)]
    public sealed class DecoderExceptionFallback: DecoderFallback
    {
        public DecoderExceptionFallback();
        public override DecoderFallbackBuffer CreateFallbackBuffer();
        public override bool Equals(object value);
        public override int GetHashCode();
    }

    public sealed class DecoderExceptionFallbackBuffer: DecoderFallbackBuffer
    {
        public DecoderExceptionFallbackBuffer();
        public override bool Fallback(byte[] bytesUnknown, int index);
        public override char GetNextChar();
        public override bool MovePrevious();
    }

    [SerializableAttribute(..)]
    public abstract class DecoderFallback
    {
        protected DecoderFallback();
        public static DecoderFallback ExceptionFallback { get; }
        public abstract int MaxCharCount { get; }
        public static DecoderFallback ReplacementFallback { get; }
        public abstract DecoderFallbackBuffer CreateFallbackBuffer();
    }

    public abstract class DecoderFallbackBuffer
    {
        protected DecoderFallbackBuffer();
        public abstract int Remaining { get; }
        public abstract bool Fallback(byte[] bytesUnknown, int index);
        public abstract char GetNextChar();
        public abstract bool MovePrevious();
        public virtual void Reset();
    }

    [SerializableAttribute(..)]
    public sealed class DecoderReplacementFallback: DecoderFallback
    {
        public DecoderReplacementFallback();
        public DecoderReplacementFallback(string replacement);
        public string DefaultString { get; }
        public override DecoderFallbackBuffer CreateFallbackBuffer();
        public override bool Equals(object value);
        public override int GetHashCode();
    }

    public sealed class DecoderReplacementFallbackBuffer: DecoderFallbackBuffer
    {
        public DecoderReplacementFallbackBuffer(DecoderReplacementFallback fallback);
        public override bool Fallback(byte[] bytesUnknown, int index);
        public override char GetNextChar();
        public override bool MovePrevious();
        public override void Reset();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Encoder
    {
        protected Encoder();
        public EncoderFallback Fallback { get; set; }
        public EncoderFallbackBuffer FallbackBuffer { get; }
        public virtual void Convert(char* chars, int charCount, byte* bytes, int byteCount, bool flush, ref int charsUsed, ref int bytesUsed, ref bool completed);
        public virtual void Convert(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex, int byteCount, bool flush, ref int charsUsed, ref int bytesUsed, ref bool completed);
        public virtual int GetByteCount(char* chars, int count, bool flush);
        public abstract int GetByteCount(char[] chars, int index, int count, bool flush);
        public virtual int GetBytes(char* chars, int charCount, byte* bytes, int byteCount, bool flush);
        public abstract int GetBytes(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex, bool flush);
        public virtual void Reset();
    }

    [SerializableAttribute(..)]
    public sealed class EncoderExceptionFallback: EncoderFallback
    {
        public EncoderExceptionFallback();
        public override EncoderFallbackBuffer CreateFallbackBuffer();
        public override bool Equals(object value);
        public override int GetHashCode();
    }

    public sealed class EncoderExceptionFallbackBuffer: EncoderFallbackBuffer
    {
        public EncoderExceptionFallbackBuffer();
        public override bool Fallback(char charUnknownHigh, char charUnknownLow, int index);
        public override bool Fallback(char charUnknown, int index);
        public override char GetNextChar();
        public override bool MovePrevious();
    }

    [SerializableAttribute(..)]
    public abstract class EncoderFallback
    {
        protected EncoderFallback();
        public static EncoderFallback ExceptionFallback { get; }
        public abstract int MaxCharCount { get; }
        public static EncoderFallback ReplacementFallback { get; }
        public abstract EncoderFallbackBuffer CreateFallbackBuffer();
    }

    public abstract class EncoderFallbackBuffer
    {
        protected EncoderFallbackBuffer();
        public abstract int Remaining { get; }
        public abstract bool Fallback(char charUnknownHigh, char charUnknownLow, int index);
        public abstract bool Fallback(char charUnknown, int index);
        public abstract char GetNextChar();
        public abstract bool MovePrevious();
        public virtual void Reset();
    }

    [SerializableAttribute(..)]
    public sealed class EncoderReplacementFallback: EncoderFallback
    {
        public EncoderReplacementFallback();
        public EncoderReplacementFallback(string replacement);
        public string DefaultString { get; }
        public override EncoderFallbackBuffer CreateFallbackBuffer();
        public override bool Equals(object value);
        public override int GetHashCode();
    }

    public sealed class EncoderReplacementFallbackBuffer: EncoderFallbackBuffer
    {
        public EncoderReplacementFallbackBuffer(EncoderReplacementFallback fallback);
        public override bool Fallback(char charUnknownHigh, char charUnknownLow, int index);
        public override bool Fallback(char charUnknown, int index);
        public override char GetNextChar();
        public override bool MovePrevious();
        public override void Reset();
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract class Encoding: ICloneable
    {
        protected Encoding();
        protected Encoding(int codePage);
        public static Encoding ASCII { get; }
        public static Encoding BigEndianUnicode { get; }
        public virtual string BodyName { get; }
        public virtual int CodePage { get; }
        public DecoderFallback DecoderFallback { get; set; }
        public static Encoding Default { get; }
        public EncoderFallback EncoderFallback { get; set; }
        public virtual string EncodingName { get; }
        public virtual string HeaderName { get; }
        public virtual bool IsBrowserDisplay { get; }
        public virtual bool IsBrowserSave { get; }
        public virtual bool IsMailNewsDisplay { get; }
        public virtual bool IsMailNewsSave { get; }
        public bool IsReadOnly { get; }
        public virtual bool IsSingleByte { get; }
        public static Encoding Unicode { get; }
        public static Encoding UTF32 { get; }
        public static Encoding UTF7 { get; }
        public static Encoding UTF8 { get; }
        public virtual string WebName { get; }
        public virtual int WindowsCodePage { get; }
        public virtual object Clone();
        public static byte[] Convert(Encoding srcEncoding, Encoding dstEncoding, byte[] bytes);
        public static byte[] Convert(Encoding srcEncoding, Encoding dstEncoding, byte[] bytes, int index, int count);
        public override bool Equals(object value);
        public virtual int GetByteCount(char* chars, int count);
        public virtual int GetByteCount(char[] chars);
        public abstract int GetByteCount(char[] chars, int index, int count);
        public virtual int GetByteCount(string s);
        public virtual int GetBytes(char* chars, int charCount, byte* bytes, int byteCount);
        public virtual byte[] GetBytes(char[] chars);
        public virtual byte[] GetBytes(char[] chars, int index, int count);
        public abstract int GetBytes(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public virtual byte[] GetBytes(string s);
        public virtual int GetBytes(string s, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public virtual int GetCharCount(byte* bytes, int count);
        public virtual int GetCharCount(byte[] bytes);
        public abstract int GetCharCount(byte[] bytes, int index, int count);
        public virtual int GetChars(byte* bytes, int byteCount, char* chars, int charCount);
        public virtual char[] GetChars(byte[] bytes);
        public virtual char[] GetChars(byte[] bytes, int index, int count);
        public abstract int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex);
        public virtual Decoder GetDecoder();
        public virtual Encoder GetEncoder();
        public static Encoding GetEncoding(int codepage);
        public static Encoding GetEncoding(int codepage, EncoderFallback encoderFallback, DecoderFallback decoderFallback);
        public static Encoding GetEncoding(string name);
        public static Encoding GetEncoding(string name, EncoderFallback encoderFallback, DecoderFallback decoderFallback);
        public static EncodingInfo[] GetEncodings();
        public override int GetHashCode();
        public abstract int GetMaxByteCount(int charCount);
        public abstract int GetMaxCharCount(int byteCount);
        public virtual byte[] GetPreamble();
        public virtual string GetString(byte[] bytes);
        public virtual string GetString(byte[] bytes, int index, int count);
        public bool IsAlwaysNormalized();
        public virtual bool IsAlwaysNormalized(NormalizationForm form);
    }

    [SerializableAttribute(..)]
    public sealed class EncodingInfo
    {
        public int CodePage { get; }
        public string DisplayName { get; }
        public string Name { get; }
        public override bool Equals(object value);
        public Encoding GetEncoding();
        public override int GetHashCode();
    }

    [SerializableAttribute(..)]
    [DefaultMemberAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class StringBuilder: ISerializable
    {
        public StringBuilder();
        public StringBuilder(int capacity);
        public StringBuilder(int capacity, int maxCapacity);
        public StringBuilder(string value);
        public StringBuilder(string value, int capacity);
        public StringBuilder(string value, int startIndex, int length, int capacity);
        public int Capacity { get; set; }
        public int Length { get; set; }
        public int MaxCapacity { get; }
        public char this[int index] { get; set; }
        public StringBuilder Append(bool value);
        public StringBuilder Append(byte value);
        public StringBuilder Append(char value);
        public StringBuilder Append(char value, int repeatCount);
        public StringBuilder Append(char[] value);
        public StringBuilder Append(char[] value, int startIndex, int charCount);
        public StringBuilder Append(decimal value);
        public StringBuilder Append(double value);
        public StringBuilder Append(float value);
        public StringBuilder Append(int value);
        public StringBuilder Append(long value);
        public StringBuilder Append(object value);
        public StringBuilder Append(sbyte value);
        public StringBuilder Append(short value);
        public StringBuilder Append(string value);
        public StringBuilder Append(string value, int startIndex, int count);
        public StringBuilder Append(uint value);
        public StringBuilder Append(ulong value);
        public StringBuilder Append(ushort value);
        public StringBuilder AppendFormat(IFormatProvider provider, string format, params object[] args);
        public StringBuilder AppendFormat(string format, object arg0);
        public StringBuilder AppendFormat(string format, object arg0, object arg1);
        public StringBuilder AppendFormat(string format, object arg0, object arg1, object arg2);
        public StringBuilder AppendFormat(string format, params object[] args);
        public StringBuilder AppendLine();
        public StringBuilder AppendLine(string value);
        public void CopyTo(int sourceIndex, char[] destination, int destinationIndex, int count);
        public int EnsureCapacity(int capacity);
        public bool Equals(StringBuilder sb);
        public StringBuilder Insert(int index, bool value);
        public StringBuilder Insert(int index, byte value);
        public StringBuilder Insert(int index, char value);
        public StringBuilder Insert(int index, char[] value);
        public StringBuilder Insert(int index, char[] value, int startIndex, int charCount);
        public StringBuilder Insert(int index, decimal value);
        public StringBuilder Insert(int index, double value);
        public StringBuilder Insert(int index, float value);
        public StringBuilder Insert(int index, int value);
        public StringBuilder Insert(int index, long value);
        public StringBuilder Insert(int index, object value);
        public StringBuilder Insert(int index, sbyte value);
        public StringBuilder Insert(int index, short value);
        public StringBuilder Insert(int index, string value);
        public StringBuilder Insert(int index, string value, int count);
        public StringBuilder Insert(int index, uint value);
        public StringBuilder Insert(int index, ulong value);
        public StringBuilder Insert(int index, ushort value);
        public StringBuilder Remove(int startIndex, int length);
        public StringBuilder Replace(char oldChar, char newChar);
        public StringBuilder Replace(char oldChar, char newChar, int startIndex, int count);
        public StringBuilder Replace(string oldValue, string newValue);
        public StringBuilder Replace(string oldValue, string newValue, int startIndex, int count);
        public override string ToString();
        public string ToString(int startIndex, int length);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class UnicodeEncoding: Encoding, ICloneable
    {
        public UnicodeEncoding();
        public UnicodeEncoding(bool bigEndian, bool byteOrderMark);
        public UnicodeEncoding(bool bigEndian, bool byteOrderMark, bool throwOnInvalidBytes);
        public const int CharSize;
        public override bool Equals(object value);
        public override int GetByteCount(char* chars, int count);
        public override int GetByteCount(char[] chars, int index, int count);
        public override int GetByteCount(string s);
        public override int GetBytes(char* chars, int charCount, byte* bytes, int byteCount);
        public override int GetBytes(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetBytes(string s, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetCharCount(byte* bytes, int count);
        public override int GetCharCount(byte[] bytes, int index, int count);
        public override int GetChars(byte* bytes, int byteCount, char* chars, int charCount);
        public override int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex);
        public override Decoder GetDecoder();
        public override Encoder GetEncoder();
        public override int GetHashCode();
        public override int GetMaxByteCount(int charCount);
        public override int GetMaxCharCount(int byteCount);
        public override byte[] GetPreamble();
        public override string GetString(byte[] bytes, int index, int count);
    }

    [SerializableAttribute(..)]
    public sealed class UTF32Encoding: Encoding, ICloneable
    {
        public UTF32Encoding();
        public UTF32Encoding(bool bigEndian, bool byteOrderMark);
        public UTF32Encoding(bool bigEndian, bool byteOrderMark, bool throwOnInvalidCharacters);
        public override bool Equals(object value);
        public override int GetByteCount(char* chars, int count);
        public override int GetByteCount(char[] chars, int index, int count);
        public override int GetByteCount(string s);
        public override int GetBytes(char* chars, int charCount, byte* bytes, int byteCount);
        public override int GetBytes(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetBytes(string s, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetCharCount(byte* bytes, int count);
        public override int GetCharCount(byte[] bytes, int index, int count);
        public override int GetChars(byte* bytes, int byteCount, char* chars, int charCount);
        public override int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex);
        public override Decoder GetDecoder();
        public override Encoder GetEncoder();
        public override int GetHashCode();
        public override int GetMaxByteCount(int charCount);
        public override int GetMaxCharCount(int byteCount);
        public override byte[] GetPreamble();
        public override string GetString(byte[] bytes, int index, int count);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class UTF7Encoding: Encoding, ICloneable
    {
        public UTF7Encoding();
        public UTF7Encoding(bool allowOptionals);
        public override bool Equals(object value);
        public override int GetByteCount(char* chars, int count);
        public override int GetByteCount(char[] chars, int index, int count);
        public override int GetByteCount(string s);
        public override int GetBytes(char* chars, int charCount, byte* bytes, int byteCount);
        public override int GetBytes(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetBytes(string s, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetCharCount(byte* bytes, int count);
        public override int GetCharCount(byte[] bytes, int index, int count);
        public override int GetChars(byte* bytes, int byteCount, char* chars, int charCount);
        public override int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex);
        public override Decoder GetDecoder();
        public override Encoder GetEncoder();
        public override int GetHashCode();
        public override int GetMaxByteCount(int charCount);
        public override int GetMaxCharCount(int byteCount);
        public override string GetString(byte[] bytes, int index, int count);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class UTF8Encoding: Encoding, ICloneable
    {
        public UTF8Encoding();
        public UTF8Encoding(bool encoderShouldEmitUTF8Identifier);
        public UTF8Encoding(bool encoderShouldEmitUTF8Identifier, bool throwOnInvalidBytes);
        public override bool Equals(object value);
        public override int GetByteCount(char* chars, int count);
        public override int GetByteCount(char[] chars, int index, int count);
        public override int GetByteCount(string chars);
        public override int GetBytes(char* chars, int charCount, byte* bytes, int byteCount);
        public override int GetBytes(char[] chars, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetBytes(string s, int charIndex, int charCount, byte[] bytes, int byteIndex);
        public override int GetCharCount(byte* bytes, int count);
        public override int GetCharCount(byte[] bytes, int index, int count);
        public override int GetChars(byte* bytes, int byteCount, char* chars, int charCount);
        public override int GetChars(byte[] bytes, int byteIndex, int byteCount, char[] chars, int charIndex);
        public override Decoder GetDecoder();
        public override Encoder GetEncoder();
        public override int GetHashCode();
        public override int GetMaxByteCount(int charCount);
        public override int GetMaxCharCount(int byteCount);
        public override byte[] GetPreamble();
        public override string GetString(byte[] bytes, int index, int count);
    }

    [ComVisibleAttribute(..)]
    public enum NormalizationForm
    {
        FormC,
        FormD,
        FormKC,
        FormKD,
    }

    [SerializableAttribute(..)]
    public sealed class DecoderFallbackException: ArgumentException, _Exception, ISerializable
    {
        public DecoderFallbackException();
        public DecoderFallbackException(string message);
        public DecoderFallbackException(string message, byte[] bytesUnknown, int index);
        public DecoderFallbackException(string message, Exception innerException);
        public byte[] BytesUnknown { get; }
        public int Index { get; }
    }

    [SerializableAttribute(..)]
    public sealed class EncoderFallbackException: ArgumentException, _Exception, ISerializable
    {
        public EncoderFallbackException();
        public EncoderFallbackException(string message);
        public EncoderFallbackException(string message, Exception innerException);
        public char CharUnknown { get; }
        public char CharUnknownHigh { get; }
        public char CharUnknownLow { get; }
        public int Index { get; }
        public bool IsUnknownSurrogate();
    }

} 
namespace System.Threading
{
    public struct AsyncFlowControl: IDisposable
    {
        public bool Equals(AsyncFlowControl obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public void Undo();
        public static bool operator ==(AsyncFlowControl a, AsyncFlowControl b);
        public static bool operator !=(AsyncFlowControl a, AsyncFlowControl b);
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class AutoResetEvent: EventWaitHandle, IDisposable
    {
        public AutoResetEvent(bool initialState);
    }

    [SerializableAttribute(..)]
    public sealed class CompressedStack: ISerializable
    {
        public static CompressedStack Capture();
        public CompressedStack CreateCopy();
        public static CompressedStack GetCompressedStack();
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public static void Run(CompressedStack compressedStack, ContextCallback callback, object state);
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    public class EventWaitHandle: WaitHandle, IDisposable
    {
        public EventWaitHandle(bool initialState, EventResetMode mode);
        public EventWaitHandle(bool initialState, EventResetMode mode, string name);
        public EventWaitHandle(bool initialState, EventResetMode mode, string name, ref bool createdNew);
        public EventWaitHandle(bool initialState, EventResetMode mode, string name, ref bool createdNew, EventWaitHandleSecurity eventSecurity);
        public EventWaitHandleSecurity GetAccessControl();
        public static EventWaitHandle OpenExisting(string name);
        public static EventWaitHandle OpenExisting(string name, EventWaitHandleRights rights);
        public bool Reset();
        public bool Set();
        public void SetAccessControl(EventWaitHandleSecurity eventSecurity);
    }

    [SerializableAttribute(..)]
    public sealed class ExecutionContext: ISerializable
    {
        public static ExecutionContext Capture();
        public ExecutionContext CreateCopy();
        public void GetObjectData(SerializationInfo info, StreamingContext context);
        public static bool IsFlowSuppressed();
        public static void RestoreFlow();
        public static void Run(ExecutionContext executionContext, ContextCallback callback, object state);
        public static AsyncFlowControl SuppressFlow();
    }

    public class HostExecutionContext
    {
        public HostExecutionContext();
        public HostExecutionContext(object state);
        public virtual HostExecutionContext CreateCopy();
    }

    public class HostExecutionContextManager
    {
        public HostExecutionContextManager();
        public virtual HostExecutionContext Capture();
        public virtual void Revert(object previousState);
        public virtual object SetHostExecutionContext(HostExecutionContext hostExecutionContext);
    }

    public abstract sealed class Interlocked
    {
        public static int Add(ref int location1, int value);
        public static long Add(ref long location1, long value);
        public static double CompareExchange(ref double location1, double value, double comparand);
        public static float CompareExchange(ref float location1, float value, float comparand);
        public static int CompareExchange(ref int location1, int value, int comparand);
        public static IntPtr CompareExchange(ref IntPtr location1, IntPtr value, IntPtr comparand);
        public static long CompareExchange(ref long location1, long value, long comparand);
        public static object CompareExchange(ref object location1, object value, object comparand);
        public static T CompareExchange<T>(ref T location1, T value, T comparand);
        public static int Decrement(ref int location);
        public static long Decrement(ref long location);
        public static double Exchange(ref double location1, double value);
        public static float Exchange(ref float location1, float value);
        public static int Exchange(ref int location1, int value);
        public static IntPtr Exchange(ref IntPtr location1, IntPtr value);
        public static long Exchange(ref long location1, long value);
        public static object Exchange(ref object location1, object value);
        public static T Exchange<T>(ref T location1, T value);
        public static int Increment(ref int location);
        public static long Increment(ref long location);
        public static long Read(ref long location);
    }

    [ComVisibleAttribute(..)]
    public struct LockCookie
    {
        public bool Equals(LockCookie obj);
        public override bool Equals(object obj);
        public override int GetHashCode();
        public static bool operator ==(LockCookie a, LockCookie b);
        public static bool operator !=(LockCookie a, LockCookie b);
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ManualResetEvent: EventWaitHandle, IDisposable
    {
        public ManualResetEvent(bool initialState);
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    public abstract sealed class Monitor
    {
        public static void Enter(object obj);
        public static void Exit(object obj);
        public static void Pulse(object obj);
        public static void PulseAll(object obj);
        public static bool TryEnter(object obj);
        public static bool TryEnter(object obj, int millisecondsTimeout);
        public static bool TryEnter(object obj, TimeSpan timeout);
        public static bool Wait(object obj);
        public static bool Wait(object obj, int millisecondsTimeout);
        public static bool Wait(object obj, int millisecondsTimeout, bool exitContext);
        public static bool Wait(object obj, TimeSpan timeout);
        public static bool Wait(object obj, TimeSpan timeout, bool exitContext);
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Mutex: WaitHandle, IDisposable
    {
        public Mutex();
        public Mutex(bool initiallyOwned);
        public Mutex(bool initiallyOwned, string name);
        public Mutex(bool initiallyOwned, string name, ref bool createdNew);
        public Mutex(bool initiallyOwned, string name, ref bool createdNew, MutexSecurity mutexSecurity);
        public MutexSecurity GetAccessControl();
        public static Mutex OpenExisting(string name);
        public static Mutex OpenExisting(string name, MutexRights rights);
        public void ReleaseMutex();
        public void SetAccessControl(MutexSecurity mutexSecurity);
    }

    [ComVisibleAttribute(..)]
    public struct NativeOverlapped
    {
        public IntPtr EventHandle;
        public IntPtr InternalHigh;
        public IntPtr InternalLow;
        public int OffsetHigh;
        public int OffsetLow;
    }

    [ComVisibleAttribute(..)]
    public class Overlapped
    {
        public Overlapped();
        public Overlapped(int offsetLo, int offsetHi, int hEvent, IAsyncResult ar);
        public Overlapped(int offsetLo, int offsetHi, IntPtr hEvent, IAsyncResult ar);
        public IAsyncResult AsyncResult { get; set; }
        public int EventHandle { get; set; }
        public IntPtr EventHandleIntPtr { get; set; }
        public int OffsetHigh { get; set; }
        public int OffsetLow { get; set; }
        public static void Free(NativeOverlapped* nativeOverlappedPtr);
        public NativeOverlapped* Pack(IOCompletionCallback iocb);
        public NativeOverlapped* Pack(IOCompletionCallback iocb, object userData);
        public static Overlapped Unpack(NativeOverlapped* nativeOverlappedPtr);
        public NativeOverlapped* UnsafePack(IOCompletionCallback iocb);
        public NativeOverlapped* UnsafePack(IOCompletionCallback iocb, object userData);
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ReaderWriterLock: CriticalFinalizerObject
    {
        public ReaderWriterLock();
        public bool IsReaderLockHeld { get; }
        public bool IsWriterLockHeld { get; }
        public int WriterSeqNum { get; }
        public void AcquireReaderLock(int millisecondsTimeout);
        public void AcquireReaderLock(TimeSpan timeout);
        public void AcquireWriterLock(int millisecondsTimeout);
        public void AcquireWriterLock(TimeSpan timeout);
        public bool AnyWritersSince(int seqNum);
        public void DowngradeFromWriterLock(ref LockCookie lockCookie);
        protected override void Finalize();
        public LockCookie ReleaseLock();
        public void ReleaseReaderLock();
        public void ReleaseWriterLock();
        public void RestoreLock(ref LockCookie lockCookie);
        public LockCookie UpgradeToWriterLock(int millisecondsTimeout);
        public LockCookie UpgradeToWriterLock(TimeSpan timeout);
    }

    [ComVisibleAttribute(..)]
    public sealed class RegisteredWaitHandle: MarshalByRefObject
    {
        public bool Unregister(WaitHandle waitObject);
    }

    [SecurityPermissionAttribute(..)]
    public class SynchronizationContext
    {
        public SynchronizationContext();
        public static SynchronizationContext Current { get; }
        public virtual SynchronizationContext CreateCopy();
        public bool IsWaitNotificationRequired();
        public virtual void OperationCompleted();
        public virtual void OperationStarted();
        public virtual void Post(SendOrPostCallback d, object state);
        public virtual void Send(SendOrPostCallback d, object state);
        public static void SetSynchronizationContext(SynchronizationContext syncContext);
        protected void SetWaitNotificationRequired();
        public virtual int Wait(IntPtr[] waitHandles, bool waitAll, int millisecondsTimeout);
        protected static int WaitHelper(IntPtr[] waitHandles, bool waitAll, int millisecondsTimeout);
    }

    [ComDefaultInterfaceAttribute(..)]
    [ClassInterfaceAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Thread: _Thread
    {
        public Thread(ParameterizedThreadStart start);
        public Thread(ParameterizedThreadStart start, int maxStackSize);
        public Thread(ThreadStart start);
        public Thread(ThreadStart start, int maxStackSize);
        public ApartmentState ApartmentState { get; set; }
        public static Context CurrentContext { get; }
        public CultureInfo CurrentCulture { get; set; }
        public static IPrincipal CurrentPrincipal { get; set; }
        public static Thread CurrentThread { get; }
        public CultureInfo CurrentUICulture { get; set; }
        public ExecutionContext ExecutionContext { get; }
        public bool IsAlive { get; }
        public bool IsBackground { get; set; }
        public bool IsThreadPoolThread { get; }
        public int ManagedThreadId { get; }
        public string Name { get; set; }
        public ThreadPriority Priority { get; set; }
        public ThreadState ThreadState { get; }
        public void Abort();
        public void Abort(object stateInfo);
        public static LocalDataStoreSlot AllocateDataSlot();
        public static LocalDataStoreSlot AllocateNamedDataSlot(string name);
        public static void BeginCriticalRegion();
        public static void BeginThreadAffinity();
        public static void EndCriticalRegion();
        public static void EndThreadAffinity();
        protected override void Finalize();
        public static void FreeNamedDataSlot(string name);
        public ApartmentState GetApartmentState();
        public CompressedStack GetCompressedStack();
        public static object GetData(LocalDataStoreSlot slot);
        public static AppDomain GetDomain();
        public static int GetDomainID();
        public override int GetHashCode();
        public static LocalDataStoreSlot GetNamedDataSlot(string name);
        public void Interrupt();
        public void Join();
        public bool Join(int millisecondsTimeout);
        public bool Join(TimeSpan timeout);
        public static void MemoryBarrier();
        public static void ResetAbort();
        public void Resume();
        public void SetApartmentState(ApartmentState state);
        public void SetCompressedStack(CompressedStack stack);
        public static void SetData(LocalDataStoreSlot slot, object data);
        public static void Sleep(int millisecondsTimeout);
        public static void Sleep(TimeSpan timeout);
        public static void SpinWait(int iterations);
        public void Start();
        public void Start(object parameter);
        public void Suspend();
        public bool TrySetApartmentState(ApartmentState state);
        public static byte VolatileRead(ref byte address);
        public static double VolatileRead(ref double address);
        public static float VolatileRead(ref float address);
        public static int VolatileRead(ref int address);
        public static IntPtr VolatileRead(ref IntPtr address);
        public static long VolatileRead(ref long address);
        public static object VolatileRead(ref object address);
        public static sbyte VolatileRead(ref sbyte address);
        public static short VolatileRead(ref short address);
        public static uint VolatileRead(ref uint address);
        public static UIntPtr VolatileRead(ref UIntPtr address);
        public static ulong VolatileRead(ref ulong address);
        public static ushort VolatileRead(ref ushort address);
        public static void VolatileWrite(ref byte address, byte value);
        public static void VolatileWrite(ref double address, double value);
        public static void VolatileWrite(ref float address, float value);
        public static void VolatileWrite(ref int address, int value);
        public static void VolatileWrite(ref IntPtr address, IntPtr value);
        public static void VolatileWrite(ref long address, long value);
        public static void VolatileWrite(ref object address, object value);
        public static void VolatileWrite(ref sbyte address, sbyte value);
        public static void VolatileWrite(ref short address, short value);
        public static void VolatileWrite(ref uint address, uint value);
        public static void VolatileWrite(ref UIntPtr address, UIntPtr value);
        public static void VolatileWrite(ref ulong address, ulong value);
        public static void VolatileWrite(ref ushort address, ushort value);
    }

    [HostProtectionAttribute(..)]
    public abstract sealed class ThreadPool
    {
        public static bool BindHandle(IntPtr osHandle);
        public static void GetAvailableThreads(ref int workerThreads, ref int completionPortThreads);
        public static void GetMaxThreads(ref int workerThreads, ref int completionPortThreads);
        public static void GetMinThreads(ref int workerThreads, ref int completionPortThreads);
        public static bool QueueUserWorkItem(WaitCallback callBack);
        public static bool QueueUserWorkItem(WaitCallback callBack, object state);
        public static RegisteredWaitHandle RegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, int millisecondsTimeOutInterval, bool executeOnlyOnce);
        public static RegisteredWaitHandle RegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, long millisecondsTimeOutInterval, bool executeOnlyOnce);
        public static RegisteredWaitHandle RegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, TimeSpan timeout, bool executeOnlyOnce);
        public static RegisteredWaitHandle RegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, uint millisecondsTimeOutInterval, bool executeOnlyOnce);
        public static bool SetMaxThreads(int workerThreads, int completionPortThreads);
        public static bool SetMinThreads(int workerThreads, int completionPortThreads);
        public static bool UnsafeQueueNativeOverlapped(NativeOverlapped* overlapped);
        public static bool UnsafeQueueUserWorkItem(WaitCallback callBack, object state);
        public static RegisteredWaitHandle UnsafeRegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, int millisecondsTimeOutInterval, bool executeOnlyOnce);
        public static RegisteredWaitHandle UnsafeRegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, long millisecondsTimeOutInterval, bool executeOnlyOnce);
        public static RegisteredWaitHandle UnsafeRegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, TimeSpan timeout, bool executeOnlyOnce);
        public static RegisteredWaitHandle UnsafeRegisterWaitForSingleObject(WaitHandle waitObject, WaitOrTimerCallback callBack, object state, uint millisecondsTimeOutInterval, bool executeOnlyOnce);
    }

    [ComVisibleAttribute(..)]
    public abstract sealed class Timeout
    {
        public const int Infinite;
    }

    [HostProtectionAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class Timer: MarshalByRefObject, IDisposable
    {
        public Timer(TimerCallback callback);
        public Timer(TimerCallback callback, object state, int dueTime, int period);
        public Timer(TimerCallback callback, object state, long dueTime, long period);
        public Timer(TimerCallback callback, object state, TimeSpan dueTime, TimeSpan period);
        public Timer(TimerCallback callback, object state, uint dueTime, uint period);
        public bool Change(int dueTime, int period);
        public bool Change(long dueTime, long period);
        public bool Change(TimeSpan dueTime, TimeSpan period);
        public bool Change(uint dueTime, uint period);
        public void Dispose();
        public bool Dispose(WaitHandle notifyObject);
    }

    [ComVisibleAttribute(..)]
    public abstract class WaitHandle: MarshalByRefObject, IDisposable
    {
        protected WaitHandle();
        protected static readonly IntPtr InvalidHandle;
        public const int WaitTimeout;
        public virtual IntPtr Handle { get; set; }
        public SafeWaitHandle SafeWaitHandle { get; set; }
        public virtual void Close();
        protected virtual void Dispose(bool explicitDisposing);
        public static bool SignalAndWait(WaitHandle toSignal, WaitHandle toWaitOn);
        public static bool SignalAndWait(WaitHandle toSignal, WaitHandle toWaitOn, int millisecondsTimeout, bool exitContext);
        public static bool SignalAndWait(WaitHandle toSignal, WaitHandle toWaitOn, TimeSpan timeout, bool exitContext);
        public static bool WaitAll(WaitHandle[] waitHandles);
        public static bool WaitAll(WaitHandle[] waitHandles, int millisecondsTimeout, bool exitContext);
        public static bool WaitAll(WaitHandle[] waitHandles, TimeSpan timeout, bool exitContext);
        public static int WaitAny(WaitHandle[] waitHandles);
        public static int WaitAny(WaitHandle[] waitHandles, int millisecondsTimeout, bool exitContext);
        public static int WaitAny(WaitHandle[] waitHandles, TimeSpan timeout, bool exitContext);
        public virtual bool WaitOne();
        public virtual bool WaitOne(int millisecondsTimeout, bool exitContext);
        public virtual bool WaitOne(TimeSpan timeout, bool exitContext);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ApartmentState
    {
        MTA,
        STA,
        Unknown,
    }

    [ComVisibleAttribute(..)]
    public enum EventResetMode
    {
        AutoReset,
        ManualReset,
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ThreadPriority
    {
        AboveNormal,
        BelowNormal,
        Highest,
        Lowest,
        Normal,
    }

    [SerializableAttribute(..)]
    [FlagsAttribute(..)]
    [ComVisibleAttribute(..)]
    public enum ThreadState
    {
        Aborted,
        AbortRequested,
        Background,
        Running,
        Stopped,
        StopRequested,
        Suspended,
        SuspendRequested,
        Unstarted,
        WaitSleepJoin,
    }

    [ComVisibleAttribute(..)]
    public delegate void ContextCallback(object state);

    [ComVisibleAttribute(..)]
    [CLSCompliantAttribute(..)]
    public delegate void IOCompletionCallback(uint errorCode, uint numBytes, NativeOverlapped* pOVERLAP);

    [ComVisibleAttribute(..)]
    public delegate void ParameterizedThreadStart(object obj);

    public delegate void SendOrPostCallback(object state);

    [ComVisibleAttribute(..)]
    public delegate void ThreadStart();

    [ComVisibleAttribute(..)]
    public delegate void TimerCallback(object state);

    [ComVisibleAttribute(..)]
    public delegate void WaitCallback(object state);

    [ComVisibleAttribute(..)]
    public delegate void WaitOrTimerCallback(object state, bool timedOut);

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class AbandonedMutexException: SystemException, _Exception, ISerializable
    {
        public AbandonedMutexException();
        public AbandonedMutexException(int location, WaitHandle handle);
        protected AbandonedMutexException(SerializationInfo info, StreamingContext context);
        public AbandonedMutexException(string message);
        public AbandonedMutexException(string message, Exception inner);
        public AbandonedMutexException(string message, Exception inner, int location, WaitHandle handle);
        public AbandonedMutexException(string message, int location, WaitHandle handle);
        public Mutex Mutex { get; }
        public int MutexIndex { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class SynchronizationLockException: SystemException, _Exception, ISerializable
    {
        public SynchronizationLockException();
        protected SynchronizationLockException(SerializationInfo info, StreamingContext context);
        public SynchronizationLockException(string message);
        public SynchronizationLockException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public sealed class ThreadAbortException: SystemException, _Exception, ISerializable
    {
        public object ExceptionState { get; }
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ThreadInterruptedException: SystemException, _Exception, ISerializable
    {
        public ThreadInterruptedException();
        protected ThreadInterruptedException(SerializationInfo info, StreamingContext context);
        public ThreadInterruptedException(string message);
        public ThreadInterruptedException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    public sealed class ThreadStartException: SystemException, _Exception, ISerializable
    {
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class ThreadStateException: SystemException, _Exception, ISerializable
    {
        public ThreadStateException();
        protected ThreadStateException(SerializationInfo info, StreamingContext context);
        public ThreadStateException(string message);
        public ThreadStateException(string message, Exception innerException);
    }

    [SerializableAttribute(..)]
    [ComVisibleAttribute(..)]
    public class WaitHandleCannotBeOpenedException: SystemException, _Exception, ISerializable
    {
        public WaitHandleCannotBeOpenedException();
        protected WaitHandleCannotBeOpenedException(SerializationInfo info, StreamingContext context);
        public WaitHandleCannotBeOpenedException(string message);
        public WaitHandleCannotBeOpenedException(string message, Exception innerException);
    }

} 
